{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# PyTorch ST-GCN Dataset\n",
        "\n",
        "SEOYEON CHOI  \n",
        "2022-12-21\n",
        "\n",
        "> PyTorch Geometric Temporal Dataset\n",
        "\n",
        "https://pytorch-geometric-temporal.readthedocs.io/en/latest/modules/dataset.html#module-torch_geometric_temporal.dataset.chickenpox\n",
        "\n",
        "[논문](https://arxiv.org/pdf/2104.07788.pdf)\n",
        "\n",
        "\\|Dataset\\|Signal\\|Graph\\|Frequency\\|𝑇\\|ㅣ𝑉ㅣ \\|\n",
        "\\|:–:\\|:–:\\|\\|:–:\\|\\|:–:\\| \\|Chickenpox\n",
        "Hungary\\|Temporal\\|Static\\|Weekly\\|522\\|20\\| \\|Windmill\n",
        "Large\\|Temporal\\|Static\\|Hourly\\|17,472\\|319\\| \\|Windmill\n",
        "Medium\\|Temporal\\|Static\\|Hourly\\|17,472\\|26\\| \\|Windmill\n",
        "Small\\|Temporal\\|Static\\|Hourly\\|17,472\\|11\\| \\|Pedal Me\n",
        "Deliveries\\|Temporal\\|Static\\|Weekly\\|36\\|15\\| \\|Wikipedia\n",
        "Math\\|Temporal\\|Static\\|Daily\\|731\\|1,068\\| \\|Twitter Tennis\n",
        "RG\\|Static\\|Dynamic\\|Hourly\\|120\\|1000\\| \\|Twitter Tennis\n",
        "UO\\|Static\\|Dynamic\\|Hourly\\|112\\|1000\\| \\|Covid19\n",
        "England\\|Temporal\\|Dynamic\\|Daily\\|61\\|129\\| \\|Montevideo\n",
        "Buses\\|Temporal\\|Static\\|Hourly\\|744\\|675\\| \\|MTM-1 Hand\n",
        "Motions\\|Temporal\\|Static\\|1/24 Seconds\\|14,469\\|21\\|"
      ],
      "id": "9d370952-19fd-4bbf-8442-4165677e485c"
    },
    {
      "cell_type": "code",
      "execution_count": 1,
      "metadata": {},
      "outputs": [],
      "source": [
        "import networkx as nx\n",
        "import matplotlib.pyplot as plt\n",
        "import numpy as np\n",
        "from tqdm import tqdm\n",
        "from torch_geometric_temporal.signal import temporal_signal_split"
      ],
      "id": "19babf03-eb6e-41cf-bf6b-44f956cfb446"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### RecurrentGCN"
      ],
      "id": "31860127-eb27-4cf2-9d0d-34bc270047f0"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [],
      "source": [
        "import torch\n",
        "import torch.nn.functional as F\n",
        "from torch_geometric_temporal.nn.recurrent import GConvGRU\n",
        "\n",
        "class RecurrentGCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(RecurrentGCN, self).__init__()\n",
        "        self.recurrent = GConvGRU(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "a107ea3e-d9f1-42f7-a03c-7f93e2ae46ed"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## ChickenpoxDatasetLoader\n",
        "\n",
        "Chickenpox Hungary\n",
        "\n",
        "-   A spatiotemporal dataset about the officially reported cases of\n",
        "    chickenpox in Hungary. The nodes are counties and edges describe\n",
        "    direct neighbourhood relationships. The dataset covers the weeks\n",
        "    between 2005 and 2015 without missingness.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 519\n",
        "-   N = 20 \\# number of nodes\n",
        "-   E = 102 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,)\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   X: (20,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (20,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `20`\n",
        "\n",
        "-   vertices are counties\n",
        "\n",
        "`-`Edges : `102`\n",
        "\n",
        "-   edges are neighbourhoods\n",
        "\n",
        "`-` Time : `519`\n",
        "\n",
        "-   between 2004 and 2014\n",
        "-   per weeks"
      ],
      "id": "fc030ec1-f3ee-4bee-8d50-38b3e3134a59"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  ChickenpoxDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = ChickenpoxDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=1)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "e88abd86-3127-4a4d-af71-64fad9dc6fa4"
    },
    {
      "cell_type": "code",
      "execution_count": 4,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "ee5d8b83-6ff5-432c-92bb-3bb971cddc7f"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "2f091f24-4b16-4d89-8c11-380a4ea1e79f"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.type,(data[0][1]).edge_index.type,(data[0][1]).edge_attr.type,(data[0][1]).y.type"
      ],
      "id": "5176434c-f470-41ae-9ae5-9ab2ef3d3342"
    },
    {
      "cell_type": "code",
      "execution_count": 1697,
      "metadata": {},
      "outputs": [],
      "source": [
        "max((data[4][1]).x[0])"
      ],
      "id": "0e968c6a-04c5-408c-a03f-238c5c0d274f"
    },
    {
      "cell_type": "code",
      "execution_count": 1668,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "2b8d1032-bc32-462c-b672-60b5998090eb"
    },
    {
      "cell_type": "code",
      "execution_count": 1669,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(20)).tolist()"
      ],
      "id": "91a73e9b-0e4f-466e-af35-78dd576dd6b5"
    },
    {
      "cell_type": "code",
      "execution_count": 1670,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "b936bae5-5669-4b85-aec8-7933452a9f32"
    },
    {
      "cell_type": "code",
      "execution_count": 1671,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "79cdc30c-38c0-4153-9c7e-482c504c1ef0"
    },
    {
      "cell_type": "code",
      "execution_count": 1672,
      "metadata": {},
      "outputs": [],
      "source": [
        "len(data[0][1].edge_index[0])"
      ],
      "id": "6e963d8e-c680-4806-bdd7-bf5998ce58b3"
    },
    {
      "cell_type": "code",
      "execution_count": 1673,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(519):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "5443c9bb-b63f-4ed1-825a-6ff29b359b96"
    },
    {
      "cell_type": "code",
      "execution_count": 1674,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "84870fcc-d873-40cf-ae3f-16910e2a5a22"
    },
    {
      "cell_type": "code",
      "execution_count": 1675,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "f5e44108-4c8a-47ac-9665-cab6a279cc46"
    },
    {
      "cell_type": "code",
      "execution_count": 1677,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "bc8fc947-c8f5-4f7c-a168-b16f40f3496a"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "606999a6-1ec6-45a3-a18a-ac257facd8e6"
    },
    {
      "cell_type": "code",
      "execution_count": 1559,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "a7c87a34-b784-4886-a871-f486d5aad34b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "a8e48226-1fa3-4ade-acfd-ce755c2053bb"
    },
    {
      "cell_type": "code",
      "execution_count": 216,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  ChickenpoxDatasetLoader\n",
        "loader = ChickenpoxDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "9e69a6c5-a990-46eb-896a-2464ba469f8d"
    },
    {
      "cell_type": "code",
      "execution_count": 21,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "ba7b3495-c1cb-4e93-8e8c-29038cee9960"
    },
    {
      "cell_type": "code",
      "execution_count": 37,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "73c814a9-99b0-4ed1-9dd3-a593c99b6a50"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "b9382212-b392-4861-94a7-2c66192eeabf"
    },
    {
      "cell_type": "code",
      "execution_count": 34,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0]"
      ],
      "id": "9a71d231-9e99-4e05-ad1c-ef4efcde9d14"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "56bfecfc-fdae-4903-988f-6a8dc5b1f0e9"
    },
    {
      "cell_type": "code",
      "execution_count": 35,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0]"
      ],
      "id": "e9b58e09-e39f-4f2e-b4cc-8dd3c8b652e2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 20개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{20}\\}, t=1,2,\\dots,519$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "60fd6b3d-3cc5-41ed-a426-56227615d5e4"
    },
    {
      "cell_type": "code",
      "execution_count": 217,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:52<00:00,  1.05s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "000e919f-f3d3-408c-8932-cef2c829b226"
    },
    {
      "cell_type": "code",
      "execution_count": 218,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "b871b973-66c8-4221-87cd-2ca818c8aa5c"
    },
    {
      "cell_type": "code",
      "execution_count": 219,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "f4be5954-e3dd-474c-9911-f54f12668857"
    },
    {
      "cell_type": "code",
      "execution_count": 220,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "5310a24c-1ab9-4ccb-9635-b14573228fc3"
    },
    {
      "cell_type": "code",
      "execution_count": 221,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "8bf580cd-9997-487c-a0bf-eaba23ac10ff"
    },
    {
      "cell_type": "code",
      "execution_count": 222,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "ed07fcfb-d1a0-48c9-a8d7-254a948a198d"
    },
    {
      "cell_type": "code",
      "execution_count": 223,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "828f4037-bdc0-47ef-a558-945a83bfed2b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   Vertex features are lagged weekly counts of the chickenpox cases (we\n",
        "    included 4 lags). y\n",
        "\n",
        "-   The target is the weekly number of cases for the upcoming week"
      ],
      "id": "6c04b38a-b57f-4f27-8702-31061a4a3f35"
    },
    {
      "cell_type": "code",
      "execution_count": 224,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x"
      ],
      "id": "fe247eda-2129-416f-9679-b13bcf5d4aa5"
    },
    {
      "cell_type": "code",
      "execution_count": 225,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y"
      ],
      "id": "be9a1935-276b-4744-bc6f-53d83c83112b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## PedalMeDatasetLoader\n",
        "\n",
        "Pedal Me Deliveries\n",
        "\n",
        "-   A dataset about the number of weekly bicycle package deliveries by\n",
        "    Pedal Me in London during 2020 and 2021. Nodes in the graph\n",
        "    represent geographical units and edges are proximity based mutual\n",
        "    adjacency relationships.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 33\n",
        "-   V = 지역의 집합\n",
        "-   N = 15 \\# number of nodes\n",
        "-   E = 225 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# number of deliveries\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (15,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (15,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `15`\n",
        "\n",
        "-   vertices are localities\n",
        "\n",
        "`-`Edges : `225`\n",
        "\n",
        "-   edges are spatial_connections\n",
        "\n",
        "`-` Time : `33`\n",
        "\n",
        "-   between 2020 and 2021\n",
        "-   per weeks"
      ],
      "id": "c9f316c8-0b76-4adb-916d-84d8a564d4fc"
    },
    {
      "cell_type": "code",
      "execution_count": 33,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  PedalMeDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = PedalMeDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=1)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "f389acf5-bbcd-4961-a40d-198f4baaaab8"
    },
    {
      "cell_type": "code",
      "execution_count": 1561,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "36f66aca-1835-4a1a-92e8-79226afc539b"
    },
    {
      "cell_type": "code",
      "execution_count": 1541,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "af966f67-cea9-4056-a8fa-525d6348410e"
    },
    {
      "cell_type": "code",
      "execution_count": 1542,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "cdda9b11-304d-4c74-849a-14e41a148225"
    },
    {
      "cell_type": "code",
      "execution_count": 1232,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "1d8e3bf5-d5b8-443e-9feb-5acb775c7401"
    },
    {
      "cell_type": "code",
      "execution_count": 1233,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(15)).tolist()"
      ],
      "id": "a479c9a9-05c8-4f6e-bef3-185cf0b39cb7"
    },
    {
      "cell_type": "code",
      "execution_count": 1234,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "4fa78aad-250e-4e32-a975-fc08acdad79e"
    },
    {
      "cell_type": "code",
      "execution_count": 1235,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "df396989-4947-47b1-8c71-041ec509ba6c"
    },
    {
      "cell_type": "code",
      "execution_count": 1236,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(33):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "abbd6071-4a1d-48ed-ad03-7cb8e1dc2099"
    },
    {
      "cell_type": "code",
      "execution_count": 1237,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "eaef0ff8-5b87-47d3-b64a-de272478c872"
    },
    {
      "cell_type": "code",
      "execution_count": 1238,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "c14e17c6-9943-43c6-b26b-4fc53e6e93e6"
    },
    {
      "cell_type": "code",
      "execution_count": 1239,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAAEAAElEQVR4nOyddVzUy/f/D929u7SkhAIiIaIiIGFggmKggoGJLbZiBwa2ohjY\nhWJ3YyugGMi9ggWKonTv7uv3Bz/3695dYEG814/u8/HYhzIz75l5v3ffc2bOnHNGAgBIjBgxYsSI\n+UOQ/K87IEaMGDFixPybiAWfGDFixIj5oxALPjFixIgR80chFnxixIgRI+aPQiz4xIgRI0bMH4VY\n8IkRI0aMmD8KseATI0aMGDF/FGLBJ0aMGDFi/ijEgk+MGDFixPxRiAWfGDFixIj5oxALPjFixIgR\n80chFnxixIgRI+aPQiz4xIgRI0bMH4VY8IkRI0aMmD8KseATI0aMGDF/FGLBJ0aMGDFi/ijEgk+M\nGDFixPxRiAWfGDFixIj5o5D+rzsgRkxdeffuHT158oRSUlLo/fv3FBMTQz179iRDQ0Nq0qQJ2dra\nUpMmTUhWVva/7qoYMWJ+QSQA4L/uhBgxtZGXl0d79+6lbdu20fv378ne3p5sbW3JyMiInjx5QjY2\nNlRUVERPnz6llJQU+vTpE/Xt25eGDBlCzZo1+6+7L0aMmF8I8YpPzC8NANq7dy9NnjyZPDw8aNmy\nZdSuXTuSkpKq8brXr1/Tzp07qVOnTtShQwdasWIFaWho/Eu9FiNGzK+MeMUn5pelvLyc+vfvT2lp\nabRt2zZycnKqcx2FhYU0Y8YMOnr0KJ0+fZrs7e0bvqNixIj5n0Is+MT8kpSXl1PPnj1JRkaGDhw4\n8MP7dXFxcTR69Gg6c+YMOTg4NFAvxYgR87+IWNUp5pdk1qxZRER08OBBkpGR+eH6AgICiIioe/fu\nlJKSQmpqaj9cpxgxYv43Ea/4xPxy3Lt3j7p3705PnjwhJpPZoHUPHz6cANCWLVsatF4xYsT87yAW\nfGJ+OTp37kzdu3enoUOHNnjdBQUFZGJiQsnJyWRoaNjg9YsRI+bXRyz4xPxSvHnzhhwdHent27ek\nqKj4U9oYM2YMaWho0Pz5839K/WLEiPm1EUduEfNLce7cOercufNPE3pERH369KEzZ878tPrFiBHz\nayMWfGJ+KZKSksjR0fGntmFvb0/Pnz+nysrKn9rOnwYAKisro4KCAqqoqCCxMknMr4pY8In5pXj9\n+jWZmZn91DaUlJRIU1OTPnz48FPb+d0pKiqi2NhYGjx4MDk7O5OysjIpKCiQmpoaKSkpEZPJJE9P\nTxo3bhxduHCBOBzOf91lMWKISCz4xPyCSEr+/J/lv9HG70p2djaNGDGCDA0N6ciRI9SiRQtau3Yt\nffjwgQAQAKqoqKCnT5/SjBkzSF9fn6ZPn04mJia0bNkyqqio+K9vQcwfjvjtF/NLoaCgQIWFhT+1\nDQBUWFhICgoKP7Wd35Hdu3eTnZ0dqaqq0rNnz+jkyZM0YsQIcnV1JVVVVV45CQkJ0tHRIR8fH5oy\nZQo9evSITp48SQkJCeTg4EAPHjz4D+9CzJ+O2IFdzC+Fra0tPXnyhHr16lVrWQD07PMzepP3hooq\nikhZVpmM1I3IhmVT43Xv3r0jeXn5BvcR/N2ZN28e7d+/n86ePVuv6DfNmjWjEydO0MGDB8nPz4/2\n7t1LPj4+P6GnYsTUjFjwifmlaNGiBUVGRtZYpqSyhA48PUDLbi2jzIJMkpaUJi64JCkhSWwum/RV\n9Wlq66nUx6YPKcoIWodev36dWrRo8bNu4bckMjKSDh06RNevXydtbe161yMhIUF9+vQhAwMD8vf3\np6NHj1KbNm0asKdixNSO2I9PzC9FRUUFGRkZ0dWrV8nKykog//CzwzTo+CCSIAkqqiyqth5lWWUC\nQDu67aBeTflXj23btqVx48bxwpiJqZmkpCRq3749JSUlkb6+foPVe/LkSRo/fjw9efKElJSUGqxe\nMWJqQ7zHJ+aXQlZWlkJDQ2nhwoUCeWvuraHg+GAqriyuUegRERVVFFFxZTEFxwfTmntreOk3btyg\njIwM6tq1a4P3/XcEAA0fPpwiIyMbVOgREXXp0oVatWol9LsWI+ZnIl7xifnlKC4uJjs7O1qzZg11\n7tyZiKpWesHxwVTKLq1zfQrSChTbPZY6GXeiZs2aUVRUFHXp0qWhu/1bcu/ePerXrx/99ddfP8US\n9tWrV9SyZUvevqsYMf8G4hWfmF8OJSUl2rFjBw0ePJju3btHJZUlNOj4IBrmOIwej3hM7NlsQgQo\nwj2Cd00fmz50I+QGfZr8iYpnFFPKyBQaZD+IiIhK2aU06Pgg6tazG7m7u4uFXh3YsWMHhYaG/jT3\nDzMzM2revDmdOHHip9QvRowwxIJPzC9J27Ztafv27dSlSxeavm86SZAEOeo60tfSr/Su4J1A+fZm\n7clUw5TOvzpPCW8TyIZlQ9u7bafOFlUrxrLSMioyKqLo6Oh/+1b+p7lz5w55e3v/1Da8vLzo7t27\nP7UNMWK+Ryz4xPyydO7cmQ4dOkQbH2+kosoiGhg/kDxjPSn5Y7JA2fX315PJGhMacGwAtd/Tnq69\nvkZERD6mVebyHGkO5TbNJWlpsSGzqFRWVlJaWhrZ2NTsHvKj2NvbU3Jy8k9tQ4yY7xELPjG/NIwm\nDJJl1H76+qMPj6iS+3+xN2Wlqq55X/Cel5ZZmElPPz1t+E7+ppSXl5OUlNRP33vT0NCgoqKajZXE\niGlIxIJPzC/Nm7w3JCNZtxPYJ7ScQK0MW9FfX/6izQ8389KlJaXpbf7bhu7ib82/Yfsmtq8T828j\n1vuI+aUpqigiLrgil5/jPofmecyjV19fkdcuLyqs+L/wZ4VFhTRz/kw6rnic9PX1BT4aGhokISHx\nM27jfxJFRUWSlpamnJwcYjAYNZatbxQdoqrA5A3tKiFGTE2IBZ+YXxplWWWSlKhdMSFBErS+03oa\n5TyKEj8kUqe9nSi7OJuvjKysLHXy6kQGpQaUmZlJCQkJ9P79e8rMzKTMzEyqrKwkPT090tfXJwMD\nA6HCUVdXl2Rk6rYC/V9FUlKSmjdvTomJieTr6yu0zI9G0SEiSkxMrFcINDFi6ovYj0/MLwuXy6WY\nEzE0KmkUcSQ5NKT5EGrTqA21M2lHjdQaUfLHZEr+mEzxqfHkrO9MM91mEofLoZ2Pd1JhedVK7++v\nf9OGBxuIiEiSLUnye+TJo4kHeXt7k7e3N9nY2PBWeUVFRTwh+P3ne+H46dMn0tLS4gnC6gSkqqrq\nb7F6XLx4Mb1580aoNWxDRNHhcrlkaWlJu3fvppYtWzZ4/8WIEYZY8In55cjMzKQdO3bQtm3bSFVN\nlT4GfKRP3E+0o9sOCrEPESg/99pcMlY3Fpp37fU18oz1JCIiSy1Lut3vNl25coUuXbpEFy9epOLi\nYvL29iYfHx/y9vauVeXGZrMpOzu7RuGYmZlJRFSrcNTR0SEpKakffl4/kw8fPlCTJk0oIyOD1NXV\neelr7q2h6Zem1ymggIK0Ai3xXkLjXMbx0i5cuEDh4eGUnJz8W0wUxPxvIBZ8Yn4J2Gw2nTlzhrZu\n3UoJCQkUGBhIoaGh5OjoSDuSd9CYM2OohF1S7/qlOFK0sNVCmtZhGl96eno6Xb58mS5evEhXrlwh\nFovFWw16eHjwHbUjKgCooKCgVuH45csXYrFYNQpHfX19UlZWrvd9NwQjRowgALxVX0NE0enVtBeV\nl5eTg4MDRUREUGBgYEN3W4yYahELPjH/Kenp6bRt2zbauXMnGRkZ0dChQykwMJBvsD9/5Tx1vNKR\nIFP/n6okW5LUt6rTiCEjaMaMGUKDInO5XEpOTqaLFy/SpUuX6O7du2RnZ8dbDbq4uDTo/l5lZSV9\n+PChRuGYmZlJsrKytQpHFov106Kr5Ofnk62tLa1fv568O3oTazmLiiuLhZbtbtWdZrSZQTYsG6rg\nVFDKpxTqsr8L5ZXl8cooyShR9uRsmjllJr19+5bi4uLEqz0x/ypiwSfmX6e8vJzi4+MpJiaGkpKS\nqH///jR06FChjtJbtmyh2bNn07DVw2hl+sp6rzKsX1pTZXIlmZiYUFJSEq1cuZJ69uxZ44BbWlpK\nt27d4gnCv//+m9q2bctTjVpbW//0ARsA5ebm1ioc8/PzSUdHp0bhqK+vX+/Dd+/fv09dunShPsv6\n0Pas7UL39PrY9KH9AfupjF1G8anxVFRRRM56ztRpXyfKKszilVOWVaa2xW3p/cn3dPny5VotRsWI\naWjEgk/Mv8aLFy9o69attHv3brK1taXQ0FDq0aOHUAdpNptNEyZMoEuXLtGJEyeocePGtOTqEppx\neQZRXRZdlUSTmk2i5T2X0/r162n+/Pk0fPhwOnnyJGlpadG6deuoadOmIlWVk5PDtz9YXl7OE4Je\nXl6kp6dXh441LOXl5ZSVlVWjcMzKyiIlJaVahSODwRAq0O/du0etD7QmjjpHaB/ejH9DjdQakcdO\nD7r+5nqN/ZUrlKPM6ZmkpaXVIPcvRkxdEAs+MT+VkpISOnToEMXExNCrV68oJCSEhgwZQubm5tVe\n8/XrVwoMDCQZGRnav38/z6hiyJAh9FziOd3TuUdSUlLElmRXW4csZAkE0nugRxVJFXT79m0yNjam\nx48fU+/evcnZ2ZmaNWtGy5YtowEDBlBERASpqamJfF8AKD09nScEr1y5Qrq6ujy1qLu7O6moqIhc\n378BAMrJyal19VhSUkK6uroCApLL4NKs17OoHOUCdTfWbExpY9KopLKErr2+Rm2N2tLHoo8UdTeK\nNj7YKFBeUUaR7g29J5KfnxgxDY1Y8In5KSQmJlJMTAwdOHCAXF1dKTQ0lPz8/GrdI0tNTaUuXbpQ\n165dKTIykmf1ePnyZRo8eDDZ2tqSWzs3WnR8ETG6MehT2SeSlpSm/IJ8UlBQIEkpSWIpsOjzsc/0\n4vAL6u3fm5hMJqWlpdHt27dJXV2diouLaezYsXTz5k3asGEDHTx4kM6cOUNLly6l/v3712uvjMPh\nUGJiIl26dIkuXbpE9+/fJ3t7e96K0NnZ+X/G/6+kpETo6vFhwUO6p3+PODKCKz5XA1e6PeQ2ERGl\n5qTS7Xe3qa9NX1KQUaDuB7rT8ZfH+cqryanRvoB91Klxp3/lnsSI4QNixDQQeXl52LhxIxwcHNCo\nUSPMmzcPb9++Ffn6M2fOgMlkYvv27XzpRUVFMDExwfr166Gjo4OLFy/Czs4OAJCSnYLTaaeh3FIZ\n/eb2Q0p2CgCgb9++WLp0KV6/fg0mk4m+ffvC09MT5eXlvHr3798PJpOJVatW4e7du3B2doarqyse\nPXr0w8+iuLgY58+fR3h4OOzt7aGmpoauXbti7dq1eP78Obhc7g+38W9zIOUAVBargOaSwMd8rTmv\nnNMWJ9Bcwvr76wEA2xK3CZRXWayCAykH/qtbEfOHI17xifkhANDt27cpJiaGjh07Rt7e3hQaGkre\n3t4i+6gBoKioKFqxYgUdPnyYWrduzZc/adIkys7OpsrKSnJycqLs7GxSVlamuXPn8so0btyYWrVq\nRbGxsURE9PTpU/L29qaMjAw6deoUzZgxgywtLUlLS4t27tzJ28NKT0+nfv36kZaWFm3bto1Onz5N\nM2fOpB49etDChQsbbA/q8+fPdPnyZZ5qlMPh8O0P6ujoNEg7DQUAev/+PaWmplJqaiq9ePGCEj4l\n0FOLpwQ5wSFDRlKGPod/JjV5NXLe6kwPsx7Shk4baJTzKFp7by2NOzeOr7x4xSfmv0Qs+MTUi5yc\nHNq9ezfFxMQQm82moUOHUnBwMLFYrDrVU15eTiNGjKCkpCQ6fvw4GRkZ8eXfv3+funbtSkePHqXu\n3bvTq1evyN7enuLi4sje3p5XrlWrViQvL09XrlzhpXXv3p28vLxozJgxNHToUCotLaW//vqL/Pz8\nKCLi/w6xrayspNmzZ9Pu3btp165d5ODgQHPmzKFDhw7R/PnzaejQoQ3qaA6A/v77b54QvHr1Khka\nGvL8B9u2bfuv+e6Vl5fT33//zSfgUlNT6eXLl6SsrExWVlZkbW1NVlZWJN9InsY/G1+tZe1cj7kU\n4R5BLz6/oDvv71Bfm74kIyVDrbe3pvuZ9/nKivf4xPyXiAWfGJHhcrl05coViomJoXPnzlGXLl0o\nNDSU3Nzc6mXWn52dTf7+/qSjo0OxsbECg31FRQU5OjrS9OnT6cyZM9SkSRPe/l96ejpfm7169aJn\nz57R8+fPeWkPHjyggIAA+vvvv6myspIcHR1p7NixtGLFCoqIiKDg4GC+9i5evEghISEUHBxM8+bN\no+fPn1NYWBiVlJTQ+vXrydXVtc73KApsNpsSExN5bhMPHz4kBwcH3orQycnph88RzM3NFRBuqamp\n9PbtWzIyMuIJt+8/30dqAUB79uyhIclDqFK1UmgbUhJStKDdAgppFkKqcqr0/PNzirgWQWf/PitQ\n1lTNlF6Nf/VD9yRGTH0RCz4xtZKVlUU7d+6kbdu2kbKyMoWGhlJQUBBpaGjUu87k5GTq3r07BQcH\nU0REhFCDkgULFtC9e/do1apV1Lp1a3r16hWtXr2acnNzKSoqiq/slClTaNeuXfTx40e+dF9fX+rd\nuzcNGTKEkpOTycfHh/bu3UsDBgyg/fv3U7t27fjKf/r0iYKDgykvL4/27dtHxsbGtH//fgoPDycf\nHx9atmwZaWtr1/u+RaG4uJhu3rzJE4Rv374lD4//iy9qYWEhdKLB5XLp3bt3QgVccXEx3+rt2//N\nzMxIVrb68w5zc3Np5syZtHv3biotLSWLPhb0xuoNlXDqH0VHBjIkc0mGepr1pClTpojsTiJGTIPx\nn+wsivnlqaysxIkTJ9C1a1eoq6sjNDQU9+/fbxCjjLi4ODCZTBw6dKjaMs+ePQODwcDbt28REhKC\nuXPnAgCaN2+Oa9euCZSPjo6GoqKiQPq1a9dgbm6OyspKAMDq1avRokULXLx4ESwWC8+ePRO4hsPh\nYOXKlWAymTh48CAAoKCgAOHh4WAwGIiKikJFRUW97r0+fPz4EXv37sWgQYNgYGAAAwMDdO/eHWPH\njkV4eDj69u2L5s2bQ1FREXp6evDy8sLo0aOxbt06XLx4Ee/fv6/z93bjxg20atUKkpKSUFdXR3h4\nOIqKivCl4Auk50gLNXAR9aO0SAnvs99j4cKF0NbWRufOnXHz5s2f9PTEiBFELPjE8JGeno5Zs2ZB\nX18fLi4uiImJQWFhYYPUzeVyMW/ePBgaGtZoOclms+Hq6oqNGzciPT0dmpqa+Pr1K16/fg0Gg8ET\nYt+TkJAASUlJoW22bt0a+/bt4/3t5+eHadOmYffu3TA2NsaHDx+E9uPBgwcwNzfH0KFDUVRUBAB4\n8eIFvL290bRpU1y5cqU+j0FkcnJykJCQgK1bt2LSpEnw8/ODqakpZGRkoK2tDV1dXcjJycHQ0BBB\nQUGIi4tDcXFxvdsrLS3FsmXLoKOjA0lJSTRt2hRHjx7lCc3U1FQ0a9YMrkNcobBQoV5CT2auDA49\n/b8JT0lJCTZu3AhTU1O0bt0aJ06cAIfD+eFnJ0ZMTYgFnxiUl5fj0KFD8PHxgZaWFsaOHYsnT540\naBvFxcXo1asXWrZsWa2g+caaNWvg5uYGDoeD0NBQzJw5E0DVam3QoEFCr8nOzgYRIT8/XyDvzJkz\naNq0KW9A/fTpE/T09HDp0iXMnz8fTk5OPMH2TwoKCtC/f39YWVnh8ePHAKqEZ1xcHIyMjNC7d2+8\ne/dO5OfwTzgcDtLT03HmzBmsXLkSoaGhcHNzA4PBgKqqKlxcXBAcHIwlS5YgPj4eqampfKvNyspK\n3LlzB/Pnz0fbtm2hrKwMDw8PLFy4EPfu3QObza61D2lpafD394eMjAxkZWXRs2dPZGRk8JXZtWsX\nGAwGNm/eDC6Xi1Gxo0Az6yb05BfIg9WFxVu9f09lZSUOHDgAe3t7NGnSBDt37uRzPREjpiERC74/\nmBcvXmDSpElgMpnw8PDA3r17UVpa2uDtvH37Fs2bN8eAAQNqrT8jIwNaWlpITU3FmzdvoKGhgc+f\nPwMAPDw8cOLECaHXcTgcEBFPOH0Pl8uFg4MDjh07xku7ePEi9PX1kZ2djZCQEHTt2rVGIfFt4F+/\nfj1vBVRcXIw5c+ZAS0sLixcvRllZWbXXl5SUIDk5GQcOHEBERAR69+6NZs2aQUFBAQYGBvDx8cGY\nMWOwYcMGXLlyBVlZWfVSKxcWFuL06dOYMGECbGxsoKGhAX9/f2zcuBFpaWm8OtlsNvbt2wcrKytI\nSkqCxWJhyZIlKCkp4auvqKgIISEhsLKy4k2G/v77b7BYLAxcOhA0gyATIVOjwJOYIQGFBQo49PQQ\nPnz4gCZNmmD27NlC74/L5eL8+fNo164dDA0NsWrVqgbTOIgR8w2x4PvDKC4uRmxsLNq0aQNtbW1M\nnToVaWlpP629O3fuQE9PD5GRkbUO5FwuF76+vli8eDEAYPTo0ZgyZQoA4PPnz1BVVRUYmL9HVlYW\ne/fuFZp35MgRODk58fVhypQp8PPzQ1lZGby8vDB27Nga+5eWlgYHBwd069YNOTk5vPRXr16ha9eu\naNy4Mfbv348bN24gOjoaEyZMQMeOHWFiYgI5OTk0adIEAQEBmDlzJnbv3o2HDx+ioKCgxjZ/lKys\nLOzevRvBwcHQ09ODgYEBmjZtCjk5OUhKSsLFxQWXL18W+t08fvwYVlZWCAkJ4a2I8/Pz0aRJE6xd\nuxaGhobQN9ZHu4ntoDVXC0qLlKC2RA1Ss6SguEARigsVITlWEoFLAuHr58urNzs7G7a2tpg+fXqN\nv4n79++jZ8+eYDAYmDVrFj59+tTwD0jMH8kfKfiePXuGLVu2YMyYMfDy8oKuri6ICC1btkRgYCAW\nLFiAEydOVKv++l8kKSkJo0aNgqamJjp27IijR4/+dAON2NhYMJlMnDx5UuTy9vb2qKioQGZmJjQ0\nNJCdnQ0A2LFjBwICAmq8XlNTExEREULzOBwOrK2tcf78eV5aeXk5nJ2dsXbtWuTm5qJp06ZYvXp1\njW2UlZVh/Pjx0NXVxdKlS7F8+XIMGTIErVu3hrKyMiQlJaGhoYGePXti2bJlOHHiBNLS0oTuS/5b\ncLlcXLlyBW3atIGUlBRkZGTQqFEjqKiowN7eHuHh4Th//jxvf5DL5SI6OhoMBgO7du3i1cPhcNCl\nSxcMHz4cS5YsgZKSEuLj48FkMvHq1SteFJ0Wg1tg2rZpSMlOQbdu3RATEwMjIyMkJCTw6vr8+TOa\nNWuGyZMn1zohSktLw7Bhw6Curo7Ro0cjPT395zwoMX8Mf4zgKy8vR3R0NJydnaGvr4/g4GCsWLEC\nZ8+exd27d3Hp0iUkJCRg9+7dmDJlCry8vKChoYFhw4Y1+H7Xv0V+fj42b94MR0dHGBoaYu7cuXUK\nIVZf2Gw2wsPDYWpqiqdPn4p0zcePH8FisXhGL+PHj8f48eN5+V27dsXu3btrrMPMzAz9+/evNn/X\nrl1o27YtX9rff/8NBoOB5ORkvH79Gvr6+jyVaFFRERITE7F3717Mnj0bvXr1go2NDeTl5cFisSAr\nKwsXFxesX78e165dw8ePH1FaWorFixdDU1MTc+bM+SFjkx8lPz8fy5cvh7a2Nk/Ybdq0iaeSraio\nwK1btzB37ly0adMGysrKaNu2LWxtbWFubi5g8Tpjxgy4ubnh1atXUFJSQsuWLREfH482bdrwlQsO\nDuaFndu7dy/8/PwQExMDT09PvnJfvnyBg4MDxo8fL5Ja98OHD5g2bRo0NTXRt29fJCcn/8jjEfMH\n80cIvjt37qBp06bw9fXFmTNnRNrwB4DMzEwsWrQITCYTU6dOrVHN9qvA5XJx+/ZtDBo0CGpqavD3\n98fZs2dFvucfJT8/H35+fvDw8OBTB9ZGYGAgpk6dCqBKCGpoaCAzMxNAlQBSUVHB169fa6yjZcuW\n8PDwqDa/srISJiYmfKbzXC4X69evR6NGjbB69Wr07dsXMjIy0NHRgby8PGxtbdGrVy/Mnj0b+/bt\nQ2JiIk8TkJWVBS8vL7i5uQlMKN6+fYvAwEAYGRkhLi7uX43N+fjxYwQGBkJWVhYyMjLw8vLCnTt3\nar3u2rVr0NbWhp2dHaytraGpqYmePXti8+bNWL16NYyMjPDp0yd0794dysrKePToEQICArBlyxa+\nekaNGoV169YBqDIOUlVVRXZ2NszNzXH58mW+sl+/foWTkxPCwsJEfkZ5eXlYtmwZdHV10b59e1y5\ncuV/MvapmP+O317w7dy5E9ra2ti/f3+9X46PHz+iV69ecHBwwJcvXxq4hw1DTk4OoqKi0LRpUzRu\n3BjLli3Dx48f/9U+/P3332jSpAlGjhxZJzVqfHw8GjduzJtYhIeHY/To0bz8uLg4eHt711pPz549\nYWVlJTSvsrISaWlpGDVqFCwsLDBo0CC4urpCXV0dmpqaYDKZsLS0xPLlyzF79mwwmUz89ddftbbJ\n4XCwZMkSsFgsHD16VCD/ypUraNKkCXx8fPDixYta66svZWVl2L17N6ysrCArKwtlZWVMnDixVgta\noEr4R0VFgclk4siRI7z0zMxMxMbGolOnTpCUlIS+vj46duwIRUVF9OjRA1++fIGqqipyc3P56psy\nZQqWLFnC+9vf3x/bt2/Hnj170KpVK4H3MDc3Fy4uLhg5cmSdXBnKysqwdetWWFhYwNnZGXFxcf/a\nBE/M/za/teDbuXMn9PX1kZqa+sN1cblcTJ48Gfb29gIv+n8Fh8PB5cuX0adPH6ipqSEoKAjXrl37\nT2a/V65cgba2NjZu3Fin6/Ly8qCvr89zSv/8+TM0NDT4VlADBgzA+vXra61r8uTJYDKZePjwIXbv\n3o2ZM2ciICAATZo0gby8PExMTNC+fXsoKSlh5syZuHHjBs9goqCgAGZmZjh8+DAAYP369bCysqp1\nlfmNO3fuwNjYGCNHjhTQDFRUVCAqKgoMBgPh4eENatCSkZGBcePGQUlJCfLy8rCwsMCuXbtEdgXI\nyclB165d0aJFC6F7Zx8+fIChoSEOHz6MxMREaGpqQkpKCioqKjA0NISVlRUuXrzIZ607b948zJo1\ni/f3gQMH0KFDB7DZbDRp0gRnzpwRaCc/Px+tWrXC0KFD6+zHx2azERcXhxYtWsDCwgJbt26t0cL2\nV6WkpASPHj3CuXPnEBkZiXPnziExMfGnWFr/6fy2gu/FixfQ0tJq0Fk2l8vFsGHDMHDgwAarsz5k\nZWVh8eLFMDMzg62tLdauXSvyAP0z2LhxI7S1tevl0D1s2DAMHz6c9/eMGTMwbNgw3t8VFRXQ1NTk\n85XjcrnIysrC5cuXsWHDBowZMwY+Pj7Q0NAAEaFZs2bo3bs3IiIicODAASQnJ/Ptta1atQr+/v4C\nfbl//z6YTCZev34NAJg4cSI8PDxEHkRzc3MRGBgIW1tboRFhPnz4gODgYOjr62PPnj31nqCw2Wyc\nPn0abdu2hZycHOTk5NCtWzc8ePCgTvXcvHkTjRo1wqRJk4QKyrKyMri6uvIMhhYsWAAjIyOEh4ej\nvLwcTZs2Rd++fdGqVSsoKyvD29sbS5cuFdifLSoqgqqqKnJycnD48GE4OjoKvfeCggK4ubkhJCSk\nXiu3b0Y87du3h56eHpYtWybUr/NXIjExEWFhYbC0tOSp1n19fUFE8PX15e0pW1lZYcyYMUhKSvqv\nu/xb8FsKvm/ROkRZJdSVwsJCmJiY4Ny5cw1ed02w2WycOnUK3bp1g7q6OoYOHYp79+79p3sbFRUV\nGDlyJKytrfH333/X+fqrV6/CwMAAeXl5AKr2ezQ1NXkrj4qKCuzYsQPm5uZYsmQJgoOD0aJFC6iq\nqoLJZMLNzQ2hoaFYtWoVzpw5gwMHDoCIal0xFBUVVRuubNmyZWjdujUqKyvB4XDg7++P/v37i/yc\nuVwuYmJiwGAwEB0dLfS627dvw8HBAW5ubnUy0Pj8+TMWL14MFosFZWVlaGhoICIigmf5KiocDgeL\nFi2CtrY2Tp06Ve19DBo0CD169OA52aupqUFLSwtfv37FX3/9BRaLxVNp5+Xl4fjx4xgzZgx0dHQg\nJyeHXr16YcuWLUhPT0evXr2wdetWcDgc2Nvb8/lUfk9RURE8PDwwYMCAH1JbJiUloW/fvtDU1MS0\nadNEUvn+mzx8+BAtWrRAo0aNEBERgcePH1e7Si8vL0dycjLmzJkDQ0NDuLi4NMiZkX8yv6XgS0hI\ngIWFxU8LfbR//360a9fup9T9TzIyMjB79mwYGBjAxcUFW7du/em+X6KQk5MDT09P+Pn51WtWXVxc\nDHNzc5w4cQL5+fm4d+8eunfvDjs7O/To0QNWVlaQk5ODqqoqLC0tMWnSJMTExCAhIaFao5k3b95A\nUlJSpL3NhQsXCrUA5XA48Pb25q1yiouL4eLigjlz5tTp/p4/fw47Ozv06tVLqGqczWZj8+bNYLFY\nCAsLq3bF/s1YqWfPnpCTk4OSkhKaNWuGAwcO1Msd5ePHj/Dx8YGbm1uNEWdWr14NW1tbnvN4ly5d\nYGlpiVWrVgEA5syZw7eq+57du3eje/fu2LFjB4KCgqCtrQ1tbW3o6+vj8OHD2LdvH2xsbKp9P4uL\ni+Hl5YV+/fr9sBtIeno6Ro8ezbPQ/pk+q6LA4XAwffp0sFgsxMbG1kutu2PHDrBYLMycOVMc3q2e\n/JaCb8CAAbwX9GdQXl4OFoslkvFDfes/fPgwfH19oaWlhTFjxgiNSPJf8ezZM5iZmSE8PFzkWTmX\ny8X79+9x8eJFrFu3Ds2bNweLxYKenh4UFRVhZ2cHOTk5jBs3DocOHcKTJ09QUlICAwMDPH/+XKQ2\nysrKICEhIZLKLzc3F5qamnj16pVAXlZWFnR0dHD9+nUAVQ7Xpqam2LFjh0j9+EZpaSnCwsJgbGyM\nW7duCS2Tk5ODESNGQFtbGzExMbyBrLCwENHR0WjcuDFUVFSgoKCAoKAgJCYm1qkP33Px4kXo6elh\n9uzZNQqUCxcuQEdHhxe27Pjx4zAwMICxsTHKysrA4XBgbGxcbV+OHTuGrl278v7mcrm4d+8e5OXl\n4e3tDRUVFSgpKaFbt264fPmy0D2skpIS+Pr6IjAwsEH8TT99+oTZs2eDwWCgZ8+edVYLNwQcDgdD\nhgxBmzZt6rxK/ycfP35E69atERoaKhZ+9eC3FHwGBgb1Ur3VhQEDBmDr1q0NWmdqaiomT54MFosF\nDw8P7Nmz55dzoTh16hSYTCZiY2OF5peXl+P58+eIi4vDokWLMGDAADg5OUFFRQXa2tpwd3eHv78/\nlJWVceDAAbx+/ZqnegsKCuKr68GDB7CwsKiTOldGRqZWf79vzJw5k28/8XtOnz4NQ0NDnhXvixcv\nwGKxcOnSJZH78o34+Hhoa2tj4cKF1U4UHj16BFdXV9jY2MDf3x9KSko8a9PFixfzwrbVh8rKSsyc\nOZMXn7Qm0tLSwGKxeMZGxcXFMDIy4kWlAapObmjatGm138uFCxfg5eUlkN6nTx9s3rwZ5eXlWLFi\nBTQ1NeHi4gJlZWX4+voiMjISSUlJvIG8tLQUHTt2REBAQIPF7SwsLMSqVatgYGCAdu3a4fz58//a\ndsHUqVPRtm3bBgvBVlhYCDc3N0yfPr1B6vuT+O0E3+fPn6GmpvbTf8xRUVEYOXLkD9dTUlKCXbt2\nwc3NDdra2pgyZcp/ro4RBpfLRWRkJPT09HD79m3k5ubizp072LFjB6ZOnYquXbvCwsICcnJyaNy4\nMbp06YLw8HBs374dt2/f5qnyKioqYGdnxxcRpLCwEEwmU2BlN2PGDJ5vn6ioq6vzWRTWxDcL0vfv\n3wvNHz9+PPz9/Xm/pevXr4PJZCIlJaVOfQKAd+/ewd3dHZ6enjz/xG+Ul5fj4MGDcHV1hZycHCQk\nJMBkMrF9+/YfVvW9e/cObdq0ga+vb60q4Pz8fFhbW2PTpk28tJkzZ6Jly5ZwdnbmPYehQ4di2bJl\n1dZz+/ZtuLi4CKQfPXqUt0XA5XLRtm1b7Ny5E7m5uTh27BhGjx4NCwsLMJlM9OnTBzExMXj58iU6\nd+6Mbt26NWjQ6vLycuzcuRNNmjRB8+bNceDAgZ8aXefOnTvQ0dFp8LBr2dnZ0NbWxr179xq03t+d\n307wPXv2rFpfrobk0KFDtYbQqonk5GSMHj0ampqa6NChA+Li4v7VM95Egcvl4u3btzh58iScnZ3B\nYDDQsmVL6OjoQElJCY6OjggKCsLChQtx5MgRPH36tFYLyEWLFqFDhw58E5PIyEgEBgYKlG3SpIlI\njtffY2Jign79+olcfsKECdXuVZWVlcHe3h6bN2/mpe3duxdGRkbIysqqU7+Aqv2Z+fPnQ1tbGydP\nnsS7d+8we/ZsaGlpgcViQUlJCYMHD0ZCQgImTJgABoOBdevW1XtAPnnyJLS1tbFkyZJa1WFsNht+\nfn4YMWIEL+3ly5fQ1NSEoaEhbwVYUlJS42QBqHKgt7GxEUgvLS2Furo6TwBfv34dJiYmAgLtzZs3\n2LZtG/r27Qsmkwlzc3MYGxvD0dGxwY1UOBwOTpw4gdatW8PU1BQbN278KVoWFxeXauPI/ii7du2C\nq6vrT6n7d+W3FHzW1tY/vZ3Dhw/XWfAVFBQgOjoaTk5OMDQ0REREBN68efOTeig6ZWVlSElJweHD\nh7FgwQL069cPDg4OUFJSAovFgqqqKszMzLB8+XJcuHABb9++rdeK+puLyTd3AaBKlaatrS0QFu7l\ny5fQ1dWt8/5Fy5Yt4ebmJnL5bzFBq5uJv3jxAgwGgy/02sKFC+Hg4FAvlRWHw8GqVasgLy8PaWlp\nsFgs6OvrY/ny5QLBEZ4+fQpPT0/Y2dnhxo0bIrdRXl6OiRMnolGjRnzxMWti2rRpcHd35wkhLpcL\nb29vdOnSBV26dOGVO3DgAHx8fGqs69WrVzA2NhaaFxQUhA0bNvD+9vX15ZtY/BMOh4Pk5GQsW7YM\n2trakJKSgpOTE2bOnImrV682qL/ezZs30blzZ55auqFchBITE2FoaPjTnOsrKyuhr6//S9kB/Or8\ndoIvMzMTTCZTpIGZy+UiJTsFp16ewoGUAzj18hRSskVTY23cuBFDhgwRqY07d+5g8ODBUFdXR48e\nPeoUNq0h+fr1K27duoVt27YhPDwcnTt3hrm5OeTk5GBpaYlu3bph2rRp2LlzJ+7evYtr167B0NAQ\n8+bN+2HVMYfDQZs2bXihrL4RFRWFHj16CJRftmwZ3+pDVPz9/WFhYVGna4YPH44ZM2ZUmx8TEwNb\nW1ueEQaXy8XgwYPRuXNnkb/HL1++YOXKlTAxMQGLxYKKigoYDAZMTU1rNN7hcrk4ePAgDAwMEBQU\nJKAm/SevXr2Cs7MzunbtKnKUoX379sHY2JhP+B88eBBWVlYCKuhOnTrVuof68eNHMJlMoXnHjx+H\nu7s77+979+7BwMBAJCftiooK9OzZE05OTggPD0eLFi2goqKCDh06YMWKFXj8+HGDGHqkpKRg4MCB\n0NDQwMSJE3/ovEWgKhLR7Nmzf7hfNTFjxgxMmzbtp7bxO/HbCT4ulwsmk1mjKqa4ohjbErfBYp0F\n7ygVlcUqUFuiBqVFSrBYZ4FtidtQXFF9gOHQ0NAa/QS/fPmC1atXw8bGBubm5li6dOm/4kvE4XCQ\nkZGBs2fPIioqCsOGDUPbtm15g62zszMGDBiAxYsX4+jRo3j+/LnQvZNDhw6BwWDwhbD6ETZs2IBW\nrVrxDUylpaXQ09MT6pPk6urKd5KCqEycOBFaWlp1uiY9PR1aWlrVRuThcrkIDAxEWFgYL62iogLe\n3t4YPXp0rUfrBAcHQ0lJCUZGRlBRUcGIESPw7NkzcLlcbNq0CQwGAzt27KixnsLCQkyfPh1aWlqI\njIys9jtjMplYs2aNyBOVBw8egMFg8K0WCgoKoK+vj969e/MFF/jw4QPU1NRqPbWkqKgICgoKQvPK\nysr44rACVa4Sa9asEam/lZWV6NevH9q1a4fi4mJ8/foVcXFxGDlyJMzNzcFisdC3b19s3779hwOy\nv3nzBuPHj4eGhgYGDRoksnXxP2nXrh3Onj37Q32pjVOnTtW6Ehfzf/x2gg8AevTogZiYGKF5h54e\ngtIiJSgvUq7x8EzlxcpQWqSEQ08PCdTBZrNhZGQkEEXhW+SIvn37Qk1NDf369cPVq1d/iqFNaWkp\nHj9+jIMHD2LevHno06cP7O3toaioCH19fXh5eSEsLAzr16/HpUuXkJmZKVI/OBwO5syZg0aNGjVY\nlIg3b95AS0tLYOBYv349OnfuLFA+KysLGhoa9TJm2Lx5M2RlZet83YABA7Bw4cJq83Nzc2FkZITj\nx4/z0vLy8mBjYyPgOlNcXIxt27bBwcEBDAYD+vr6MDY2xqpVq4QK15SUFDRp0gR9+/at1ScyLS0N\nHTt2hKWlJS5cuACgat9txIgRMDMzq5OZflZWFgwMDBAXF8eXPmnSJPj7+0NTU5NvsrZq1SoEBwfX\nWi+Hw4GEhES1q+GBAwdi7dq1vL+TkpKgo6Mj8jFgbDYbAwYMgIeHh4C6OSMjAzExMejduzcYDAYs\nLS0xevRoHDt2jBcooa58+fIF8+fPB4vFQrdu3XD79u06Xa+jo/PDq8baePPmDfT09H5qG78Tv6Xg\nO336NJydnQXSV99dDYWFCjUKvH9+FBYqYPVd/jPazpw5A0dHR97fHz58wJIlS2Bubg4bGxusWbOm\nwYJZf/78GTdv3sTWrVsxadIkdOrUCaamppCTk4O1tTV69OiBGTNmYNeuXbh///4PhWgqKiqCv78/\nWrVq1WABrrlcLjp27IgFCxbwpZeVlcHQ0FCoNdrmzZvrZKDyPZcvX4aEhESd936eP38OFotV4+B7\n69YtaGtr82kT3rx5A319fcTFxeHly5eYMGEC1NXVYW5uDnV1dfj6+uLUqVO1quCKi4sxfPhwmJqa\n1mqhx+VyceLECZiYmMDHxwdWVlbo06dPnb77srIytGzZEnPnzuVLT0lJAZPJhL+/v0Cevb29wOkK\n1aGkpFRtoIXTp08LHGXUq1evGi1F/wmbzcagQYPg5uZWbTscDgeJiYmIjIyEr68vlJWV0bJlS8ye\nPRvXr1+v88SquLgY69evh7GxMdzc3HD69GmRJpNaWlo/5I4iCtnZ2dWql8UI8lsKPjabDSsrKz41\n3aGnh+os9L4Xft9WfhUVFXB0dERsbCxOnz6N7t27Q11dHUOGDMHdu3frtbpjs9l49eoVTp8+jZUr\nV2Lo0KFo06YNGAwGVFVV4eLigpCQECxduhTx8fFITU1tcAvQ169fo1mzZhg0aFCDGgzs2bMHtra2\nAoNMdHQ02rdvL/Sa9u3b49AhwZW2KKSmpkJaWprnfF0XAgICag18sGDBAnh6evJWM5WVlVi+fDmk\npaWhrKwMKysrqKmpISwsrF7B0Q8fPgwmk4lly5bVKiy3bNkCRUVFKCsrY+7cuSJbI3K5XISEhCAg\nIICvDS6XCzc3N0yZMgW6urp8q6knT57A0NBQ5D00FotVrWq/vLxcIP7qs2fPwGQy6yS8ORwOQkND\n0apVK5GuKy0txeXLlzFt2jSeb2mnTp2watUqpKSkiPzuVlZWYu/evbCzs4OtrS12795d4/vIZDJ/\n+jbH+/fvoa2t/VPb+J34LQUfUDU719HRQXZ2NooriqG0SAnjzo7D44+PweZUDVoRVyP4BFzPQz3x\nNPspyirLkJGbgfAL4bw8pUVKKK4oxsSJE2Fqagp9fX04Oztjy5YtIocQKy4uRlJSEvbv34+IiAgE\nBgbCzs4OCgoKMDQ0hI+PD8aOHYuNGzfiypUr+PDhw7/iXJuQkABdXV2sXLmyQdv79OkTtLW1cf/+\nfb70iooKGBsbC7U4zMvLg4qKSr3DsuXn50NSUlJka8bvSUxMhJ6eXo2Cn81mw93dHdOmTcO8efOg\np6cHMzMzMJlMSElJYc6cOT8cGPn169do1aoVfH19hQ6YhYWFGDhwIKytrZGSkoLXr18jICAAJiYm\nOH78eK3fYVRUFJo1ayawuo2NjYWDgwPc3d0RHR3NlxceHl4nR2lTU9MaIxsNGjQIUVFRfGn9+/fH\n/PnzRW4DqBJ+I0eOhIuLS51PTfny5QsOHz7MW2lra2sjKCgIO3furNFG4BtcLhdnz56Fh4cHjIyM\nsGbNGqEag1atWuHq1asi1VdfY7tLly7VyZr5T+e3FXxA1fEoNjY2iLoWBeVFytiVvAtXM64iIzcD\nAL/gaxnTEhwuBwVlBdiZtBPv8qtmo8NODgPNJcjPl4deJz1ISkoiODi42uDCXC4X2dnZuH79OqKj\nozF+/Hh06NABxsbGkJeXR9OmTdGzZ0/MmjULe/bswcOHDxsskkN92L59O5hMptCjYn6Uvn37YtKk\nSQLpO3bsEDiN+xv79++Hn59fvdvkcrmQkpLCzp0763V9x44dqzWv/7aH26lTJ0hISKBx48bQ0NCA\nn58fzp07h3Xr1sHS0rJB1NyVlZWYNWsWdHV1+QKiP378GJaWlhg8eLDAIHvhwgVYWVmhY8eO1QZB\nOH/+PHR0dPhcSoCqPUwdHR2sXLkS1tbWfL6DbDYbenp6dTLusLW1rTEA97lz5wR8z/766y9oaWnV\n+flxuVyMGTMGTk5OP+SC8OrVK0RHR6NXr17Q0tKCtbU1xowZg+PHj9c6mbl79y569OgBJpOJiIgI\nPtVmWFhYjWrchjC2W7x4McaOHVv3m/5D+a0FH5fLxew5syEzUYZvZXfsxTEA/ILvW9rE8xNBcwnt\nYqsiTGTkZvDKSI6T5Plzsdls/PXXXzh58iSWL1+OwYMHo1WrVtDU1IS6ujpcXV0xePBgREZG4sSJ\nE/jrr79+amSIusJmszFx4kSYm5vX21qtJk6ePAkzMzO+44CAqgHd3Ny82hlwYGDgD4eCU1VVrdE9\noSYSEhJgYmLC913l5uZizZo1sLS0hJGREZo1awYlJSWoqqoKxKucPHky2rZt22Dq4itXrkBfXx+T\nJk3CunXrwGAwsGfPnmrLl5eXY/ny5dDS0sL06dP5hOO3cGTfYpB+z+jRoxEaGoomTZrg5MmTfHnn\nz58XumdeE66urjWuuisqKqClpSXgxzp06NB6fXdcLhcTJkxA8+bNqw1iXhc4HA4ePnyIpUuXwtvb\nG8rKymjVqhUiIiJw8+bNalWbqampGDJkCDQ0NDB27Fi8fv0aly9fho2NjdCVeEMY23G5XFhbW/OC\nDIipnd9a8AFASnYK5ObJ1Sr4XudWzYDb7mgLmktQXaLKq0NtiRpoLkE6Qho+QT68M7KMjIzQvn17\njB8/Hps3b8a1a9eQnZ39nx4VJAp5eXno0KEDvLy86jy7rqysxNWrV7Fy5UqEhISgdevWICIQEdzc\n3DBkyBAsXboULBYLFy9eFLh+z549aNOmjdBnVFZWBjU1tR8O4GtkZITevXvX+3p3d3fs2rULiYmJ\nCA0NhZqaGpycnGBiYgJra2ts3LgRhYWFGDlyJPr06cN3LxwOBwEBAejXr1+D/Q5evXoFXV1dKCoq\nCn2mwsjMzERQUBAMDQ1x4MAB5ObmwsrKSuhq9tGjR9DW1kZUVBTc3d0F+h0UFMRnhSkK3t7etbqj\nDB06FCtWrOBLe/36NTQ1NesV2ovL5SI8PBzNmjVrcGOSkpISXLx4EVOmTIGDgwNUVVXRuXNnrF69\nmuea8j2ZmZkIDw+HpqYmgoKCYGRkJBAntaGM7c6fPw8rK6tfftz5lfjtBd+pl6d4gqsmwVdaWeVA\n6xDtAJpLkJonxavDcp0laC5BLkIO4VvCkZSUJLCS+V8hLS0NVlZWCAsLq5OBTFZWFmbMmAF9fX04\nOjoiLCwM0dHRuHbtGq5fv45bt27hypUr2LhxI5o2bQoNDQ2YmJhg/vz5vBk4m82GtbU1zwz/nwiz\n9qsPzs7OaN26db2uLS0txZQpU6CgoABdXV20bt0aGhoa6Nq1Ky5evMg3uJSUlKBp06YCpzaUlJSg\nZcuWIscMrYn79+/D1NQUo0aNwooVK2pd8f2TGzduwM7ODpqamkInAxwOBy1atMDGjRuhp6cn4A5R\nUFAANTW1Ogui7t27C7hJ/JOLFy+iRYsWAumjR48WqiIXBS6Xi+nTp8PW1vaHJ1A18fnzZxw8eBCh\noaEwNjaGrq4uBgwYgF27dvH5KObm5mLJkiVQV1eHoqIiLyh2QxnbFRUVwczMDCdOnPhp9/o7Ik2/\nOUUVRcQFt9Zy2UXZZKRuRMqyykREvH+JiD4WfSQiovLKctq2ZxsdXnyYpKWlhX6kpKSqzavPpyHr\nu3//Pk2dOpXGjx9PAwcOpM+fP1dbVlJSkoiIuFwubdu2jWbMmEF9+/alc+fOkY2NTbXPUVpamvLy\n8ujVq1f06tUr2rRpE9nY2FBUVBRJSEiQqqoqeXt7C702Pj6eevToIfJ3Wx0GBgb05MmTOl2Tnp5O\nmzdvph07dpCRkRFJSkpSUVERubq60u7du8nExETgGgUFBTpw4AB5enpSq1atyMLCgpd+4sQJcnV1\nJRMTExo8eHCd7wEARUVF0dKlS2nz5s3k7+9PRETt2rWjPn360MWLF2n9+vWkrKxcYz1ubm7Uvn17\nio+Pp8uXL9OECRNo7ty5pKamRkREMTExJCUlRZ8+fSJ3d3dycnLiuz4uLo7c3d2JyWTWqf9KSkpU\nXFxcYxkPDw/KyMigjIwMvuc7Y8YMsrGxoYkTJ5Kenl6d2pWQkKBFixaRtLQ0eXp60uXLl0lHR6dO\ndYgCg8GgwMBACgwMJACUnp5Oly5douPHj9O4ceNIT0+PvL29ydvbm0aPHk3jx4+ntm3bUs+ePcnS\nxpKednxKZdwygXqtGda0zHsZuRq6kpyUHF3OuEzjzo2jt/lveWVK2aU06Pgg6mDWgUYMG0EtW7ak\nLl26NPg9/s789oJPWVaZJCUkay2X/DGZjNSNqIV+C7rx5gY56zsTEdGbvDeUX55PREQqSiq0askq\naqvblthsdq0fDocjUjlhn7Kysgarq7Kykj59+kSfPn0ibW1t2rZtG23ZsqXG8hISEiQlJUWo0gqQ\nkpISHThwgI4cOVKtUJaUlKTnz5+TiYkJ+fv789LNzMxo2LBhVF5eTi4uLjRw4EChgnbPnj00YMAA\nmjVr1g8JeAkJCcrOzqabN2/WWu769eu0a9cuSkxMpGbNmpGKigqVlZXRgAED6Pbt2xQZGUkSEhLV\n/m5sbGxo/vz51KdPH7pz5w7JyckRERGTyaQzZ85Q27ZtydDQkHx8fET+zebk5FBISAjl5OTQ/fv3\nydjYmJfXvHlzevToEY0dO5YcHR3pwIED1Lx582rr2rt3Lx05coTu379PAGjGjBlkZWVFS5cupY4d\nO9Ls2bNp3759FBgYSA8fPhS4fteuXTR69GiR+/4NZWVlKioqqrGMtLQ0+fv70+HDh2nKlCm8dD09\nPRo8eDAtXryY1q9fX+e2JSQkaP78+SQtLU0eHh505cqVOgvQurZnZmZGZmZmNHz4cOJwOJSYmEiX\nLl2iqKgo6tu3L9nb25OPjw9xOBzKM8yjiooKgdFXTU6NLg64SPqq+nTy5Umq4FRQQJMAMtc0J7tN\ndgTC/7VJEuQzwYdUPqnQ8ePHf9q9/a5IAEDtxf53efrpKbWMaUnFlcU0pPkQatOoDbUzaUeN1BpR\n8sdkSv6YTPGp8fS55DPdHHSTSipLKO55HHmbepO+qj6NPD2SNj/cXFVZBZHSfiXytvOm0NBQatOm\nDW/m/KtSUVFBYWFhdOfOHTp+/DiZmpqKdB2bzab+/ftTTk4O7d27l2RkZGoV8GvWrKG3b9/SvHnz\nBMpcvnyZNm/eTO7u7hQUFCQgyP/66y86fPgwjR079oeEPJvNptevX9PLly+pdevWQusqLy+nvLw8\nKigoIAkJCZKQkCA2m01SUlIkKSlJXC6X2Gw2EVUNzrKysjWuvKWkpCgrK4vk5OTI2NiYL6+wsJCe\nPHlCrq6upKmpWesq/uPHj3T69GmysbEhb29vkpOTq7bsw4cPac+ePdSjRw/q0qULycjI8OX//fff\nNG3aNFq/fj1ZWVnx0p8/f04LFy6krKws3m9YSUmJFi9ezNe3zMxMcnR05N1bXZg0aRLp6urS5MmT\nayx39epVCg8PFxC6nz9/JisrK0pMTCQjI6M6tf09ixcvpp07d9LVq1dJX1+/3vX8CCUlJZSQkEAX\nL16k8xfOU4p7CpGWYLlOjTvR6X6nKSM3g0zXVr2nScOTyF7HngIOBdDRF0f5yiuXKdOnOZ9IQUHh\n37iN34rfXvABIKsNVpT2JY12dNtBIfYhAmXmXptL867Po8CmgRThHkHmmub0segjbXywkZbdWsYr\nJ18kT1gHKi8v56UpKSmRm5sbBQYGkpubG5mZmdW4Qvg3ycnJoYCAAFJTU6O9e/eSioqKyNdu2LCB\ndu/eTdeuXSN5eflayyclJVH79u3pyZMnAqolAOTo6EiTJ0+mBQsW0Lx58ygwMJCvzOTJk0lJSYnm\nzZsnch+r49y5c9S5c2f68uULb2ICgBISEmjTpk10+vRpcnV1paKiInr58iUNGTKERo4cyTfAAqB9\n+/bRhg0b6MKFCzwBWp1QzsnJocDAQJo+fTo5Ozvz5V26dIl27NhBS5YsIVVVVaGr+IqKCjp//jwl\nJCSQv78/mZmZiSTk8/Ly6ObNmyQnJ0f29vYkJSVFbDabiouL6f79+2RqakpqamoC1xUVFVFWVhbv\nXjU0NHgC//u+SUhICAhUUT5ZWVkkJSVFpqamtaryDx48SD169CAtLS2+vBs3blBpaSkFBAT8kNr/\n4MGDdOLECYqOjiYDA4NqNRbV9a8h3+enn56Sy1YXKmGXCOS1M2lHlwdepoLyArLfbE8VnApKHJ5I\nLCUWzb8+nyKuRfCVV5JRortD75INq/qtBzHC+e0FHxHR9qTtNO7sOCqqrFn1UhMSlRI0SGcQRY+I\nJjabTVu2bKGYmBhKTU2lysrKqjISEiQrK0vOzs7UuXNnatOmDTk6OookOBqalJQU6tatG/Xp04cW\nLlzI27MThXfv3lHz5s0pISGBrKysai3PZrOpRYsWNHbsWAoJCRHIP336NE2fPp2Sk5Pp/v371L17\nd3r+/DlpamoSUdXA27hxYzp8+HCNajtRSU5OJhcXF0pKSiJDQ0Pas2cPbdy4kUpLS8nOzo5SUlJI\nWVmZxowZQ3379q12xszhcMjKyopiYmLI3d291navXbtG/fr1o8TERAHhv2TJEjp8+DDduHFDYF/u\n48eP1L9/f2Kz2bR37946r0wqKipo9uzZtHfvXtq1axe1atWKPDw8yM/Pj2bPni1Qns1mk7OzM4WH\nh9Pu3bupsLCQ0tLSaP78+RQaGspTcVtZWdG2bdsEBLkon9jYWPr69SuFhobWqqrftWsXqampkZeX\nF196YWEhrVmzhoKDg0lFReWH1P7v37+njx8/kqmpKUlKSgrVWFSnzRBVQIoihL9ofqFHJo+ILcUW\n+F6kJKToWsg1atOojUDelkdbaPip4XxpanJqtC9gH3Vq3KlOvxcxf4jgK6ksIdZyFhVX1rzZXhPy\nkvLkeMWRPmd9poiICOrduzdJSUkRUdXKavXq1XTw4EHKyMggDodDRFVqMiIiKysr8vHxoTZt2lCr\nVq1+ymb795w4cYKGDh1KUVFRFBQUVOfrp0+fTmVlZRQVFSVS+WXLltHly5fp/PnzArNjANSyZUua\nPHky9erVi4iI+vfvTw4ODjRx4kQiInr69Cl17tyZMjIyGmR2nZ2dTQYGBtSxY0dKSEggJycnUlRU\npBs3bpC3tzeNHTuWWrduLVJb27Zto4MHD9KFCxdEanv27Nl0//59Onv2LN9kAwANGzaMPnz4QPHx\n8bzfxsWLFyk4OJiGDRtGs2fP5v2m6sOFCxcoODiYmEwmWVhY0OHDh4Xe49q1ayk+Pp4iIiIoJCSE\nXrx4QWlpaRQWFkZFRUW0fv16kpaWpqCgIEpLS6vXd7JhwwZ69uwZbdy4sdayN27coHHjxlFSUpJA\n3oIFCygtLY12795d5z78k7Vr19KqVavoypUrIqv8AYgkaCsqKig3N5e+fPnC++Tm5tLXr18pNzeX\n8vLyKC8vj96pvqMPzh8IssKHXWlJaQpsGkhNmE3obf5batuoLQXZBdGim4to1pVZfGVVZFVoa5et\n1Num9w8/mz+NP0LwEREdfnaYguODqZRdWveLK4gCZQPpwJwDdPnyZZo9ezYVFBTQvHnzyN/fX2A1\nlZaWRlFRUXTy5EnKzMzkpcvLyxMAYjAY5O7uTq1bt6bWrVuTjY3NDw143wBAS5cupQ0bNtDRo0ep\nRYsWda6DzWaTgYEBXb9+nSwtLWstn5aWRq1ataIHDx4ItXy8cOECjR8/np4+fcp7Trdu3aIhQ4ZQ\namoqEVUNbl++fKHVq1fXub/fU15eTkePHqWNGzdSQkICOTs7k6KiIr148YJCQ0NpxIgRZGBgUKc6\nKyoqyNzcnOLi4sjZ2bnW8mw2m9q2bUsBAQE0adIkvrzKykrq3LkzmZmZ0Zo1a2ju3LkUGxtLu3fv\nJk9Pzzr1qzrmzZtHK1euJGtrazp48CCfYQwR0YcPH8jOzo6uX79OgwYNonHjxlG/fv2IqOr3s3//\nfpoyZQopKytT165dKTIysl79iI2NpcuXL9OuXbtqLcvhcMjQ0JCuXbvGs4z9RkFBAZmbm9O1a9eo\nSZMm9erL92zcuJE3UTM3NxdaBgAVFBRQTk4OffnyhXJycqr9fMv/+vUrKSkpEYPBEPioq6tTWVkZ\nff36lRKLEumB4QPiygq3NJeRlKFKbpUGiaHIoOejnhNTiUmesZ507fU1vrLiFV/9+WMEHxHRmntr\naPql6XUSfnKSctRZrjMdm36MunfvzptFnz17lubMmUNsNpvmz59PXbp0ETozBkC3bt2itWvX0tWr\nVyknJ4eIqtSiysrKJCsrS2VlZdSyZUtq3bo1tWrVilq2bFlno5nS0lIaOnQopaWlUXx8fL038p88\neUKBgYE8oVQTXC6XPD09qUePHjR+/HiBfADk5uZGo0aN4g2u39KZTCalpKSQrq4uOTo60qpVq0RS\nJwrjzZs3FB0dTdu3bycLCwsyNTWlXbt2EYvFomXLllHv3r1/SN28bt06unz5MsXHx4tU/vXr19Si\nRQs6e/YsOTo68uUVFBRQixYtqLy8nCwtLXn9bAjOnz9PISEhdPv2bYqLi6PIyEjasGEDb6VNVLXa\nNjAwoObNm1NkZCQ9ePBAYOL25csXMjQ0JHl5eZo9ezaFhYWRjIxMnfpy5MgR2r9/P8XFxYlUfuzY\nscRisWjWrFkCeZGRkfTw4UM6dOhQnfpAVPVbKyoq4hNghw4domPHjlGfPn0IgIBw+/LlC8nLywsI\nMC0tLaGCjcFgkKamJsnIyFBJSQk9efKEEhMTeZ/U1FQyNDQkdXV1ypHMofR26USywvt7Nfgq5ZTk\nUH55PnU070h6Knp0Ku0Uddkv6K6gKKNI94beE+/x1YM/SvARVa38Bh0fRBIkUeOen7KsMrHZbJI/\nJ0/PDj+j1NRU6tixIzVu3Jju3btHSkpKBICOHz9Oc+bMIXl5eZo/fz61b9++RtUQm82m+Ph42rJl\nC929e5cKCwuJiEhSUpI0NTVJRUWFPn78SObm5tSqVSvepyajmaysLOrevTuZmZnR9u3bf8jKKzY2\nls6fP0/79u2rtWx0dDTt2LGDbt26JXTFevXqVRo+fDi9ePFCIN/Hx4fGjx9PNjY25OTkRB8+fOCp\n/0SBy+XShQsXaOPGjXTr1i3q1KkTsdlsOnfuHHXs2JEuX75Mbm5udOTIEZHrrI7S0lIyNTWlCxcu\nkK2trUjXHDx4kGbPnk2PHj3iMyo6ceIEDRkyhCorK2nLli0CRj71JS0tjdq0aUNxcXHk5uZGREQP\nHjygvn37Urt27Wj16tV0//59Cg4OpqSkJHJ2dqaYmBihK83jx4/TqlWrKDo6msaOHUuZmZm0bt06\nateuncj9OXfuHEVFRdH58+dFKn/r1i0aOXKkUP/L4uJiMjc3p7Nnz5KFhUWNKy9hHxkZGQHhlZ2d\nTQ8ePOD9Br/P09LSEsmKtbCwkJKTk3kC7tGjR5Senk7W1tZkZ2dHSkpK9PnzZ0pMTKSioiJycnKi\n4pJium5znbiawld8azqsod5Ne5OmgiZ9KPpA+1L20dxrc6mcUy5Q1lLLklLDap+gihHkjxN8RFV7\nfoviF9GKeytIRlOGpCWlqai4iOTk5KikrITMGGY0030m9bbpTauWraILFy7QlStX6P379+Tk5EQA\n6P79+2RmZkZEVYPwkSNHKCIigrS0tGjBggUiq64KCwspNjaW9uzZQ48fP6aysjKeD52uri4xGAzK\nysoiAHyC8JvRzMOHD6lHjx40YsQImjFjxg/vkS1fvpyys7NpxYoVNZZ7//49NW/enK5du0ZNmzYV\nWqZdu3Y0cOBAoQYvISEh5O7uToWFhZSUlEQ7duwQqX85OTm0Y8cO2rx5M6mqqlLr1q3p2bOqicmw\nYcNo+PDhpKenR46OjiQjI0N3794Vqd7aWLZsGT1+/FikCcE3hgwZQhwOh3bu3EkVFRU0depUOnbs\nGO3fv58UFBTI19eXjh8/Tq6urj/Ut/z8fHJxcaFJkyZRaGgoX15BQQGNGjWKHj16RJWVlRQZGUlv\n376lS5cu0alTp4TWFxAQQJ06daIhQ4YQAIqPj6cJEyaQi4sLrVixggwNDWvt082bN2n69OmUkJBQ\nbZmysjKecPr06RP16dOHRo8eTdLS0gLCKyMjgwoLC0lWVrbaVZewlZmWlla1E8HY2FiaMWMGXbhw\nodrf8Ddyc3MpKSmJT8i9f/+ebG1tycHBgRwcHIjJZFJ6ejpdvHiREhISqFmzZuTp6UkcDofOnDlD\n+fn5NHToUCq1KqXFSYuJK117YI3qUJZVprUd1tKg5oPqXccfzc8JCPPrM2HCBERERCAlOwWn006j\n5dCWmBozFV59vfhCQnE4HHTo0AFTpkwBUBUiyMbGBrKysgKxCNlsNnbv3g1zc3N4enrW62ict2/f\nYvbs2WjSpAmkpaVBRJCUlIScnBysrKzg4eEBGxsbKCoqwtzcHAoKCpgyZQqysrJ+7IH8fyIjIzF5\n8uQay3C5XHTp0kXgoNLvuXnzJkxMTKoNixYSEoLt27fDw8OD71Tz6tq7c+cOBgwYADU1NfTu3Rth\nYWEwNjaGi4sL9uzZI3DeX5cuXWBsbFxjvXUhPz8fDAajxqN2/klRUREsLS2xatUqODk5oXv37nyx\nUc+cOQMdHR38/fff9e4Xm81Gx44dERYWVm0ZLpeLwMBAyMjIIDIyEkwmkxds/Z98+fIFqqqqAqeV\nFxcXY86cOdDS0sKiRYsEgnCXlZUhMzMTT548wZUrV7Bs2TLo6+tj/vz5GDt2LPr16wdfX184OjrC\nyMgISkpKkJWVhZ6eHuzs7NCuXTs0btwYzs7OmDNnDtasWYO9e/fi/PnzePToEV6+fAl9ff1aD+mt\nK3v27IGOjg6ePHnCS/v06RPOnTuHxYsX8457UlZWRps2bTB27FjExsYiJSUFBQUFOHPmDMaMGQNz\nc3Po6upi0KBBOHjwIC5evIjBgwdDXV0dPXv2xIULF1BWVob58+dDVkkWNKPuocq+/3w7Jk1M/fgj\nBR+Xy0WjRo2QkvJ/Z12FhoYiOjoa69atw+DBg/nKf/78GY0aNeIN0N8CEUtKSmLlypUC9VdWVmLb\ntm28INY/8rImJSVh5MiRMDIygoSEBE8QSktLQ1ZWFp6envDw8ODFxgwKCsKGDRuQnJzMOyy1LkRH\nRyMkJKTGMgcOHEDTpk1RVlZW7flhvr6+2LJlS7V1+Pn5ITY2FqqqqtUeoFpUVIQtW7agefPmMDU1\nxcSJEzFgwACoq6tjwIABAuf8fc+YMWOgoqIiwh2Lzpw5czBkyJA6XbNkyRJISEhgzpw5QoMIb968\nGRYWFvU+USA8PByenp41xl19+/YttLS0cOHCBbBYLBgZGVUbnHzjxo3o1asXPn78iKdPn+LatWs4\ncuQINm/ejIULF2LQoEEwMDCAoqIiGjduDBMTE6ioqEBaWho6OjqwsbGBh4cH2rdvD1VVVcycORNR\nUVHYvXs3zp49iwcPHiAjIwMFBQUCz+POnTuwtrauNtjy5s2b4evrW6/nJAwul8sLJq2srAwPDw8Y\nGBhATU0Nnp6emDRpEvbt24fU1FTeu5SWloY1a9agQ4cOUFFRgZubGxYvXoykpCR8/foV69atg52d\nHczMzLB06VJ8/PgRQNWpH9+OJuvbty9iH8RCbr7cD8fqFFM//kjBd//+fVhaWvK9YJMmTUJkZCSe\nPXsmdKVw+/ZtsFgspKen89LmzZsHSUlJ9O/fX+jJ1OXl5di0aRMMDAzQpUsXJCUl/VC/ORwO4uLi\noKenx7calJaWhoqKCry9vRESEoLAwEBYWlry0ubMmYNz584JzOKFcf/+fTRr1qza/JycHGgbaGPm\nkZnVnh/WKLIRNL00kVuUW209enp6WL58Ofz9/QXynj9/jjFjxkBTUxOdO3fGrFmz4O7uDj09Pcyf\nP583mNTEmjVrICkpWS/hXx05OTnQ0NDA27dvay1bUlKCYcOGwdzcHJMmTUKLFi2qFU5TpkxBmzZt\nUFpaWqf+7Nq1C6ampjUKTTabjc6dO2PUqFE4dOgQb+XybeUcHBwMPz8/uLi4wMzMDFJSUpCUlASL\nxUKTJk3g5uaGHj16IDQ0FNOnT8fKlSsRGxuLefPmwdDQEO3atUNSUpLQ0wl0dHTqdD/CJqTfU15e\nDhMTE6HHKolS9+vXrxEXF4eZM2eiY8eO0NbWBoPBgK+vL3r06AE1NTWBg3yLi4tx+vRphIWFwczM\nDHp6ehg8eDAOHz6M3NxccLlc3Lp1C8HBwbxnevnyZd548OXLFwwcOBCKiopgMBi8AO3JyclQ9lKu\ns/BTWKiANXfX1Pn+xfDzR+7xTZ06laSlpWnRokW8tAULFlB5eTktWLCAdHV16c6dOwLm+atXr6a9\ne/dSQkICb/P72LFj1Lt3b7K1taWbN2+SoqKiQHtlZWUUHR1NS5cupdatW9O8efNq3VMQxuvXr6lr\n167UokUL2rhxI3E4HDp48CDt37+f7t69SwUFBbwYlMrKyuTp6UlGRkZUUVFBT58+pYcPH5KpqWmN\nRjNlZWWkp6dHT548EWr633ZkW7qrfZfkZOVqNA6SIzmSlpGmHd12UK+mvfjyUlJSqGPHjuTo6Eg9\ne/akAQMGUGVlJR0/fpw2btxIz58/p379+pGsrCzt37+fDAwMaOzYseTv7y+ydeE3q73Xr1+Trq6u\niE+4dsLDw6m8vJzWrl1bbZkXL15QYGAg2dra0ubNm0lFRYX8/PzI3t6eFi9eLFCey+VSnz59SEpK\nivbu3VttsAEul0u5ubmUk5NDN27coMmTJ9OkSZNIXl6+WoOPvLw8IiIyMzOjvLw80tDQIDc3N8rP\nz6dz586Rl5cXhYSEkLa2NhUWFtKAAQPo3bt3JCtbjdnhd5SXl1NUVBStWLGCRo0aRdOmTeP9/vPz\n88nQ0JAKCgpEeKr/x+TJk0lRUZHmz58vND82Npa2b99O165dq3Y/m8vlUnp6Oj169IjPulJOTo4c\nHBzI0dGRty9nYGDAq+fYsWM0fPhw2rhxI2VmZtLZs2fp1q1b5ODgQB07dqSOHTuSnZ0dSUhI0Nev\nX2nPnj20ZcsWqqyspNDQUJ4PJVGVNenu3btp/PjxVFlZSQEBAbR27VpSVVWlV69eUdu2bavcd5oQ\nBR8LptLS0motPYmIpDhSJCUlRXt67hF4n8TUg/9Y8P7rcLlcmJqaChwgumbNGt4+Sd++fbFt2zah\n1wYEBGDUqFF86U+ePIGKigpYLJbAwZrfU1xcjMjISLBYLPTt2xcvX74Uud/Xr1+Hjo4O1qxZU60q\n6NOnT1i6dClcXFwgLy8PIoKsrCxkZWXBYrEQHByMefPmYe7cuQgMDIS+vj5YLBa6d++OyMhIJCQk\noLS0FCNHjhS6fzd8+3BIzJL44fPDRo8ejenTp0NFRQUpKSmYM2cOdHV10bZtWyxZsgQhISFQV1dH\nSEgIHj16JPIz+p47d+5AUVERDx8+rNf11ZGVlQUNDQ2hq04ul4sdO3aAwWAgJiaG73vKzs6Gnp4e\nLl++DKBq9f7161ekpaXhzp07OHLkCMzNzdGuXTtMnToVQ4YMQbdu3dCmTRtYWVmBwWBASkqKp9KW\nlZWFs7MzBg0ahPDwcCxduhQxMTGIj49HQkICUlNT8f79e5iZmeH06dNITEyEjo4OCgoKeH3KzMxE\nu3bt0LZtW7x9+xazZs3ChAkT6vxM3r17h969e8PIyAhxcXHgcrmorKyEpKRknc+Iu3//PiwsLKq9\nrrKyEhYWFrxzCdlsNp49e4bdu3djwoQJcHd3h6qqKho1aoQePXpgwYIFOH36dI174MXFxTh16hRG\njx4NHR0dSEpKokuXLjhy5AifloTL5eLGjRvo378/1NTU0K9fP1y7dk2gr8+fP0ebNm3AYDCgra2N\nc+fO8fKysrJgamrKdy6iX3c/qLZVheEyQ0jNloLifEU+DYrlOkvMOTYHOoY61W4LiKkbf5zgS0pK\ngomJicCPdefOnRgwYAAAYOvWrQgKChJ6fV5eHszNzbF//36+9M+fP8PExATy8vK1noRcUFCAhQsX\ngsFgIDg4GK9evaqx/NatW8FisWo92POfvHz5EpMmTYK1tTVPNSovLw9ZWVno6+tj6NChWLduHTZu\n3IgxY8bA0dERioqKsLOzg4KCAmJiYngDRuyD2DoLPWF7Ei9fvoSWlhYmTJgAJpMJDQ0NDB8+HMuX\nL0ebNm1gYGCAxYsX1+sg0u/JyMiAvLx8rYYz9WHUqFGYOnUq728ul4v379+je/fuMDExwcaNGxEb\nG4uVK1di+vTpCA0Nhb+/P2xsbCAtLQ0GgwFpaWmoqanBzMwMLi4u8PPzQ2BgINTV1dGjRw9s2bIF\nR48exY0bN/D8+XN8+vQJlZWVKC0tRYsWLbBw4cJa+zlv3jz06NEDXC4XXl5e2LRpk0AZNpuNRYsW\ngclkgslk/pA6/sqVK2jatCm8vb3x/PlzyMnJ1Xmg5nK5MDExQXJyskBeRUUFkpOTMXz4cGhra6NV\nq1ZQUlKCubk5AgMDsXTpUly4cKHWQ2i5XC5SU1MRFRUFX19fKCsrw93dHUuXLsXjx49x6tQpMJlM\n3Lp1C0DVu71y5UpYWVnBysoKq1atEtpGSUkJZs6cCTU1NWhoaCAkJIRPcObm5sLOzo7vu3v8+DE0\nNTV5wl63mS62XtuKAykHcDrtNG/PHKg643DVqlV1ep5ihPPHCb6ZM2ciPDxcIP3YsWPo2rUrgP87\n8bq6WWdSUhIYDAZevHjBl15eXo527dpBSkoKGzZsqLUvubm5mDNnDjQ1NREaGiqwWqysrMS4ceNg\nYWGB1NRUUW9RKFwuFwkJCRg0aBAaNWoECQkJSEpKQllZGXJycjA2Nsbw4cOxc+dOxMXFwcPDAywW\nC+rq6jAyN4LETEGht+XRFjz79AyF5YXIKc7B6bTTaLKhSbVWaBnvM2BiYgImkwl1dXV069YNs2bN\ngr6+Ptq2bYvDhw+jsrLyh+7zG6WlpZCUlMTGjRvr/JwKCwuRkZGBBw8e4OzZs9i9ezeioqIwa9Ys\njBgxAp06dYK0tDSsra2ho6MDaWlpSEhIQFlZGQ4ODujQoQP69++P8ePHY+HChdi8eTOOHDmCa9eu\nYdCgQfDx8RGwivxGWloatLW1eZOcnJwc7N27F1OnTkWnTp2grq4OIoKOjg5atWqF0NBQrF27VkBg\nvXr1ClpaWnjz5g3OnDkDS0vLGg1gNmzYABkZGYwaNarOe43fU1FRgdWrV4PBYEBeXp5vT1xUpk6d\niilTpuDBgweIjo7G8OHD4ezsDEVFRVhbW6Nfv37Q0dHB4sWLkZubK1KdRUVFOHnyJEaNGgUTExPe\nxC8uLk7o3vfZs2ehrq4OLy8vqKmpYcCAAbh582a1Y8LZs2dhYmICMzMz6Orq4syZM3z5xcXFaNOm\nDcaNG8dXR2BgIBwcHLBq1Srk5eVBSUlJqL0AUCUktbW1UVRUJNI9i6meP0rwcblcWFpaCrWyvHLl\nCtzd3XnljIyMBATb92zduhVNmzYV+BFyuVyMHTsWUlJSGDp0aLU/4u/JycnBtGnToKmpibCwMGRl\nZeHr16/w8fGBr68vvn79WrcbFYHy8nIcOXIE3bp1A5PJBBHxViFycnK8F7hdu3YIWhEk1PwaAO68\nu4Mtj7Yg/WvVAPcu/x3kFghu2EvPkYakoyT09PSwYcMGyMrKQlVVFUOHDhU6u28I5OXlMWbMGLx5\n8waPHj3C+fPnsW/fPqxduxZz5szBqFGjEBgYiHbt2sHOzg76+vqQk5ODkpISGjVqBAcHB/j6+qJf\nv34YO3Ys5s+fj40bN+LgwYNo3749RowYgUWLFoHBYGDv3r0iP3cnJyesXbu22jIJCQlQV1eHr68v\n1NTU0L17d8yfPx/BwcGwtLTEjRs38OTJE1y7dg3r16/H8OHDYWRkBHt7e6xfvx5lZWXw8/PDkiVL\nwGazYWNjg/j4+Br7NXjwYMyfPx+9evWCra0tnj9/Xqdn/U8+fvwIJSUlaGtrY8+ePTWqPIuLi3H7\n9m2sX78egwcPhqWlJSQkJGBnZ4eQkBCsXbsWCQkJKCws5F1z7Ngx2NvbV/t+cblcvHjxAqtWrYKP\njw/PanPZsmV48uRJjdsFy5cvR+PGjXluFzVpDd6/f49evXpBT08POjo6CAkJERDGFRUV8PPzEzCC\ne/HiBRgMBlRVVZGTk4OEhAQ4OztX2xYA9OrVC0uXLq2xjJja+aME39OnT2FoaCj0R//o0SPY29vz\n/h40aFCNqzYul4uBAwdi4MCBQuvbunUrpKWl4erqKvIMLTs7GxMnToSqqio0NDQwbNiwBlsB1UZe\nXh42bNgAd3d3qKio8PYHpaSlQGHCVZiuMa68/xtFGfHqar65udDyshNl0aJFC7BYLBgYGNTZhL+0\ntBTv3r1DcnIyLl26hAMHDmD9+vWYO3cuwsLC0KdPH/j4+KB58+YwNDQEEUFCQgIGBgawt7eHt7c3\n+vTpg7CwMERERGDdunXYv38/Ll68iKSkJLx7905k1dz9+/chKyuLZs2aIS0trU738ddff4HBYAgV\n+Lm5uQgNDYWmpibU1dV5/nZnzpyBrq5utXvIHA4Hly5dQseOHdGoUSMYGRmhvLwc27Ztg5ubW42C\np6SkBBoaGsjMzASXy8XWrVvBYDCwdevWOu/RfU+TJk2we/duODg4oE2bNkhKSkJ+fj6uX7+OqKgo\n9O/fH02aNIGCggIcHR0RGhqKTZs24d69ezAxMalxf5fL5cLR0RFHjhzhpRUVFeHEiRMYOXIkjI2N\nYWBggNDQUBw9ehT5+fnV1vXt2QUGBkJNTQ0hISG4ffs2uFwurly5AgaDgUuXLvFdw2azsWbNGmhq\nasLZ2Rl6eno4deqU0LoHDBgAPz8/gRX3wIED0alTJ/Tr1w8AsGnTJgFXqn/y7NkzMJnMGu9HTO38\n9iewf8+RI0coICBAqDWYmpoa5efn8/729PSk48eP06hRo4TWJSEhQRs3biQXFxfatm0bDR06lC9/\n6NChZGVlRb6+vmRpaUl37typNeIFi8Wi9u3b065du8jOzo6OHDlCmpqaNHnyZNLSEnJyZQOipqZG\no0aN4t3v27dvafv27bTu4Dr6qvpV6DV33t/h/V9WqsokjcPl0IeiD0LLs5XY1G98P/r79t/EYrGo\noqKCUlJSRA5BVVlZWW2EjsaNG5OrqytffufOnUlWVlboyeI/wr1796hPnz7UqFEj6tOnDzVu3LhO\n15ubm9OqVauoT58+9OjRI54l5Pv376ldu3bk6elJ6enptHnzZurfvz9t27aNgoOD6ejRo9SoUSOh\ndUpKSpKXlxe5uLiQsbExcTgc2rVrF82dO5fi4uJqjOhz/PhxatGiBe+U8qFDh1Lr1q2pT58+dPHi\nRYqOjiZ1dfU63SMRkZycHOXl5VFgYCAdOXKEnJycSEJCguzt7alFixbk4eFBkyZNoiZNmghYkfbt\n25cOHTpEDg4OQuv+dsr62LFjKSMjg86fP093794lZ2dn6tixI508eZKaNm1a431nZ2fTzp07aevW\nraSkpETDhg0TuFdPT0+Ki4ujgIAA2rt3L/n6+tKDBw9oxIgRBICUlJTIysqKzp8/TxoaGnz1A6BJ\nkyZReno6Xbhwgc8iOT09nU6fPk0MBoOio6OJqMraubaQeE2aNCFfX19au3at0LimYkTkv5a8/ya2\ntrbVRlP5/PkzNDU1eX+/e/cOmpqataoqv6krqjMKyMjIgI6ODhQVFWuM5MLlchEVFQUdHR3cuHED\nAPDmzRve7H/OnDki72c0FI8fP4aqoypUFqnUGkXi1tsqQ4BlCcuqLzuNoNBMAUQEKSkpnsOzu7s7\nAgICMHz4cAGH5/v37yM9PV2ow3NtdOrUCQYGBg32PDgcDpYvXw4Wi4WjR48iOTkZurq69d4TCwoK\nwrBhwwBUWfuZmZkhMjKSl8/lchEcHAwlJSVER0eLVOf06dPRt29fPHv2DCoqKnBxcan1mo4dOwpV\n1ZaWlmL06NEwNjbG7du3a6wjOzsbZ8+excKFC+Hv7w9jY2NISUnB1tYW48aNw65du5CQkMAzTNm6\ndWuN71ZycjKMjY0FvvPCwkIcP34cI0aMgLGxMS+Iw7Fjx/gsVquDw+Hg/PnzCAgIgLq6OoYMGYJ7\n9+7V+ttKSEiAlpYWOnfuDG1tbbRv3x66uro1qkEXLVoEW1tboe/tsGHDEBwczGfB6ubmxrP6rYm0\ntDQwGIx/fTz4nfhjBF9qaip0dXWrfdkqKiogLS3N9wJYWFiIZOW2f/9+mJubV+sgnp+fD0dHR8jI\nyAiNZlJWVobBgwfD1tYWGRkZAvmvXr1CcHAwGAwGFi5cKNIL/qNUVlbCyckJw9YOg8ri6gWf1jIt\n3HtftWca/TC6RgEpN1cOrYe3hqKiokCkmaSkpAZ1NgeqrC8VFBQapK7Pnz+jU6dOaNmyJV6/fs1L\n79y5s0iGTMLIz8+HqakpDh06hE6dOmHGjBl8+Ww2G76+vmjUqBFGjBhR6+D8bRKWlZWF7OxsnnVh\nTSHRPnz4AHV1dRQXVx/+6tixY2CxWFi8eDHYbDbev3+PEydOICIiAl26dIG+vj7U1dXRrl07hIeH\nY//+/Xj58iX8/PyECoZHjx6hVatWcHZ2rjaqEZfLhYWFBe7du4fnz59jxYoV8PLygrKyMtq1a4fl\ny5fj6dOnuHz5MszNzWvdEsjKysKiRYtgbGyM5s2bY9OmTSKrC7lcLvbv3w8GgwFZWVno6OigX79+\nNarqo6OjYWpqKtSN4u3bt9DQ0EDv3r2xYsUKXhtqamoiWzMPGjQIs2fPFqmsGEH+GMG3aNEijB49\nusYyCgoKfPtxI0aMEBqSTBijRo2Cv79/jf5Hffr0gYyMDEaPHs0TwNnZ2WjTpg26devGt3kvjNTU\nVPTt2xcsFguRkZE1DlY/yooVK9CuXTucTD0JtSVqQgVZo6hGSP1cZW26+ObiWt0aZObIwG2wG8aP\nHw8Oh4Pnz58jJiYGgwcPhpWVVb0izdTE8uXLISkp+cO+T9euXYOBgQGmTp0qsE9z584dGBkZ1Wgx\nWRP37t2DiooKrK2tBeKNTpo0CV5eXvj69SuaNWvGtxr8J99cFqKiogBU/R7HjRvH+x6rY+XKldWG\nqONyucjIyMCRI0cQFhYGDQ0NyMjIQEtLCx06dMCMGTNw5MgRpKenC/3d9+nTp1qjHy6Xi127dkFX\nVxdDhgxBdnY2L6+wsBDx8fFwcHDg+eQNHz4c8fHxQid9np6eQv1u2Ww2zpw5g+7du0NdXR3Dhg2r\ns1/nX3/9BR8fH9jY2KBPnz5gMBhQU1PDsWPHqr3m8OHD0NPTq3bCMWbMGISFhfEJurdv30JbW1vk\nfqWnp0NTU7Peoe7+dP4Ywefg4ICrV6/WWEZHRweZmZm8vw8dOgQ/Pz+R6i8rK4OTkxNv4KmOxYsX\nQ0ZGBu7u7rxBc+bMmSJZf34jJSUFAQEB0NXVxerVq3/I/FwYf//9N7S0tPD3338jJTsFSouUhAqy\n9/nvAQCvc18j6k4U7+O8xVm48JtBIBaBiMBisdChQwesW7eO9/J+/vwZJ0+exPTp0+Hu7g4lJSXY\n2tpi+PDhiI2NxV9//VUndefevXuhqKhYq59kdbDZbMybNw86Ojo4e/ZsteXatWuHHTt21KsNLpcL\nXV1dNG3alG/VEhsbCzMzM96zeffuHQwNDXHokPAYjQcOHICdnR0qKyuRmpoKBoOBnJwcsNlsNGrU\nqFpDkWbNmuHKlSvgcDh4+fIl9u/fj/DwcHh5eUFDQwN6enro0qULIiIicOzYMUyYMAEsFkuoIcc/\nGTJkSI3xWoEqo6oJEybw3Fs8PT2hrKwMLy8vTJ48uUYtzTcSEhJgZGTEcxF5//495s+fj0aNGsHJ\nyQlbtmyps5akrKwM8+bNg5aWFsLCwmBhYYE+ffrg8+fPePjwIVgsFp9hzTcuXrwIFotVraXyhw8f\noKGhgUWLFqF379689NOnT8Pb27tOfRw2bBifP6kY0fkjBN+rV6/AZDJrVaVZWlryuTB8+vQJqqqq\nIltWpqeng8Vi1bofEh8fDxkZGUhKSmL9+vUi1S2MxMREdOnSBQYGBti0aZPAiqE+cLlceHp68lQw\nFRUV0F2sK1SQVUfwsWCh5aXGSYGIeB9paWlISVWlfXOcHz16NC5fvozCwkJUVFTg/v37WL16NS/S\nDJPJRLdu3fgizVTHlStXoKqqytszrQtZWVm8AODfT4aEcfnyZVhYWNRLVfvgwQOYmprCy8sLERER\nAIC7d++CwWAInKCQnJzM51j9jfz8fOjp6fH2kHv06IFly5bx8hcuXIjhw4fz/q6srMTTp0+xcOFC\nKCsro23btlBVVYWxsTH8/f2xcOFCnDlzBh8+fBDa5xs3bsDQ0BDjx4+v1h8RAMaNG1etw3VBQQHi\n4+MxbNgwNGrUCHp6etDX14eRkRFvksHlcmFtbY07d+5U28Y3vrmXdOnSBRoaGhg5cqRAdCZRuXTp\nEiwsLNClSxcMHz4cOjo6AkIuKSkJ2traOHjwIC/t/v37YDKZNf7ewsPDERYWBltbW779vKVLl9Y5\nas43lakosWvF8PNHCL7IyEieEUFNtGjRAnfv3uVLs7OzE0iriRMnTsDQ0LDa6BFcLhcLFiyAtrY2\nlJWVoaKiItKLXRP37t1D+/btYWxsjG3btv2QC8TWrVvh5OSEnJwcrFy5EkZGRjAPNIfcvPpFkv/2\nUV6kjF6LeyE0NBRXr15Fr169oKWlxScI5eXloaCgwHOuZzAY8Pb2xtKlS3H16lXk5eXh7du3OHDg\nAF+kmZYtW2LixIk4cuQI357K8+fPoaysjAMHDtTpGZw7dw66urqYN2+eSMKMy+WiZcuWfIOgqCxf\nvhxjxoxBVlYWdHR0EBcXB319fZw4cUJo+bNnz0JHR4fveKQJEyZg0KBBAKqOg2rUqBFPvVteXo4D\nBw5AV1cXo0ePhqurK5SUlNC4cWNYWlrC09MTFy9erLPK7MuXL+jevTuaN29ebei9GTNmYMGCBQCq\nntHTp0+xfPlytGvXDsrKyvD29sbKlSvx/PlzcLlccLlcHDp0CIaGhujXrx/ev3+PuXPn1igQ3rx5\ng4iICGhra0NGRgabNm2qt4P3x48fERQUBCMjI0RGRsLKygq9evWqdt/t8ePH0NHRwd69e/HixQvo\n6OhU+70BVf66mpqaiI+Ph7m5Od9KNigoqF5ag7CwMEycOLHO1/3p/BGCz8XFhRcVvSZ8fHwEwoKN\nHz8eixcvrlN7U6ZMQfv27QVUNMXFxejTpw9atGiBzMxMfPjwAY0bN4acnBx27txZpzaEcfPmTXh6\nesLc3By7d++u8wokMzMTWlpa6N+/P2/zfdOmTejWs9sPnx8mMVMC1nbWfHELgSofsn379vGcjOn/\n+95JSEhARUUFampqkJKSgqqqKmRkZKCnpwd/f39eeKrXr1/j6tWrWLRoEfz8/PiMZpYvXw5paWks\nX75cpPuvqKjAtGnTYGBgUGvYuX9y8uRJNGvWrM6Wp/369eMNeHFxcZCVlcWsWbNqvCY6OhqNGzfG\n58+f8eTJEzCZTHz69AklJSWwsbFBSEgIhg0bBicnJygoKMDa2hpSUlJYsmQJrl27hry8PFRWVkJH\nR6fGIA21weVysWHDBjAYDOzcuVPg3ufMmQN/f38MGzYMhoaGMDIywogRI3D8+PEa97OLioowY8YM\naGlpYeLEidDT0+N7lyorKxEfH49OnTrxgj48fvy43iG9OBwONm3aBCaTiUmTJmHixIkCq7nqSElJ\nAYvFgpaWFmJjY2ssO2vWLISGhmLQoEF8K3KgyuK8PnFls7KyoKmpWatWQgw/v73ge/PmDbS0tEQy\nPggICBDYQzlx4kSdde+VlZVwc3PjzXaBqn0HR0dHBAUF8RlbFBcXw8fHB3Jycjyjjx/l8uXLaNWq\nFaytrXHw4EGR6rx16xb09PQgLy+P8ePHY+nSpbCzs4OVlRXWr1+P2AexUFioUC+hp7BQAaPWj4KE\nhAT69evHZ8jwT3JycrBq1Sq0aNECcnJyPNcHCQkJaGpqgslkQlZWFoaGhjA2NoaSkhIMDQ150U1O\nnDiB69evIyYmBoMGDQIRQUZGplajmTdv3sDV1RUdO3asV5xQLpeLZs2a4eTJk3W6ztfXF+fOnQOX\ny0VQUBAaN26MgICAWgXoxIkTYWNjAxMTE7i6usLOzg6ysrKQl5dHSEgI1q1bh9u3b/NWP/r6+nzH\nKZ09exYtWrSo830K48mTJ7xQYnfu3EFkZCQ8PT0hJycHQ0NDrFq1Ci9evKjzpOCvv/5Cp06dICsr\ni1WrViEjIwOzZs2Cnp4eWrVqhZ07d/IZeD158gTa2tq1Gol9T1JSElxcXNCqVSvs27cPTZo0gb+/\nv8jqw28xetXU1LB9+/Zqy+Xm5kJLSwvJyclQU1PjewcqKiogLy9fbyOsiRMn1ngQsRhBfnvBFxUV\nxVMD1cbgwYOxdetWvrS8vDwoKyvXuJchjMzMTOjq6uLy5cu4e/cu9PX1sWTJEqEvP4fDwdixYyEv\nLw9vb+86vbjVweVycfbsWTg5OcHOzg7Hjh0TaLuyshKHDh1Cy5YtwWKxwGAwEBYWBgaDgc6dO+PC\nhQt81yy6vKjOgaolZ0si6nYUoqOj0atXL0yePBlMJhPR0dEiCeSXL19iypQpsLKy4u0HftsfZTAY\n0NHRgby8PGxsbNC2bVs4OztDQ0MDurq68PPzg6KiIpo1a4bt27dj2rRpPKMZGxsbntHMt9l+ZGTk\nD008Dh48iJYtW9ZpgP8m+CIjI+Hg4IAvX76gWbNmfH57eXl5uHbtGlatWoWgoCBYW1tDQUGBd4r5\nhg0bcPv2bZiYmPBOLfgnBgYGfIKvb9++P7S//I38/HwcPXoUgwYNgpKSEqSlpREQEICTJ09iw4YN\nIr971VFRUQE3NzfewcuDBg2q9vR4oMqSVBQNTUFBAc9QZ9OmTZg+fTpYLBb2798v8vdXUFAAZ2dn\nTJ8+HampqTAwMKjWmGfhwoUYOHAgNmzYgF69evHlpaSkwMLCQqQ2hZGdnQ0NDY0aT4YRw89vL/ja\ntGkjkgUaULVX8s2o43tatGhRZ9UXULVJrq6uDi0trRp1/9+Ijo6GvLw8zMzMRDrsVBS4XC6OHz+O\nZs2awdHREadPn0Zubi5v/65169aYMmUK5OTkoKamhokTJwo1w+ZwOPDz80OXqV2gtEgJyouVa1Vt\nKi1Sgl1fOwwbNgwdOnTgqY4eP34MV1dXuLq61ilOJ4fD4QXaNjQ05KlE5eTkeIenamtrQ1FREW5u\nbrzT2lVUVKCtrQ0tLS34+Phg8uTJWLJkCaZNmwZzc3PecT/dunXDsmXLajWaqQ42mw1LS0uRnJC/\n0bt3b0yaNAm6urp4+/YtcnJyEBMTAyUlJbRv3x7m5uZQUlKCq6srRo0ehfmb52PtubWIvhUNdWd1\nWLSxwLRp07B27Vp06NBBaBuVlZVQVFTkWTbm5+dDTU2t1lMMhMHlcvHkyRMsW7YMHh4eUFZWho+P\nD29Vd/DgQTCZTCxfvhz79u0TGORF5dWrV5g+fTp0dHTg5OQEVVVVzJ49G5qampg3b161q6PU1FQw\nmcxqXWG4XC7i4uJgYGCAkJAQXLp0CTY2NujWrVu1xjzCKCsrg7e3N0JDQ3mC8q+//oKhoaHAKRiF\nhYVgMpl4/vw57OzsBCYn+/btQ8+ePUVuWxhTp04VyY5BTBW/teDLzMyEurq6yKu1uXPnCnUKnTZt\nGubMmVOnttlsNqZOnQoNDQ04OjqKbHBy9epVKCsrQ01N7YeNXr6Hw+Fgw4YN0NTUhJSUFNzc3DBl\nyhQ0bdoU6urq8PT0rNEoIDIyEi1btkRFRQWKK4qxPXE7FKcqQm6eHN8J7LLzZKE8TRmWfSyxPno9\n8vPz0bRpU8jJyfGZlHM4HGzZsoW3r1KfVW5ZWRkOHz6Mrl278gxlpKWloaioCCkpKbBYLMjIyICI\n0L59e8yePRtRUVGYO3cuvL29ISMjA2lpabRu3RqhoaEICwtD//79azWaqYkdO3bU6Df3PR8/fkSP\nHj0gLS2Ntm3bwsjICCoqKmjbti28vb1haGiIxMREFJQWYFviNr4T72XmyEB2jiwUFypCZoIM5F3l\ncS9RuDP406dP0bhxY97f27dvR/fu3UXqI1AlKOPi4jB06FAYGBjAxMQEo0aNwsmTJ4X+ZjIyMuDq\n6goHBwd4eXmJ3E55eTkOHToEb29vMBgMTJw4kRcsu1mzZrh+/Tpev36NgIAAmJiYID4+XujqLDg4\nmGch+89+de7cGdbW1rh48SJmz54NFotVaxDtf8Jms9GzZ08EBAQI7KO/evUKRkZGWLduHS9txYoV\nCAwMxL1792BqaiqgVZg2bRrmzZsncvvC+GY4U5/TMP5EfmvBt379evTv31/k8lFRURg7dqxA+vnz\n59GmTRuR68nPz0fnzp3h7u6O7OxstG/fvk7+Ni9fvoSenh4UFBSwa9cuka+rjtu3b6Nnz57Q1NTE\nkCFD4OHhAUlJSWhpaWH48OFo1KhRjYLn1q1bAofsstlsqKmp4fqL6ziddpp3flhCWgJUVVVx5coV\n6Ovro7i4GOvXr4e8vLxQH7Ts7GwMHDgQhoaGQtWxdeHr169Yt24d3NzcoKSkBCKCpKQk799v6lw5\nOTnIyMigR48euHTpEs6cOYMlS5agV69eMDMzg7KyMlq2bIkePXogICAAbm5uIkeaqaiogJGREd+k\nhcvl4t27d4iPj8ecOXPQuXNn6OnpQV1dHbKyslBSUsL+/fuRlpbGGxS5XC569eqF9hPbV62wF9W8\nwqYZBPn58rxzD79n+fLlfMGPPTw8cPTo0WqfI5fLxePHj7F06VK4u7tDWVkZvr6+iIqKQmpqqkjf\nUUVFBYKCgiArK1vrOZJpaWmYMmUKWCwWPDw8sG/fPoEV9+LFi/kOgL548SKsrKzQoUMHAavSb0cy\nfbNULS8vx5IlS6ClpYXFixfj/v37sLOzQ5cuXUSe0HyDy+Vi+PDh8PLyqnZCnZFRdfzWqlWrUFJS\nAl1dXTx+/BhDhw7FkiVLBMr7+fnV+H2IyuzZs39Ytfyn8FsLvm8x/ERl+/btCA4OFkgvKiqCkpKS\nSGbSr169QtOmTTFs2DCeX93nz59haGhYJ8OHnJwc3spj0qRJdd57+n7/ztjYGCNHjkSHDh3AYDAw\nZcoU/PXXX9i0aROkpaXRvHnzal02cnJyYGhoKKCqTUxMhJWVldBrunbtip07dyIgIABLlixB7969\nMXv2bDAYDAEftG9cvXoVVlZW6NKlC19IsB8hPT0d7u7uvH1BCQkJSEtLQ1JSElJSUmAymdDU1ISy\nsjL8/PywevVqJCcn48uXL7h69SpWrFiBfv36wcrKCgoKCry4oq1bt4axsTFUVVUFjGa4XC7mzZsH\nBwcHTJ8+He3btweTyQSLxULHjh0xc+ZMxMXF8SKCjB07FtbW1kKDKyy5sqTOe6pyC+T4TrzncDgw\nNzfn+Za+fv0aWlpaAoN2Xl4ejhw5giFDhkBfXx+mpqYYPXo0Tp06Ve8IQffv30fjxo2hr6+PKVOm\n8PmZlpWVYf/+/fD09ASLxUJ4eHi1bhFAlRpRW1ubb7JRXl6OFStWQEtLC9OmTeObvA0fPhxTp07F\njRs30LRpU3Ts2BGpqamYO3cumEwmYmNj6zXJmjlzJpycnGp1iH/z5g3MzMzQvXt3dO3aFfn5+VBX\nVxeqTm3UqBGfe0p9+WZAU9fTQv5EflvB9y1WYV0speLi4qpVAbm5uQmY4v+Tq1evQltbG+vWrRN4\nqW7fvg0WiyU0Fmd1lJeXo3fv3lBWVkb79u1FUgfm5eXx9u9atmyJoUOHwtLSEnZ2dti6dSvfIDZ+\n/HgEBQUhOjoahoaG8PPz44vw8W1fb/LkyQLtrFmzBqGhoUL7cODAAfj6+iI1NRVaWlpQVVXFx48f\ncebMGWhra1f7kpeXl2PRokXQ0tLC0qVL6x0G7HtiYmKgpqaG+Ph4mJqawtzcHEZGRpCUlISkpCQ0\nNTV5h8kyGAxoaGhARUUFnTt3xtq1a5GSkgIOh4PCwkIkJCRg7dq1CAkJga2tLeTk5GBgYABDQ0Oo\nq6vz6lRUVIS0tDT69u2L48eP4/379wK/h4kTJ8Lb2xuVlZXYunUrWrZsyTeoH3p6qN5WtPIL/m/l\nt3nzZj6Dm4ULF2LUqFHgcrlITk7GkiVL0LZtW95vbPXq1Xj58uUPrby/8fz5c1haWuLTp0/w8/ND\nixYtcOHCBUycOBFMJhNeXl44ePCgyFsRDg4OuHLlikB6VlYW+vfvDwMDAxw4cIC3YpWVlYWenh6O\nHDmCpKQk2Nvbo1OnTnj//n297icqKop3P6Lw6tUrSEtLY/To0di8eTP8/f0FytR2+GxdmT9/PoKC\nghqkrt+Z31bwRUdH84UEEoVLly7B09NTaF5ERASmTJlS7bWbN28Gi8Wq1qoOAFatWgUnJ6c6WYh+\nc3j/5nRcneVWRkYGJkyYAA0NDXTq1AmBgYHQ0NBAz549cf36dYGB7M6dO9DR0eGpg0pLS7F27Vro\n6uqiR48ePAMGV1dXoQKoZ8+e1aphi4uLoaamho8fP6Jjx47Q19fn5W3evBnm5uY1Gla8evUKHTp0\nQNOmTesVdeV7Tp06BSUlJZ65+bfnUFFRgfj4ePTo0QMsFgsSEhKQkZGBrq4uDA0NeTEp1dTUoKam\nhs6dO2PmzJlYvHgxxo4dCzc3N6ioqEBPTw/NmzeHk5MTzMzMeEGMv8W1VFdXh5+fH5/RzM6dO2Fu\nbo4vX74AqJpgeHh48A4YLa4ohtIiJYw7Ow6PPz4Gm1MlECOuRggIOc1lmsgsqPLhyi3N5aUrLVLC\n05dP+SLA5ObmQldXl6dqNTMzQ1hYGE6fPv1T4r6+efMGBgYGKC0txe7du2FmZgYJCQl07dq1xsDZ\n1bFs2TK+CDT/5ObNm7Czs4OlpSU0NTVhb2+P4cOHY/78+WAymdixY0e9BfquXbtgaGhYJ8vJrVu3\nwt3dHZaWltDV1RU6cU5ISGgwtxKgapuFyWTi2bNnDVbn78hvK/h8fX2rjWtYHQ8ePICDg4PQvOvX\nr8PJyUkgvaKiAqNHj4aVlVWtKgYulwt/f/9ag2UL4+DBg1BSUoKGhgZfSLRv+3caGhoICAiAu7s7\nmEwmpk+fXq1laFlZGZo0aSI0oklxcTFWrFgBDQ0NyMnJCbVQ5HK50NbWrnH12r9/f6xduxZBQUFQ\nUFDgGzCmTJmC1q1b12g5yeVycfjwYejr62Pw4MH1skAsKChAhw4dICkpyedTKYz8/Hxs2rSJZ6lI\nRLxT4uXl5Xn7hNLS0pCXl0fr1q2xYsUKgT2v8vJyJCUlYcOGDZCXl4e1tTVkZWWhrq4ODQ0NXpi2\nPn368BnNZGRk8MzhtyVug/IiZexK3oWrGVeRkZsBQLjgO/T0ECrYVROT7wWf5CxJaHlpYfr06Vi8\neDHc3NygqKgIRUVFrF69+l9Rh926dQtycnLQ0tKCr68vjhw5grt378LCwgKDBg2qs0FTeno6mExm\ntYZiT58+RZs2bWBkZAR1dXUEBARAUlISHh4eePfuXb3v49SpU9DW1q7TqfSVlZUwNTXFzZs3ce7c\nOcjIyGD27NkCgnfjxo0YMmRIvfsmjKVLlyIwMLBB6/zd+C0FX05ODlRUVOr8YqWlpcHMzExoXllZ\nGZSVlfnOwPry5Qu8vLzQoUMHkU8SyMvLg5mZWZ3DaAFVock0NTWhpKSE0aNH8/bvevToAVNTUzg4\nOGDHjh21muJ/O06mutnv58+fYWBggIEDB4LBYGDAgAF8M/S0tDQYGBjUOHs+c+YMXFxcoK2tjZEj\nR/JtunM4HPTq1Qu9e/euVcWTn5+PcePGgcViYfv27SKrhBITE9G4cWMEBQVBUVERCxcuFFqupKQE\n9+7dw6ZNmxAaGgoHBwcoKCjAwsICdnZ20NfXh7S0NIgImpqasLW15VmpqqurQ1lZGRoaGvD398eW\nLVuQlpbGey7z589HcHAwLzbm6tWroaioyDtHTkFBATIyMtDQ0ICnpycmTZoEbR1taMzR4BNux14c\nAyAo+AYeGwg2h42IqxEA+AUfzSVQGMHc3BxjxozBmTNnMGzYsFonAD9KSUkJYmNj0bp1a+jq6kJS\nUlLA0rCwsBDBwcGwtLQU6div73F2dhbQqhQXF2PatGlgMBjYsGEDysrKMGPGDMjJyUFOTg4eHh71\nViXevHkTTCazTmELgaoVoru7O4CqYNLTpk2DjY0NZs6cyffejBw5EqtXr66mlvpRVFQEHR0dPH78\nuEHr/Z34LQXf9u3bherTayM7OxsMBqPafB8fH975Ys+fP4e5uTkmTZpU59BgSUlJYDAYSE1NrdN1\neXl5mDlzJs9Aw9jYmBda7NatWyKpcVJSUsBgMKqdAXM4HHTq1Anh4eG8NufOnQstLS0MGTIEr1+/\nxrZt29C3b98a26moqIC6ujosLS2Rl5cHJpOJlJQUXn5JSQlatWqFadOmiXTvjx49grOzM9zc3Gp0\nYOZyuVi3bh2YTCb2798PNpsNSUlJDB8+nG+fLjg4GLa2tlBQUIC9vT0GDx6M9evX486dOwJqPy6X\ni0ePHmHkyJEwMzPj7eXp6+vDxcUFDg4OkJeXh5qaGpSUlKCpqYmePXtizZo1UFNTQ3p6OkpKSuDo\n6Miz6vt2GsLevXsxePBg3spQUkdSIDycMMHXKKoR8krzsCxhGdx3uAMQFHwSsyQwfvF4AFUTNy0t\nrTrtMdeFJ0+eICwsDJqamujYsSOOHTuG8vJySEtLVxs8fc+ePWAwGFizZo3IKsgVK1Zg6NChvL9P\nnToFY2Nj9O3bFx8+fMCzZ8/g5OQEHx8fvHnzBhcuXOAZcNU1JNjjx4/BYrFECnf4PWw2G1ZWVrh4\n8SIKCgqgrq6OzMxMfPr0CXZ2dpg6dSrvftu0aVMnv09RWbVqVZ1cVv40fkvB5+fnV+05YDVRVlYG\nGRmZal/CJUuWYNy4cThz5gxvz6C+bNmyBTY2NiLtrXy/f+fm5gZHR0deeCpPT0+RV7ZsNhsuLi7Y\nvHlztWWWLVuGVq1aCezrffnyBTNmzICmpiasrKxEio5hb28PDw8PAFXnvnXp0oUv//PnzzA3N6/1\n6Jrv+/8tNuTUqVMFrGy/fv2KHj16wMHBAY8ePcLVq1excuVKyMjIQFFREQoKCnB2dsbw4cOxZcsW\nPHz4sM4ReYAqNdaZM2cQGBgIHR0dSEhIQFZWFhYWFvD29oarqysUFBSgqqoKaWlpyMnJoVGjRnBx\ncanRz4rL5WLbzW1QmKdQo+CTmCuBaxnXkPQhCTLzZaoVfCqLVMBwZeDAgQM4evQobwXSUBQVFWH7\n9u1o2bIl9PX1MWfOHAGLXDU1NXz9+rXaOv7++284OTmhc+fOIqmzv4UgTE9Ph7+/P8zNzXHhwgVU\nVlZi6dKlYDAYiI6O5nuHZ82ahdatW0NbWxvDhg0TqZ1X/4+9tw6Lam3bh2+6h5geYOhOCaWREsFA\nTBQV7ECwEywUxRY7sWNjYGEruu1ut1u3HaiooNLMrPP7g2/W6zgzMKjPu/ez3995HBzKmntWsdZ9\nXfcV5/n4MQQCwQ8Rj0uqqSmKwqpVq6QM0IcPH9CkSRO6Ursx4rONQUVFBQQCwQ/xf/5fwL/O8JWW\nlsLAwEBpdeXvoaWlpTBUePHiRfB4PPD5fIVl+cqCoij06NEDSUlJCg2tJH9nZGSE5s2bw9zcHL6+\nvti0aRPKysowaNAgGBkZwdHRUakWgAULFiA0NFRh2OfMmTPgcrn1ssa8f/8eRkZGYDAYGDZsmEK2\nC4qiYGpqCisrK1AUhcrKSgiFQpw5c0Zq3MOHD8HlchusmP0WRUVF6NatGywsLLB//34UFxdj4cKF\nMDIygp2dHaytraGnp4eAgACkpqaCy+XCysrql1SJykNZWRnWrl2LyMhIGBoaghACAwMDeHt7o1Wr\nVnR+UE9PDzo6OmCz2ejcuTM2bNggc6+339kuo3j/veETLhACAG4W3cT+P/fj/Iu6nG+NqAb7/9wP\n9mx2neGbYYBZBbPAZrMRHBwsV6z1R3Djxg0MHjwYxsbGaN26Nfbt26cw7/Y9R6g8VFdXY/To0TAz\nM5NbtfktamtrYWFhAQaDgcmTJ6OyshL3799H06ZNER4eLvc9KCkpAYvFwpUrV5CWlgY2m41ly5Yp\njNQUFRXBxsZGhoFFGVAUBXd3d5otysfHBwcPHpQa8+nTJ/j4+KB3796NEp9tLBYvXozY2Nj/2P7/\nm/GvM3ybNm2SWVk0BhwORy5BbVVVFXr06AFVVVWFop6NRVlZGVxcXLBmzRp627f9d2ZmZggICICR\nkRESExPl5hlycnLAYDDAZDLrNcZPnjypt8dH0mvYEL2bhA3+1atXSEtLg7GxMUaPHi3jRd+5cwdC\noRBCoZCmJduwYQMCAgJkDP2ZM2fAYrGUoi978+YNDhw4gMzMTAQGBtJhXw0NDbRt2xabN2/G/fv3\npSa1sLAwmJiYNLjvX4U3b95g+vTp8PHxoZljtLW1ER4ejt69eyMsLIxegWpqatIK7M2aNYNFlAXI\n+PpDnRYLLOo9vsUCC5ApBIYzDVHwsAA7duyAiorKD+vTAXV5udWrV8PX1xfm5uaYOnWqUgUj9vb2\nSitASOSgMjIy5BrSixcvwsPDA3Z2dmjfvj1EIhFmz54NFouFZcuW1ZvHy8rKosPzt27dQkhICDw9\nPWkNQwlKSkrg4eHxw7nQvXv3wtPTExRF4fr16xAKhXINbElJCezt7WFmZvbLWhm+R1VVFczNzRvU\nB/2/iH+d4WvXrt1PSfzY2dnJNNIWFRXB398fHTp0QExMzA+FPxTh/v37YLFYOHPmDObNmwehUAhH\nR0e4urqCz+djypQpDXIIFhQUwNDQEAYGBnKlUSiKQmRkpIwUigRisRgxMTH1tmtI8Ntvv0k5Fi9f\nvsTAgQNhYmKC9PR0Oqw1bdo0pKWlYdy4cfR+RSIRXF1d6Tzpt9i2bRvMzc3pHiuKovD8+XPk5+dj\n4sSJaNWqFfh8PkxMTBAVFYWxY8di9erVCAoKgpmZGYyMjDBv3jy5E2ZycjJUVVV/SqfwR3Dnzh2Y\nmJhg8ODBUFdXh5GREa09KOEYFQgE4PF40NTUhKamJtQF6iDpdQavz94+WHdjHZ6X1lXE3ii6gXU3\n1iFuW5yUYVQU6tTK1MLtt7exdOlSNG3aFLa2to0Oq129ehUDBgyguUwLCgoaldP28vLClStXlB5f\nVFSEqKgoBAQE0Ku3T58+YeDAgbT23YsXL2BoaAg/Pz80b95cKZqur1+/gsvl0nlmiqKwdetWmJqa\nomfPnigqKkJFRQWCg4ORlpb2Q20PFEXB19eXFq0dNGhQvVRkkydPBp/Px4ABA/5jxm/lypWIior6\nj+z7vxn/KsP35csXGBgY1JtTaAje3t64fPky/bvEa5s0aRLEYjHmz59fby9RY/H06VPExMRARUUF\nrq6u4PF48Pf3x9atWxulqH7r1i3w+XwYGxtjzJgxUpNTbm4uvLy8FE782dnZcvN68jBkyBDMnj1b\n7nX07t0bTCYTmZmZ8PT0RGFhIW7fvg1zc3P6xT5w4ACcnZ2lzoWiKPz111/o1q0bOBwOwsPDwWKx\nwOVyERsbi4yMDOzevRvPnj2jJ6TCwkKYmppi/PjxqKmpwcOHDxEZGQkPDw8ZjtP09HTo6en9RzTL\nampq8OjRIxw6dAhLlizBsGHD0Lp1a9jZ2UFFRQXGxsYICQmBvb09wsLCsH37dixfvhwdO3aEQCCg\n+wfd3evIvKdMmQLtUdogUwjW3Vgn95jfV3cqMnxkCKEp0YYMGYIxY8bA39+/QVKHz58/Y8WKFfDy\n8oKFhQWmT5/+w/cuODi40QTvYrGYXsmlpaWBx+Nh0KBB+PTpE0QiEebNmwd1dXUMHDiwUQZj7ty5\nMkVvX758wZgxY8BkMuHs7IyuXbv+sBE6cuQInJycIBaLUVZWBmNj43pXxd26dcOyZcsQFBSEPn36\n/EeMX01NDaysrH66H/bfhn+04fvy5Qv27t2LadOmoVOnTvD39wchBHZ2doiOjsaIESOwbt06mglk\n+/btiI6O/qljhoeH0+XSO3bsAIvFkuoHvHnzphTh749Ckr9jMBhwc3ODpqYmhEKhlNFtLIqKitCk\nSRNwOBy0atUKX758QVFREdhstsKycWXyet9CnmH5Fg8fPkR8fDxUVFSQlZWFsrIyuLq60rm92tpa\n+Pj4oF+/fhg5ciTCwsJgZGQEc3NzxMXFwdvbG15eXgobhUUiEaZMmQI+ny/DAUlRFLZt20Z70RIH\naPHixWCxWD98byV5pP3792PBggVISUlBdHQ03bBuaWmJiIgIDBgwAHPmzMHOnTvh7+8v1a/56NEj\nMJlMmdyzpPw/OjoaBgYGdSvCJuSnhX/1Z+hj9ZXVyMrKgoaGBrS0tKCiogJ9fX3Y29vLTMgUReHy\n5cvo27cvjIyM0L59exw+fPinJ+OYmBil1VG+xYMHD+Dj4wNNTU20a9cO5eXlePjwIQIDAxEcHIyJ\nEyeiZ8+ejdpneXm53IIPsViMuLg4MJlM2NjYYNq0acjKykJaWhpUVFSQmpqKqVOn0lRziu5JcHAw\nNm/eDABYu3ZtgykXNzc3XLt2DV+/fkVoaCiSkpIaXSGuDNatW4fQ0NBfwsbzb4EKAJB/GG7cuEGW\nLFlCdu/eTXx9fYmXlxdxc3MjFhYWpLy8nDAYDPLx40dy9+5dcufOHXLixAlib29PqqqqSN++fUn/\n/v1/+Njt27cnXbt2Jffv3ydr164le/bsIV5eXvTnFEURDodDbty4QczNzRu1b5FIRPLz88ncuXPJ\ns2fPiIGBAamsrCSDBw8mPXv2JPHx8aRHjx5k6NChP3z+FRUVpEePHuTcuXPExMSEWFlZEQ8PDzJj\nxgyZscXFxcTLy4usXLmSxMbGNrjv0tJSYm5uTj5+/Eg0NTUVjlu8eDE5efIkUVdXJydPniRmZmZE\nLBYTY2NjcvPmTWJoaEg+ffpExo0bR5o1a0a8vLwIm80mhBBSW1tL2rRpQ6ysrMiyZcuIiooKvd83\nb96QxMREoqqqSjZv3kz4fL7C88zIyCC7du0ic+bMIdra2mTIkCFk5cqVJC4uTu53ysvLyZMnT8hf\nf/0l8/P27VsiFAqJra2tzI+lpSXR0tKS2tfw4cPJvXv3yMGDB4m6ujq9PTExkbi5uZFx48bR2wCQ\nw4cPkxkzZpCioiKSkpJCXhS9IAs1FhKi+BY3CD0NPfJ+9HsyY+oMUlVVRebMmUPOnj1LFixYQPbv\n309EIhFhMpkkJCSEWFtbk+PHj5OvX7+Sfv36keTkZMLj8X784N+gU6dOpFOnTqRz585Kja+qqiIz\nZ84kS5cuJRkZGaRnz54kJSWFnDp1ilRVVZGpU6eSIUOGkLdv3xJXV1dSVFQkc//rw9KlS8nBgwdJ\nQUEBIaTu/g8cOJAcOXKEaGlpkeLiYlJZWUmEQiFJSEggDx48IAEBAeTdu3fkzp075Pbt24QQQnr1\n6kV69epFLCwsCCGE/P7776RPnz7kjz/+IOrq6sTPz49kZGSQ1q1byz2Pmpoa+j3Q0dEh5eXlpG3b\ntoTP55P169dLPTc/C5FIRJydncny5ctJRETEL9vvfzX+XrsrjbKyMgwbNgw8Hg+zZs1SWh+rpqYG\n27dvh5qaGry8vHD79u0fPofExER4e3vDz89P4fE7duwoN5emCBL+TDMzM1hYWIDJZCIoKAh5eXlS\n4cUnT56Aw+H8tByRWCzGuHHjYGBgAFVVVbl9QmKxGC1btmyUakRBQYFCSreqqipcu3YNq1evhkAg\ngJ2dHd2szeVyoaKigiFDhtD3ND4+Xm7IFKgLtbm7u0t9fujQIfB4PGRmZirtFV++fBlNmjSBl5cX\nTExMMHfuXFy7dg2//fYbsrKy0KtXLwQHB4PP50NLSwtOTk5o06YNhg8fjqVLl+LIkSN4/Phxo3KD\nubm5sLOzkxtuv3PnDrhcLsrLyyEWi7Fz5054eXnBxcUFW7ZsoY8THx+PuPFxjSao/rZ/L3hgMK07\n930jc3FxMV2drKKiQpN4BwUFYcOGDY0KsTeE5ORkpatJjx49CltbW3To0IFekT569AjBwcGws7OD\nsbExli9fTq9cQkNDldK5/BZVVVUQCoU4f/48RCIRWrVqBTU1NSQmJuLs2bOgKAoVFRWYPHkymEwm\nsrKyZFpebty4gdTUVDCZTEycOJHW5pNc582bN2FmZlbvc3P79m04ODhIbSsvL0dUVBQSEhJ+eT56\n8+bN8Pf3/3+rvv8f/xjD9/btW7i4uKB79+4/RE+1a9cuhIWFYdWqVWCxWD8k8/HixQuw2Wz4+PjU\ny36ybNkyuSoO30PSf8dgMGBlZQUDAwP07t27XraKvXv3QigU0hyaP4pPnz7RzCKGhoYyBT8zZ85E\nYGBgo0r8JbqEFRUVuHjxIk231KRJE1q9oEuXLtDS0sLx48elGOzd3Nzg7e0NoVCIVatW4datW2Cx\nWArzsS9fvoSZmRm2bt2KMWPGwMzMDKdPn673/CiKwocPH3Dx4kVs3rwZU6ZMQbdu3WBqakq3FLi5\nuaF9+/YYM2YMVq1ahZMnT+L58+e/JMR07tw5WnBUEdq2bYvu3bvDyckJPj4+yM/PlwqdHTx4EFZW\nVvD29kbYuDCoTVJrnOFLJ+C3q8v1ShTrJSw8W7ZswaxZs+Dq6kpr/23ZsgXl5eVYtGgRXYWqqqoK\nR0dHTJw4Ee/evfupe5KSkoJFixbVO6aoqAhdu3aFpaUlHRYVi8VYtGgRmEwm5s+fD5FIhAcPHsDT\n0xPt27fHx48fsXTp0h8iZJZwaNrZ2UFbW1th/uvJkydo164dbG1t5YZrX716hbi4OFhbW0MgENAO\nQ0pKilw9wG+xZcsWueKzlZWVaNmyJTp16vRL229EIhGcnZ1x6NChX7bP/2b8Iwzfu3fv4OjoiClT\npvzwPiSJYqCO5YPD4TTK+J0/fx58Pp+WmakPDx48gLm5eb39d+3bt4eenh4EAgEEAgGys7OVNmaj\nR49GTEzMT+VX+vTpg0GDBqGwsBBMJhNsNhujR4+GSCTC77//Di6Xq1Q5+pcvX3DmzBksXLgQbDYb\nlpaW0NHRQZMmTdCnTx8sW7YMFy9epBvx169fj/j4eJn9LF68GImJiTh//jwiIiJgbW2NkJAQmiFG\nHgoKCqCuro6AgADaGaIoCkVFRThz5gzWrVuH9PR0dOnSBd7e3nR/obe3N7p06YL09HSsW7cOx44d\ng5qaGoRCIaytrf8jL/+LFy/A5/MV5rOqqqqwYsUKCAQCaGpq4sCBAzLPT0VFBSwtLeHs7IyUlBTs\n378f7OZspfX4yAQCDU8NaGpqokuXLoiLi0OnTp3g5+cHTU1NupqUzWajZ8+emDNnDkxMTKTaHMRi\nMQ4ePIhWrVqBwWBARUUFHA4HPXv2xNWrVxu9Yhg7dqxCsgORSIQlS5aAxWJh/Pjx9DP0+PFjhIaG\nwt/fX4bdqKqqCkOHDoVQKMTevXthZGTUKAUWoG6+kXCu1ieFJMGhQ4dgZ2eH1q1by5BrUxQFR0dH\nsNlsvHz5EuXl5TA2Nm6QzLo+8dmqqiq0atUK8fHxv3T1nZeXBx8fn/+36sM/wPBRFIV27dph5MiR\nP7yPyspKGBoaSoUmr169ChaLpVTRxvr168Fms3HgwAHMmzcPw4YNa/CcBQKB1Esg6b/z8vKCsbEx\nDA0NERxcF25qbNiipqYGQUFBCvklG8Lx48dhbm5OF1L8+eefsLa2hpmZGaKiomBqairTVAvU9Rad\nPHkSc+bMQdeuXeHg4ABdXV00bdoU/fr1g6amJs6cOVMv20m7du3khoHfvn0LQ0NDmm3l1KlTaNq0\nKVRVVbF48WIpIy9RZzcyMkJQUBB0dXXRokULuLu7Q09PDywWC35+fujevTumTJmCzZs348KFCygu\nLlb4Uuvp6aF58+Y4ePAgrK2t0alTp19W5VleXg5vb29aXeFblJWVYf78+TA1NUVMTAzOnDmDFi1a\nYPXq1TJjJ0yYADabjT59+uDDhw8wNTVFYWEhymvKMXzjcOiM1qEV2CWK96oTVSGYIUDu9Vy8fPsS\n8+bNg6enJ902IWmcT0xMxKVLl7Bu3Tq0bt0aJiYmUtqEnTp1QkFBgQwL0L1799C/f3+YmppCRUUF\nurq6CA8PR15enlKTcmZmJtLT02W2X7t2DT4+PlIUdGKxmGbmmTNnTr2r8P3799PEBJL2AWVAURSC\ngoLoSlpljUBVVRWys7PBZDKRkZFBG+nr169DIBBgypQp8PPzw9q1a9GqVasG99eqVat6tUKrqqoQ\nFxeHtm3b/hC7kDyIxWK4u7vLbSf6v4a/3fDl5eXB2dn5p/64+/btQ3BwsMz2zMzMeh9CkUiEUaNG\nwcbGhpbxWLNmjVIqxt27d8eqVavo/B2PxwObzYaenh769ev3U3lGoC6MwufzG2Sy+B7l5eWwtraW\nWXl8+PABQUFB0NbWBpPJxNWrV3H48GHMmDEDHTt2hLW1NfT19REUFIS0tDSsX78et2/fpsMtp0+f\nhq+vb4PHZjAYtNzO94iOjsa2bdsA1DkKf/31F63wzWQy4evrCycnJ6ipqUFNTQ2enp7o1asX4uLi\nwOVycfz4cSmS8MbAysqKJiCvqKhAeno6mEwmcnJyfirMSVEUEhIS0K1bN6lJtKSkBNOnTweHw0GH\nDh2kSA9Onz4NGxsbKYfo3r17tCq8SCRCUlKSVFXo8OHDMW3aNNx5d0dK8X7Skkk0Ez9FUTh16hQS\nExOhra0NFRUV+Pn5wcXFhRbiNTc3R48ePXDq1Cm8evUKGzZskLrnampqsLCwQHJyMg4dOiRFqffx\n40fMnDkTrq6u9FhXV1fMmDFDYX/g947k58+fkZaWBg6HIyUT9PTpU4SHh6NZs2ZKN7y/fv0aDg4O\n9GpLGcyYMQNqamo4fPgwnJycGsUYBNSF4BMSEiAUCrFjxw506NAB8+fPh1gsRmhoKCwsLJQyLObm\n5g1KM1VXV6N9+/aIjY1tkHheWezZswceHh7/sb7B/xb87YbP29sbBQUFP7WPpKQk5OTkyGyvqakB\nn8+XS2pcWlqK2NhYhIWFSYUgd+zYoRTB9ezZs2FnZwc9PT0wmUzw+XzMmTNH4aT/Izh27Bj4fD4t\nXaMMRo4ciW7duklte/PmDfbv34+wsDBoamrSuR8vLy+MHDkSW7ZswR9//FGvAZg+fTpGjBhR77Hz\n8/MRHh5O/15dXY0HDx7gwIEDWLhwIaKiosDhcGBnZ0e3b4SEhEBbWxvx8fEwNTWFlpYW/Pz8ZHJ/\nykgZ1YfAwEDo6elJbbt//z6aN28OLy+vH251mDlzJnx8fOhw2/v37zFhwgQwmUz06NFDoS5aUFAQ\nzSdbXV0NDocDNzc31NbW4sCBA7CyspJafbm6uspl7ikuLoa+vj5mzJgBBwcHODs7Y+HChQgLC8Ps\n2bPB5/Oxbds2UBSF8+fPo1evXrQQr7q6OpycnDB8+HAkJCQgNDQUubm5aNu2LVgsFm3cLC0t0atX\nLxw9epS+zurqavz2228IDw+Hjo4OVFRUIBAI0K9fP9y6dYs2aCtXrkTfvn1lZKYk7xxFUVixYgVY\nLBZmzZrV6OhIUVERtLS0wOFwGjQ49+/fh5qaGs3K8jOhv8LCQtjZ2UFDQ4Nuj9i3bx9UVVUb5M4t\nKSlRWny2pqYGnTp1QsuWLRsd0pUHiqLg7e2NHTt2/PS+/pvxtxq+a9euwdLS8qc87urqapiYmCj0\n+CZOnIi0tDSpbY8ePYKTkxMGDx4sk0A+evQoIiIiFB7v/PnzaNWqFbS0tEAIQWBgIPbu3fsf6b8B\ngKlTpyIkJESpCeHSpUtgsVhYt24dMjIyEBsbCx6PR6+m9PT0sGzZMowcORJsNhvGxsZKE21HR0fL\nDc2Ul5fjzp07yM/Ph4+PD4KCghAZGUlL79jY2CA6OhqDBw/GjBkzoKOjg/Pnz0sZsDlz5sDb2xss\nFgv9+/eHi4sLmjVrhiNHjtCTkkTKKCEh4Ye81a5du0JdXV2u8sLGjRvB5XKRkpKitLwUUDfRCQQC\nvHr1Cq9evcKwYcNgbGyMAQMG4PHjx/V+99ChQ3BxcUF1dTUCAgKgr6+Pr1+/4tOnT3SIU4I3b97A\n2NhY6hmjKAonT55EQkIC1NXVERISQlclvn79GkZGRvTfhsfjyWhT1tTUYMeOHWjbti3YbDYdFmWz\n2XQ++v3799i8eTM9RmIIrays0Lt3bxw7dgyVlZWgKAoXL15E9+7dwWazoaqqCn19fbRs2RLDhw9H\nbGysXGHhZ8+eITIyEr6+vj8lnBoVFYXp06fDwsICQ4YMkescvXjxAhwOBwKBQOqZ8vDwwJ49e37o\nuF27dkXr1q3BYrEwcuRIDBgwAFZWVnQvnyKcOXOmUeKztbW16Nq1K6Kion6JYHBBQQGcnZ3/Y3PW\nfwP+VsM3d+5cpKam/tQ+Dh8+DD8/P4WfX716FW5ubvTvJ06cAIfDoQthvselS5dkBGdra2uxfft2\nODs700TDffr0gbm5eb0SOb8CYrEYLVq0kJHvEYvFePToEX777TeMHTsWERERUFNToxW/J06ciPz8\nfDx//hzv3r2DmZmZVFFHXl4ejI2NwePxMGrUqHpfgk+fPkFPTw9r167FzJkz0adPH4SGhtIrNEdH\nR8TGxkJbWxuZmZk4dOgQHj16JLcqrVOnTli5ciX9e1lZGZKSkqCurk4bYbFYjG3btsHBwQFBQUG0\nEZBIGY0fP77R93HEiBEwNjamyQ6+x8ePH9G/f3+pFVJ9uHfvHlgsFnbu3In+/fvD2NgYw4cPpynX\nGgJFUfDy8qLDz5Jm/O9DnEAdx2mHDh0A1BVmzJo1C7a2tnB1dcWiRYuwZMkSKQWAOXPmoHfv3vTv\nN2/eBJfLrTcX9vnzZ8yZMwd6enp0IYyxsTGio6OxYcMGVFZWori4GFu2bKENoSQ/aGVlhT59+uDE\niROoqqrCixcvkJ6eDltbWzrXKBAIMHv2bDoPK6m+njFjxk+X7q9evRqdOnVCSUkJOnbsCA8PD6lw\naXFxMRwdHdG8eXNkZmZKfXffvn1wd3dvtDP1LSHB27dv0aNHD6ioqCAhIQEJCQn1fvdHxGdFIhF6\n9OiBsLAwGVWSxoKiKPj5+WHr1q0/tZ//Zvythq9bt27Izc39qX307dsXc+fOVfh5VVUVtLW1UVFR\ngaVLl4LL5dabN3vw4AHNzFJaWors7Gxa/JXH42HevHl0nqlv374Nlmr/ChQVFYHH42HkyJEYMWIE\nQkNDwWAwIBQK0a5dO2RmZiIxMRHh4eEyE7ZYLEZ0dLRcYyFRm7CxsUFUVBROnjyJrVu3IjMzEz17\n9kRAQAA4HA4t6NmuXTuMGjUKK1aswPHjx/Hs2TPaYJ48eVKuQv33yM/Pp+Vx7t69C2dnZ/To0QPL\nli1DcHCw1PnX1tZiw4YNsLa2Rnh4OM6dO9doKSMJZs+eDYFA0GBLxLlz5+Du7o6oqCiFhN4fP36E\nubk5/P39wWQykZ6e3mgOTLFYjMjISLoCE4DcECdQ11ualpaGTp06wdDQEL169cKFCxfoe1VSUgIG\ng0EXM7m7u8vQhF2/fh0cDqfeggqgLm8mFAqRk5OD9PR0uLu7Q1NTkw5lduvWDcePH4dYLMbHjx+x\ndetWxMXFgcPh0IbQ2toasbGxsLCwgJeXF6ytrREQEFCnN6iqCi0tLbDZbOTn5/+SCsMPHz6AwWCg\nrKxMyqiuWbMGX758QdOmTTFu3DhERETIpFUoikLTpk0bzb/bp08fqervjRs3ws/PD05OTtDR0am3\nZWnQoEFyUzMNQSQSITk5GSEhIY0W2f4ex44dg729/f86f+0/BX+r4YuMjJShnWoMamtrwWKxGiSp\n5fP5dO9UQwnloqIisFgs9OnTB9ra2nTO6cCBAzJe4ZYtW3652GNNTQ1u3bqFdevWITU1FQEBAdDT\n06NXV2PGjMGRI0ekeh0lRNfyKlizsrIQFBSEmpoavHv3DufOncOGDRswceJEdO3aFR4eHlBTU4Oq\nqiq0tbURGxuL8ePHY+3atTh9+jRev36NBQsWoH///vWed2pqqlJVqFVVVTAyMsKsWbPAYrHo/kKR\nSAQXFxfs379f7j1ZvXo1hEIhWrZsiV27djVaymjTpk0QCoVKebm1tbWYN28emEwmpk6dKlV4dfHi\nRbDZbOjo6GDGjBmNCo1KQFEUhgwZAg8PD6iqqmLbtm1yQ5xFRUXIysqCmpoanJycsGzZMoXHa9Om\nDTZu3IibN2/CwsJC7grm6tWr4HA4DTZ93759G2w2mw5LSujM+vXrBysrK9rA2dvbIy0tjQ5TlpSU\nYOXKlTA3N4eqqipUVFRoMu4+ffpg1KhRYDAYcHZ2BoPBgJqaGhgMBk1+/TOl+y1btsT27dvp3+/d\nuwdnZ2dwuVz07NkTFEXBxsZGbvvCkSNH4ODgoLQReP78OUxMTKTy+UFBQdi9eze+fv0KdXV1cDgc\nDB48WG7OPzAwsNFFaxKIxWL07dsXgYGBUn2yjQVFUQgJCfkpQv//Zvzthq+x6sbf4sSJE/D29q53\nzIcPH6CpqYmIiIgGNfrOnTuH4OBgWkYmOTm5XpV0ebmXxqCqqgpXr17FqlWrMGDAAPj6+kJXVxeO\njo7o1q0b5s6di8LCQnqFOW/ePPj6+kpNxCKRCP7+/li6dCnEYjFevXqFU6dOYc2aNUhMTISWlhZc\nXFygr68PExMTNG3aFN26dcOkSZOwceNGnD9/Ho8fP0bLli3h6OgIDocj09DboUMHbNq0SeF1UBSl\ndNj38+fPsLa2Bo/Hk2n03rt3L1xcXBTez6qqKixduhSmpqYICgqCkZGRUlJGQF2Lh5mZWb3Rge/x\n4sULxMfHw97eHgsWLEB0dDT09PTg6Oj4w3qPFEVh1KhRdCl/9+7dERISQoc4xWIxDh8+jPbt29Oc\nmaampg2ujLZs2YLY2FiMGDECGRkZCsddvnyZbt2pD0ePHgWXy5X7/ItEIuzZswft27cHh8MBIQRa\nWlqwsLCAnp4eBgwYgC9fvqC0tBSzZ8+WCp+qqqrCxsYGffv2xYYNG5CamgqhUAg1NTVoaGigadOm\nWLp0aaNJLHJzc6WK0kQiEdq3bw9ra2tYWlriwoULsLGxkRvqpigKwcHBSrMxDR48WIrx6N69e+Dx\neKipqUFVVRU0NTXx8eNHDB48GBwOB6tWraKfaYqiYGho+EMkHRKIxWIMHDgQ/v7+P+R4SXDq1ClY\nW1v/x3Qq/8n4Ww1fhw4dlI4zUxSFO+/u4MCfB7D9znYc+PMAOg/pjJkzZyr8zt27d2FlZQUNDQ2F\nZfC1tbXYtGkTrKysoKmpSYdslH0wnZyclFI5Li8vx4ULF7BkyRL07t0bnp6e0NHRgZubG5KSkrBo\n0SKcPXu23hCGpOexZ8+eOHbsGJYvX47w8HCYmJjAxcUFOjo64HK5CAwMRJcuXWBgYICxY8fiypUr\nDSpW1NbWYsiQIRAKhTAxMaFD0BRFgcPh1Ct0e/XqVdjZ2TU4OV+7dg22trZo3bo1PDw85F5fYGBg\ng15oRUUFFixYACMjI+jo6CjlPd+7dw9sNhvDhw9vcOy353P48GE4OztDXV0dVlZWsLKy+in1j4kT\nJ8Ld3R2rVq2Cp6cnKisrwePxwOVykZGRAQsLC3h7e2PFihX4/Pkz5s6di4EDBza4X4kyCZfLbbAp\nW7JqbaiRf82aNbCxsWkwjHvx4kVYW1vDwMAAenp6IITA0NAQERER6NixI1RUVDB16lR8/PgReXl5\niI+Pp5Xr1dTUYGNjg+7duyM1NRWenp5QV1enq0lHjRqFu3fvNvhsffr0CQwGA1++fAFFURgwYADC\nwsJQWVmJ3bt3g8PhgMvlKtTSPH36tFJG4PXr1zA2NpZitBk2bBgmTJgAoC6fyGAw6M+uX7+OgIAA\n+Pj44OLFi3j+/Dl4PF69x1AGkqhB06ZNf7jFBwAiIiIanTb4N+BvNXzTpk2rl7kDAMpryrH2+lrY\nL7aXat5lzGSApBNYzrPE2utrUV4jXe20f/9+sNlszJgxA7a2tjL7LS0tRXp6OgwMDKCurk63VYjF\nYjCZTKVzNikpKTKck1++fMHp06exYMEC9OjRgzZKXl5e6NevH5YvX45Lly4pLE+WyOwcPHgQixYt\nQlpaGmJjY+Hg4AAtLS2oqanB2dkZCQkJ0NXVRU5ODm7cuEGHPiQFMZKXsTFYtGgR2Gw2TE1NMXLk\nSNy/fx/m5ub1ficjI6PevyNFUcjJyQGbzcZvv/0GkUgEPp8vl9rr7NmzMDc3V6ptoaysDC1btoS6\nujo6d+6sMCcH1OXldHV16XxafRCLxdi9eze8vb3h7OyMzZs34/Dhw9DV1YWRkVG96t31YcaMGXBy\ncsKjR48gEAhw5swZbN++naYJGzBggIwTFR0drTQDUWBgIKytrZUaK6FXayjikp6eDj8/P7nPallZ\nGUaPHg02m40VK1bQ4dVXr15hxIgRNPMLIQR8Ph+dO3fGoUOH6HFlZWX47bffZAyhtbU1IiMj0axZ\nM+jq6kJdXR2Ghobo1KkTDh8+rDAk2qpVK2zZsgUZGRnw9vaWWpU/f/4cLBYLzs7OCtuDoqKiaCMg\nz9G+8+4ORowYgaFDh9LfqaysBJPJpNMtx48fR2BgoNR+JZXDAoEAUVFRdI77Z0FRFIYOHQpvb+8f\nbqM6f/48hELhL2uS/2/B32r4CgsL62VPyLubpxRdk/4Mfehl6SHvbh4oikJ2djYEAgEuXLiAefPm\nSfFqPn78GB06dICGRh21U9euXWXCH9bW1gqr/77Hhg0b4Ovri9mzZyMhIQH29vbQ1dVFs2bNMHjw\nYKxZswbXr1+XeVkrKytx79497N27F/PmzcOgQYMQFRUFa2traGpqwsrKClFRURg0aBDmzZuHPXv2\n4O7du6ioqMD169dpouusrCyZc5o+fTqCg4N/OHFdUFBATxJubm7o1KlTveNdXV0Vqjx//PgR7dq1\ng7e3t1R+dfjw4Zg4caLc77Rt21bpkCRFUUhKSoKdnR1YLBZ69eolN+dLURQ0NDTg7++vcF+1tbXY\nvHkzXFxc4O3tjd27d0MsFuP58+fg8/koKCjAnTt3EBQUhKZNmzZK0Xz+/PmwtbXF69ev0bt3bzRp\n0gTm5uZgsVgIDQ0Fn8+XMXqVlZXQ19dX2qMPDAyUIT6uD2fOnAGbzcbx48cVjqEoCt26dUOHDh2k\n8oYSTtnu3bvj7du3UuM3btwINpuNSZMmoaSkBJqamhg0aBBsbGzo/KCtrS0GDRokRaBdXl6OvLw8\ntG/fnibQVlVVhampKRwcHGBsbAx1dXVoaGggICAAq1atkorMbNiwAa6urrC3t5fruM6ePRtNmjQB\nj8eTy1x08eJFmFqaYsWlFTKOtuFMQ+hO14XqUFXMPTGXdrQ3b96MFi1a0PuYPHmywqjC58+fERwc\nDB0dHeTk5PySwhKKojBy5Eh4enr+ML9vTEwMli5d+tPn8t+Ev9XwicVi2NjYyFUjWHhxIXSm6zSK\noFdnug68U+r03F68eAGKomBvb48zZ87gxIkT8PLygpqaGs26riis2KRJE7nhy3fv3uHQoUPIyspC\nhw4dYGVlBX19faipqSE1NRUbNmzAnTt36Af669evuHnzJnbu3Ins7Gz07dsXYWFhMDc3h5aWFuzt\n7REbG4u0tDTk5OSgoKAAf/75p1JJ/l69ekFbW1smxn/q1CnweDyly+oV4datWxAKhWAymeDxeAr7\n0h49egQejye3mOLcuXMQCoUYNmyYjEd55coV2NjYyHV67t69CzabrfSEX1NTg+joaPTq1Qvp6ekw\nMTHBgAEDZIp9TE1N5a5eq6qqsGrVKlhbWyM4OBiHDx+mz6u8vBxNmjSRWtWLxWKsXbsWHA4Hw4YN\na7DIYNmyZbC0tMTatWsREhICFRUV9OrVC4sWLaKrOBcsWCBDnHD8+PF6W3W+RWlpKRgMBgwMDBpF\nLH369GmwWCypoprvUVVVheDgYIwaNQrPnz9HXFwc7O3tZVQ/ioqK0LZtW1pnDqibmFVUVOgVslgs\nRkFBATp16kSv8rS0tNCkSRNMmTJFajVWUVFBE0pIDKGamhpMTExgZGQENTU1qKurw8bGBunp6Zg8\neTJUVFRolfXv8ebNGxgZGeHgwYMwNzfH8OHDpZ7LvLt5UJuoBs0pmko72qGhoXSbiEgkgrm5eb15\n565duyIrKwsRERFwc3NrtEivPFAUhXHjxsHd3b3R1cVA3btoamr6Sxrk/1vwtzO3LF68GM2bN5ea\nOPPu5jXa6El+1CapYdO1ukKM1atXw9zcHFwuF6qqqnB1dcW+ffsazBeEhoZi+/bt2LdvH6ZMmYK2\nbdvCzMwMRkZGCA8Px6hRo7B161Y8ePAAHz9+hIODA6ZOnYpp06YhOTkZQUFB4PF40NbWhouLC+Li\n4jBixAgsW7YMR48exZMnT37K23v37h04HA5iYmKQnJwstd3U1LTRNEyKIGHFcHFxAYfDkdsKMGfO\nHBlFerFYjOzs7HorCCmKgp2dHS5duiT38969ezeqX+9bKaPi4mKMGTMGxsbGSE1NpSdTX19faGpq\nShm1hQsXwszMDNHR0TJFPRRFoUuXLujevbvcZ6a4uBi9e/eGmZkZduzYIXfM7NmzwWAwwOVy4efn\nB1tbWyxatIiu4pTkJ8vKysDhcKQauceOHatwVfw91qxZg/j4eHTt2lVhj6oiFBYWgsVi1dvq8fbt\nW5qSLzMzU8pgUBSFLVu2gMPhID09XcbJ0dfXV1gMVF5ejtWrVyMiIgKGhoYghIDBYCAsLAzLly+X\natiurKykacL4fD5Nui2hZyOE0KTmR48eletAdu7cGdOmTcOHDx8QFxcHLy8vPHz48Iccbe1p2tCP\n1KePs27dOgQEBNR7r11dXXHt2jWaycbc3Bxdu3b9aUeVoihkZGTAxcVFagWuLOLi4rBgwYKfOof/\nJvzthk8kEqFZs2ZYvHgxgLqcnl6WHoYeGopbb29BJK7zFCcXTqYfOPfl7jj++Di+VNV52k9Lnko9\nkHpZeuic2BmEEKipqSEuLk5h6JKiKDx9+hS7du1Ceno6YmJioKWlBQaDgejoaIwbNw5r1qzBjh07\nsHHjRkyePBmJiYlo1qwZmEwm9PX1wWaz4eLigrFjx2L16tUoLCzEy5cv/2N8eF26dMGYMWNQVlYG\nZ2dnrF27FmKxGFFRUT+U11MESSK/Q4cOcHFxAZPJxJo1a6TGBAQESBVJvHv3DtHR0QgMDGyQIHzy\n5MlS+ZJv8eLFC5iYmDSKSFoiZSRhKXn79i3NpjJy5EjExMRAV1cXT548QVZWFjgcDuLj43HlyhW5\n+8vKyoKvr2+DnvDvv/8OZ2dnxMTE4PHjx6ipqcHu3bvh4eEBFRUVdO/eHbdv30Zubi6aNm0KsViM\npKQkDB48WOZ43bt3p39v0qQJrVzfEEJCQpCfn489e/b8UA7p+PHjYLPZOHv2rMxn586dg5ubG4KC\ngsBisaQqQt++fYv4+Hg4OzsrvI9cLldp2r23b99i2rRp8PHxgba2Nggh4HK5aN++Pfbt2yf1TlVX\nV2Pnzp0IDQ2lDd+35NwaGhoICQlBbm4uHRKV5Pru3LkDiqKwZMkS6DfTh+bU+ld5in7UJ6sj724e\nXr9+DTabXW//XnV1Nd1TLEFZWRnNG5udnf3TagxTpkyBk5NTo2gOgTqSAx6P99PN8f8t+NsNH1DX\nNM7j8bB161asvb4W+ln62HhzIwqfFuJpyVMA0oav9dbWuPvuLk4/q/NQvzd8ZDyBShMVREZGSnmM\nYrEYDx8+xPbt2zFmzBhERkbCxMSEliNKSkpCamoqHBwc4OvrCy8vLzAYDBgZGcHX1xcJCQnIyMjA\n+vXrcfbsWbx9+xYURdUr0PqrsXfvXtja2tIvj6SHb/DgwUpTmymL7du3o23bthCLxRg/fjyEQiGE\nQiFGjBgBkUiEoqIiGBkZ0S/riRMnYGpqivT0dKXOQ/J3V1QoMnr06Ab7B7/HjRs3wGKxcO7cOXrb\nq1evMHjwYGhqakJDQwOGhoZITEyst/1i7969MDU1VdoTr66uxpgxY6CjowMDAwM4ODjA0NCQNgYf\nP34El8vF1atXFTaql5aWgslk4vHjx3j//j0YDIZSpeZPnjwBi8VCdXU1qqqqYGxs/EPKE0eOHAGb\nzabztR8/fkS/fv0gEAiwfft2UBSFCxcugMVi4erVq9i+fTs4HA7Gjx9fb3GEjY1NvYVH9eHOnTtI\nTU2Fvb093W9qbW2N/v374+rVq7h9+zY4HA6OHDmC6upqbNy4kU5nfG8IhUIhJk+ejOnTp8PKygpP\nnz5FeU05dKbJrvTW31iPV59foaq2CsXlxTj06BA8V3jKNX6603Xh7u3eYB/r7du34ejoKPezR48e\noXXr1rC3t//piM20adNgb2/f6FVkx44dFYpD/9vwjzB8wP+vTs3jgjmFKfVQ5f+RD0Da8El+4rbF\nAZBj+KYQsKaycO/ePWzatAnDhg1DcHAw9PX1weFw4OnpiaCgIAQEBMDJyQm6urpgs9nw9/dHjx49\n0KxZM/To0QOXLl1Sqlrqy5cv0NPT+4/HyEtLS2FmZiaTj0lPT4eamlq9PYc/gpSUFMyZM4f+PTc3\nF2w2G56enoiNjcXChQtpteiJEyeCz+c3ui/T29sbx44dk/vZx48fwWKxlGbrl+DgwYPgcrn0Kv/1\n69cYPnw4tLS0oK6uDj09PUyZMkVhD9Tdu3fBYrHkkkJ/j5qaGuzcuRMtWrQAk8lE79694eLiAjU1\nNSnpoQEDBiAlJUUmxPk90tPT0b9/f2zbtg1t2rRR6nozMzOlaM6SkpKwcOFCpb77PQ4dOgQWi4VJ\nkyaBy+ViyJAhMvdp7dq10NbWho2NjcJQ9bdwd3evdyWkLCiKwrFjx9C1a1cIBAJ6lWdhYYGMjAya\nrzc+Ph7r1q2jV4QxMTFgMBi0EZTkCnV0dJA4NxF6WXoy80fh00Jsub0Fy64sw4PiuvfqWckzuYZP\nNV0VMRNiGkyhbN68ucFCsf3798PGxgbt2rVrkJijPmRnZ8PW1lZp1Qqg7rnncDg/1Rj/34J/jOED\ngCM3jkBtotovMXxkAoG+tT74fD7YbDY0NDTA4/EQEhKC3r17Y8aMGcjLy8P169dl8g8ZGRkKRSIV\nwd/fXybZ/6vRv39/mRXQ27dvYWpqilatWqFjx46/VGTS3d1dZvIvLCwEh8Oh5YQkJNoRERFSeojK\nYt68efXKQGVnZyullvE9VqxYAUtLSyQlJcHY2BjDhg2jOS5nzpyJnj170u0u3668Pnz4AGtr6wab\nmR89eoSxY8eCy+UiNDQUmzdvRmVlJY4ePQo2m41Zs2bBzMwMSUlJOHLkCHg8HkpKSpCcnCwT4vwW\nxcXFMDY2RpcuXejwf32Qlys9ePBgvdWr9eH+/ftwc3ODurq63H7KvLw8cLlchIWFwdnZWakG6oCA\nAKVDtsqiqKgI1tbW6NmzJ6Kjo2FsbAxCCAwMDODo6AgnJyeZFXVNTQ02bdqEZs2a0STzZEjD4cwm\nK5oAAERiEdQz1eWOcVjccDXt2LFjZbhC5aGyshLTp08Hk8nElClTftihnjt3LqytrRsUxf0W3bp1\n+2Ed0P8m/KMM34E/D8BwpuEvMXwaEzWQND0JeXl5uHbtGj59+oSqqipUVVWhurpa7k9NTQ1qamqQ\nnZ2NYcOGoaamBrW1tTI/IpFI5mf8+PGYMGECxGKx1A9FUTI/P4JTp07BzMxMaqIRiUSIjIxEeno6\nKisr4eXl9UMcgPJQUlICfX19uaE2ibCtqqoqCCHo06fPD7PXvHr1CsbGxgr79ioqKmBqaiq38lcR\n7t+/jx49ekBbWxtmZmZ0rlHiTUsmnz/++AMJCQngcrmYO3cuSktL6eIleaiqqsJvv/2GiIgIsNls\njBw5Umo1eurUKbBYLHqS//LlC4YNGwZ1dXX06tUL+/btkxvi/B7Dhg2Dvr6+Uiv4CxcuwMHBQeq5\nqqmpAZPJrJd04Ht8q1G4aNEi5Ofng8Ph0NWZxcXF6Ny5MxwcHGie0JSUFERGRjYYjo2KivplBVdA\n3bPp4eEhY0SKi4uRnZ0NHx8fenXHZrMRFxcnVxD66our0JisodDgpRSkYOnlpfSKb9bZWQrH6mXp\n4c47+dWkEsTGxjbIlfotnj9/jo4dO8LS0vKHeU0XLlxIh3WVwZ9//gkWi/VTTfH/DVABAPIPwW93\nfyP99vcjX2u+0tvyu+STdo7tyJRTU8jU01Olxsc5xJE9CXvIs9JnxCrHSnpn1YSoHFAhan+oEUII\nUVFRIYQQAoD+/7f49jZQFEUAEFVV1XrHfQuKoqSOU9/YxkBFRUVqPyoqKlLX8v15UhRFVFVV6THy\nrlXR9m+3URRFxGIx0dTUlBkHgNTU1Eidn4aGBlFXV1fqON9vr6ysJJqamgq/X1tbS2pra4murm69\n+6UoilRVVdHnraWlRSorKwkhhOjp6RGRSETKy8uJhoYG0dPTo78nFotJZWUlqa2tJaqqqsTQ0FDm\nXlRVVZHq6mqipqZGtLW1iZaWltSY2tpa8uXLF8JgMKTuWWVlJamqqiIAiFgsJgYGBkRHR6fe+19T\nU0M+ffpE2Gw2UVNTq3dsaWkpUVNTIwYGBlLjSktLibq6OtHX12/wb11ZWUlKSkqIlpYWMTIyov8O\nlZWV5OPHj4TBYJCvX78SPT09YmhoKPV8vXv3jqipqREWi6Xwb/3+/Xuir68vdc9/5rl8/fo10dbW\nJmw2W2a85Pc3b94QTU1NQlEUKS8vp59XDQ0NoqurS4yMjIjYRkze+L0hlCYl91wKkwpJc8vmhBBC\nXn5+SYYcGkL2/blP7lhDLUOytcNWEmsXK/dzQggRCoWksLCQ2NjYKBwjDydOnCCpqalEKBSSnJwc\n4uDg0KjvL126lMyZM4ecOHFCqWMnJycTCwsLMnXqVJnPamtryaVLl8jt27fJ7du3yatXr0hBQQHx\n9vYmtra2xNnZmbi7uxM/Pz/C4/EadZ7/m5Cdaf5G6GvqE1UVWWPzI9DQ0CDNfJoRba42KS0tJSUl\nJaS0tJSUlpbSL7ixsTH977f/f/r0Kbl//z7JyMiQ2m5kZKRwIqmsrCRsNpsUFRURAwODRp+vPCMp\n2TZu3Djy/Plzsm3bNnpbYWEh6d69O7ly5QoRCAT09n379pHhw4eTy5cvExMTk0YfS4L09HSira1N\nMjIypLY/f/6c9OjRg7x69YqkpKSQBw8ekGvXrpGKigrSunVrMnPmTKKmpqbwOPK2r1u3jpw4cYJs\n2rRJ7jiRSET8/PzIjBkzSIsWLWS+f+HCBTJ37lxy//59Mn78eJKUlET09PQIAFJZWUni4+NJQEAA\n6du3LwkMDCT+/v5ky5YtUvvYuHEjmTdvHrG1tSUPHz4kqamphMFgkK1bt5KHDx+SHj16kMTERGJj\nYyNz/Fu3bpGuXbuSrVu3kvDwcHp7cXExCQ0NJfv37yfLly8nL1++JA8fPiQdOnQgI0eOlDIE3+5z\nzZo1ZMOGDaRVq1Zk7NixCu9fdXU18fHxIYcPHyYCgUBqzNmzZ8mMGTNIQUGBwu+/e/eOTJ06ldy5\nc4fMmTOHhIWFSY0rKSkh/fr1I9evXyezZs0iHTt2lDnX8vJykpCQQKKjo0lKSorcY40cOZIEBgaS\n9u3by3xf3nkp2iYSiciQIUOIk5MTmT17toxj+u3Yw4cPk507d5LVq1fTn129epXs3LmTXL58mbx4\n8YKoGKoQEMXOadiGMKKlpkWibaPJ7s67yc5OO4ndYjvy/PNzmbEUKPK1+qucvdRBMgdZWVkpHKMI\nERER5NatW2Tx4sUkMDCQ9O3bl2RkZBB9fX2lvp+SkkLU1dVJWFgYOXHiBLGzs6t3/KRJk4ivry9J\nS0sjTCaTEELIkydPyIoVK8jGjRuJqakp8fLyIm5ubqRVq1akffv2hMvlkpKSEnLv3j2yevVq0rt3\nbxIYGEj69OlD4uLiFDo6fxv+wyvKRuHOuzt0ornP3j5Yd2MdnpfWxadvFN3AuhvrELctDg6LHbDu\nxjqceFKXU/ta/RXrbqzDnHNz/ifhPFEV4+aPw6NHj6RCBBRF4cuXL3j+/Dlu3bqFU6dOIT8/H+vW\nrcP8+fMxadIktG3bFnw+H61bt0ZQUBBcXFxgamoKXV1dumLM1tYWvr6+iIqKQufOndG/f3+Ym5sj\nKSkJK1aswPbt23HkyBFcunQJDx8+xPv373+IDFbCqP9tU/Lbt28hEAgUKluMGjUKMTExP9VOERAQ\nIMPosXPnTrDZbMyePRtGRkZ0VeuMGTNgamqKpk2bIiYmptHEuR8/fpSS1ZGH/Px8uLm5SZH9Hjly\nBCEhIbCyssKKFSsUVhYWFxfDxsYGy5cvh5qaGry8vKQ+lzCYPHjwAPfv30dCQgI0NDSgra2NQYMG\n1Sv+eevWLXC5XLkhrKSkJIwcOVKqivPdu3fo0aMHhEKhQgHU1q1bY9GiRWAymfWGnHbt2qWwmri2\ntlaqwOdbiEQi5OTk0JJK8nJIe/bsAZ/Px/Dhw7Fx40bweLx6G8OFQqFCAdaBAwf+NDOIpAUkJiZG\nqfeovLxcigy6uroa169fx6pVq9C/f380adIEqo6qIOPk9OdN14bqVFX6d81pmiitrHumm69vLjfU\naTjTEAUPCxSez++//45mzZr91D0A6u51jx49YGZmppRu5LdYs2YNzMzMlAqh9+vXD+PHj0dNTQ2d\nbxwzZozSBXRlZWVYv349mjRpgubNmyvNhPW/hX+U4aMoCvaL7UGmEKy7sU7umMmFkxG6LlTuZ9/m\n+jRHaEJdXR2ampowMDBAixYtsGzZMjx48KDBh+XChQsKH9Lq6mq8e/cODx48wMWLF3Ho0CFs27YN\ny5YtQ2RkJHx8fNCvXz907NgRkZGR8Pb2ho2NDUxMTKCmpgZ9fX2YmZnBzc0NwcHBaNu2LXr27Imh\nQ4di8uTJWLhwIdavX4+9e/fixIkTtDLA169fQVEUnderj4G/pqZGIZ2ZMqioqICuri7d01NZWYnB\ngwfD2toaly9fxqFDh2T4CPPy8sBisRAbG6uU/NP3aNu2bb3k1BRFwd/fH+vXr0d+fj58fX3h5OSE\njRs3KtU68eeff4LL5YLBYIDNZtPbJaTBo0aNQnBwMHg8HsaPH4+//voLv//+O0JDQ2FnZ4fNmzfL\n5DH/+OMP8Pl8KTkcCc6cOQMzMzM8f/5cbhXnyZMn4eDggLZt20rl4qqrq8FgMFBcXIwePXrUW2gQ\nFxdHi/fKQ0pKisz3r1y5Ai8vLzRv3lwuV+rHjx+RmJgIGxsbqYb+rVu3gs/nK1RKv3PnDthstlwm\nkpEjR/5UmTxFURgxYgQCAgKUUiCvra3FrVu34Ovri9DQUPj6+kJHRwfOzs5o2bIlIiMjYWVlBRNH\nE6hNUpMxYqHrQvH6y2tsu7MNy64so3N378re1XEEyzF8KhkqGJE9QmEubenSpejbt+8P34Pvcfbs\nWXh6eiI0NBS3b99W+nvr1q2Dqamp3L/9t3j+/DmMjY3RtGlTtGzZslH54m8hEomwYMECsFgsuTRx\nfxf+UYYPAN3H19hG0u/Li1NWp6CsrAyHDh1Cr169wOfzoaWlBV1dXTAYDLRp0wZLly6Vy/x+//59\nhf029eHs2bNo0qSJws/FYjE+f/6MZ8+e4ebNmygsLER+fj5yc3Mxf/58TJw4EampqejevTtatWpF\ny7wIBALo6OhAXV0durq60NHRgY+PD1q0aIHOnTtjwIABGDt2LLKzs7FixQr89ttv2Lp1K5hMJjZt\n2oTi4uJG9fedOnUKTZs2BVBnMDw8PNCpUyd6Jde/f3+pNgcJLl68CIFAgA4dOoDD4TSKjmn79u1S\nnIffQ9IyoaGhAU9PT+zcubPRK9ozZ85ATU0NampqqK2txaVLl8BisaCrq0vr/H2/mqAoCsePH4e/\nvz+cnZ2xY8cOiMViPHr0CGZmZnKrP2tra+Hm5obffvut3irOqqoqTJs2DUwmE7Nnz0ZNTQ1Onz5N\nS23dv38fHA5HblNxcXExDA0N6y09//333+Hm5gagrhVmyJAh4HK52LBhg1znb9++fRAIBEhLS5N7\nzE2bNkEgEChsLzl27Bg4HI7M55MnT5YSbW0sZs6cCVdXV7mqGCKRCHfv3qUljvz9/aGrqwsHBweE\nhITA2toamZmZ6Nq1K1gsFjw8PJCRkYGCggKMGDkCqkNVZeYPu0V2KHxaiA/lH1Atqsarz6/w293f\n4LLUReGcozVSi+b/NTc3x8iRI3Hz5k36Pg8cOPCXFZ59e+3Lli0Dm81GWlqa0gUpmzZtAp/PV7iC\nB+qYkLhcLjw9PX9JpfiFCxfAZrP/McbvH1XcQgghFbUVhDOHQ8pry394H1oqWsS5wJlUl1WT9PR0\n0qVLF6KmpkZevnxJjhw5Qnbv3k1Onz5NtLS06EKWsLAwEh4eTkJDQwmTySRNmzYlb968adRxa2pq\nCIvFIs+ePVOYX1MWf/75JwkMDCTXrl0jFhYWhBBCjhw5Qnr27El27txJNDQ0pHKXJSUlUv8vLS0l\nL168IE+ePCEGBgbky5cvRFdXVyZnKS/PefToUSISiYiHhweZM2cOmTJlChkyZAhRVVUlFEURgUBA\nzp49S2xtbWXO+/nz56R169bEysqKXLx4kWRlZZF+/fo1eL0VFRVEIBCQP//8k3C5XKl7unHjRpKd\nnU14PB6pra0lCQkJZPjw4T90X93c3Mjdu3eJm5sbefToEbGzsyN79+5tMPcCgBw+fJhMnDiRVFRU\nkI8fP5LMzEwyYMAAmbELFiwgBw8eJEOHDiVpaWnk9u3b9eZjHj9+TFJSUsjr16+Jt7c34fP5ZObM\nmYQQQjp27EgCAwNlrnfJkiXkwoULMrnKb0FRFDE3NyfDhw8nCxYsIK1atSLZ2dkyz2ZJSQkZNmwY\nOXv2LMnNzSWhoaEK97lhwwaSnp5OTp48Sezt7WU+X7duHZk2bRq5ePEi4XA4hBBC5syZQ969e0fm\nzp2rcL+KsHr1ajJz5kxy9uxZwuPxyKNHj8jVq1fpn5s3bxIej0d8fHzoHyMjI3Lq1Cmyd+9eUlhY\nSMLCwkjHjh1J69atCUVRZPbs2WT79u2ke/fuRBgnJFMuTfmp+UZXXZcsiV1C2lm2IwcOHCDr168n\n586dI4QQoqOjQ9q0aUOuX79OcnJySERExA8fRxE+fPhA0tPTyb59+8iMGTNIUlKS3MK8b7Ft2zYy\nYsQIcuTIEeLu7i7zee/evUl5eTk5evQouX//PuHz+T99nhcuXCBxcXHk5s2bMjnp/3X8vXZXPn6W\nq5PTnINz587h8OHDCAwMhJ2dHXJzc6W8+draWpw7dw6TJk2Cp6cntLW1YW5uDjabDQaDAVVVVcyf\nPx/Xrl1rVKl+y5YtlZaRUQSxWIygoCAsWrSI3lZUVASBQNDoBvEpU6YgNDQU1dXVKC0txbNnz3Dj\nxg0UFhZi9+7dWLt2LebNm4eMjAwMGTIEiYmJYDKZMDQ0hKamJq02rqGhATabDXNzc+jo6CA6Ohpd\nunTBwIEDMW7cOMyaNQsrV65EXl4e8vPzERAQAG9vb1haWiItLU2pFWf37t3pay4vL0dOTg7MzMzQ\nokULmkfyzp074HA4jc4j3rp1CykpKdDUrAuB6+vrw8vLSyn5o2/x8uVL8Hg8CAQC+Pr64tChQ1Ie\n8atXr8BkMnHlyhWYmZkprbRNURTy8vKgoaGB2NhYmmn/+vXrEAgEMvlLX1/fBlsEHj16BAsLC3A4\nHCkmm29RUFAAU1NTpKSkNNhmIcHatWthZmamkI1l4sSJaNasGR2WXLp0qVKagt9CQidmZGSEPn36\noHnz5mAwGLCyskLHjh2RnZ2N48eP49OnTxCJRDh79izGjh1Lq6737t0b+fn56NSpE5YtW4Y//vgD\nPXv2hImJCcaNG0fnzG/dvwWVdJWfijCRCQQ6DB34+flh9uzZ+PTpE6qrq3H06FEkJCTQHKTa2tqI\njo7Gzp07lQrZNhZXrlxBs2bN0KxZM4X0cd9C0pP5vcrI0aNHYWlpSbfjpKam/rJznDx5Mtq2bfvL\n9vej+EcaPuDH1RlyLuZg9+7d4HK5mDx5MmpqalBYWIiIiAhYWlpi+fLlcosgPnz4gO3btyM5ORlc\nLheEEDg5OcHMzAyGhoZo1aoVZs+ejcuXL9c7ic+ePRtDhgz5qWtfunQp/P39aYMrEokQERGhNGHx\ntxCJRIiKilKa8Pn69etQVVVFQkKC1ERYWVmJt2/fonfv3khOTsbBgwexZcsWLF26FNOnT8eoUaPQ\np08fdOjQAeHh4WjSpAntQBBSx5lqZmYGd3d3hIaGIi4uDsnJyRg2bBimTp2KnJwcjBw5Era2thgw\nYACYTCZNHP19qCUpKaneHKcEZWVlWLt2LZo1awYzMzNMnjwZKSkpMDU1hZaWFsLCwhoVAn779i0c\nHBwwa9YsiMVi5OXlwcnJCQEBATR5QZcuXZCent5go7o8fPr0CQYGBhg8eDC4XC7WrVsHiqIQExOD\nFStW0OPu378PPp+v8NyrqqqQmZkJJpNJ0319fw9LSkrQq1cvWFpaKm2cv8WqVatgbm4uN5dLURS6\nd++O+Ph4iEQibNiwQYqDVN74p0+fYseOHRg7diwiIiKgp6cHVVVVhIWFISsrC0eOHJGS3fn8+TPy\n8vLQo0cPOoSZnp6OixcvSoXA58+fDzabDTabjczMTKlw6e+//w4ul4v+C/v/sKOtM10HG65swKJF\ni2h2KEIITExM0LJlS2zatInujRsxYgTMzc2hrq4OdXV1+Pr6Yvny5T8sJyQPYrEYubm54PF46Nev\nX4OC2rt27aKp9CQICwvDtm3bANQ988bGxo1igKkP1dXVEAgE9dIF/m/gH2v4gG/0+GY0kPObQKCd\nqY28u3n0d1+/fo2oqCj4+fnRL+f58+cRGxsLU1NTLFy4UKHXRVEUGAwGJk+eTL+Ezs7O8PPzg42N\nDQwMDNCyZUvMnDkT58+fl1pJXr16Fc7Ozj98zRIS3W+LCKZOnYrmzZv/cJP4+/fvYWZmJkUu/D0o\nisLKlSthZGQEgUCgcIytra1CFWt5WLRoEfh8Ptq0aQMbGxvs3bsXJ0+exK5du7B27VrMnTsXGRkZ\nNNUXIQTGxsawtramFS40NDTA4XBgb2+PZs2aITQ0FJqamujZsyfGjx+PWbNmYdWqVcjLy8OxY8ew\nefNmdO3aFYaGhmjTpg32799PG4lx48ZBTU0Nw4cPR3R0NAYOHKhUDqO4uBiurq6YMmWK1HaRSIRN\nmzbB1tYWHh4e4PP52LVrl1KN6t9j586daNmyJYC658jHxwchISHYtGkTrKys6GsYP368wiZ7SUFU\nXFwcnj9/DoqiYGlpKSWVc+jQIZiZmWHgwIE/RU+1fPlyCIVCudRaVVVVCA0NxYgRI7Bz507Ex8cD\nqHuGXrx4gd27d2PChAmIjo4Gk8mEQCBA27ZtkZmZiYULF4LJZMrkiB8/foycnBxERkbS7+DSpUvl\nMpOcPXsWMTEx4PP50NbWlqkq3LJli5QQ78842t/j+fPnmDBhAtzd3aGpqQlCCLS0tJCYmIiTJ0/i\nxYsXmDNnDtzd3Wm1eVtbW0yePFnpRvOGUFJSgqFDh4LNZmPp0qX1zh179uwBh8PBpUuX8ODBA3C5\nXCmy7DFjxjR6xV4fMjIykJaW9sv29yP4Rxs+oE6tIfd6rlxhSL0sPdjl2EEvSA9cM67MRCMWi+mK\nIon3DNRNKhLV51mzZsl9+S0tLWkNurKyMhQUFNDeM5vNRmhoKKKjo+Hi4gIDAwNERkZi2rRpKCws\nhLGx8Q/Rd1EUhdjYWClGihMnToDP5zeabf17nD17FhwOR2511ufPn9GlSxe4u7tj3LhxMjJDEty9\nexdCobDRye6CggKw2Wz07t0bXC5Ximv09evXGDFiBIyNjdG3b18kJibKVCJWVlaiqKgI9+/fx/nz\n51FQUIDY2FgEBQVh+vTpGDlyJHr06IEmTZrAwMAAGhoaMDIygqGhIVRVVcFgMCAUCuHq6kq3Kbi5\nuSElJQUcDgdxcXHYtGkT9u/fj7Nnz+Lu3bt4/fo1ysvLQVEUSkpK0KRJE4wbN07htZeVlYHH44HF\nYkFLS+uHyvcHDBiAefPm0b+LRCIsWbIELBYL5ubmWL16NcRiMczNzWUq+d6+fYvu3bvLbZMYM2YM\nxo8fj9LSUvTp0wcWFhYK+VEbiyVLlsDS0lLuc/Xp0yfY2toiNjYW1tbWiI2NBYfDAYfDQWxsLCZN\nmoR9+/ZJEWpLiMv37NmjMIS5e/duuU4FRVE4evQoQkND6RaXyspK9OjRg6Z/oygKmZmZsLCwkCnu\nyLubB93puiAT6jd43+rxKYNBgwbBzc0NVlZWUFVVhbq6OhwcHDB06FBcvXoVW7duRVhYGLS0tKCm\npla3Cu3fHzdu3PjpwpLbt28jNDQUnp6ecpU3JNi/fz/NRtSnTx+pz4qLi2FiYvLLjPKNGzd+anHw\nK/CPN3zf4s67Oyh4WIDtd7aj4GEBXWa8evVqcLlchcrHt27dgqurKzp27ChFOn379m0kJCTQYZBv\nq6I8PDwUKmw/efIEy5cvR7t27WBoaAgPDw907NgRnTt3psVunZ2dMWXKFBQWFiqdR9qyZQvc3Nxo\nb6uoqAh8Pv+XTVJz585F06ZNpbw5iSDsoEGDUFFRgfbt2yvsx5o+ffoPe2oSYdvk5GSw2WxkZWVh\n4MCBMDY2RlpaGk0rdvbsWTg5OTX4wn/48AEmJibYuXMn+vXrByMjI7Rr1w4HDx6U8m7FYjFKSkrw\n559/wsfHB2FhYeDxePD398ecOXOQmpoKPT09BAUFISYmBv7+/nB0dASPx4OWlhadEzQ2NkazZs3Q\nsmVLJCQkYNCgQZgwYQJmz56N1atXo2vXrvDz80OrVq3QtGlTCAQCtGrVqlEq7VZWVnIr7d68eYPm\nzZtDQ0MD06dPh6enp9T1rVixAmw2G6NHj5ZrEK5fvw4ejwehUIj+/fvX2y/5I8jJyYGVlRWuXbuG\ngoICTJ06FW3atIFAIICxsTE0NDTAZDKRn59PC0TLw8uXLyEUCjFo0CD07NkTLBYL7u7uckOY30Is\nFtfb4rJ//34EBwejuroaPXv2hI+Pj0JHctb8WQgcEkg72owZDJDxBJqTNKGXpQeHxQ7IvZ5LK7Ar\ng65du9LVvyKRCHv27EF8fDw4HA4IIdDR0YGvry+mTZuG/Px8JCQk0EK7BgYGaNeuHY4ePfrDyisU\nRWHbtm0wNTVFjx49FF77oUOHoK2tjREjRsh8JonK/ApUV1dDR0fnb5VA+q8yfIpQW1sLe3t7GBoa\nKpxoKisrMXToUJiZmcmQST948ABJSUl0Q29xcTFCQkLqVaWWoKamBr///jsmTJgAb29vGBoawtnZ\nGc7Ozujfvz+aNWsGPT09BAcHIyMjA8eOHZP7B3///j24XC4uX74MoO4FCQ8P/6ky8O9BURTatWuH\n1NRUUBSFBQsWgM1m0/p1FEWBzWYrJLX19vb+oXyQBG/evIGbmxvMzMygoqICHx8fGfkcsVgMCwuL\nelWsP3/+jOXLl0MgEEBXVxdZWVkNrohTUlIQExND9/NFRkbSn8mTMgLqVnGBgYHo3r077t27h3Pn\nzuHAgQPYvHkzFi9ejGnTpmHEiBHo3LkzNDU14ejoCE1NTQiFQhgaGkJFRQUqKip0eX3z5s0RHx+P\nXr16YcSIEcjMzMTixYuxadMmrF69Gkwmk15tft9UTlEU7O3toaOjAzc3N7x8+RI3b96En58fAgIC\ncOvWLbnX/eXLF/Tr1w/q6upSxVI/iw8fPuDIkSPIyspCfHw8jIyMoKqqiqCgIIwdOxY7duzA06dP\nQVEUNm3aBDU1Nak80rd48uQJZsyYAT09PWhpadEhzIZ6x2pra7F582a4uLjAy8sLu3btkmscq6ur\nYWRkBH9/f7Rr167eCdfX15cOf955dwd77u0BcSHIOZjTIBenIri4uCicl8rKyrBs2TK6eIcQAiMj\nI0RFRWH69OlITU2FUCiEqqoqNDU1ERwcjI0bN/5QcczXr18xduxYMJlMzJ07Vy4RQNOmTcFgMGRE\niT99+gQmk/nLGtEtLCx+Sn3iZ/GvMHxAnVfH5/Ph7e1dbzz7yJEjEAgEGDlypEyRy+PHj9G/f38Y\nGxvDxsam3uZgRXj37h1mzpwJfX19cLlc2NnZYcCAAcjMzMTIkSMREBAAPT09BAQEYPz48Th8+DC+\nfv2Kbt26YeTIkfR+pkyZ8lN5PUUoKSmBhYUFfHx84OvrS4dzgToHQCgUyv3eixcvwGQyf9jrvH79\nOjp27AgWiwUXFxf4+PjQ4eLv+4/GjRuHMWPGSG2jKAoXL15E7969YWRkhI4dO2Lv3r3g8/m0s6AI\nK1euhIODA0pLS1FWVgYtLS2ZPs2DBw+Cx+PRL3ZlZSUiIyORnJzcYL9gXFwcJkyYIONUiUQivHr1\nCuPGjYOxsTHCwsKQk5OD1atXY86cOZgwYQIGDx6Mrl27wsXFBSwWCw4ODuByudDU1ISWlha4XC4c\nHR3h5+cHT09PqKiowNXVlSZn6N69O/Ly8nD8+HFcu3YNT548wadPnyAWi3H8+HFYWFigT58+GDVq\nlNTz1RiUlJTg+PHjyM7OpkmTGQwGmjdvjlGjRmH79u3466+/MHv2bNjZ2ck4Mw8fPgSXy4VAIMCz\nZ8+kQpiS62axWIiPj1cqL1pVVYVVq1bBxsYGQUFBMpW13+Ovv/6iVd3re58k5/ntM56fnw8tLa0f\nDvNJxGeVjfq8evWKrjTX0tKCiooKBAIB4uLi0K9fP7i5udG9qC4uLsjOzm50ccyDBw8QHR0NJycn\nmWhSbGwssrKywGazZZzcqVOn1luk1BhYWlr+P8P3K0BRFEJCQmBvb9+gZ1tcXIx27drBw8NDbnXR\nixcv4ODgAF1dXaSmpjaoJC7vXDgcDh4/fozr169j5syZaN68OfT19REREYHp06dj1apVyMjIQEhI\nCLS0tKClpYVhw4bhwIED9IT+s3k9eTh79ix4PB50dHRkwmqrV69GYmKi3O8tWrQISUlJjT7euXPn\nEBsbC4FAgHnz5uHr16+0sK2NjQ0SExPh6Ogo5Unevn0b5ubmdJhy8eLFcHd3h42NDbKzs/H27Vt6\n7MqVKxEWFqZw4vv999/BZrPx559/0tv09fXBYDBkxq5YsQJ2dnZ48+YNYmNjkZCQ0KDjceDAAdjZ\n2aFHjx4YNGiQwnFfvnxBVlYWWCwWkpKSpBwOoE5DbtOmTfTvFEWhoqICr1+/xr1793D27FkMHz6c\nbsVwcnKCqakpjI2NERoaiubNm8PDwwMWFhZgMBj0alPShNy0aVNoa2vTq81p06Zh8eLF2Lx5MwoK\nCnDu3Dncv38ff/75J44cOYK5c+ciISEBtra20NfXR1BQEIYNG4bNmzfjwYMHCp2BmTNnwsHBQerZ\nffPmDdhsNpKSkmBoaAgmk0mHMH///XdERkaiT58+DYa3y8rKsGDBApiamtIVvw3h3Llz4PF4SElJ\nQUBAQL1jp06dKhPKj4mJgZWVlVLajPJw69atHyLDkODGjRsYOHAgbGxsoKqqCjU1NVhbWyMqKgq+\nvr7Q0tKCqqoqzM3NMXToUKUZkyiKwp49e2BpaYmOHTvSUZ4uXbpg48aNOHXqFNhstpRh/Pz5M9hs\ndoOsL8oc+1s6ub8D/xrDBwCXLl0Cm82GiYlJg+W3FEVh9erVYLFYWLx4scxLJ6F7GjVqFIyNjdG/\nf3+Zyao+dOnSBbm5uVLbvnz5gr1799L0XwKBAImJiTAxMUFmZiamTp2KgIAAqKiowM7ODiNGjMDe\nvXvlMlY0FmKxGDNmzACXy8X+/fuxYsUKuLm5SYVMevbsKVU2/y3Cw8OVllSRCIY2b96cbiGR5/Hm\n5uaCw+Fg6NCh4HA4tIdJURSsra3RsmVLGBoaonPnzjh+/LjcyVYS5pbX0/bs2TPweDyZz+zt7aGl\npSU35DVy5EgwmUy0bdu2QU7IiooKWFlZYdq0aUpXcZaWlmLy5MlgMpno168fnj9/jtraWhgZGdVb\nEPX06VOwWCwYGxvD1dWVlrjasmUL+Hw+Bg4ciE+fPuHkyZOwsrJCz5498eTJEzx+/BhXr17F8ePH\nYWZmhrFjx2L27NkYP348+vbti4iICDg6OoLJZNIViBKhVkNDQ1hbW8PPzw8xMTHo1q0bBg8ejPT0\ndMydOxdr1qzBrl27cOLECVy/fh1PnjxBSUkJMjMz4ejoiEuXLiEnJwfNmzcHIQTR0dEIDQ2Fv78/\nqqurIRKJ0LlzZ8THx9cbSSgtLUVWVhY4HA7at2+vVI8aUMcGJGELkUg1KXJiJaHkbw3cs2fP6LaE\nvXv3KnXM76GM+KyyEIvFKCgoQMeOHcHj8ehqUTs7O7i4uNDhdRMTEyQkJNDyUfWhoqICU6ZMAZPJ\nxPTp05GZmUnn+CQctocOHaLHz5w5E126dAFQd8/uvLuDA38ewPY723HgzwNKhYMfP34MU1PTn7gT\nP49/leED6gxO8+bNlRYvffjwIXx9fRETEyM18UyYMAHTpk0DULdClGiVJSUlKUXUunLlygbDAo8e\nPUJwcDCEQiEYDAZ8fX1hYWGBnj17orCwENOnT0dUVBQMDAzg4eGBtLQ07Nq1q9Ge0tu3bxEVFYXg\n4GDaIaAoComJiVIisFZWVnK5GCUk0g3lFcRiMfbu3YumTZvC0dERGzZsaNB4SIRtR4wYARaLhc6d\nO8PFxQVMJhN+fn54//59g9e3a9cueHh4SBnGsrIyeHh4SFVJShASEgI+ny/TgC0SidClSxfweDx0\n6tSpwRCnhNBcXt64IXz8+BHjx4+HiYkJOnToACcnJ7njJPqQxsbG0NbWxsePH2FnZydV6l9SUoJ+\n/fpBV1cXxsbG2L9/v8x+Kioq0K9fP4SEhCApKQkuLi7Q1dVF06ZNMWjQIKxduxa3bt1CbW0tKIpC\neXk5Xr9+jbt37+Ls2bPYv38/Nm7ciEWLFmHq1KkYPnw4kpOT0a5dO4SGhsLDwwNCoRB6enr0alPS\nmuLq6gpCCHr37o3hw4fDwcEBzZo1Q0REBNzd3VFYWIj79++jqKhIykF6//49JkyYABMTEzrPqgwk\nxOnm5uZSueI+ffrIfR6AukpvGxsbKUMhoRDs3bs3Vq1apdSxv8fYsWPpeeRXo7KyEqtXr0ZERATd\nJC/hAjY2NoaKigp0dHQQEREhV4/wWzx9+hTx8fEQCASwtLSk78P58+fBZrNRUFBHwP3161dwTDmY\num+qwkp7+8X2WHt9rcICoFWrVqFjx46//oY0Av86w/fXX3/BxMQE1tbWSntpNTU1SE9PB4/Hw759\n+wAAs2bNkumVknizbDYbCQkJ9ZLDPnr0CAKBoF6P6/fff4dAIKBFcnv27AmhUAgPDw8YGxujQ4cO\nWLVqFf766y9cuHAB2dnZaNmyJRgMBlxcXJCSkoK8vDyp0N/3OH78OAQCATIyMmQe/K9fv8LJyQm5\nubk044i8892wYQPatWun8BgikQjbtm2Dm5sbPD09sWPHDqVzk5JVi6QNQV9fH/Hx8XTT77cVqPXt\no1mzZtiyZQv9e8eOHZGUlCT3erp06QIHBwep4iWxWIzk5GRERETg06dP8Pf3r7fp/+HDh2Aymejc\nuXO9Ic6G8O7dOwQEBEBbWxvDhw+XUuE4c+YMXFxc0LJlS4wdO5YuM1+7di2ioqLocadPn6bbBVxd\nXdG8eXPs2LEDy5YtQ+/eveHu7g4dHR24uLhAR0cHK1aswPXr15W6tw3h8+fP2LFjh1QV5rhx43D4\n8GEMHjwYNjY22LlzJzQ0NLBkyRL6vdLV1YW2tjYiIiLQrFkz2Nvbg8PhQENDg+bUVVVVBZfLRfPm\nzZGYmIiUlBRkZGRg7ty5WLt2LXbt2oWTJ0/i+vXrePr0KUpKSlBVVYXevXujSZMmMrnGI0eOKCSf\nHzFihBRBRG1tLQQCAW7fvo3x48f/sPGKiYlRqMLxq/H27VtMmzYN3t7e0NbWpg2hhEhCXV2dFqtW\nVOBz8OBBaGhoICAggE4/XLx4ERwOB/v27UPe3TxoTtGE2kRZcm9lWz68vb3/ds7Of53hA4ChQ4ci\nLi4OQqGwUU3EZ86cgaWlJQYMGICcnBz069dP7rgvX75g1qxZ4HK5aNeundxqNYqiYG5uLpVb+haV\nlZWwt7en6c2OHz8OPp9PrzqLioqwYcMGmlzXyckJw4YNw+HDh/HlyxdcvnwZc+bMQevWrWFkZARH\nR0cMGDAAW7duxevXr1FbW4uMjAwIBAIZeaFvce/ePbBYLGRnZyMuLk7umPj4eLlkzNXV1Vi7di3s\n7OwQEBCAgoICpfuOiouLMW/ePDg6OsLR0RHTpk2Dv78/WrdujfDwcLRo0QJNmzatt+n+W5w6dQpW\nVlY0a0mzZs0UFhQMGzYMnp6eUoZy4MCBCA4OpieE9+/fw8bGRq6nT1EUoqOj0bt3b1haWja6Uf17\nBAUFYevWrUhNTYWJiQlSU1ORmJgIU1NTmhTbxcWFrrSrrq6GUCjE6dOnkZKSAjabjZSUFFpuR0ND\nA2pqamjSpAlycnJw+fJl+l40adLkpypzgboqzJycHDoaER0djSVLlshUYVIUhfHjx8Pd3R0mJia0\nUc/JyYGNjQ3MzMyk8pp//fUX+vbtCyMjI/Tr1w/Hjx/HmTNnsG/fPmzcuBE5OTmYOnUqhg0bhuTk\nZMTFxSEkJATu7u4wNzeHgYEBVFRUoKGhAUtLS3h5eSE8PBwdOnRAnz59MGLECOjq6iIzMxNbtmzB\nwYMHcf78edy9exdcLldqdbh37174+/sDqFMx/1E2JjMzs0alSH4l7ty5gyFDhsDe3h6qqqpQUVGB\ntrY21NTUoKKiAhsbG4wdO1YmxD537lzY2trCxMQE6enpKCsrw5UrV6AfqQ/NqZqNbvJfeHEhve89\ne/bA3t7+lxftNRb/SsP34cMHsFgstGvXTmFvnyKUlpaie/fu4PF4Ul61PEj4JE1NTREbG4vz589L\nfZ6UlITly5fL/e748ePRoUMHAP/Tr6fIQInFYly5cgXTpk1DUFAQ9PX10aJFC8yfPx/37t1DbW0t\nrl+/jgULFiAuLg5GRkbQ1taGQCDAkiVLGizO2bx5MwwNDeVK4JSXl4PBYEhVjlVUVGDRokUwNzdH\nZGQkCgsLlTJ4FEWhsLCQZlXp3r27FCVZdXU1kpKS4OXlhd69e4PD4aBNmzYN7leC2NhY9O7dG2Zm\nZnILgz59+oSjR4+iVatWYDKZsLa2BiEE9vb24PP5WLFiBW7evEmHOCWtD9/rHu7cuROOjo4/FOL8\nHl++fIG+vj7dLD937lzo6OhAS0sLY8aMQUlJCa5fvw5LS0tUV1fj1q1bWLt2Ldzc3OhiBwcHByQl\nJWHx4sW4cOECKioq8OrVK3Ts2BE2NjZS55+dna2QoEARRCIRzp07h3HjxsHFxQUcDge9evXCrl27\nGmR+oSgKY8aMgYaGBq5fv47NmzfDzMwMz549w927d8Fms5Gbm0tzxGZkZPxQ0cOTJ0/g5OSEIUOG\n4N27d3j06BGuXLmCo0ePIi8vDytXrsSsWbPg6emJZs2aoUuXLrRzZWZmRtOI6ejogM/nQ19fH7a2\ntmjVqhUCAwNha2uLjIwMzJs3D7m5udi9ezcKCwtx48YNPHv2DKWlpTKh8U+fPkFfX/+ndDF/FcRi\nMY4dO4aEhATw+XwQQujnhxBCF11Jwt3e3t7Izs5G165dIRQKMWLNCGhlakkZNY/lHjj86DA+lH9A\neU057r2/h0EHBsk1fnl38/DhwwcIBAKlipL+0/hXGj6g7gVv1aoVOBxOoyi2JBg7diw0NDQwc+bM\nBr2TqqoqrFixAhYWFggPD6cNwYYNG+Qmtm/cuAE2m42ioiKIRCKEhYXJUGHVh9LSUuzevRv9+/eH\nhYUFzMzM0LdvX+zYsQPbt28Hl8tFWloaFi5ciA4dOoDNZsPKygrJyclYt24dnjx5ImOoTExMEBER\nIbN9z549tNjp58+fkZ2dDR6Ph7i4OFy6dEmp833//j3mzJkDe3t7uLi4ICcnR4pI4Ft8m58ZNmwY\nVFRUlF717dy5EyoqKlIrGolgbefOnWFoaIjQ0FBERkbC3NycLrawsLBARkYGEhISYGdnB2tra0yb\nNg1v3ryhE/ySPrmvX7/C3NwcMTExPxXilGDfvn2IiIjA3bt3ERwcDB8fH1y7dg0PHz5EXFwc9PX1\naVJsPT092Nvbw9HREQwGA/r6+g1WGxYUFMDKygpdunTBmzdv8OTJE7BYrAZzr9+HMN3c3DBhwgRc\nuHCh0RM5RVFgMpkwNzcHh8OhK6mvXLmCwMBAqKioYNiwYY0mHpfg4sWL4PP5Ssn+nDhxAj4+PlLb\n+vTpgzlz5oCiKJSVleHixYtgMBg4evQo9u3bh3HjxsHGxgZTpkzB0KFDkZSUhLZt2yIkJARubm4w\nNzeHvr4+VFVVabo9Ly8veHt7w8TEBH379sXo0aORlZWFZcuWYevWrTh06BAuXLiABw8e4O3bt78k\n7NwYVFVVYf369WjRogXdPyjJy2ppaSEgIABGRkbYvXs3Dp84DNUMWfmmpyVPAQC33t7Cjns7IKbq\nngt5Yr26Wbrw9PVUmjP4P41/reGrqKiAubk53Vje2KX1uXPn4OXlhdDQUISEhChs6v4WNTU1WLdu\nHezs7BAUFIRNmzaBxWJJTRS1tbXw8vKiKz4nTZqE8PDwH176UxSFBw8eYO7cubC0tKT7vKZOnYqL\nFy9CJBKBoijcu3cPy5YtQ5cuXcDlcmFubo7u3btj9erVuHr1KvT09NCkSROZVpCkpCTMnDkTkyZN\nAovFQteuXZUSvpT0kUkMTnJyMs6dO6d0KDQvLw9sNht2dnZgMBgKV84SFBcXw8rKCkFBQXTT/7Nn\nz9CyZUs4Oztj2bJldL/g0aNH4eLiAhcXF7i6ukqtMCiKwpUrVzBw4ECwWCwsWbIEW7Zsgbm5OV69\neoUxY8YgPDz8l4Q4gTqastDQUBgbGyMpKQlpaWn0qt7W1hYxMTFQV1eHgYEB+vTpA1tbWyQkJKC4\nuBizZs1C165dGzxGeXk5JkyYQFcwN23aVG4V7NOnT7Fo0aIGQ5g/AkdHR7p/8sCBA2jRogXMzMyQ\nk5ODlStXwsrKqt5ctSLs3LkTLBZLbkGPPNTW1oLD4dBl/1VVVTIkzBIycwnu378Pe3t7pfZdXFyM\nR48e4fLlyxgyZAjCw8OxYsUKZGdnY+zYsRgwYAA6d+6MFi1awNfXF3Z2dmCxWPRqUyAQwNnZGYGB\ngWjdujW6d++O1NRUTJw4EfPnz0dubi7y8/NRWFiImzdv4tmzZ/j8+fNPU5t9+PABM2fOhJeXF9TV\n1UEIoX/0Q/ShNUV6taeeqQ6RuG7OkugUXnldV22bvCdZrkZq9NjoX6Lt9yvwrzV8ALB+/Xr4+/sj\nJCSk0SKQd+7cgbOzM0QiEbKzs8Fms7F161alvisSibB161Y4OztDS0sLOTk59B981qxZiIyMpEv+\nBQLBD/F6fovHjx/D19cXbdq0watXr3D06FGMHDkSrq6uMDExoVsrJMl+ibFcuXIlunXrBhMTE2hq\naqJNmzYwMDDA9u3baTJhHR0dGBoaok+fPgplaL7F27dvkZ2dDRsbG7i5uWHJkiVKC2R+j4sXL8LY\n2Bh2dnZwcHDAkCFD5Fam1dTUoHnz5hg7diyePn0KExMT7NixAywWC1lZWTKrmzt37sDY2Bg6Ojr1\nTrb3799HYGAgoqOjMXXqVDg4OMDY2BgCgeCHQ5wUReHRo0fYtm0b4uPj6dYBc3NzdOrUCbNmzcKJ\nEyfoe3bgwAE0bdoUycnJ0NbWhpGRERYsWIDKykp8+fIFLBZLaTaNe/fuISQkBGZmZmjTpo1MCJPN\nZiM5OVmpEGZjcPv2bWhoaCApKYkWhF60aJHUKmfy5Mnw9fVVmpGEoijMnj0bZmZmjaKFA+q4M2fO\nnAmgrkG9efPm9GcikQhmZmZS+b6PHz/C0NCwUccA6pwaZdlyKIrC169f8eLFC9y+fRunT5/G3r17\nsX79eixcuBCTJ0/G0KFD0bNnT7Rt2xbBwcE0C5Kenh7U1NRgYmICGxsbeHt7IzIyEh07dkS/fv0w\nevRozJgxA8uWLcO2bdtw6NAhXLx4EQ8ePMC7d+/krjb/+OMPpKWlgcVmgQyRn7+bd76uQvZm0U16\nxXej6AYMZxrKHe+w2KHR9/A/hX+14ROJRHB3d8eiRYvAZDIbJa3x4sULqV6Tq1evwsHBAYmJiUqH\nZMRiMVq0aAFTU1O4u7sjJycHTCYTT548wZs3b8Dn8386RyRZGS1YsECuN/Xy5UusXbsWnTt3hrGx\nMdzc3DBq1CgcO3aMZq4ZPXo00tLSsHbtWjRv3hyqqqp0ElxfXx/Hjh2r11MTi8U4cuQIOnToACMj\nI/Tu3RsXL178Jd7d3bt3oaqqisTERERFRSEqKkqmr3Hw4MFo1aoVvWqOj4+Htra2wlzCjBkzoKKi\nAjMzswaPLxKJkJiYiPDwcHC5XBgZGSmdI6MoCk+ePJGS2zEyMgKfz4dAIICRkRF0dXXrbdmIiIgA\nl8tF586d8f79e9y4cQNt27aFqakpli1bhoyMDBlS4frw+fNnJCUl0fpwzs7OdAjzP1FwIKmy1tHR\ngVAoxJYtWzBgwAAEBARIGVeKotCjRw+0a9euwfOoqalB//794eHh8UNyOadOnUKTJk0AAJ06dZIq\nYJI4Gt+CoihoaGg0WrsxICBAKdrDX4Gamhq8f/8eDx8+xKVLl3DkyBFs374dK1aswMyZMzF27Fj0\n798fnTp1QlRUFHx8fGBrawsmkwk1NTXo6urC1NQULi4uCAoKQuvWrdGjRw90G9YNGpM15Bqy4Nxg\nPPn0P+wr1aJqTC6cDNWpsmFRMoVAL0vvh2nffjX+1YYPAA4fPgx7e3ukp6fT0ijK4PPnz9DX15fa\nVl5ejoEDB8LCwkLpBO1vv/2GNm3aYN++fTAwMACHw8H69esRGhqKqVOnNupavkVlZSUGDRoEGxsb\npRt6RSIRLly4gClTpsDf3x8GBgaIjY2FpaUl1q9fjz/++INeWQiFQgQHB6NJkyawtrYGi8VC+/bt\nkZOTQxeAvHnzBllZWbCysoKnpyeWL1/+ywmQAaBdu3ZwcXFBVFQUBg4cCHt7e7padsWKFXB0dKSd\nkTdv3oDFYoHBYMhdCUl05DQ0NKChoaGUcRaJRPD19QWDwYC2trZclpHv5XZatGgBExMTKbmd/fv3\nY+rUqWAymZg0aRKWL1+OhIQEucesrKxEWloaVFRUZIgQAODy5cto2bIlzM3NoaenV2/loLwQpqWl\nJYKDgyEQCOgV/q9ETU0NFi1aBA0NDVhYWNAck0Cdo9S/f38EBQVJhYurq6sRFhaGYcOGKdxvaWkp\nWrRogdjY2B9elYpEIvB4PFy/fh0MBkMq39y2bVusWbNG5jumpqZKpTskkEib/Uqtvf8UKIrCly9f\n8OLFC9y6dQunT5/Gjh07kJWVhcjBkVDLkG1dMJllgrLqugrowLWBMMo2wqVXdTl/eQUuZAqB4UxD\nFDws+Dsvlca/3vBRFIXIyEjk5OTAzs5O6Z4asVgMVVVVud7nvn37wOPxMGHChAaLBN69ewdDQ0Ms\nW7YMzZo1w+HDhyEUCqGjo4OVK1f+UFL7jz/+gLu7Ozp37vzDBQFAXQhn8+bNUFNTg7a2NlRVVeHj\n44N169ahadOmMDIyogsRXr58ic2bN6NPnz4wNTWlDYefn58MG/6vRn5+PkJCQjBkyBA4OzvTLB7z\n588Hh8ORCsHGx8cjIyMD06dPpxkmJNi4cSNMTU3x6NEjmJubg8FgKFVBWFpaCjabDVVVVWRnZ8PN\nzQ3p6enYu3cvJk2apJTczsWLF+Hp6Ynw8HCaAKFLly5Yu3atzPEuX74MJycneHl5oVWrVvWe29mz\nZ2lS7I0bN0IkEkEkEuH8+fMYP348XF1d5YYwlyxZgsTERJw9exZubm5o0aLFLyEgrqysxLJlyyAU\nCqGvr4+ePXuCoij07dsXK1eupMeJxWL06dMHISEhUj1lnz59gpOTk9zUxPPnz+Hq6orBgwf/9PM2\nZMgQtG/fXkoN/NWrVzA2Npabu/Xy8mqQE/ZbPHv2TKGu5d8BiqLw7t07nD59GmvWrEF6ejp69uyJ\nqKgomnzA2NiY5geVFLuoe6qDjJc1Yt4rvQHUrfI0p9W1OKy/sR4AsOjSIrmGz2CGAbbf2f533gYa\n/3rDB/yPLMv+/fthbm6utKdoaGiokC7s7du3iI2Nha+vr8JePQkcHBxgaGiIO3fu4OjRoxAIBMjP\nz0eLFi0gFAqxZMkSpcMoGzZsAIvFwsqVK3/aSz9//jz8/PygoaFBq8vPmzcPUVFR0NHRodk2rl69\nihcvXiAzMxNCoRA+Pj6YM2cOcnNzMXDgQDg5OUmp1F+6dOmXGkJJAcKLFy9oYdvMzEyoqqpK9Vfd\nvXsXfD4fVVVVKCsrA5/Pp3ssf/vtN/D5fJpnsGnTprC2tq5XBUKCvn37wtTUFJaWlrSBU1VVpVW/\n8/Pz8fLlS7l/j5KSEgwaNAg8Hg+bN2+mx4jFYrBYLKlWk6qqKowfPx4cDgfbtm1DUFCQUiQMRUVF\n0NPTg62tLRgMBhgMBl2Fef78ebnO29u3b2FkZISKigrU1NRgzpw5YDKZyMzMlCFvVwZfv37F3Llz\nIRAI0LJlS3h6emLIkCH09Q4bNkyGNUVCGhAWFiaV23v69Cn4fL6Uk3rlyhUIBALMnz//l6xOz5w5\nA319fWzf/j8TcWZmpkLB1ZiYGKULaIA65zg6Ovqnz7M+VFRU4N69e8jPz6cltuLj4xEQEECTnevr\n60sVq6ipqUFPTw8cDgd2dnbw8/NDXFwcBg8ejOzsbOzYsQO3bt1CRUUFnj59isELB0M9Q11uleaH\n8rrV7JnnZ7D+xnpUi+qc+M47Ov+/Fd8/BT169MDEiRPRs2dPpXv7hEJhvazsFEXRQqGrVq2S+0JS\nFAUrKytERETg9evX4PP5UuX2Fy9eRJs2bcDn8zFv3jyFjApfv35Fz5494ejoqFRVZX3nfPz4cYSF\nhcHCwgKtW7eWG1oaN24cgoKCoKWlRdNQ2draIjMzU25ByLt377Bjxw4MGTIErq6uYDAYiI6OxowZ\nM3Du3LmfLteWlJwDdZV8ampqiIuLg5OTE1JSUlBbW4u0tDRkZGTQ31m+fDkiIyOxZ88ecLlcKeme\ntm3bwtPTU4ZBori4GIcPH8b06dMRHx8PLpdLl3inpKTAwMAAZ86cwfXr1+VKGUkgj0fzW1y9elWK\nvPjKlStwcXFBu3btUFRUhMePH4PNZtd7354+fYrFixejRYsWdNP24MGD4e7uDjc3N+zevbteIxEe\nHo5du3bRvz9//hxxcXGwt7dXOvf86dMnTJ06FWw2G506dcKVK1fQtm1bdO3aVaqaOT09XUpgWQKR\nSIQePXogMjJSSorp8uXLYLFYuHz5MvLz88FisZTmilUGb968gYqKCt3qJBKJIBQKFRbKJCcnyw2B\nKkJWVpYM81NDEIvFePv2LX7//Xfk5uYiIyMDSUlJaNGiBTw9PRWuyjQ1NWFoaAgzMzO4ubkhPDwc\niYmJGDduHFasWIHjx4/j1atXDbahVFRU4NChQxg6dCgcHBzA4XAQ3SMaapPks7Q0Xd0UR/86KtXH\nl3YoTWEzu26W7v/L8f1vQ0I4e/v2baV7+9zc3JRaEdy7dw+enp6Ii4uTCZ1t374d5ubmCA8Przev\nd+PGDXTs2BEcDgczZsyQypXdunULDg4O6NWr1w+LN1IUhX379tH0UOvWrUNNTQ2ioqJkVhXPnz8H\nh8MBm82GqakpHBwccOvWLaxcuRLt27eHkZERPD09MW7cOBQWFsqdnIuLi7F7924MHToUnp6e0NfX\np1Xqf//990avKk6cOIEmTZpALBajQ4cOaNu2LYRCISZMmIDo6GhERkbC1tZWyrjV1NTQRSTfs+sM\nGDAAPj4+GDFihEK5na1bt8LV1RXGxsa0IejevTs9AX4vZSTBn3/+iYiICHh4eODChQtyr2fmzJlI\nTU1FdXU1MjIywOFwsGXLFtpQTZ06VYYtpL4Q5r1792BiYoKPHz/Sf2tPT094eXnhwIEDcg3gqlWr\n5PaZ7t27FxYWFujevbvCqte3b99i7NixMDExQXJyMh48eACKopCcnIyWLVvKPBMzZ86UkZr69rq6\ndeuGFi1aSEU+8vPzYWBgAC6Xq3QeW1ksWrQIjo6O9Pt48OBBmf6+bzF27FhkZWUpvf+EhARs2LAB\nZWVluH//PvLz8zF37lykpqaiffv2Da7KdHV1wWazYWtri2bNmqFt27YYOHAgZs6cid9++w03b978\n6XYaiqJw//59zJ8/H9HR0dDX10dwcDCysrKQl5eHfv36wdDIEAYTDBrF1qLo5/9Vdf5NGD16NPr1\n64fc3FylevuCgoJkBBkVoaqqCqNHj4ZAIKB7pD58+AAej4ejR49CU1NTqX69e/fuITExESwWC5Mm\nTcK8efPAYrGkqJ0aA5FIhO3bt8Pd3R0eHh7Iy8ujz6G2thYGBgb48OEDamtrsWfPHsTGxsLQ0BC6\nurq4ceMGRCIRIiMjMWHCBHqftbW1OHv2LDIyMuiij7Zt22Lp0qUKZVE+ffqEffv2YeTIkfDx8YGe\nnh6axL90nAAAmC5JREFUN2+OyZMn4+TJkzLCq/Kug8/nIyUlBf7+/qiqqsKbN2/g6+uLbt26oX//\n/lBRUZGSmTpx4gQYDAbs7e1RUlKCwsJCzJkzB126dIGJiQlUVVUhFAoxfPhwuXI7a9asAZvNlgp/\nzZs3T6rHSyJl9OHDB1RWVtLKC/Pnz6833BseHo4FCxbAzc0Nbdq0kWKaoSgKNjY2uHz5Mr58+YKd\nO3ciOTkZHA4Hrq6uGD9+vNwQZq9evaSIEMRiMXbu3AkXFxf4+fnh6NGjUgbww4cPYDAYcifQsrIy\njBkzBmw2G8uXL6fvy/PnzzFkyBAYGxsjJSWF7vGjKAojR46Ev7+/XOds0aJFUvfte9TW1qJLly6I\niYlBVVUVamtrMXjwYPD5fNja2v5wS4wi+Pn5Yf78+XB2dgZQV0BVHxH1/PnzkZaWhpqaGrx+/Vrh\nqszCwoImiJasyggh0NDQAIPBgJmZGVxdXREWFoZu3bphzJgxWLZsGY4dO0Yrdfwn8fnzZ5r8QigU\nQigUon///ti9ezc+ffqE/fv3IzIyElwuF5MnT0ZRURGmHZgGlXSVnzJ6+jP0kXtdtkjr78L/KcP3\n6dMnsNls3L17V25vn0TsdNGiRejbty+MjY3pB7dp06ZISEhAVlYWCgoKFObkTpw4ATMzM6SlpaFb\nt24YOnQojhw5Ag0NjUaR1V67dg2WlpZQU1NDv379lFIp+BY1NTXIzc2Fvb09/P395Xr9V65cgZ2d\nHc3pGRAQgPXr12PGjBno378/Pe7du3cwMzOjGdq/R3FxMbZu3YqkpCTweDzY2NggJSUF+/btU+iV\nlpaWoqCgAGPGjFFapb5169ZgMBhSfY/l5eXo0KEDvL29wWQyaTLdpUuX0qtMbW1taGlpwd/fH6mp\nqdiwYQMmT54Mf39/qev8Fh8+fIChoSEEAoFUTnj37t0ynKajR4+Gi4sLbGxs0L59+wYp4kpKSqCh\noQEWi4WNGzfK/F127doFLpdLV2G2aNECixcvblAMVULs/X0OW9JXam9vj5CQEClnrmXLlti2bZvC\nfd6+fRuBgYHw8PBAXFwcTExMMHr0aJne0+zsbLi4uChk5Fm7di2Sk5PrPf/a2lp07NgR0dHRiI6O\nRosWLVBaWoqhQ4ciLCzsl7Gb/PXXX2Cz2aiqqoKZmRn27dsHfX19bNu2DfPmzUNaWho6dOiAwMBA\nelX2bXhRQvelo6MDFosFGxsb+Pr6onXr1ujfvz+mTp0KDQ0NXLhwAZ8+ffpbm7bFYjGuXbuGrKws\nBAcHQ19fH9HR0ViwYAHu379PV3Tm5OTA1tYWXl5e2LBhA6qqqkBRFFatWgV9Y32QCT+32tPL0lOo\n1vB34P+U4QPqPPY2bdrgjz/+oHv7vnz5guzsbNjb28PBwQEDBw7E0qVLERERgalTp+LMmTM4f/48\nNm7ciNGjRyMkJARMJhOpqalyK+E+fvyI4OBgaGho0BWgCQkJStOSXb58GdbW1hg8eDAePHiAQYMG\nwdjYGMOHD29QnLaiogKLFy+GUChEREQETp48KfPi1dTUYNeuXXBwcIC2tjaGDh0qtVIKDAyUyX2d\nOXMGXC63wZJuiqJw8+ZNzJo1C+Hh4dDX10dYWBiys7Nx48YNhZPA169fceTIEUyYMAGBgYHQ09OD\nv78/xo0bh0OHDuHcuXMwMjKCmZmZ1D7Ky8tx9uxZWsdQIBDQE1ObNm2Qm5uL1atXw8rKSmri3Lt3\nL3x8fNC6dWu559OzZ0/o6+vL5Lry8/OlDF9RURESEhKgq6uL4ODgBvMoN2/ehLW1NUxMTOiqz29D\nmG5ubtDW1oaXlxd27tzZ6JL9Ll26YPbs2XI/q62txfr162FlZYXIyEhcuHAB69evV0hODtSF2Tt3\n7gx9fX3o6elh0KBBMue0evVqWFpa4tWrVwr389tvvyklRfPkyRMwGAxYWFjQzo9IJEJcXBxdIdoQ\nKisr8eLFC5w5c0buqszQ0JAWf/6WoUTCkCMQCODi4oLmzZsjISEBo0aNQlpaGtzd3fHkyZMGoxM3\nb95UKDP1v4H3799jy5Yt6NGjBzgcDhwcHDB06FAcOnRIqojor7/+wtChQ2FiYoJOnTrh7Nmz9P39\n9OkTOnToAC6XCz6fj9kHZkNnus4PGT0JV+c/Cf/nDF9VVRUsLS1x6tQpTJo0Cf7+/hAKhejWrRvO\nnz8v9WINGjQIS5Yskbufp0+fIiMjA0wmEzNnzpRqa/jy5QssLCwwfPhwaGhooGXLljh48CBCQkLq\nPTeKojB//nyw2Wzs3LlT6rNXr15h2LBhMDY2xuDBg2UMkEQxgsfjoU2bNnI5HB8/fozx48eDx+Mh\nODgY3t7eWLdundSYt2/fwtDQUG4Obs6cOWjWrFmjPO+vX79i//79GDJkCGxtbcHj8dCzZ09s2bKl\n3lVseXk5jh8/jokTJ8LPzw8qKiqwsrKCgYEBOnTogO7du9NyO15eXkhMTIS2tjYMDAzAYDBgbm6O\nQYMG0X8XCf2WBJcvX4ajoyPdyPwtLl68CB0dHfTu3Vvms3Xr1qFbt24QiURYunQpWCwWxo0bh+Li\n4nqljGpqaugikOjoaKSnp2PXrl0yIczCwkKYmJg0qmfsW9y6dQs8Hq/eybmmpobuZ2zRogX09PRk\n2mIuXLiANm3agMfjYfbs2fjy5Qvev3+P5ORkmJmZYdeuXaAoCrt27ZKrbfg9Dhw4gJiYmHrHXL9+\nHWZmZpg5cybatm2L+Ph41NTUQCQS4enTp3BxcUGXLl3oVVn79u2lVmUSBhNJ0YdEjUBCSO7j40OH\n8vv3748tW7Zg7dq1UFNTU5iLleDOnTtKG7NNmzahc+fOSo39Ffg29eDj4wNDQ0O0a9cOK1askIkS\nSIrb2rRpAxaLhbFjx8o8a+fOnYNQKISNjQ38/PzoPO/Ciwsbbfx0pusg52LjWLP+N/B/zvABwJYt\nW+Dr64uJEydCXV1dYcHJuHHjGkxoP336FFFRUYiMjKS9qdTUVCQnJyM9PR2BgYHw8/NDWFgYdHV1\nFVIyffjwAa1bt0bTpk3x5MkTuWOAurCjpKigT58+uHr1KiZPngwWi4UuXbpIFXcAdU3BeXl5iIyM\nBIvFwvDhw+kQB5vNlgnLrVq1Sqb/TQKKohAXF4e0tLR670l9ePz4MZYtW4a4uDgwGAz4+PggPT0d\nZ86ckXIeqqurce3aNSxduhQ8Hg8cDoeuMNXV1YWWlhYcHByQmpqKPXv24MOHDzAyMoKhoSGMjIyw\naNEixMTEICIiAh8/fsSNGzfA4/Hw9evXOrq4W8dg5GsEwwBDKeVokUgEGxsbuSFDoE7yKi0tDb6+\nvggKCpJaKUukjFavXi31ndu3b6NJkyYIDQ1FZmYm9PX1oaurixYtWmDRokVSk9OOHTsQHh7+w/cX\nANq0aaPQYfsWVVVVWLJkCb3CvHnzJk6cOIHw8HBYWFhg6dKlcg3oqVOn4OTkhGbNmoHJZCpFGXbq\n1CkEBwcD+B96rsePH+PMmTNYt24dEhISoKWlBQ8PD3h6esLc3Bzq6upQVVWlV/CSlZm2tjb4fD6c\nnZ0REhKCzp07Y8SIEVi8eDEOHjyIP//8E6WlpXJXhzdu3JASWj18+DA0NTUbLGJ7//49TExMGrxO\nABgzZsx/THxWgpcvX2LNmjXo2LEjjI2N6WKzU6dOyXVMy8vLsWrVKri6usLZ2RkrV66UmYtEIhGm\nTZsmRWr/vQOcdzcPell60J+h32BOT5Ee3z8B/ycNn1gsBp/Ph5mZGXbs2KGwt6++SrRvIRKJ0L17\nd4SHh+PkyZPg8/nYsWMHTE1N8e7dO9TW1tJxfwmB8rf4/fffYW5ujlGjRim9mrp37x78/f1pXa3v\nQ5MPHz7EmDFjwOFw0Lx5c2zdulUqL/nHH3/AwsJCZr+xsbFSvU3fo6SkBNbW1sjL+/kHurq6GqdO\nncKYMWPg6OgIXV1dWFlZwcLCAlpaWnB1dYWDgwNcXV1x9uxZVFRU4MGDB+DxeCgvL8eZM2dolXpJ\ny4WbmxsWL14MKysrjBo1CsOGDYOdnR0ePHiAzomdETclDvaL7aGbpQsyjoCMJ2DMZNDK0Z1mdIKm\nnqZciajS0lKwWCwYGRkhNzdXbljzWymjqqoqDBgwADo6OjA1NQWLxUKnTp2gr6+vsFijbdu2WL9+\n/U/d14sXL0IoFDZIriBBbm4uTUpgYGAgl9/0e1y4cAF6enpgMBiYMWMGysrK8ObNG9y8eRN79uzB\nvHnzpCoYhUIh1NXVaYFZFRUV2phJ9OF4PB68vb0RExODPn36YNKkSXB3d0dERASePHmCqqoq3L9/\nHxwO54ep/kaPHi1VqNWhQwdERUUhPT293u+JxWKoq6sr9X7GxMQoLYKtLKqqqnDs2DGMHDkSLi4u\nYDKZ6Nq1KzZs2FAv1++LFy8wduxYsFgstG7dWiH94MuXLxEaGgovLy9wOBzMnTtXYVi5vKYcuddz\nFSqwOyx2QO713H9UTu97/J80fCdPngSbzYZQKKSVz+X19i1btkxhQ+v3EIlEtM7bihUrwOPxZHj6\nevfuTXNZfv36FSKRCNOnTweXy1VYOPI9nj9/jpSUFBgbG2PIkCG4c+cOzWTSvn17ZGdnIywsDGw2\nG6NHj1bYXL9q1Sp0795datvnz59hYGDQIO3Y1atXwWazG2zclweRSIS7d+9i/fr1GDJkCPz8/KCr\nqwtHR0c6hNmiRQuwWCxwuVwYGxtj586dUt6pt7c3jh07Rv/+5MkTmJubo0OHDrC0tERMTAy9qrKy\nskLv3r2h31QfWlO1Gk7SjydQm6gm5alSFIUdO3aAzWbDwMBASiX9e3z9+hXTp0+nxWD19fWRkpKC\nc+fOQSQSYePGjbQO4/d4//49DA0NfwlBdEREhFyqs28hqfh1dXWFqqoqli5diqysLLDZbCQmJuLq\n1at48OABTp06hdzcXEycOBFJSUkIDAyEuro6WCwWLf4qWZVJDJqenh64XC4cHR0RFBSE6OhoGBkZ\nIScnBwcOHMDdu3dRVFSE1NRUODk5KYxyVFZWokWLFnR4Gah7fzkcDu7du9eoeyIWi2FmZkav0ouK\nimBkZIRTp07B1ta2wfwhn89XihvUzMys3qiNMqAoCg8fPsSiRYvQqlUrGBgYwN/fH1P/P/a+O6zJ\nbPv6ANJrGgm99yqgICBIFRFEbKAOKCpKFXtXUEQs2LCCYu+9ix3LKDZs2B0L6lgBAekk6/vDL+/P\nmACBce7MvbKeJ4+SnLwtydnv2XuvtWbOxNWrV5vsDufxeLh06RL69u0LGo2GkSNHNqnKc+DAAWr+\nYDKZYs9FAHDvwz0cfXIUO+7twNEnR/81PL3m8MsFvpqaGhgaGuLIkSMIDAzEkiVL8OnTJ5Hcvq1b\nt4pl+8LH6NGjISsri/bt24tMdZw7dw6Ojo6IioqCnp4eOnToAA8PjyabAvh4/PgxoqKiQKfTMWHC\nBIG7vEePHiExMRGKioqQkZGBo6MjLl261OT2IiIiBCSkgG8NCAEBAWKd66pVq2Bra9tkLYnL5eLh\nw4fYvHkzRo0aRdntmJiYoH///li4cCHy8vJEBtozZ86ARqNhzJgx8PDwoDo0MzIyMG7cOKpDsKio\nCAYGBlixYgXq6uqgq6uL06dPo76+Hr///jscHR0h5ykHMrXlBfkl+Uvwxx9/oFu3brCwsEDHjh2x\nePFioWN9+fIlli9fTnGhjI2NISsrC1VVVaGJ8rfffsPq1atFXq/MzEyhm5HW4uzZszAxMRGYIKur\nq/Hq1StcvnwZCQkJYDAY4HA46NSpE+h0OthsNlgsFqXa871Hm7S0NNTU1KiVoZWVFaKiojBjxgxs\n2LABqamp4HA4GDhwoMgbgx9F3ysqKhAcHAxvb+9mqQpVVVXw9fXFb7/9Rp3Ppk2boK+v3yJnk7y8\nPNja2lJ/p6enU7qrhoaGzaZs7e3thfigP6KkpATKysqtMp+tqKjAoUOHEBcXB0NDQ2hqamLIkCHY\ntWtXo92y36OmpgabNm2Co6MjjIyMsHTp0iZvYquqqhAfHw99fX0MGDAARkZGLb6Z+G/FLxf4tm7d\nCl9fXwDfCtbq6uooLS3F+vXrhbh9/OAoDu7cuQMmkwl3d3doaGiIvCOrrq6GoqIi9u/fDxqNBgUF\nBcyYMaNJ7s6dO3cQFhYGJpOJlJQU6gdQXV2NLVu2wMPDA2w2GxMnTsTTp0+prk6+0erFixdFbldf\nX5+S7+IjPDxcKBg2Bh6PhwEDBlANIN/b7YwdOxaenp5QVlaGgYGBSLudpvD8+XOw2WyBVV1ZWRn2\n79+PmJgY6OrqQkJCAn379gWbzRa4yTh27Bj09fWpVdPOezsx5vgY3Hl/h/IPSz6XTAW4vrv64v7H\n+6iorcDX2q8o/FBIiexKp0hDsaMi0tPTkZWVhfbt26Ourg5cLhdXrlzBlClTYGNjAxaLhUGDBmHx\n4sVwcHCAj48PXr58iTlz5sDe3p46Fh6PBw6H06igtJOTE06ePCnW9Qe+rdg+fvyIwsJCnDlzBjk5\nOZg2bRoiIyPh6+sLBQUFMBgMqKiooF27dgLpRb4aDYvForqZ1dXVMXLkSCxevBgHDx5EXl4eEhMT\nQaPREBsbS1l1NdY1Wl5ejtGjR0NdXR1r164VmPxLSkooa5+3b9+iffv2GDJkiNip/crKSnh7e2PQ\noEHUdmfOnAknJyexRR2GDx+OefPmAfh2U2ZoaEiZKU+aNAmTJk1q8v1du3ZtdjV0/vx5uLi4iHU8\nPB4Pd+7cEeiA9vHxwfz583H37l2xaRDv379HSkoKOBwOfH19cfjw4WYD7/3792FjY4OePXvC398f\nXl5e/xWC2j8Lv1zg8/T0FOiYHDJkCCZNmgQejwdPT08sWbKEeu3ChQtwc3Nrdpv19fVwcnJCUlIS\nOBwOVFRURE7w9fX10NfXB51Ox5kzZ/DmzRv4+PjA1dVVaDLkS5l931UHfPvCjho1CgwGA/7+/tiz\nZ4/IyaO2thbZ2dkwMDCAp6cnTp8+Tf2QXr9+DSaTKfDDqqmpgZqamlh30Hy7nU2bNoHBYMDCwgJq\namrQ1dVFr169MGfOHJw8ebJVP6SKigrY2NgIfA6i9u/g4AA1NTWYmZlBWVkZLi4uSE5OxuXLlxEb\nGwsPDw98KPkAxTRFbLq9CedenKMco78PfONOjsOxJ8ew8vpKHH78f1qMfBdphdkK2HtoL5hMJhYu\nXIioqCiqC3PSpEmUHNu8efPAYDCwatUq6rryxZm7deuG+vp63L17F0ZGRiLP6f79+9DQ0EBpaSme\nPXuGy5cvY9++fZTaR2hoKDp16gQTExOwWCzIycl9ExFu1w7S0tKQlJSElJQURZLmN4moqalh/Pjx\n6NOnD9TU1ODt7Y2TJ08KTYyVlZVQVVUVqdTy6dMnJCUlQUpKCo6Ojs1+RwoKCtCxY0e4ublR8nq1\ntbVo164dbt26BR0dHcyZM6fF/LavX7/C09MTQ4YMAZfLBY/Ho9zQmxOGqK2tBYPBoDoYT506BTs7\nO+oYbt26BQMDgyaPKTIystn08fLlyxEdHd3o68XFxdi5cyeioqKgqakJQ0NDxMfH4/Dhwy1WYrl5\n8yYiIyOhpqaG4cOHCzRaNQYej4esrCwwmUzMmTMHFhYWAt3Pvwp+qcBXU1MDOTk5gfTc69evQafT\nUVRURHH7+J2Od+7cgbW1dbPbzcjIgKurK9hsNvLy8uDl5SXkcF1UVAQ3NzcYGxsLkKa5XC6lzrJh\nwwacOXMGPj4+lHh1VVUVqqqqsHHjRri5uUFDQwNTpkwRu4ZQX1+PTZs2wczMDJ06dcLRo0exdetW\n9OzZU2Bcbm4uXF1dhd7fnN1OQkICVFRUforvGJfLRWhoKIYMGdLkBFRcXAxtbW1K67KmpgZnzpzB\n+PHjYWtrCzU1NRgYGIDpz4R86v+1X+9/uB+AYOD78XHn/beu2KgDUSApBBJTJCDh8K0t3s/PD5mZ\nmQLX/uHDh1TXrqjPpLKyEh4eHujTpw+GDRsGT09PgVWZra0ttLS0ICMjQ5nSSktLUys0WVlZMBgM\nqrU8JCQECQkJWLBgAfbt24f8/Hw8f/5c5Krn06dPYLPZUFFRQf/+/ZvVeB0wYABWrFgh9HxtbS38\n/f3Rv39/jBw5kiKxN+Vs0dDQgFWrVoHJZGLChAn4+vUrpKSkwGQym2yeag4VFRXo3LkzoqOjweVy\nUVtbC29v72Y7jQ8dOkR1lQLffPi+P1cejwcTE5MmpdHGjx9PGdg2hhEjRmDZsmXU3w0NDcjPzxew\nAuvevTuWLVvWKjeM+vp67N69G+7u7tDR0cHcuXPFvsEsKSlBnz59YGtri/Xr14PNZov8vH8F/FKB\n7+bNmyID2ZQpU6iaUXJyMhUUXr58CR0dnSa3+ezZMzAYDDg5OWH27NkAgLFjxwr8QA4dOgR1dXWk\np6fj999/F6gzAN9+dJmZmZCXl4eSkhKWLVuG2tpa3L17F4mJiaDT6ejWrRv279/f6juzhoYG7Ny5\nEzY2NmAymRg8eLDAXf+IESMwf/58vH37FgcPHsT06dPRrVs3yo2ge/fuSE5OxuHDh4VI9Js3b4ap\nqelf9uJLTk6Gq6trkzqeX758gZOTExISEqCsrCzSlunt27dYu3YtZMbKCAS1xgJfh+wOWJK/hFrx\n3f94H/R5dOp12bGy0NDQgIaGBsLCwpCRkYHDhw8jNjYWSkpKCA0NRXx8PHr27AkXFxcYGRmBwWBQ\nah/S0tICosKKiorQ1NSEtbU1JSisrKyMlJQUnDhxArdv38aff/7ZavmqP//8E2PHjgWNRoO3t7fA\nyqYpHDx4UIhr2tDQgLCwMPTs2ZM6ntevXyM2NhZ0Oh1Tp05t1MEE+JaG++233ygZr+PHj7fqnL5H\neXk5XF1dERsbCx6Ph9LSUlhaWjaZJQgLC8OqVasA/J9V2I/fnalTp2L8+PGNbiMjI6NJr0AA6NSp\nE/bu3YsNGzYgPDwcDAYD1tbWGDduHE6fPt0q5wvg283evHnzoKurCzc3N+zatatF349Lly5BT08P\niYmJWLZsGdTV1UV2Lv8q+KUCX25uLvz8/ISe//LlC9TV1XHnzh1UV1fD1NQU+/fvR2lpKVRUVBrd\nHo/Hg7e3N7y9veHn50cFkoULF2LUqFGora3FqFGjoKenR6n419fXUz5w/GBkZ2cHW1tbbNq0CSNG\njACNRoOlpSW0tLQwffp0Sg/xZ4DL5UJXVxfm5uYwNzfHhAkTMGPGDKrew2AwKIJ1U3Y7P2L48OHo\n169fq+WZ+LSSxkSRgW93+66urpTdTUhIiBABn497H+5BMU1RrMA3aP8g6n0N3AYsvLwQ0rP+z3Va\nYpoEWFYsKCgoCGkw8tvxVVRUYGBggI4dOyI4OBixsbGYO3cudu7cifPnzyM3NxeEEJGpstOnT4sk\n0rcUL168oFR+Ro4ciaKiIjQ0NMDMzEysSY5v/8RvtuLxeIiLi0OXLl1ESvS9ePECQ4YMAYPBwMyZ\nM0Xe+DQ0NGDMmDHQ0dGBlJQU/P39W03O/x5lZWVwcXGhvgt8/ztRDg7l5eUC3ovz589HVFSU0Li7\nd+9CT0+v0e/w5s2bRTa71dbW4ty5c5gwYQIkJSWhpqaGPn36YO3ata1yiP8ehYWFGD58ONTU1BAR\nEdFsc82PaGhowKxZs8Bms7Fv3z7Ex8fD3Nz8p3gv/jfjlwt8/v7+Il/LzMyk/LPOnj0LHR0dlJaW\nQlJSstFC8dq1a2FiYgJNTU2BTrZFixZh8ODBcHJyQkhIiFBHVmBgIOLi4mBmZgYXFxccPnwYBQUF\niIuLA41Gg7OzM+h0OsaOHdvqO8QfwbfbmTJlCqSkpKCtrQ0lJSWoqqpCWVkZdDodT58+bXXgqq6u\nRvv27QXSPOLi1q1bYDKZTTpmVFZWokuXLhg2bBj1eezcuVPkjQwA7L27F8ppymIFPpJCIJEiAaOl\nRrjx9tvEMuXMFOo1qWlS8BzmifHjx6N3795QVlbG2LFjcf78eWRnZyMqKgqGhoZgMBgIDQ3FkiVL\ncOvWLYHvzenTp6nV9o9WRpGRkSK7RcXFw4cPERkZCTqdjsmTJwt1VW7YsAFeXl5ibWvw4MHUsSQn\nJ8PBwaHZlfzTp0/x22+/gcViIT09nUq7fv36FT179oSnpyeKi4thYmKCxMREMBgMLFiw4C/Xlb58\n+YIOHTogKSkJPB4P169fB5PJpBpW+Ni8eTMlTcfj8WBsbIzLly8LbY/H48Hc3Fyk6hEAnDx5khIX\neP78OVatWkUJMXTo0AGJiYlgMpl/WWiay+WKFItuKfjcPC8vL9y7dw8+Pj4ICAj4S+bV/yv4pQJf\nfn5+o3fWtbW1MDY2prrqIgdF4rcxv0HeVh7rrq4TUPcAvqXT6HQ66HS6kINDSEgIFBQUkJmZKRBI\nqqursWLFCtBoNGhpaeHIkSPIzs5Ghw4doKOjg5SUFKq++PHjR8oz7sfuy+ZQUlKC06dPC9nteHl5\nITQ0FNbW1nj27Bl4PB54PB7Cw8Ohp6cHAwMDZGVltTrY8sV/f5x4msKHDx+gp6fXZN2npqaGqjE9\ne/YMV65cwf79+zF37lzIyMggICAAzs7OlAamtLQ0JKwlhJyjRQW+HxUoVt/4RjXYcGsD9ZzyHGUs\nObUE7u7ucHd3b/Rume9SHx0dDVNTU9BoNPTo0QMLFy7EoEGDMHXqVCEro4qKikabSppDQUEBevfu\nDRaLhdTU1EY7Zuvq6qCvry9ysv8Rx48fh4uLCzIzM2FiYtIkZ/FHPHjwAP369aMmawcHB0RGRlLN\nV46Ojrh27RqePn0Kf39/2NjYNOpnKC5KS0vh6OiIMWPGUHZMGhoaAvXWbt26Ydu2bQC+3dRaW1s3\neoOXnJyMMWPGCD1fWVmJFStWgE6nw9TUFGw2W0h676+azzYmFt0a8Ll5aWlpKCwshLGxMcaOHdts\nE9Cvgl8q8FVWVkJeXr7RFurdu3fD1tEWa26ugdFiI5CpBBKTJSh1Ar66R05BDoJCg6CjoyMgaVZV\nVUUpdSxatIh6vqKiAgsWLICGhgaCgoIwc+ZMqKmpQU1NDSEhITh69KjILyS/A4vBYGDFihUif6xl\nZWUCdjtGRkaUr9bo0aOxdetWPH78mFp9jB8/XkAsm1/Uv3HjBi5duoSAgABoa2sjMzOzWTFeUdi3\nbx/09fXF4h3V1tbCzc0N8fHxyM/Px969ezF//nzExsYiODgYHTp0gL6+vkCNTFpamvpbWloaMjIy\nYDAYcHZ2pho/Fi5ciMnrJ0Mx9Vuqc+jBoVh/az1effmWYrv17hbW31qPkO0hePz5MXKf5mLl9ZU4\n+OggRXnov6f//wXESQSSZpLw8vLCrl27UFRUJNbK+M8//8SOHTsQExMDOTk5KCoqIjAwEKGhodDR\n0cG7d++wadMmdO/evUXX+NKlS+jWrRvlSC5OO//KlSvF2k9dXR2UlJSgoaHRrBtEY9izZw/k5eWh\nrKyMZcuWUZO3h4cH1QTF4/GwY8cOaGpqIjo6WqzvS2MoLi5G+/btMWHCBPB4PCxbtgzm5uYoKSmh\nRAH41yg8PByZmZmNbquwsBDa2tpoaGjA/fv3sWjRIvj7+0NJSYkSWygoKBCZBUpLS2uyRtgYmhKL\nbim+5+ZdvnwZx48fB4vFarYb9VfDLxX4AKBDhw5CHZd87Ly3E5LTJL8pfDRBbpabJQcyhcA6zJr6\nATx48AA2Njbo3bs3VFVV8eHDBwF36tDQUEybNg0ODg7Q1dWFgoKC2Oaajx8/hpOTE7p27YoDBw5g\n8eLFGDhwIMzMzKCoqAhXV1eMHDkSGzduxP3795u8q3NxcRGQe7p//z50dHQEfmjXr19HSEgIRaVo\naZv1yJEj4e3tjStXrmDnzp1IS0tDdHQ0AgMD4eDgAD09PaiqqgpIVvFlq+Tk5KCurg5TU1O4ublB\nW1sbhoaGyMzMxJEjR3Djxg0UFRVRk+mxY8dE8qa+r/Gtv7Ve5HEmn0vGimsr8KL0BWrqa1BcVYz8\n1/mI3B8p8HlLTpPEzFUzkZqaiqCgILBYLGhoaKBnz56YM2cOzpw502Q68OPHj1BRUcGbN28ol3om\nkwkpKSnQ6XSEh4c361LP4/Fw4sQJeHh4tGplXl1dDU1NTdy6davJcceOHYO8vLxIJSNxcOLECbBY\nLGzZsgU3btxAYGAgdHV1kZ2djYCAABw+fFhg/JcvX5CYmAg2m42NGze2esL//Pkz7OzsMHnyZPB4\nPIwePRpdunTB4sWLMWDAAAD/p4zTWDPOly9fsHfvXtBoNLDZbOjq6mLEiBHYv38/ysrK0NDQgHbt\n2jWaygwLC8OmTZvEOl5xxKJbCj43r1+/figpKcGiRYvA4XCaFbP4FfHLBb7Vq1cjNDRU6PnWKI/L\nzZbDkvwl2LBhA5hMJtasWYNVq1ahe/fulJB0UFAQxaHq1asXcnNz0dDQgN69ezdpLltZWYnLly8j\nMzMTkZGRsLCwoDhbgYGBWLduHe7evduiekJlZaWQUHZaWhoSExNFjueT51ksFpKTk3Hv3j3k5+dj\n69atmDlzJoYMGYKAgABKVFhVVZVqw+d3MEpKSlIrCCsrK3h5eWHgwIHw9/eHhoYGDh48iMLCQnz8\n+FHgLpqvf9q1a9cmJ/i6ujqwWCwhHiSPx4PpMtNW2aj8+DDNNBXa9osXL7Bjxw6MGTOGslGytLRE\nVFQUVq1ahYKCAuqz2b59O4KDgwW2weVy4evri3bt2iEuLo5yqffx8cGsWbNw/vx51NTUgMvlYv/+\n/XBycoKlpSU2b97c6hpSRkaGSMd1Pn7//XewWCxkZmbCwcGhxdvPzs4Gm83GhQsXBJ6/fPkyfH19\nKVsjUcd//fp1ODo6wtPTs8WpfT4+ffoEGxsbTJ8+HQ0NDQgNDQWLxaKCbUZGBiIjI6nxXC4XN27c\nwOzZsylVoa5duyIgIAC//fabyCCsrq7eqDWYpaVlszcW34tFW1lZiRSLbim+5+atXbsW1dXVGDJk\nCOzs7H5qY9z/EiQAgPxCqKioIGZmZmTPnj3E1dWVEELI7vu7yaADg0h1Q3WLtyfFkyKcfA7JXZhL\nCCGkU6dOhBBCHBwcyKdPn0htbS0ZNmwYGTx4MNHQ0KDet3LlSnLjxg2ybt06UlNTQ+7evUtu3LhB\nbty4QW7evEmePn1KLC0tiZOTE3FyciKOjo7EysqKXL16lURERJDAwECSkZFBFBQUxD7Wc+fOkcmT\nJ5P8/HxCCCF1dXWkQ4cOZNiwYURFRYU8e/aMvH79mrx9+5Z8/PiRlJSUkPLyclJZWUm4XC61nXbt\n2hFFRUWioqJCGAwGUVdXJ5qamkRPT48YGRkRIyMjwuPxSO/evcnOnTtJly5dhI4jPDycXL58mRgZ\nGQkdJ4/HIyNGjCDPnj0jR48ebfYc4+PjiaamJpk6darA8+turSMjj40klQ2VYl+jHyFZL0k6f+1M\nTi04RaSlpRsdV19fTwoLC8nVq1fJ1atXybVr18irV6+Ivb09+fLlC+nQoQNJTk4menp6REJCghBC\nSFpaGsnMzCTDhg0jaWlppLS0lFy6dImcP3+e5OXlkcLCQiIlJUVUVVVJTEwMGTt2LFFUVGz1uXz9\n+pUYGhqSCxcuEHNzc4HXCgsLiY+PD9m4cSPx8/MjWlpa5OLFi8TExKTZ7fJ4PDJ58mSyb98+cuzY\nsUbfExgYSP744w9CCCEpKSkkLCyMSEpKUq9zuVyyatUqMnPmTDJ8+HAyderUFn2/CSHk48ePxMvL\ni/Tr14/07duX2NnZkYkTJ5LU1FRibm5OFi5cSMrKykhubi45ceIEYTAYJCAggAQEBBAPDw8iLy9P\nHj16RLy9vcmbN28Ejo8QQuzs7MiGDRtI+/btBZ6vra0lampq5MuXL0RWVlbouF6/fk1WrFhBcnJy\niIuLC0lKSiI+Pj7Ud6G1KC0tJcOHDydPnz4l27dvJwwGg/Tu3ZuwWCyyadMmoqSk9Je2/z+Lfzry\n/hPYs2cPzMzMUFFRgcq6SqG2d/7j3ItzQu+99+GesK5jqjx+i/oN0tLSoNFoUFZWRt++fXHq1Cmh\nWgDfbiclJQVKSkqwt7eHvLw87OzsMHToUKxatQrXr19vlss2cOBAmJubC3VC1tbWoqioCHl5ecjO\nzsakSZMwcOBAeHl5QV1dHUpKSlBWVka7du0EWvJlZWVBp9NhYGAAJycndO/eHcOHD8ecOXOwc+dO\nqgY4ZMgQisDcXEPGiRMnoKmpKdCR9scff4DNZjfaXs/j8ZCQkABXV1exU6yXLl2ChYWF0B360ZNH\nITFV4i+t9mRSZNCtRzd06dKlxUo0X758walTp6Cqqgpvb2/KXik4OBizZs2Cnp4etm/fLmBlVFNT\ng6ysLBgaGsLV1RWpqakYP3485VLv7u6OqVOn4uTJk2JLdX2PWbNmYdCgQQLPPX/+HNra2lQDCAAk\nJCSIZa1TVVWFPn36wN3dvdnrk5CQgCVLluDUqVNwcXGBlZUV9uzZI/Qbefv2LcLCwmBgYNAiwWQ+\n3r9/DwsLC/j6+iIiIgIaGhro1KkT5OTkmvSq+x62trZCK1cA8PPzE8lFvH37NiwtLQWea6lYdEvB\n5+aNHDkS1dXVuHPnDvT09DBt2rRWaYX+SvglAx/wjXfWuXNnrLi8Akppor2l+IFv8ZXF1GPCqQnC\nY6cQSHf81nSRkpJCBYS6ujrcvn0ba9euRUxMDJycnCAvLw9ra2sMGjQIKioq2Lt3b7NNJHV1dXj1\n6hVOnTqFFStWYNy4cQgPD4e5uTmkpKSgrKwMJSUlyoSTkG9K+fLy8mAymTA2NoaLiwtYLBYCAwOR\nkZGBAwcOYMqUKQgLC2vxj+TVq1dISEigfsxNiWzPmDEDXl5eaGhoQHl5OaytrRttLuDxeBg3bhyc\nnJxa1HLN5XKhp6dHearxeDzMnTsXHA4H07dPb7VztFyqHLT8tRAdHY0xY8bAyMioxWm4hw8fUjVU\nvgrO7t27ERkZSTW8GBgYQFZWFu7u7lBXV4e/v7/ISbc5l3pxXB1KSkpAp9OpSf/9+/cwNjYW8u+7\nePFis6pFHz58gLOzMwYMGCBWvfF7f0sej4ejR4/CwcEB9vb2OHTokNCNS25uLoyMjNCnTx+xhNz5\nKCoqQkZGBiQkJCAjIwMLCwtISUmhZ8+eYlMo0tLSEB8fL/R8eHg4UlNTcfr0aZw5cwZ3795FZWUl\nNm/eTPlYtlQsuqX4npt36NAhAMD+/fvBZDKxffv2n7af/2X8cqlOPng8Hhk+YjjZoraF1CrVihxz\nbtA50kW/C5GY2Xw6QrpMmpwKOUVevnxJpSzv3r1LdHV1qXSlk5MTsbe3J4qKiqS+vp706dOH6Ovr\nE0NDQ/Ly5Uvy+vVr8v79e/L582fy5csX8vXrV1JTU0OlGaWkpIicnBxRUlIiNBqNMJlMoqKiQu7c\nuUPk5OTIjBkziJubG+FwOEIpsYaGBkKn08mLFy8Ig8EghBDi6+tLEhISSM+ePVt1Dd+9e0cWLlxI\n1q1bR/r160cmTZpE9PX1BcZwuVwSEBBAOnbsSB48eECYTCbJzs4WmeKZMWMGOXToEDl79iyh0+kt\nOpbJkycTHo9HpkyZQgYPHkzevXtHdu/eTXR0dMjSq0vJ5NOTW5TKlm8nT+b6ziVRllEkMjKSfPz4\nkfTr14+kpaWRTZs2kYCAALG2s2zZMnL79m2Sk5Mj8PyoUaOImpoaSUhIIDNnzqRS3lpaWqS4uJjY\n2toSZ2dn4uzsTDp27EgMDQ2FrllVVRXJz8+nUqM3b94klpaWxNPTk3h6ehJ3d3eipqYm8lqVlZWR\n9PR04uXlRUJCQkhycrLAGB6PR/T09MiJEyeIpaWl0DYePHhAgoKCSEREBElJSRErZTd79mxSXV1N\n0tLSqOcAkIMHD5IZM2YQeXl5MmvWLOLv709tr7q6mqSnp5OVK1eSadOmkYSEBNKuXTuB7dbU1JCL\nFy+S3NxckpubSz5+/Eg6dOhArly5Qmg0GomMjCQZGRlEXl6enDt3jlhbWzd7rE+fPiWdO3cmL1++\nJCdOnCDbt28nN2/eJC9fviR0Op18/PiREEKIpaUlefHiBZGTkyMcDofY29uTs2fPEhsbG5KUlEQC\nAwOF0qV/BW/evCEDBw4kUlJSZPPmzURTU5Okp6eTVatWkX379pEOHTr8tH39T+MfDrz/KO68uwOZ\nFJlG7/j5K76SqhKUVJXg9B+n4ZTtJHr8FAJtR20EBgZi8ODBiImJwfDhwxESEgIXFxcYGxuDxfqm\n/vH9ykxCQgLKysrQ1NSElZUVunTpgv79+2PixIlYvXo1zp49izdv3jTZ0NDQ0IA5c+aAxWI1yoe7\ndu0arKysqL+Li4uhrKz8lwvrwLduuSlTpoBOp2Pw4MF48uSJwOsfPnyAsrIyLC0tG+1cTEtLg4WF\nBcWJainu3r0LNpsNExMTxMXF/VTnaC6Xi5SUFOjo6GDNmjXgcDhYsmSJWB2IQUFBQp9JXV0dmEwm\nYmNjwWAwEBERgfv372P79u3Q0dHBo0ePcO7cOcybNw+9evWiTGwDAwORkpKC48ePi2z/r66uRl5e\nHmbOnEmp/bdv3x6jR4/GgQMHqPd8+PABampq6NSpE6V8IgqjR48WaZx8+vRpsFgsbNy4sdnz/x6L\nFi1qVFOTy+Vi586dlH/fj9qvDx8+hJeXF+zt7ZGfn4/Hjx8jMzMTgYGBUFZWhqurK2bNmoVr166h\noaEBEydOxMSJE/HmzRswmUw4ODhgy5Yt0NPTa7Q55Xs0NDRAS0sLNBoNrq6uyM7Oxv3795Geni7E\n88vPzweLxYKMjAxl7bR8+fKfnm7cv38/xc1raGhAVVUV+vfvjw4dOuDt27c/dV//6/ilA9+Rx0eg\nmq7a6CR46NEhHHp0CKuur8Ltd9/SaMVVxWAvYAuPn0RATAiVXlFVVYWOjg5sbW3h6+uLyMhITJs2\nDevWrcPvv/+Oz58/U/Wu1rZw/4jr16/D1NQUERERQqmVhQsXCpjqbtq0CSEhIT9lv3zw6RtMJhP9\n+/en1OJ37doFNpsNJpMpsmV70aJFMDExEWtCagxbtmyBlJQUpk2b1uiYyrpK5BTkgD2bDTKVQDZF\n9luaexKBxFSJZp2j+emkhQsXwtraGtHR0U1SEOrq6gSksoBvJPfg4GBISUkhJiZGqBv1RysjPt68\neYN9+/Zh0qRJ8PLygrKyMoyNjTFw4EAsXboU+fn5QsG+trYWly5dolzqlZWVYWtri/j4eLDZbBgb\nGzc5OV+9ehWmpqYC38+cnByoq6u3SpQ8OzsbQ4cObXIM36zXyMgI3t7eFMG9vLwcBw4cgI+PD6Sk\npKCoqIiIiAjs2rVLiJ7Al+W7c+cOpdSiqamJpUuXIjU1FQ4ODk3Wj589ewYXFxfo6+sLdcFu3LgR\nAwcOFBKLVlFRoertt2/fhpubG1xdXf+yIS3wrY4aFxcHAwMDXLlyBcC3OqiTkxP69+/fKr7tr45f\nOvDtuLcDynOUm1wB8B/Ss6QpW5vwPeEimyBG54zG1atX8ezZM5SWlooV0ET54v0VfP36FSNGjICB\ngYEAf6dnz57YunUr9XevXr2wYcOGn7bf71FeXo65c+eCzWbD29sbampqKCgowPz58+Hs7CwQLFau\nXAkDAwNKsaalqK2tRXx8PIyNjZGYmCgQ3H/E69evERAQAAcHB+y9uJdyjla0V0Q7zXZi3aEXFhbC\nyMgI8fHx6N69Ozw9PRtt6rhw4QJFC3j27Bmio6NBo9FgamqKuXPninwP38ooMDCw2VV+YWEhcnJy\nMHz4cNjb20NBQQEdOnRAQkICNm/ejMePHwt8B+vq6nD58mU4OjqCTqeDEAIzMzPExsZi586dQrJY\nPB4PBgYGlPzalClTYGhoiIcPHzZ7nURh69atCA8PF2tsbW0tkpOToaamBjqdDgUFBfj4+GDBggW4\ndOkSRowYAQ0NDWzdulXod/Z9ffLixYswMzPDixcvoK+vj2XLliEqKgpBQUEi+a6PHj2CtrY2Fi9e\njKdPn4LFYgl8Drt374axsbGAWDQ/o/H994fL5WLBggXQ0dH5Sw0thYWFsLa2RlhYGFX3vnbtGrS1\ntVtl7dSGb/ilA19TKz752fLQyNAQGfj67uorHBinS8MhzAFOTk7Q19enOifV1dVhYWEBd3d3hISE\nYMiQIZgwYQLmzZuHtWvXwsfHB6NGjcL9+/fx/v37n+aLdfDgQXA4HEybNg21tbVgMplUcKmqqoKK\nisrfbjz5/Plz0Gg00Gg0dO/eHZcvX0aPHj2QlJQE4NvqQUdHp9V3xa9fv6YUW0pLS/H8+XMwmUyh\nVRiPx8O6devAZDIxa9YsoWtsa2tLiQ6Ig+LiYvj7+8PHxweJiYkwNDQU6Vw9bdo0DB06FAMGDACD\nwcD06dPx9OlTqKioNOloUFdXB39/f8TExLRoYvv69SsuXLhA8fV0dXVBo9HQtWtXTJ8+HUeOHEF8\nfDxcXFzw9etXDBkyBEOHDkVGRgaCg4Mpf8Phw4dj69atePPmDSZOnIhx48YhLCwMnTp1anUqGvj2\nneRrZopCcXExduzYgcGDB0NDQwPGxsaIiYlBbGwsNDQ00KNHD6qBCQCuXLkCOzs7+Pj44PHjx9Tz\nsbGxmDNnDgAgIiICCxcuBPDt+6inp4fly5fD19cX8fHxAtf348eP0NbWFlA5cXJywunTpymxaGVl\nZaipqQmIRefl5aFTp04izyk7Oxu6urot/q19z83LycmhjnPbtm1gMpkixbjbID5+6cAnSsGf/9Bb\nrIea+hoce3JMINX5ruIdGPMYIjsA774X9Durra3Fu3fvUFhYiPPnz2Pfvn3Izs5Geno6xo0bh6io\nKDg4OIDBYMDMzIxS81BVVYWhoSE6dOiAgIAADBw4EElJSZg1axZWrFiBHTt24NSpUygoKEBRUVGj\ndbp3794hICAANjY20NTUpJ4/ePCg2KLFrUVtbS3c3d0xbdo0VFdXY+XKldDT04Onpyc0NDQwcuRI\naGpqCkxYLcGZM2fA4XCQnp4ucKft6uqKI0eOUH+/efMGgYGBsLe3F5g0v0dwcDD09PSaJR9/j/r6\neowbNw6GhoZITU0Fi8XCsWPHqNevXbtGBf309HQq9ZyVlYU+ffo0u/2ysjLY2NhgwYIFYh+TKLx7\n9w4HDx7ElClTYGxsDElJSejq6iI8PBxTpkyBiooK1YXc0NCAgoICLF68GD179qR8FyUlJeHs7Nzq\nz4qP06dPC3zvGhoacOXKFSQnJ8PFxQXKysoICgrC8uXLhVZJ1dXVWLJkCTgcDvr06UPdaNTX12Px\n4sVgMBhITk5GeXk5mEwmnj9/juLiYqiqqgqkmp89ewYdHR0sXboUVlZWAtKC/fr1w7hx46i/uVwu\noqKioKWlRemP3r59G+rq6gLHtmzZMgGPzR+RlJSEgQMHin2dSkpK0Lt3b9jZ2VGray6Xi6lTp0Jf\nXx937twRe1ttEI1fOvA1pe6hNEcJ2Tez8az4GarqqvCu4h32PdgHyxWWolOho6WhpaWF2NhY5Obm\nNln7+R58sWv+5M3lclFSUoKnT58iPz8fR44cwcaNG7Fo0SJMnToVMTEx6Nu3L7y8vCgTUzk5OcjJ\nyUFLSwu2trbw8vJC3759ERMTgylTpsDe3h7t2rVDYmIiLl++jF69egkFjJ99XYcNG4aQkBCBfdTV\n1SEnJ4dKs6WmprY4VcPlcpGeng4OhyOSC7h8+XIMGDAAPB4PGzdupFRnmvo8EhISYG5uLhAwxcWW\nLVvAZDKRlpYGDoeDuLg4+Pn5QUtLC7KyskIrOzc3N6oFvTkUFRVBW1sbu3btan5wM8jJyYG+vj5l\nuLxhwwbKU09aWhoODg6IjY3F+vXr8eDBA3C5XDx48AA6OjpQUFCAl5cXWCwW9PX1MWjQIKxbtw5/\n/PFHiz6//Px82NnZYf369QgLCwOdToeNjU2LvOq+fv2K+fPnQ11dHQMGDKCC8evXr9G7d29oaGhQ\nfLqlS5eKtBF6+vQptLW1MX/+fGhpaWHv3r04d+4cjIyMUFVVhbKyMkos2traGkpKSlRNsL6+Hu3a\ntRNIkw4fPrxJV5KvX79CX18fFy9ebPb8Ll68CF1dXSQlJVFWUBUVFejZsyfc3d1bJBrehsbxSwc+\nAMgpyGmUxyfuQ3KqJLS6ayE9PR2zZ89Gp06doKqqin79+mHr1q1NprUAwNzcHAUFBX/pPCorK1FU\nVIRbt27h1KlT2LFjB1asWIFZs2bB3NwcNjY2UFZWpjQy+alYJpMJMzMzuLq6okePHoiKisK4ceOQ\nnp6O7Oxs7N27F+fPn0dhYSHevXsnVip22bJlsLKyEskrO3z4MEXilpWVhZOTk0gOlyiUlpaiR48e\ncHFxadTnjF9vCQwMhI2NjVjXdf78+bCyskJ2dnazY0Xh+vXrlH6njIwMOnfujC1btiAgIEBgHN+9\noiXpbL5l019xMdi/fz80NDRErtju3bsHdXV1nDlzBosXL0Z4eDgMDAygqKgIaWlpdO/eHf369cOI\nESPA4/Fw//59rFy5EmFhYeBwONDW1sbAgQORnZ2NJ0+eCH2OtbW1OHv2LCZMmABTU1NISkqib9++\nyMnJ+UtedeXl5Zg9ezZlqsxPl3t6eoLBYKB///4wNTVttAnn8ePH0NLSQkpKCphMJnx8fJCcnIyk\npCTQaDQBsWhnZ2ecOHGCei+TyRQQb+jUqRPy8vKaPN7vNUNFoaGhATNnzgSbzRbQM3358iVsbW0x\nZMgQsW+m29A8fvnA15Ryi7gPxTRFHDj6reNMS0sL8+fPx5MnT7BmzRoEBQVBWVkZ3t7eWLp0qUjt\nvLi4OGRkZPxt56inp4cHDx6gpqYG/fr1g7S0NE6ePIm6ujp8+PAB9+/fx4ULF7B//36sXbsW8+bN\nw4QJEzBkyBCEhITA3d0dFhYWUFdXR7t27aCsrAx9fX1KOHvAgAFITExESkoKEhISoKqqio0bN+Lm\nzZt4+fIlKioqwOPxcPLkScq2iG+HxHcIt7Ozw+7duxtdhd65cwfGxsaIj49vdALg8XjYsmULZGRk\nEBoaKvZEwW+jT05ObtF1bWhowO7du9G+fXtYWFjAzMwM3bp1Q7du3aChoYFZs2YJjE9JSWm0nb8p\nHD16FBwOB8+ePWvxe8+dOwcWi9Wk12HPnj2xdOlS6u9NmzaByWRi9uzZmD59Otzc3CAhIQFdXV30\n7dsXCxYswIULF1BRUYHHjx8jOzsbAwcOhJaWFuVAEh4eDi8vL6ioqKBjx46YMWMG9u7dCx0dnRaf\nQ1MoLS3F9OnTQafTERUVBWVlZbx8+RIRERGQkpLCsmXLGhVtf/jwISU2TgiBmpqaSLHoRYsWYciQ\nIdTfVlZWVLqRy+VCWVm5WXeJ4uJiKCkpiezAfP36NTw8PODl5SVAS7h48SI4HA4WL17c1sTyk/HL\nBz7gG8erteoeUjOk0G1cN2pbN2/eRP/+/SlZrzdv3uDr16/Yv38/Bg8eDCaTCTs7O8yYMQM3btwA\nj8fDnj17EBgY+LecW1FREZhMJvXDSUpKwuDBg6GtrY1Ro0aJdNZuCjweD1++fMGzZ89w9epVHDt2\nDJs3b8aSJUuQkJAAeXl5eHp6wsfHhxKvVlBQQLt27SApKQlDQ0N06dIFvXv3RlRUFBgMBsLCwjBq\n1CiYmJhAT08PCxYswPv376kguHnzZjCZTGzZsqXR43r37h1CQkJgZWWFmTNnNtlE8SOuXLkCPT09\nREdHizW+rq4OGzZsgLm5OTp27IiDBw+Cy+WitrYWMTExsLCwgLKyMrS1tSlKB4/Hg6GhYYsdtPlY\ntWoVTE1NW9QkcfPmTbBYrGapB9evX4e2tjZqamowY8YM6OvrCzXrWFlZYevWrdi8eTMSEhLQsWNH\nKCgowM7ODkOGDMHIkSMxYMAAyvvR0NAQTCYTTCYTffr0wbJly5CXlwc6nd6a028Wnz9/RnBwMKSl\npZGYmIi+ffti7Nix6Ny5M5ycnIQCP18s2sTEhKJHmJiYiAxgRUVFoNPp1I2Uj48PtQJ8/vw5tLS0\nxDpGOzs7XLt2TeA5Pjdvzpw5AgE6JycHLBarUSeZNvw1tAW+/4/WuDPIz5ZH2uk0qKurC1kMvXjx\ngkqbDBo0CPfufTOxbWhowIULFzBu3DiYmJhAW1sbUVFRUFBQaJX2YnPYunUrevbsCeDb5Kunp4d7\n9+6huLgYffr0gY2NDe7evdvMVppHeXk5rKyshKSvgG/q/Hxy/e3bt3HmzBns2rULq1atooJlUFAQ\nAgMDYW5uDjk5OUhKSkJCQgKysrKQlpaGra0tgoKCMGjQIIwZMwZpaWnIysrC7t27MW3aNNDpdCQm\nJqKsrAzl5eUt6lr9888/oaqq2uzNB79JR19fH15eXjh9+rTIO/HU1FRISkpizJgxYLFYOHr0KC5d\nugRLS8u/dOc+fvx4uLu7i3Wz8vjxY2hoaIjd/efr6wtnZ2d07NhRpAZramoqEhISAHz7HhUWFmLe\nvHno2LEjZGVloa6uDgaDAQUFBXh6emLixInYt28f8vPzsXHjRgwZMgSGhoYghDTqUv9X0b17dyxf\nvhxxcXGQkJBAbGwsPnz4gPXr14PNZmPkyJG4f/8+Jk6cCCaTiaCgIJw6dQozZsygvoMeHh4ia42u\nrq5U89KAAQMo+6GDBw8KpbQbQ0REBHJycgCI5uYB3+aHMWPGwMTEpNW0kTY0j7bA9x3EVfdQTFOE\n5DRJRC/+tkLYsGEDHBwcRPKuiouLMXv2bHA4HHTr1g1nz56lJj8ej4cHDx4gPT0dCgoKUFRUpOqC\njblptxQxMTFUO3dBQQGMjIwE9r9+/XowmUwsXry41ZMQl8tFjx49EB0dLTSx37hxA+rq6iKFffnY\ntGkTzMzMBGqCu3fvhoqKCuTk5DBhwgScOXMGBw8exLp16zB//nxMnDgRAwcOhKamJhQUFGBoaAg2\nmw1paWkoKSlBQUEBOjo68PPzQ3h4OOLj4zFjxgxkZmZi69atyM3NxfXr1/H8+XOUlpZCWloaNjY2\nIo/vRyPh5pzMV61aha5du0JDQwNxcXHgcDhwcXFBenp6C66qMLhcLvr06YPw8PAmP6s3b95AX1+f\nmmSbw+fPn2FrawtFRcVGNSVv3LgBNTU1DB06FNra2tDT0xPwqvt+W8ePH0dKSgoCAwPBYDCgpaWF\n0NBQpKengxCC1atXC7jUBwcHIyMjAzdu3Gi1Q/inT5+goqKC8vJyLF++HMHBwYiPjwedTsekSZOw\nY8cOGBgYQEJCAt26dRNQF8rMzER4eDjYbDZcXFyo5qjvsXTpUkrce/To0VS37ezZs8U2n42JicHK\nlStFcvOAb6LmAQEB8PHx+UvGvG1oHm2B7wdU1lViXcE6mC4zpZzXlecoUw7sfHWPgnsFYDKZFEmY\nb3rZGKqrq5GdnQ1TU1M4Ojpix44dAoFy9OjRmDhxokBd0MfHB5mZmX/JU8vKyopKr8yYMUOgXZsP\nvlKFn59fq6SPpk6dCnd3d6Ga2p07d8Bms3HgwIFmtxEdHY2wsDDweDycOnUKbDYbc+fOxeXLl9G9\ne3doampi8eLFFHVj586dYLPZmDhxosAKiMfjoaysDFlZWWjfvj1yc3OxdetWLF26FDNmzEB8fDzC\nw8Ph5+dHmQIrKipS8nFWVlbw8PBAaGgofvvtN7i7u0NRUREdOnTAkiVLcOnSJTx8+BCfPn1qdJLu\n1asXNm3ahKKiIjg6OqJ79+6QkpJCWFjYX25QqKqqQqdOnTBlyhSRrxcXF8PS0hLz5s0Ta3tPnjyB\niYkJJkyYAHd3d0rkgMvl4vr160hNTaW86lRUVBAXF4dHjx6JvXLl8Xh49uwZtm3bhqSkJEhKSkJB\nQQHW1tYYOnQo5s+fj3nz5mHEiBGwsLCgVt7z5s1Dfn6+2I1Aq1ator4/NjY2VJfo4sWLwWQyISkp\niYCAAOzduxfW1tbo2rUrVTNdtmwZYmNjcevWLcoE+UcFoDdv3oBGo6GmpgZz586lfkdhYWFN+mp+\nj2HDhmHAgAFgMplYt26dwDV88uQJzM3NkZCQ8NO4vG1oHG2Brwnc+3CPUvc4+uQo7n24J/D68uXL\n0aFDB9TV1eHRo0dgMBjNKpBwuVwcOHAAbm5uMDAwwLJly/D161ccPnwY3t7e1LivX79i3759GDRo\nkEBd8ObNm2JPOp8/f4aysjIVYG1sbBp1Y66vr0dycjLYbDb27dsn1vYBYMeOHdDT0xNqs37w4AE0\nNDSwc+dOsbZTXV0NOzs7BAcHg8PhCLjEA99Wq7169QKLxYKNjQ1MTU2Rn5/f6PZqampAp9PFVoTx\n9PSElJQUbty4gb179yIkJASKiopwcHBAVFQUBg0ahKCgILi4uMDExAR0Oh1SUlKg0WgwNjaGs7Mz\nAgMDMXDgQMjKymLixIlYtWoVtmzZAhsbGygoKKBz585wc3P7SyRw4BvR+nsrIz6+fv0KFxcXsVcg\nFy9eBJvNRlZWFoBvn6WWlhYGDBgAFosFc3NzjBo1Crm5uaiqqsK8efOa5KuJAw6HgxcvXuD69etY\nsWIFIiMjYWZmBkVFRXTu3BlxcXEYM2YMBg0aBGtraygrK8Pf3x9paWm4dOlSozcOnTt3xqFDh5Cf\nnw89PT0kJyeDw+HA19cXhw8fxtOnT6nf0qxZs5CamgoGg4HU1FQcOHAAvr6+AL7VRZlMJthsttCK\nmb+P1KxUeI3wwo57O6Djo4M9F/Y0e97FxcVgMpkwMjLCo0ePBF47ffo01NXVsXr16lZe1Ta0FG2B\n7y+Ax+MhICAA06dPB/Cta68l+peXL1+mXKInTJgARUVFkfWb+vp6XLhwAWPHjoWxsTF0dHQQHx+P\nkydPNrmCOHToEPWDfvbsGdhsdrOppMuXL8PQ0BDDhg1r1g+PP0n8SPx++vQptLS0qDqIOCgtLYWP\njw/atWsn0M79Pfbs2QMmkwlzc3MwGAzMnDmzSarIsGHDxCaADx48GKqqqoiIiACNRkN8fHyzK+2G\nhgZ8/vwZjx8/xuXLl3Ho0CFMmzYNGhoamDx5MoYPH47evXuDTqdTNBJ+7ZLD4cDe3h4+Pj4ICwtD\nXFwcpk+fjiVLlmDz5s04duwYrl27hj/++ANfvnwRutl5/Pgx2Gw21WRRW1uLrl27IioqSqwbI74C\nSEZGBqZOnQpHR0eoqqpCTU0NsbGxIs/9xYsXYDKZf2lFYmxsLJJWUVpaipMnTyI1NRXBwcFQV1cH\nh8OhBBx69eoFW1tbIZf66upqvHr1CgwGA/n5+TA2NoacnByGDx9ONRZ9j0ePHqF///5QV1fHlClT\n0K1bNxgZGUFZWZn6bVy/fp36zE6ePAngWyZoYMZAKE9RhuwsWUhNk/omdziJQCFNAabLTJFTkCNS\n5/XChQvQ0dGBjIyMkL3S8uXLwWazW6V92obWoy3w/UX8+eefYLPZuHz5MmpqamBqatpiOaHHjx9j\n+PDhkJKSQnBwsJC7wffgc6nmzJkDZ2dnqKmpISwsDNu2bROqC44fPx4zZ84EAGRkZIjdtVheXo7B\ngwfDxMQEV69eFTnm/fv30NXVFSJXv3z5Enp6ei3ixN2+fRtGRkZISEjAjh07oK+vL1Dj+PTpE8LC\nwmBqakrx2R4/fozBgweDTqdj8uTJIldRZ8+eRfv27Zvd/+PHj2Fvbw8JCQkMHDhQSLOyJZg1a5aA\nev+HDx+gqqqKiooKis7Rv39/0Gg0LFmyBCdOnMC2bduwbNkypKSkIDExEQMGDIC/vz8cHR0blb/r\n2bMnunfvDnl5eSQlJaFjx47o2LEjzp07hwcPHuDDhw8ia84vX75ESEgI5OXloaysDAcHB0yZMgXn\nz59HXV0d9u3bBycnp0aDp7Oz81/qNLSzsxOLW8nj8fDixQvs3LkTY8aMofwHTU1N4ePjAx8fH1hY\nWEBeXh7q6upQVFQEk8mErKysWNq39+7dQ69evaChoYFhw4ZBWloa3t7eVOYiPz8fampqUFFRQcax\nDCimKUJxdtO0px+dPb7n5k2dOlVA1qyurg6xsbGwtLQUEipvw9+PtsD3E7Bv3z4YGhqivLwc586d\ng7a2tlimoD9i5MiRcHd3B5PJRGhoaLNNFMC3Nv7s7Gx0794dysrK8PX1RWZmJl69egUXFxecPXsW\nAODu7t5iN+vdu3dDXV0dqampAivFmpoauLq6UitdPt68eQMjI6NGjWZFYePGjUJUhdGjRyMoKAhc\nLhf79u2DhoYGxowZI5ID9eLFC8TExIBGo2HMmDECDg8NDQ3Q0NBodCK8ffs2+vXrByaTiZCQEGhr\na2P37t1iH7sodO7cWSAwLFmyBBEREdTfz549g5WVFZXSzcjIEGuFxpe/u3fvHvLy8rB3715kZ2cj\nLCwM0tLSlMmwq6urgPydiooKOBwO2Gw2FBUVISkpCVlZWQQGBiI9PR07d+7E6dOncevWLRQVFaGi\nogJWVlYChO3vsXjxYgwePLjV18fNzU2kya44qKurQ0FBAVavXo0BAwZAXV0dEhISkJCQgKamJlXL\nc3V1FdulvqCgAEFBQVBTUwODwQCTyURWVha4XC4uX74MWQ9ZkKktozjJz5ZH8vFkeHh4wNvbG2/e\nvIGPjw9l4/T582d4eXkhKCjopxrUtkF8tAW+n4ShQ4dSJNfBgwdTQswtwalTp+Dm5oavX78iMzMT\n+vr6cHNzo3hizaGiogJ79+7FoEGDQKfTISkpiSlTpuDUqVNQVVUVSxLqR7x+/Rre3t5wc3PD8+fP\nwePxMHToUPTs2VPgmN6/fw8zMzPMnz9frO3W1NQgJiYGJiYmFNWDj7q6Ojg5OcHe3h7GxsZiST29\nfv2aoo/Ex8dTtb3Ro0cLBegrV64gKCgIGhoaWLBgAcrLy3Hq1CloaWlhyZIlYh2/KJSXl0NJSUlA\nO9XBwQGnTp0SGhcaGgpHR0dYWloiKiqqVZ8N8C29rqmpCRsbG5SXl4PH4+Hx48dYunQpAgICoKSk\nBAcHBwwaNAhGRkZo37490tPTMXXqVIwYMQJ9+vQRkL/j00dkZGRgZ2cHb29vSv5u6tSpSE5OhoKC\nAg4cOID8/Hw8ffoUJSUlYncE+/v7N9nh2xz4YtFqamqIiIigupJnz54NFRUV0Gg0qKqqUg4KfHWg\niRMn4tixY40GmvPnz0NRURE0Gg1GRkZwdnbG/KPzITtLtnXCFlMJ+s/uj4aGBmzduhXW1taoqanB\n/fv3YWRkhAkTJrS6g7UNfx1tge8noby8HEZGRti3bx8+ffokktvXHCorK6GoqCigC7hjxw44OjrC\n3Nwca9asEZtwfurUKVhaWlJcMnl5ebHqgqLA5XKRkZEBJpOJ3377DdbW1gL1v0+fPsHa2ppKqzaH\nV69eoWPHjggNDRVo5+bj4MGDYLPZUFBQaHTl0Rjev3+PCRMmgE6nY9iwYdi/fz+MjIzA5XIpkWQ9\nPT2sXLlS4Fo+efIENBoNEyZMaNH+vsehQ4cEGpQKCwuhpaUlcoLjcrmYOXMmtLS04OnpCXd39xY3\nvSxbtgzGxsZ4+vQp/Pz8oKurC319fWhpaWHo0KHYvXs3SkpK8Mcff8DMzAxjxoxpdrLlCxTo6uoi\nJydHQP5u5syZGDlyJFgsFhwcHNChQwcYGhpCRUUFUlJSVEOMm5ubkPzdmjVrsG/fPnh4eGDRokVi\ny9/xr9Xhw4fh6+sLDoeDlJQUKh09ZcoUjBs3DteuXYOBgQEaGhpQVFSEPXv2ULxHeXl5MBgMsNls\nyMjIwMLCAqNHj8bhw4cFygNXrlwBnU5Hhw4dwNJkgUwRDmhJx5Nw5/0dNHC/Xcfkc8lN0p5u3LlB\nzQVHjx5tlYFvG34+2gLfT8Tly5fBZrPx559/Nsntawqenp5Cd8Q8Hg9nz55FQEAAOBwO0tLSmtX/\nnDlzJtXd1717d8yfP1+gLhgeHo7t27eLDDyNYfXq1ZCSkkL37t2p/ZeWlqJ9+/aYNGmSWCm7kydP\ngs1mY968eULjS0pKEBERAUNDQ5w/fx65ubnQ0tISSahuDp8/f8b06dNBo9EgLy8PY2NjmJmZYcOG\nDSIn3OrqarRr106kqLG4SExMFPDZ47uANwW+uW1wcDAMDAyEVr+iwOPxkJ6eDhUVFbi4uFANH6am\npujXr5/A6uv3338Hh8PBihUrWnQu2dnZjRKzV6xYIaQ7WVdXh/fv3wvJ382dOxfjx4+n5O/U1dWh\nqakJFouFdu3aQUVFBQYGBkLydzNnzsSCBQswaNAgaGpqwsLCAosWLUJxcbEAD1VfXx+3bt1CdHQ0\nZUX0I+rr63Hnzh1kZ2cjKioKhoaGkJaWhoqKCqSlpaGnp4fBgwdj3759WL58OTQ1NTF46WBITpMU\nCmabbm/CuRfnKIuypgKfQqoCVLuoYvPmzViwYAE0NTXFKl+04e9HW+D7yZgxYwYCAgLA5XLh5eXV\nJLdPFL4PWKJw9+5dREZGgkajISkpqdHOQ19fXxw6dAjl5eVQVlYWCHB//vknsrKyEBgYSNUFly1b\nJtIdnY9nz55BXV0dubm5SEhIgK6uLo4ePQpnZ2eMGjWq2aDH5XIpIj+/7vg9Dh8+DC0tLSQmJgrU\nZaZPnw5vb+8Wp4UaGhqwfft2WFpaQklJCTIyMujTp0+Tli40Gg2urq4t2s/3MDMzo6SxGhoaoKWl\nJbKz8EcUFhbC2NgYAQEBYDAYIrtaP3/+jO3bt2PQoEGg0WiQkpJC//79ceTIEep6/WhltGPHDjCZ\nzBbXdoFvqWhtbW2REmvv37+Hqqpqq5y/Y2NjKXUfLpeL0tJSAfm7TZs2YerUqZQijLa2NhwdHWFr\nawttbW3Iy8tDVlYWmpqaMDIygoKCAnr06AEZGRmMHDkSCxcuxIYNG3D48GFcvnwZjx8/RnFxsVAq\ntqKiAnl5eUhLS0OXLl2gqqoKaWlpSElJQVlFGSSx6VTm/of7ATQd+EgKASeNg0GDBqF9+/atNltu\nw89HW+D7yairq0OHDh2wfPlyPH78WCxu3/e4ePEiHB0dmx33+vVrjBs3DnQ6Hf379xfolKuvr6eE\nc3ft2tWkpBK/LhgZGQkGg4H27dsjJSUFBQUFVDArKyuDpaWlwKph3759kJGRgb29fbP1qdLSUgQH\nB6NTp05C7dylpaUYNGgQDAwMRLZ0NzQ0wMfHR4hQ3Bhqa2uxdu1aGBsbw9XVFUePHsXDhw+pVSaH\nw0FISIjINLSNjU2rRZT5mqj8CfbUqVNifY58lJSUwN/fH05OTuBwOJg3bx5+//13zJgxA87OzlBW\nVkZwcDDGjh0LOp3e6MqhqKgIWlpa6N+/P3R0dBr1IBQHS5YsQa9evUS+5uPjgz17muev/Yhx48aJ\nJNfzeDycPn0awcHBYDKZIsWi+aiqqsLr168RFhaGqKgoREdHw87ODqmpqRg1ahQiIiIQGBiIjh07\nwsjICGpqapCSkgKDwYCpqSk6deqEoKAgDB48GGPHjsWcOXOQlZWF7OxspKSkwLOvJySmSvyUwCc5\nTRK+A3z/FjnCNrQebYHvb8Djx4/BZDLx4MEDzJw5s0XcvtraWigpKTWbyuTjy5cvlK+Yr68vTpw4\ngatXr8La2hoA0L9/f7GJsfX19cjLy8Po0aNhaGgIXV1dyrH7ezmyqqoq+Pj4IDw8HEFBQXBwcGhU\nV/DWrVswMjJCYmKiUG3x2LFj0NbWRlxcXJOcwffv30NLS6vJpoiqqipkZmZSMmV5eXkCq1BHR0ec\nOnWKGqetrY2AgAABu5+QkBDIysq2Sk8zJycH4eHh1N8RERECjgfioKioCAEBAZCXl4ekpCTVqXrm\nzBnU1NSgsLCwWfm3uro69OzZE1JSUjh48GCLz+N7VFZWgs1mi3SXz87OFstQ90ekpKQINBvxxaKt\nra1hZWWFrKysRo2Vv0ddXR1YLBaePXsGR0fHZhtm6uvr8fHjRzx8+BAXL17EgQMHkJOTQ8nfDRs2\nDD179kTnzp2h46MDick/J/DJJsvi8CPRvNQ2/HNoC3x/E7KysuDg4IDy8nKYmZm1iNvn7+/fYi5g\nbW0t1q9fDysrK2hqasLHxwdfv36Fmppaq3hpfCFiT09PKCsrQ01NDf3798eWLVvg7++P8PBwNDQ0\ngMfjYfXq1WAymVi5cqVA0NiwYQOYTCa2bdsmsO0vX75gyJAh0NfXF1JoaQwXLlwAm80WWj2XlZUh\nPT0dbDYbPXv2FFK/52PhwoWIioqi/q6pqUFWVhYlOH3mzBmMGTMGMjIyrWoxDwsLo5Q+KioqoKqq\n2qxpaE1NDc6cOYPx48fD1tYWNBoN/fr1Q3R0NNTU1NCxY0fKfPTFixfQ1tamJMVEgS8CEBQUhD17\n9rTayuh7zJkzB7/99pvQ858/f4aKikqzIgc/YsGCBRgzZgyKioqExKJbcsNx/PhxODs748aNG9DT\n0/upHZI5V3OgkKrwUwKf8hxl7Li346cdWxt+DtoC398EHo+HoKAgTJ48GXl5eS3i9s2dOxeJiYmt\n3q+LiwssLS3BZDKhp6fXKk4hAGzfvh16enr4+PEj3r59ixUrVoDNZqNdu3bw8fHB8uXLqUD08OFD\nODg4ICgoCEVFRRgxYgRMTU2FmjVOnDgBHR0djBgxosXHNW/ePLi4uKC2thafPn3C9OnTwWAwMGDA\ngGabQt68eQM1NTWhrli+xZCpqSllwCpqhdMUuFwumEwmdS02btyI4OBgkWP/+OMPrFixAsHBwQJe\ndZcvXxZohLpx4wZ0dXXh5uZGiUI3xY988eIFLC0tkZiYSAWB1lgZ/YgvX76AwWCIJFl369ZN6Kam\nKfB4PIwdOxaGhoag0WgYOXIknj592qrjioiIQGZmJkaMGIHU1NQWv7+qqgr37t3D3r17kZ6ejqio\nKLi5uYHFYkHOVg6SU4QbW1oT+FTTVXH0SctrrG34e9EW+P5GfPjwARwOBxcuXEBUVJTY3L5r167B\nysqqVfvk8XhgMpl4/fo1evfuDVtbWzAYDEyaNEmA3N0cbty4ASaTSdWIGhoaEB4ejsDAQBQXF2PP\nnj2IiIgAnU6Hg4MDUlJScO3aNcTGxkJaWhqurq4CK6eysjJER0dDV1eXkoFqKbhcLiUuTaPREB0d\n3aKJ08vLC3v37hX5WkNDA8aOHQspKSmYmJhg//79YnPTbt68CXNzc+pvHx8figj/9etXHDlyBAkJ\nCTAxMQGbzcagQYOwfft2fPr0qcntfvjwAZ06dYK8vDzk5ORw6NAhkeOuXr0KDQ0NkanVllgZNYZp\n06aJ1OjcsGGDWGn8mpoabNq0CY6OjlBXV4ejo+NfIm5XVlZCVVUVf/zxB9TU1ITqxnzU19fj2bNn\nOHbsGJYuXYr4+Hj4+flBT08PsrKyMDc3R48ePTBu3DhkZWVh3bp1mDJlChy7OYqkMpAUgqEHh2L9\nrfV49eVb/fHWu1tYf2s9QraHiO7sTFMQ0vhtwz+PtsD3N+Pw4cPQ19fH8+fPwWazxeL21dfXQ01N\nrVVt/A8ePIC+vj64XC40NDTw5MkT/PHHH0hISACNRsOQIUOalXR69+4ddHR0qOYFLpeLQYMGwdfX\nV2gCra+vx7lz5zB69GhwOBxISkrC2toaLBYLMTExqKysxKlTp6Crq4thw4a1esJ7/vw5YmJioKqq\nChUVFUpYuSVYs2YNevfu3ejrBQUFUFNTQ2JiIhwcHGBjY4MdO3Y0m0ZLT0+nVuivXr2CiooK0tPT\n4evrCyUlJXh6eiI9Pb3F/nPV1dXw8PCAlZUVdHV1oa6uLkQD4euXNhYUxbUyagqfPn0CnU4XCjBf\nvnyBiopKoxZa79+/R0pKioBY9O7duyl/yNZix44d8Pf3x5o1a9CjRw/8+eefyMvLQ3Z2NsaNG4ce\nPXrA3NwcsrKy0NPTg5+fH+Lj47F06VIcP34cz549Q319PcrLy7F//35ER0dDW1sbBgYGiI+Px5Ej\nR2C81FhkIFt/a73IY2ps5We2zOwvnWsb/h60Bb7/AEaMGIHIyEhs3LhRbG5fjx49sGNHy2sDWVlZ\niIiIwJUrV2BpaSnw2ufPnzFr1iyoq6sjKCgI58+fF6qr1NTUoFOnTkhOTgbwbQUZExODzp07N9qZ\nxuVykZqaCg0NDaxbtw6zZ89G+/bt0a5dO0hLS0NVVbXRlVZzePDgASIiIsBgMDBlyhR8/PgR169f\nB4vFanGarKSkBCoqKo1yF4uLiyErK4v09HTweDwcPXoULi4uMDMzw8aNGxv93Dp37oyJEydi6NCh\nUFFRgZKSEmJiYnDgwIFWB/r6+nr07NkTYWFh4HK5yM7OBoPBgKGhIQYNGoTq6mqqqelHd/Ef0ZyV\nkTgYM2YMRo0aJfR8SEgINmzYIPDczZs3ERkZCTU1NSGx6BMnTlDC6S1BaWkprl69ii1btsDU1BTO\nzs5QUFCAvLw8WCwW3NzcEBUVhfT0dOzduxf37t0TolvwdW4zMjLg7e0NJSUl+Pn5YdGiRUJWSzkF\nOVBKa9qXs7mH0hwlrCtY1+JzbcPfj7bA9x/A169fYWJigp07d8LLywuLFi1q9j1LlixplQXMb7/9\nhuzsbEycOBFTp04VOaaqqgqrVq2CsbExOnbsiN27d1ONKlFRUQgNDQWXywWPx0NSUhKcnZ0brceV\nlJSge/fucHV1FfDyO3PmDHR0dGBiYgJpaWnIysrCz88PK1asEIvecfPmTfTu3Rvq6uqYPXu20Kpi\nxYoVsLOzazGXLCQkBOvXrxf5Go/Hg4yMjICYN4/Hw5kzZ9ClSxcYGBggOzsb1dXVlFddp06dQAiB\nn58fFi9eDENDQ7Ek1poCj8fDkCFD4O/vL9AJe+nSJXA4HFhaWoLNZsPS0lJsqkxjVkbi4u3bt6DR\naELqMtu2bUO3bt1QX1+PXbt2wd3dHTo6Opg7d65IM9VLly4JiDV/j6bqbnzptV69ekFGRgbTp0+H\nurp6s/XLr1+/4tChQ4iNjYWenh50dXURExODgwcPNtmYU1lXCcW0pkWpm3sopimKdGtowz+PtsD3\nH8LVq1ehrq6OCxcugMFgNEkWB74R1Y2NjVu8Hz09PTx48ACmpqbNplUbGhqwd+9euLi4wMjICH36\n9KHkyHg8HiZNmgQHB4dGU1m3bt2CoaEhRo4cSU3QFRUViIuLg7a2NkWcfvHiBTp16gQrKyuEhoZS\ndcGZM2fi9u3bAnfaFy9eREBAALS0tLB48eJGV5k8Hg/h4eEYNmxYi67Pzp074efn1+jr2tra8PHx\nEXr+/fv3mDp1KjQ0NCApKQkOh4PExETMnj2bIr1fv34dhoaGraJDfI8JEybA2dlZ5Lk/ePCAWlVq\na2s3Scj/ET9aGbUUMTExQqvGV69eQVZWFlpaWnBzc8OuXbuazGjcuHEDpqamOHbsGJYsWYK4uLhG\n627Z2dnIy8vDn3/+SV3T7Oxs9O3bF3FxcSIl8vhapYsXL4afnx+UlJTg5eWFBQsWoLCwsEWfzZCM\nIZCY1jStobGH/Gx5yqWhDf8+tAW+/yBmzZoFX19fpKSkIDg4uMkfIZfLBYvFajZAfo+ioiKwWCzc\nv38f2traLXLJXrRoEWRlZcFgMJCSkoKJEyfC2tq60Ttqvjjw9u3bqefy8vKoVNyPPMSGhgakpaWB\nxWJh27ZtOHfuHEaNGgUDAwPo6uoiJCQENjY2MDQ0RHZ2tliizXyqSEu0D/mNEY1RPFxcXGBqaoq6\nujqcP38ekydPhoODA1RVVdGrVy9kZ2fj0KFD6NGjBzQ0NODh4UGR6xMTE5GSkiL2sYjC/PnzYWlp\nKfK6v3r1CjY2NoiOjsbAgQOhp6cHGo3WIr7ehQsXwGKxcPfu3RYf2/Pnz8FgMFBaWiogFq2npyeQ\nXeDxeI3W3WRkZNCuXTuhutsff/whVgnA09MT27dvB41Gw+vXrwF8WykeO3YMCQkJMDQ0hJaWFoYN\nG4Z9+/a1OtWckZEBAwMDTD8yHfKz5Vsc9Jbmt4zD2Yb/LNoC338Q9fX16NSpExYsWAAzM7Nmnc77\n9esnVD9pClu3bkVoaCjS0tKQkJAg9vuePHkCdXV15OXl4eHDh+jYsSMkJSUxePBgIR5YdXU1hg8f\nDjMzM6p28/XrVyQmJkJTU7NRE1k+rl27BhMTE0RGRqK0tBR79+6FpaUlWCwWDA0NoaamhgEDBmDn\nzp1iTVr37t0Dk8kUS+OSj8bI5S9fvkTHjh2puiTfq+7ChQsi9T1v374NVVVV0Gg0zJo1C0wm8y95\nq61btw56enrUhP49bty4AU1NTSxcuBA8Ho+6WWEwGGAwGCK1TxvDtm3boKOjI5CaFgdcLhfe3t4w\nMjICh8PBpEmTcOzYMYwcORL6+voIDw+Hg4MDlJSUoK6uLrLu9vz5c6irq7dov3wUFRWBRqMhKysL\nXl5eyMzMRLdu3aCsrAwPDw/MnTsXd+7c+csr7tTUVJiYmFCfw67CXVBMU4TC7Ka5fT/68bXh34u2\nwPcfxrNnz8BkMrFu3Tpoa2s3ObmvXr0akZGRYm87JiYGixYtQocOHXD69Gmx3lNWVgYLCwusWrUK\nAJCZmQkjIyPcvHkTkydPBoPBQJ8+fXD16lW8fPkSTk5O6NWrF3XcFy5cgJGREX777TeRNR1RKC0t\nRZcuXSAtLQ1zc3MB6sCbN2+watUqylLH398fK1asEBkM+NiwYQPMzMzE5gXyyc9VVVXIzc3FqFGj\nYGFhASaTCVtbW0hISIhF/fjzzz9Bo9Fw7949dOnSBe3atcOMGTPEvg7fY//+/eBwOCLdyQ8cOAAm\nkynyRunUqVNgsVjQ1tZGRESE2PZGc+bMgb29fbPXrKqqCleuXMGQIUPAYDAE5L/4dbe+fftCVlYW\nK1aswLVr1xpNjQPfVumKiopiHeP3qK6uxrBhw2BlZQU5OTnQaDRERUVh9+7dTe6vJeDxeJg6dSos\nLS2FPv8TZ09AxVMF6rPUoZimCNV0VSjPUYZquioU0xRhtswM6wrWtdX0/kvQFvj+AeTk5MDW1haR\nkZEYOXJko+MeP34MLS0tHD58GFOmTEFwcDCMjIxACAEhBBwOBx07dsTQoUORmZkJExMTHDlyBHQ6\nXSzLl4aGBnTv3h0xMTEAvnWE6unpCQhfl5eXY/HixWCxWJCWlsaQIUPQ0NCAyspKjBo1ChoaGjhw\n4IBY581XSzE0NISHhweSk5PBZrMxY8YMkWmu8vJy7Nq1CwMHDgSNRoOjoyNmzZol8q5+6NChCA8P\nb/Jun8fj4dGjR1i4cCGkpaWhqKgINzc3pKam4vr16+ByudiyZQtkZWXFopJs2rSJ0rLs06cPZs+e\njaFDh4JOp2PixInNKrfwce7cObBYLCFBaB6Ph8WLF0NTU7NRRRrg282UpaUl9PX14eLiItZ+eTwe\nhg0bhsDAQFRXV1N8N37dzdfXFxoaGpCSkoKkpCQ0NTXRv39/ZGVlwdPTEykpKQLXeuDAgZT4dFNo\naGiAhISEWNSKFy9eYOXKlQgKCoKysjIUFRUREhICFovVYmut5sDj8TBmzBjY29sLNfCsWbMG6urq\nFP/03od7OPrkKHbc24GjT4628fT+C9EW+P4B8Hg89OzZE/Hx8WCz2SInteLiYkyYMAGSkpKUcPTe\nvXvx6NEjfPz4kVJTuXTpElauXImBAweCEAIzMzMBT7imMGnSJHh6eqK2thabNm2Ctra2EEWAy+Vi\n1qxZ0NDQwLRp02Bvbw99fX2w2WyEhYWJpQry9etXLFq0CFpaWujWrZtA1+Off/6Jrl27wtnZuUl6\nQl1dHc6ePYukpCTo6+tDX18fI0eOxJkzZ1BXV4eqqirY2dkJ2e+UlZVh//79GDFiBPT19aGtrY1h\nw4aha9euItv7L168CAUFhWYpAsC3lOnq1atRUlICVVVVauXx6tUrxMfHg0ajYdSoUY0SrIFv3EEW\niyXkWFFfX4/4+HhYWVk16sDxPSoqKhAaGgptbW1oaWkJNb2IqrsFBQVBUVERUlJSFN8tLi4OcXFx\ncHZ2Bp1Ox/jx44XqzAUFBdDS0hJYXR46dAidO3du9jgBQF5eXmTjTk1NDU6fPo0xY8bAwsICLBYL\nkZGR2L59Oy5fvgxNTU3Ex8djxowZYu1HXHC5XMTFxaFDhw4Cq/X6+nokJSXB1NRU5Eq8Df+9aAt8\n/xA+ffoETU1NTJo0Ce3btxdY8ezatQsaGhqIiYlBjx49xBKZPnjwILy9vWFtbQ0Oh4Pw8PAm7/y3\nbdsGfX19fPz4ETt37oSGhoaQ0HRxcTECAwPh5uaGt2/foqqqCmPGjAGdToednR00NTUxd+7cRlNN\npaWlSE1Nhbq6Ovr06dNoMOFyuVi6dCmYTCZycnKardHweDzcuXMHqampcHJyAp1Ox8CBA7F06VLQ\n6XRs2bIF6enp8PT0hJKSEnx9fZGRkSHQ1ff777/DwsJCaF/8LsXGCOHfHwOHw8Eff/yB1atXo1+/\nfkJj3r59izFjxoBGoyEmJkYogD158gQaGhpCKczy8nIEBgbCz8+vRX6JXC4XkydPhoqKCuTl5dGv\nXz+EhYWhffv2VN3N3d0dQ4YMwdy5c7F3715cuXIFVlZWSEtLa5FYdGBgoMD3sqamRqDhpCmwWCxq\nRV1UVISsrCyEhIRARUUFzs7OmDlzJrUC52PatGlITEwEnU5vUcNXc2hoaMCQIUPg6uoqcK1LSkrg\n5+cHf3//n5ZKbcO/B22B7x/E8ePHoaOjg86dO1PcvpSUFBgbG1O2M+vXrxc5qf6IcePGUZPex48f\nMXbsWBgYGODFixdCY69fvw4mk4k7d+7gwIEDYLPZQl1+BQUFMDAwwKhRo1BXV4crV67AzMwMYWFh\nlNTWrVu3qDQkX3gY+Ca1NXnyZNDpdERGRjarFMPHvXv3YGtri169erVIX/LOnTuIioqCpqYmCCGQ\nkJCAu7s7Nm7c2CQdQl9fX8i2p76+HpKSks2m7e7evQtDQ0MAgKurK44cOdLo2I8fP1LXIyoqCk+e\nPMGbN2+gr6+PtWvXCox9/fo17OzsEB0d3Wi6uqqqCnfv3m2U72ZkZERxJ/v164erV682OnkXFRUh\nNjYWkpKSlIOFOM0hv//+OwwMDASOMSoqqlmOal1dHdhsNoYPHw5ra2tKa3XLli2NSrjxeDwYGhoi\nJSUFgYGBzR6buKivr8eAAQPg5eUlwOl7/PgxTE1NMWrUqBYbSbfhvwNtge8fRnx8PIKCgsBgMDBu\n3DhYWloK1JdevnwJFovV7GTk7OyMKVOmCGgnZmZmQk9PTyDV9ueff0JbWxt79+7F8ePHoa6uLlRb\nysnJAZPJxI4dO1BdXY0JEyaAw+FQ+pM/4tWrVxg9ejRUVVVhZmYGZWVlxMbG4vnz5y2+HtXV1Rg9\nejS0tLRw6tQpkWPq6+spr7qOHTtCRUUFwcHBWLFiBW7duoXAwEBoaWlBTU0NTk5OSE1NFVkXnDx5\nMiZMmCC0fVVV1Wa7YhcuXIiYmBg8ffoU6urqYtVUi4uLkZKSAjqdDlVVVYwePVrg9YKCAmhra2P+\n/Pmoq6sTWXfT1dWFrKwsLCwsEBISgvHjx2PNmjVCfLf79+9DX18fLBYLAwcOFJCa4/F4uHTpEvr2\n7UsZGvMbaFriEN6lSxcBKklubi6cnZ2Fxr19+xZr165F7969oaamBnl5eYwYMQJXrlwRy1UhPz8f\npqamcHV1Fbue3Bxqa2vRu3dvdO3aVUAE4eTJk1BXV2810b8N/x1oC3z/MCorK2Fubo4uXbpAVlZW\nJL/MyMioyXb9r1+/QkFBQaQqyfTp0xEYGAgej4eamhq4uLggJSUFZ86cAYvFEpjo+J1zZmZmuH//\nPq5evQoLCwv06dOnybTp06dPMWzYMKiqqsLd3R1sNhtdu3bF6dOnW91afvLkSWhpaWH06NGorq7G\nmzdvkJOTQ03Wtra2mDBhAs6ePSvUyVhbWwsXFxfMmTMHZ86cwciRI6GnpwcDAwMkJSXh7NmzqK+v\nx927d6Gjo0Ol1Hg8Ht69ewdNTU2Ym5tj4sSJYDAYmDhxIjIyMpCbm4u3b9+Cx+Oha9eu2Lt3L2bM\nmCG2+Djw7bPq2LEjOnfuDCaTicDAQKxZswbx8fGQl5eHk5NTkzqT4vLdgP9L17FYLDg5OeHVq1eU\nWLSRkRGWLl0q0FV89OjRFlkZnTp1Cubm5tT1q6urA5PJxNOnT3Hx4kVMnjwZdnZ2oNPpCAsLw8aN\nG/H+/Xs4Ozu3KMCOHDkScXFx0NTU/CkrsOrqagQFBaFHjx7Ud4fH42Hp0qXgcDg4f/78X95HG/7d\naAt8/wJcu3YNUlJSYLPZIlvWo6OjmzQ1PXPmDLXy+TFdVFtbCzs7O2zbtg2DBw9G7969cf78ebBY\nLIEf+IsXL+Do6Ig+ffrg48ePmDRpEthsNnbu3Nnofu/du4f+/fuDyWRixowZVHqypqYGOTk5sLCw\nQPv27bFt27YWT1g1NTXYt28fTExMICcnB1VVVfTr1w/r1q0Ti3/26tUrsNls6hz5dcFZs2bB0dGR\nqgvq6Ohg586dWLJkCWxtbanVGIPBwJw5c+Dr64s5c+Zg5MiR8PLyAoPBgKWlJWRkZPDo0SPo6+s3\n2wjD15lcv349jIyMoK+vD3t7eygpKUFJSYnqnOzduzf27duHwsLCv+Sm8D0aGhoQFxcHOTk5SEpK\nwtnZGYcPH260q7IlVkY8Ho+SvHv37h3Wr18PQ0NDyMvLo3379pgyZQouXbok9Nn7+PiI7dBRX19P\nOVo0JsHXElRWVsLf3x99+/alVum1tbWIjo6GtbW1yNJAG/730Bb4/gU4evQotLS0YG9vL5Lbt337\n9ibtX1JSUhAaGoouXbqIfP3w4cPQ1dWFnZ0d8vLywGKxBCYefspz4cKFlCVSaGhooy39V69eRUhI\nCNhsNubOndsoF5HL5eLw4cPo3Lkz9PT0sGTJkib1EZ89e4bly5dT7evOzs6YMWMGpkyZAgaDgaVL\nl7ZoBXns2DFoaWmJPI/Xr19j2bJlYLFYIIRAU1MTo0aNwuvXrzF06FCw2WyR2+RTDJhMJlRVVcFm\ns1FfX0/V3fbs2YM5c+YI1d3at28PXV1dmJqaYuPGjbh27Ro+f/6MpKQkmJmZYebMmdDV1YWfnx8u\nXLgg9jk2he/For29vaGgoABlZeVmTY7FsTJqaGjA5cuX0a9fP8jLy0NNTQ19+vTB+PHjYW1t3eT2\ne/ToIbbR8okTJ+Do6AgGg9Gq1Pn3qKioQJcuXRAREUEF40+fPsHDwwM9evRotW9lG/770Bb4/gUI\nDQ1FVlYW3N3d0aFDByFu3/v376GmptZoPcTHxwe+vr5YsmSJyNePHTsGSUlJrFixAurq6pS6CpfL\nRUpKCjQ0NHDq1ClMnToV6urq2LZtm1CA4fF4OHfuHHx9faGjo4Nly5a1SCA6Pz8fvXv3BpPJxJQp\nU/Du3Tt8/foVhw8fRnx8PIyNjcHhcCivuh9XHE+fPoWzszO6du3aIl/BqVOnwtvbW+jalZaWwsPD\nA05OTlBTU8PWrVsxYMAA0Gg0aGtrQ0pKCnfv3hW4Dnx/t759+8Lf3x9GRkaQl5eHjIwMZGRkhOpu\n58+fx7t378DlcpGQkAAPDw/qmlVUVCA4OBje3t6UvFttbS3Wrl0LIyMjeHh4tNiVnH+MjYlF37x5\nExoaGlBWVsbs2bMb3XZjVkYfP37E5s2b0b9/fzAYDCrdbGhoSMmmNTQ0gMPh4MmTJ40e44ABA7B5\n82axzmfQoEEYOHAgunbtKu4lEIkvX76gU6dOGDZsGHVO9+7dg4GBASZPntxqy6Y2/HeiLfD9w+Dx\neGCxWHjz5g1evHgBOp0OBoMhxO2zsrISKTpdV1cHRUVFMBgMkXwvvhyZh4cHVFRUKHug4uJidOvW\nDe7u7sjNzYW1tTVCQkKEaow8Hg9HjhyBq6srTExMkJOT02ryMN/qp1OnTpRlUceOHTF37lwhsWpR\nqKurw4wZM8Bms8VucmhoaICXlxemT59OPVdSUgInJyckJiaCy+UKdGXW1tZi4sSJIISARqNBRUUF\nhoaGVFOJvr4+lJWV0aNHDygoKGDTpk0YNmwY7OzsGk0Pzpw5E/b29lS7/Nu3b+Hg4ICoqCiR17K+\nvh6bN2+Gubk5nJ2dceTIkWavTXFxMebOnQsdHZ0mxaI/fPgAZ2dnKnXc2KquqqoKLi4uGDx4MJKT\nk6lUemhoKLKzswVoC9u3b4erqyt1jAkJCU26okdHR4tF0amqqoKamhqcnZ1bbWsFfLs2Tk5OSEhI\noALcwYMHwWKxsGXLllZvtw3/vWgLfP8w3rx5I9C1uXHjRirt+f3ElZiYiHnz5gm9/+rVqzAwMED7\n9u2FXvvy5QvMzc0xc+ZMqKqqUqnQmzdvUgRw/ipv8+bNApNrQ0MDdu3aBXt7e9ja2oplyCoKJSUl\n2LVrF4YMGQItLS3o6+sjNjYWmzZtwqRJk8BisRASEoJLly6Jvc1Lly7BwMAA0dHRjdIVvge/YSU3\nNxc8Hg89evTA0KFDkZ+fj82bNyMgIAC6uroU341Op0NCQgJ9+vRBUlISwsPDYWFhARqNhj59+kBe\nXh5r166lXB74qh9du3YVClArVqyAsbExlW69c+cOdHR0kJaW1mww438Gtra2sLe3x549e4RWJt+L\nRUdERAh16IpCXV0dhg8fDmVlZdjZ2Qnc7Hz+/Bnbtm3Db7/9BiaTCWlpaXTt2hVnzpxp9IanoaEB\nJiYmOHfuHIBvn4+VlVWj+x89ejQyMjKaPc7du3fDxcUFHA5HrK5ZUfjw4QNsbW0xbtw4SuN07ty5\n0NLSwtWrV1u1zTb896Mt8P3DKCwsFDCM5fF46NOnD3R0dAQ4Ufv37xeZ7snIyICtrS1mzZol8HxD\nQwMCAwOpBo7Y2Fj06dMHa9euBZPJxLx582BnZ4egoCCBZpG6ujqsX78eZmZmcHZ2xqFDh1qUbuNy\nubh27RpmzZoFV1dXKCkpoVu3bli6dCkeP34stK3KykosX74choaG6NSpE/bt2ydWgC0rK0NkZCRM\nTEwalfP6vu42bNgwyMnJQV9fH1JSUlBSUoKjoyP69++PsWPHQkFBAefPn0dpaSkqKiogISEh5KtX\nVFSEqKgosFgsSElJwdbWFqtWrcLbt29RV1eH9u3bIycnhxq/fft2aGlpUbWp48ePg8VitdhgmMvl\n4uDBg3BycoKlpSU2b96MAwcOwNfXFxwOBykpKY26TTSF7Oxsqj4XFxeHTp06UdSQVatW4eXLl2Jb\nGeXk5FAGs1wuF9ra2gIGtN9j2rRpIi2FfkRoaCj8/PwwefLkFp8b8G1lbWFhgenTp4PH46G6uhq/\n/fYbHB0dxSLat+F/F22B7x9GYWEhLCwsBJ4rLi6Guro6VFRUKJWKkpISKCkpCd119+jRA0wmU4iA\nPnHiRLi4uEBfXx8rV67E5s2boa+vDzMzM8TFxYHFYmHjxo1UIKqqqsKKFSugp6cHb29vnDlzRuyA\n9+7dO2zcuJHq8LS0tMSYMWNw8uRJsbsT+aubDh06wMTEBKtXrxarhrht2zaKKL9o0aIm+W6hoaGQ\nlpbGnj17hM4tICAA27Zto/6WkZFBdna20P6GDBmC2bNnQ1VVFRs2bED//v2hpqaGDh06ICYmhlqd\n5ObmQl1dnfpcVq1aBQ6Hg99//12s6yEKX758QUxMDOTk5CArK4thw4Y12SzUGEpKSrBz504MHjwY\ndDodkpKSlMC2qM9LHCuj2tpa6OrqUquoMWPGCKSXv8fcuXMxfvz4Zo9RWVkZDAajVY4Xr169grGx\nMdLS0gB84686OzsjLCysSUWaNvwaaAt8/zA+fPgANTU1oYn45MmTUFFRQUBAAPVae4f22Hh8I448\nPoId93bg0KNDUDJUgp6ensD7t2zZAh0dHRgYGGDRokV4/vw5tLW1oa2tDVtbWwQGBlKk9vLycsyf\nPx8aGhoIDg7GlStXmj3muro65OXlYfLkyWjfvr2AV91flZPi8XjIy8tD9+7dwWazkZqaik+fPuHt\n27c4d+4csrKyMHbsWAQHB8PMzAyysrLQ1tYGjUaDpqYmUlJSKL7bjyvH48ePQ0VFBaNGjRLa76ZN\nmxAUFET9zWKxhAjmPB4POjo6mDRpEgYNGiRwPU6fPo3ExETIyMiATqdDXl4ey5YtQ21tLcaOHQsz\nMzOx+XE/4tmzZ0hKSgKNRkPfvn1x8eJFnD17Fj4+PtDT08OqVauadGXg8Xi4ffs25syZA3d3dygr\nKyMwMBDLly/HH3/8gdevX8PS0hLy8vJITk4WecMjjpXRsmXL0KNHDwDfUvCmpqbg8XiorKzE9u3b\nMXr0aPj6+oJGo1FC6xoaGnBzc0NMTAyysrIogei1a9eiQ4cOTZoGN4bnz59DX1+fypjcuHEDOjo6\nSE1N/cuWRW3430Bb4PsXQFNTU2SrdkJCApSVlbFt9zbkFOSANoMG6RRpyhJFabYSyFQC2nQacgpy\nUFlXiWvXroFOp8PQ0BBz5szBsWPHoK6uDk1NTSgpKWHdunXg8XiUigiTyURYWFizTt4vXrzA6tWr\n0bNnT6iqqsLR0RFTp07FxYsXW11/+RElJSVU3W369OkICAgAnU4HIYQid/N1Jn/ku3G5XMyfP7/J\nhoWEhASkpKRAX19fqFmivLwcKioqVIOKlZUVNYnz8fDhQ+jo6MDe3h5nzpwRuY9JkyZBVlYWAwYM\ngL29PWRkZMBms7F+/foWrc54PB5Onz6N4OBgMJlMTJw4UeRNxeXLlymlmiVLllCrmbKyMuzduxdD\nhw6FpqYmjIyMkJiYiOPHj4tcSVdXV1P1y5CQEJErv+asjKqqqsDhcKhuWG1tbfTu3Rs0Gg0BAQGY\nO3cujh49innz5lHSd69fv8bZs2exdOlSDBgwgLqJ4qd1G1MLagyPHz+Gjo4OVq5cCeCb7i2TyfxL\nzTFt+N9DW+D7F4AvsPwjqqurwfRkgkwhUExTbNYEU2G2AtTcvjliT5s2DcnJyVBXV4eJiQlkZGSo\n9vrx48eDTqdjyJAhjarOV1VV4fjx4xg1ahTMzc3BZDIxcOBAbN68WWy7nca2+z3fbfDgwXB1dQWT\nyYSysjJVd0tOTsbWrVtx7do1PHjwABMnTqQUQJpq4CgoKICFhQX69+8vpE/p5uaGs2fP4urVq2Cx\nWEJuEP369aO6Df39/YUahjIzMxEaGiqg9vI9+PJyBgYGePfuHTp06IBevXph8eLF8PPzo1Zaq1ev\nbpSSUVlZ2SKxaD5u3LgBHx8fKCkpwdDQEEpKSujatSuWLFnSJLXge/B4PMybNw9ycnKwsLAQ2eHL\ntzJqTJCAH9SWLl0KeXl5dOrUSaietmvXLvTu3Vvk+8vKypCeng4JCQnIy8u3yNuwsLAQmpqayMnJ\nAZfLxYwZM6Crq4tbt26JvY02/BpoC3z/AuTl5Yl0CliSvwSyqbJNBjyhx1QC97Hu8Pf3h76+Puh0\nOqKjo9GpUyfExcWBRqMhISFBaPXA4/Hw8OFDLF68GF27doWSkhLc3d0xe/Zs3Lhxo0U8p/r6ejx9\n+hRHjx4VS2eSH5CbS0OVlZUhIyMD2tra8PLywrFjx0S+p7KyEvHx8dDT0xNQp9HQ0KAm4WXLlsHe\n3l5g9XPgwAF4eHgAAGJjY6GlpSWw3eDgYAQFBYlstvjw4QNMTU2RlpYGFRUV6OnpYebMmQLH9+XL\nF2zfvp2qC3bs2BFpaWkoLCzEq1evMHHiRDCZTAQHB4vF4auoqMCBAwcwfPhw6OjoQF9fH2FhYfDw\n8ACTycSsWbNa5Sxw6tQpKCkpQU1NTUiVpq6uDv7+/oiNjRV5fKWlpZCVlYW9vT32798PfX19oXFH\njx5FQEBAo/tftGgRzMzMYGFhgQ4dOoh1Drdu3QKHw8HWrVvx9etX9O7dG66urmL5Krbh10Nb4PsX\ngC/9lJWVRT23q3AX5GfLtyzofRf8VDqpwNvbG0ePHoWysjKUlJQwceJEgYmgrKwM+/btw4gRI6Cn\np0d51e3Zs6fZyYbH4zVZd9PX14e/vz8SEhKQmZmJ3NxcPH/+vFWUiB9RV1eHTZs2wcbGBtbW1ti4\ncaPIVvsjR46Aw+Fg0qRJqK2tBYfDoVZaPB4P/fr1Q3R0NDW+pqYGdDodRUVFWLJkiYBTeF1dHVRU\nVMBms4XcJsrKyuDg4IDp06dj7969kJCQaJagXVtbi5MnT6J3796Ql5enfBe3bNnS6GqKx+PhwYMH\nWLhwIbW68/HxwcKFC/Hw4UOBAPPo0SMMGjQIDAYDU6dObdT5oDH88ccf1I3Kj12oZWVlsLGxEaIk\n8Hg8REZGwtDQEJGRkeDxeDAzM0N+fr7AuPPnz8Pd3b3RfTs4OEBNTQ2PHz9GUlISHB0dm6StXL16\nFerq6tizZw9evXoFe3t7DB48WGw3+jb8emgLfP8SFBYWUgK/lXWVIlObnus9G33/oP2DBMZKJ0sj\npE8I5OTkYGdnh5KSEnC5XBQUFGDOnDnw8PCAkpIS/Pz8sHDhQty/f1/kHTy/7rZp0yZMmzZNwN+N\nzWYL+Lv9bJ3J5sDj8ZCbmwsfHx9oa2tjwYIFQvJp79+/R/fu3eHo6AhNTU2B9GZ5eTlMTU2xadMm\n6rlhw4Zh/vz5OHfuHCQkJKhrcuHCBRgbG8PJyUlg+9XV1fDy8kJsbCyysrLAZDJBp9ObPO6amhoB\nseglS5bgwoULSElJQfv27cFgMBAZGYk9e/bg/fv3OHz4MGJjY6Gvrw8dHR2MGDECBw4cEEti6/nz\n5xg+fDhoNBrGjRvXItpDRUUFvL29ISMjgwkTJgh8P4qKiqClpSVQg9u8eTNsbGzw5s0byjdvxowZ\nQk1CN27cEMk7Bb7V6FRVVeHl5QXg22c8YMAAITUjPi5evAgWi4XDhw/j8uXL0NDQQEZGRlsTSxua\nRFvg+xdhzZo10NHRwZzcOVBKUxIKfEZLjbD4ymLqsebm/1mnuOW4CYyVmCIB83BzmJubIzs7GxER\nEVBXV4epqSkSExNx9OhR6i66pXW369evt8gg9T+Bmzdvon///pRr+PdWTDweDytXroS0tDRGjBgh\nMCnevXsXTCaT4pydPXsW9vb2ePfuHYg6wY6CHdhxbwfCp4fD0MUQmZmZ1Hvr6+sRGhqKfv36Yfz4\n8TA2NkZWVhbFZ/sR79+/R0pKCjgcDnx9fRsVi87Ly0Pv3r2pxh46nY5evXrh7NmzrZ7QX79+jcTE\nRNBoNCQmJlLeic2Bx+Nh/PjxkJaWhp+fn0BquKCggLIyKikpEbC4Gj9+PBISEnD//n1oaWkJnOej\nR49gYmIicn/JycnQ1tYWWGUWFxdDQ0NDiHB+5swZMJlMnDhxAhs2bACLxcLRo0fFviZt+HUhAQCk\nDf8aZGdnk7iHcYSrxm12bELHBLKs2zJS8K6AOGY7Cr0uUSxBFNcrEm9vb+Ln50csLS1JTU0NefLk\nCXny5Al5+vQpefLkCfn48SMxNDQkJiYmxNTUVODBZrOJhITE33GqfwtevnxJlixZQjZt2kR69OhB\nxo0bR6ytrQkhhCQmJpKdO3eSTp06kbVr1xIWi0UIIWTDhg1k3rx55Pr16wTtQHQDdYlqd1XyquQV\nUVRQJJKSkqSyspLwwCNGLCMyxXMKCbMKI0lxSeTVq1dERUWFfPz4kezfv58sXLiQSEhIkDlz5lDH\nVFBQQJYuXUoOHTpE+vXrR0aOHEmsrKyo16urq0leXh45fvw4OXbsGKmuribdunUjgYGBpEOHDuT3\n338nBw8eJLm5ucTU1JSEhISQkJAQYmlp2eLP5v3792ThwoUkJyeH9O3bl0ycOJEYGho2+77du3eT\niIgIoqmpSX7//XeioaFBCCHk2LFjZOjQoWTYsGHkjz/+INu2baP2Y2lpSR4+fEj8/PzIihUrSOfO\nnQkhhLx584Y4OzuTt2/fCuwDADEwMCDl5eXk3bt3RFZWlnpt8eLF5ObNm2TLli2EEEJyc3NJREQE\n2blzJ8nNzSX79u0jhw4dIpaWli26Hm34NdEW+P5lKPxYSDpkdSA1vJpmxz5OeExMGaYkYn8E2XJ3\ni9DrUlwp4vbQjXy494G8fPmSaGhoCAU2U1NToqurS6SkpP6O0/nHUFJSQlatWkWWL19O2rdvT8aP\nH0+0tbWJm5sbiYyMJNu2bSM5OTmkW7duhBBChg4dSh5LPSa39W+Turo6Ui9R3+i2lWSUSG1tLdG6\noUVYH1nExMSErFu3jkhKShI9PT1y+vRpYmpqSvbv308yMzPJq1evSHx8PImOjiZ0Op0QQsjz58/J\nsWPHyPHjx8nFixeJvb09CQwMJN26dSO2trYiA1pdXR05f/48OXjwIDl06BCRkZGhgqCrqytp166d\n2Nfn8+fPZOnSpWTVqlUkKCiITJ48mZiZmTX5ngcPHhAPDw9SW1tLTp8+TZydnQkhhKxevZokJSWR\n3bt3kx49elDjExISiKKiIlFRUSHv3r0jy5cvJ4QQ8uXLF6Knp0fKysoEtn/jxg3i5+dHhg4dSjIy\nMgReKykpIYaGhuTly5fk/PnzJDo6mmzdupUsXbqUVFVVkd27dxMGgyH2+bfh10Zb4PuX4eiTo2Tg\nvoGkrLasyXFBpkHkcP/D5F3FO6K3RI/U84QnajkiR8bqjyX9nfoTIyMjIicn93cd9r8WNTU1ZPPm\nzSQjI4OoqKiQuro6MmTIEGJnZ0ciIyNJSEgImT9/PllxYwWZcHICQTvxfw4SDRLET9KP5KbkEgkJ\nCbJmzRqyceNGEhwcTFasWEF0dXVJUlISCQ0NJVwul1y4cIEcO3aMHDt2jJSVlVGrOj8/P6Kmptai\n8wJAbt++TQ4ePEgOHjxIXr9+Tbp3705CQkKIv78/UVJSEms7X758IcuXLyeZmZnE29ubTJ06ldjY\n2DQ53svLi9y/f59kZWWRqKgoUlpaSthsNnF2dianT5+mVmpFRUWkffv25MSJEyQoKIi8ffuWSElJ\nkfr6eiIvL0/q6+sFAnxSUhLJyckhBQUFxNTUVGjfnp6exMPDg6xZs4asXr2aTJ06lXh6epKlS5cS\naWnpFl2/NvzaaAt8/zLsLNxJog9Hk4q6iibHnY44TXwMfcj0c9PJ7AuzRY6RrJck5k/MiTnXnLBY\nLKKurk40NDSIpqYm0dTUJGpqakRVVZWoqqoKpJX+F8Hj8cjhw4fJzJkzyZ07d8iMGTPI0KFDybhx\n48il0kvks/tnUsurbfF25dvJk409NxL6ezoJCgoi0tLSpGfPniQpKYkwmUxqVZeXl0dsbGyoYGdv\nb08kJSV/2vm9evWKHDp0iBw6dIhcvXqVeHh4kJCQEBIcHEw4HE6z76+oqCCrV68mixYtIi4uLmTa\ntGnE0VE4fU4IIVwulwwdOpRs2bKFjBgxgvTp04dMmzaNaGpqEmlpabJlyxbq3IYMGUL09PTIoUOH\nyIIFC4i3tzchhBBZWVlSVlZG3YxxuVzCZDKJqakpuXr1qsj9du3alVy5coUsWrSITJs2jcyYMYPE\nxcW15nK14RdHW+D7l0GcFZ+1ujW5F3uPVNdXE90luuRz1WeR49o1tCMm90yI5DNJUl5eTiorK0l1\ndTWpq6sjPB6Pmpx4PB6RkJAgsrKyRE5OjigpKRFlZWWiqqpKaDQaFTQ5HA5hMBgCAZP/fxUVlRal\n2v5JjBw5kmzcuJFIS0uTYbHDyOJ2i0kdqRM5Ntw6nGzvvZ0QQsiS/CVk9InRQmMkGySJRIYE8ejk\nQeLi4kh+fj45fvw4+fTpEwkICCDdunUj/v7+/7FU3JcvX8jx48fJwYMHyYkTJ4iZmRmVErWwsGiy\nLlhVVUXWrl1L5s+fT2xtbcn06dNJp06dRI5dtWoVGTlyJDEyMiImJiZk165dxMfHh3h7e5PZs7/d\njD158oS4ubmRpKQkUlRURLKzswkhhNDpdPL06VPqmpw5c4aEhoaSrKws0r9/f6F9rVmzhowbN47Y\n2tqSJ0+ekO3bt1NBtA1taCnaAt+/DIUfC4nLWhdSWV/Z6Ji1PdaSoe2HkrUFa0n04ehGxylIK5Cr\nw64Sa3Vroddqa2tJSUkJKS4uJp8/fybv3r0jb9++Je/evSMfPnwgnz59IiUlJeTLly8CQVNSUpJI\nS0tTNUEApKGhgdTV1RFpaWmiqKhIBU01NTXCYrEIk8mkAqSooMl/KCsr/9RVUGMAQFJSUsi2bduI\nmrcaucG8QYiM8DgtZS1yL/YeUZJRItJS0o0GPlJHiPoNdVKTX0PMzc1JYGAgCQwMJI6Ojv+R82kK\ndXV1JC8vjxw6dIgcPHiQyMnJkZCQENKjRw/i5ubWaG23traWbNiwgcydO5cYGhqS6dOnE09PT6Gg\neeXKFdKlSxciISFBnj59SuTk5EinTp3I5MmTydChQwkhhISHhxNDQ0OyZs0a8ueffxJpaWmiq6tL\nLl68SPT09AghhPTt25ccP36cfP78WSglv3z5cjJ//nxCp9PJmzdvSH5+PjE2Nv4brlYbfhW0Bb5/\nGQAQ8xXm5EnxE5GvM+QZ5PXo10ReWp5Yr7Qm9z/db3RbZgwz8ijh0U89toqKCipgfv/4/Pkz+fDh\nA/nw4QP5+PEjKS4upoJmdXU1kZeXJ7KyskRGRoZISUkRCQkJAoBwuVxSV1dHampqSG1tLVFQUKCC\nIp1OFwiMTQVN/t8KCgpidzouX76cJD1LIjwaT+TrpyNOE44Sh9z7eI+EW4c3HvgIIRxpDrkbfZfq\nFP03AgC5desWVRd8+/atQF1QUVFR6D319fVk69atZM6cOURdXZ1Mnz6d+Pv7C1zjI0eOkN69exNJ\nSUmSm5tLNDQ0iIeHB9m0aRPx9/cnd+/eJQEBAURHR4ekpKQQHUcd0i28Gxk1cRQxNzAnHHkOcTd1\nJ7/99htZs2aNwP4XLFhAVqxYQbS1tcnr169JTEwMmTx58t9+rdrwv43/jtzULwQJCQky0W0iSTqe\nRL7WfxV6vbi6mCjMUWh2O0oySmSi28SffmwqKipERUWF6Ovri/2+hoYGUlpaSgVJUYGT/+AHzadP\nnxIARFlZmSgoKBA5OTkiKytLBU1CCBU0a2trSVVVFfn69Supr68nKioqjQbG7/9fp1ZHpOnSpBbC\ntb1RLqOIu647cV7rTEa5jGr2HCtIBfmAD4RF/r2BT0JCgjg4OBAHBwcyc+ZMqi64YsUKMmjQIOLp\n6Ul69OghUBeUlpYmgwcPJhEREWTXrl1k7NixREFBgUybNo0EBwcTCQkJ0qVLFyIlJUU6d+5MfHx8\nyMKFC8nu3btJ7969yZkzZ4itrS1p37E9+cD6QMIvhRPuLS6pdq0mM67PINK3pElNXQ2pja4lel31\nSFV9FVGQViAAyOzZs8m6deuIhIQEcXFxIQ0NDcTV1fUfvopt+F9A24rvX4iq+iqivkC9yXRnc1CU\nViQfx38kCtLNB8l/K6qqqkQGycYCZ0lJCSkpKSGKiopETU2NKCkpEUVFRWq1KSUlRaUeuVwueaf8\njjwwf0C40oKcSSuWFbkx/AZJzksm83+fT9aHrCeD7Qc3ueJTlVUl23pvI4EmgX/7dfk7UFpaKlAX\ntLCwoOqC5ubm1M0Gj8cjBw4cILNnzyZcLpdMmzaN9OrVi7i6upLk5GSSn59P0tLSSP/+/UlgYCCZ\nNGkSmbptKhmdN5rUVNcQyDQ+3SjJKBEAZF2PdeT2tttk69atpLKykixYsIB07dqVWFlZkdevX4vd\nsdqGNjSGtsD3L8Xu+7vJoAODSHVDdYvfy+807GvV9284sn83eDweKSsrazJI8p97KvuUvLJ9JTQZ\nz/CcQZI9k0nus1zCA4/Yse2IjqoOeV76nOy8v5NMOTNFeMd1hOgU6BCTOhPCZrOJurp6o//Ky8v/\nh65G68CvC/L5gvLy8qRHjx4UX1BKSooAIMeOHSOpqamkrKyMuLm5kQ8fPpDDhw+Tw4cPk969exNz\nc3Oi1VuLnGg40SKaSDu0IwqXFYj8XXmyd+9e4ubmRlJTU8mbN29IVlbW33jmbfhV0Bb4/sVYenUp\nmXx6couCn3w7eTLXdy4Z6Tzybzyy/w001kGb7JlMUrqkiHxP3ss84rXRS+h5yTpJYnLXhHAqOKRd\nu3ZEQkKC8Hg8qn5ZUVFBysrKSElJCZGRkSFsNrvZAMlms4mamto/qpwDgBQUFFBB8O3btyQoKIiE\nhIQQPz8/oqCgQM6cOUNSUlJIfn4+GTlyJJk7d+43Dt/A9uSr31dCWkGxk2iQIMt9lpO4LnHk9evX\nxMHBgZw/f75NmaUNPwVtge9fjt33d5Oog1FEQkKCfK0TrvnxwU8TrQ9Z/0uu9FoDcTpoCSFipTrl\npOTIUuulRKVGpdm0bEVFBVFWViZKSkpEQUGByMjIUCnYhoYGUltbSyorK0lFRQWpra0lDAaDsNls\noqGh0WTAZLFYfzuR++XLl1SH6PXr14mnpyfFF9y4cSNJTk4mdDqdjJs8jkwvny7y2spKyZIF/gtI\nmFUYUZZRJgXvCsiYk2PItbfXBMYpSiuSP0f/Sfr27Evc3d3J9OnT/9Zza8Ovg7bA91+AqvoqsrNw\nJ5n7+1zytvwtaSfZjvDAI5ISkqSB10C0VbTJRLeJJMw67L+6pvefRnMdtHyIE/ha0kHL5XIFmn2a\nq13yqSU8Ho8oKioSWVlZIi0tLbCqrK6uJlVVVURBQYEwGAzCYrGIpqYm0dLSIpqamiID5V+tlZWW\nlpJjx46RQ4cOkRMnThBLS0siKytLXrx4QZQ6K5EHug9E1vRWdV9FYpxiyL0P90jhx0ISZh1GvtZ9\nJYZLDUlxdTE1TklaiZi/MCfMN0xy6NChNnWWNvw0tAW+/zIUfiwkRWVFpKK2gijLKhNdVV2RPL02\niId1t9Y12kErLpRklEhmQCaJah/1E49MGNXV1U3WLT9//kzev39PPnz4QNFJKisribS0NLWq5FNI\nampqqC5dGo1GmEwm4XA4RFNTk+jp6RFdXV3C4XCoQEmn05vkJNbW1pK8vDxy4MABsnnLZlIZVUmI\nCL4+S4FF3ox5Q6QkpIjGQg3yqeoT2dRzE4mwiyApeSlk5vmZAuMVqxXJ5xRhbl8b2vBX0Bb42vBL\n43+9g5bH45Hy8vJGg+SbN2/I+/fvyefPn0lJSQklVtDQ0CBQq+RyuZSqj6qqqsCqUltbm+jr6xMj\nIyOiq6tLPuADcV3nKlINp4t+F3Ju0DnyovQFMcz85gox0nkkWRqwlBx4dICE7gwVGN+UCEMb2tBa\ntPH42vBLQ0FagawPWf+XOmjXh6z/VwY9QgiRlJQkampqRE1NjRgZGYn9vrq6OooeUlxcTN6/f0+K\niopIUVERtap8+fIluX37NqmoqCA1NTWkru5boIMxCOlNCBGxSGMrsgkhRKBeXVn37aaDoySsKSot\nKU2KyoraAl8bfiraAl8bfnn0tepL/vz6Z6s7aP8Xm4lkZGQIh8MRS+CaDwCksrKSrL+2nky6PIlU\ncauExnyo/EAI+ZYe5oP///df3wuN54FHKmqbFmxvQxtain9WSLANbfiXIMk5iWzsuZEoSisKTMqi\noCSjRBSlFcnGnhvbaCPfQUJCgigpKRFDbUMi3U50I8qDTw9IHbeO6KrqEnVFdUIIIR00OxBCCLnz\n4Y7QeEkJSaIsq/z3HXQbfkm01fja0Ibv0NZB+9fRHE0kKyiLDHccTgo/FpLCj4Wkn1U/UllXSQwz\nDYWcRtpqfG34O9AW+NrQhkbQ1kHbOjRHE5FrJ0cy/DNIP8t+RFn2G49v7MmxJP9NvtDYny203oY2\nENIW+NrQhjb8Dfhvoom04ddDW+BrQxva8NPxv04TacN/N9qaW9rQhjb8dPBpIvLtWifI/W+nibTh\nvxttga8NbWjD34K+Vn3J/2vnjmoABoEoCJqrN2xXAx+0F3bGxCbkHutZ2/G7eSbCDJ46gaN8tM40\nwgccZybCJMIHfMpMhL8JHwApjlsASBE+AFKED4AU4QMgRfgASBE+AFKED4AU4QMgRfgASBE+AFKE\nD4AU4QMgRfgASBE+AFKED4AU4QMgRfgASBE+AFKED4AU4QMg5QXMN21vhQRL1gAAAABJRU5ErkJg\ngg==\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "43bcbd6b-ab0d-4596-9188-8c9a449dea11"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "6f71ca55-c4c9-48d5-973f-46dbdff484ea"
    },
    {
      "cell_type": "code",
      "execution_count": 1562,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "faee1dc1-0470-4396-8533-67bdd4a0c6fc"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "322adf58-cca1-417d-a75e-ae92778d7f2a"
    },
    {
      "cell_type": "code",
      "execution_count": 226,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  PedalMeDatasetLoader\n",
        "loader = PedalMeDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "39bbf66a-da5f-4b60-98df-346bfcb25ea1"
    },
    {
      "cell_type": "code",
      "execution_count": 227,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "1d5014c1-50e4-4e5e-a81c-bcb1e1c9b5c6"
    },
    {
      "cell_type": "code",
      "execution_count": 231,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "a44aba42-41e6-4fa5-b33b-fcc4ac6b5fd7"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "d66d088a-db54-4ba9-a92e-23b20e3ff725"
    },
    {
      "cell_type": "code",
      "execution_count": 234,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0], (data[1][1]).y[0]"
      ],
      "id": "9b88a132-ce3f-4fcc-be16-e6c8362dc509"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "0ae3dab9-069d-4c41-8a14-4cdc31012988"
    },
    {
      "cell_type": "code",
      "execution_count": 236,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0], (data[2][1]).y[0]"
      ],
      "id": "3f61ce41-25e1-4a40-85fc-29425b15cdf1"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 15개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{15}\\}, t=1,2,\\dots,33$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "caecd54c-29f1-4475-8adb-0e99924ae475"
    },
    {
      "cell_type": "code",
      "execution_count": 26,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:03<00:00, 16.04it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "493fe1ce-56b1-437c-9ee2-94fefd41773c"
    },
    {
      "cell_type": "code",
      "execution_count": 27,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "b3ca826f-9961-40cf-a9bb-208181a7b1c4"
    },
    {
      "cell_type": "code",
      "execution_count": 28,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "ca86109d-4a24-4e38-9e06-776d2fd33786"
    },
    {
      "cell_type": "code",
      "execution_count": 29,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "77ef7729-dbba-4b69-8f49-09c5b416608d"
    },
    {
      "cell_type": "code",
      "execution_count": 30,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "1098e838-cc0d-464a-b768-8583c11cd361"
    },
    {
      "cell_type": "code",
      "execution_count": 31,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "b5ea78d0-b6d3-4868-9e2b-7b96488f8c09"
    },
    {
      "cell_type": "code",
      "execution_count": 32,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "1865b2f4-f7cf-42e6-9205-bdbbef51f726"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   Vertex features are lagged weekly counts of the delivery demands (we\n",
        "    included 4 lags).\n",
        "-   주마다 배달 수요의 수가 얼마나 될지 percentage로, t-4시점까지?\n",
        "\n",
        "y\n",
        "\n",
        "-   The target is the weekly number of deliveries the `upcoming` week.\n",
        "    Our dataset consist of more than 30 snapshots (weeks).\n",
        "-   그 다음주에 배달의 수가 몇 퍼센트로 발생할지?"
      ],
      "id": "d6fbbcad-8816-4a6b-a37d-75724365b67b"
    },
    {
      "cell_type": "code",
      "execution_count": 33,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "7debdff5-8750-488b-b611-e53d2cfd9c67"
    },
    {
      "cell_type": "code",
      "execution_count": 34,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y"
      ],
      "id": "68f5f1f2-e3df-4745-b1d5-ebfe2481e4de"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## WikiMathsDatasetLoader\n",
        "\n",
        "Wikipedia Math\n",
        "\n",
        "-   Contains Wikipedia pages about popular mathematics topics and edges\n",
        "    describe the links from one page to another. Features describe the\n",
        "    number of daily visits between 2019 and 2021 March.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 722\n",
        "-   V = 위키피디아 페이지\n",
        "-   N = 1068 \\# number of nodes\n",
        "-   E = 27079 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# 해당페이지를 유저가 방문한 횟수\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (1068,8) (N,8),\n",
        "    $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3),f(v,t_4),f(v,t_5),f(v,t_6),f(v,t_7)$\n",
        "-   y: (1068,) (N,), $f(v,t_8)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `1068`\n",
        "\n",
        "-   vertices are Wikipedia pages\n",
        "\n",
        "`-`Edges : `27079`\n",
        "\n",
        "-   edges are links between them\n",
        "\n",
        "`-` Time : `722`\n",
        "\n",
        "-   Wikipedia pages between March 16th 2019 and March 15th 2021\n",
        "-   per weeks"
      ],
      "id": "220d73a1-a6e3-483a-9ea5-57a646151c9d"
    },
    {
      "cell_type": "code",
      "execution_count": 1640,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WikiMathsDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = WikiMathsDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "c7b8580c-e459-4fdb-a3b7-25ba9ca2d9ed"
    },
    {
      "cell_type": "code",
      "execution_count": 1641,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "7ac7b8d7-39e2-4c1f-8485-11e6d7f9f45e"
    },
    {
      "cell_type": "code",
      "execution_count": 1642,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "53cb459c-17d6-4ca7-800c-cf3c133aea7a"
    },
    {
      "cell_type": "code",
      "execution_count": 1643,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "74673272-4bcf-4f58-993c-c37d8eca9d6c"
    },
    {
      "cell_type": "code",
      "execution_count": 1646,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[10][1]).x"
      ],
      "id": "e087a80a-cd44-4c50-985a-9c07c24b6412"
    },
    {
      "cell_type": "code",
      "execution_count": 1616,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "96b962c4-db9e-45e2-9296-ad329449f643"
    },
    {
      "cell_type": "code",
      "execution_count": 1617,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(1068)).tolist()"
      ],
      "id": "f70e0118-0aa5-4986-8278-4defa8cb5e81"
    },
    {
      "cell_type": "code",
      "execution_count": 1618,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "9b80ac13-97a4-4f96-8290-5b278f26f2c4"
    },
    {
      "cell_type": "code",
      "execution_count": 1247,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(722):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "1ab53e62-dede-4ef3-969c-9644f64d3bd4"
    },
    {
      "cell_type": "code",
      "execution_count": 1248,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "12392889-3fae-4bbd-a770-8826b0808504"
    },
    {
      "cell_type": "code",
      "execution_count": 1249,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "c22f959c-09f0-478f-95b2-2ac3b98715fc"
    },
    {
      "cell_type": "code",
      "execution_count": 1250,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,node_color='green',node_size=100,width=1)"
      ],
      "id": "929932d3-380d-4489-adbe-27c0c59dd0f7"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "32ef1768-eaf4-4bee-888b-190687406c9b"
    },
    {
      "cell_type": "code",
      "execution_count": 1565,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "3f9a1fb7-8075-4319-bd91-ac9bdb8d4789"
    },
    {
      "cell_type": "code",
      "execution_count": 1619,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[11][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "abf86dbc-22b7-43c1-83d4-83df5bb67564"
    },
    {
      "cell_type": "code",
      "execution_count": 1620,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[11][1].edge_index != data[20][1].edge_index)"
      ],
      "id": "dd65b06e-b1ef-47f3-968a-636565c5de39"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "https://www.kaggle.com/code/mapologo/loading-wikipedia-math-essentials"
      ],
      "id": "89eb7b3f-d4cc-4bf3-a553-18aaf66cb23f"
    },
    {
      "cell_type": "code",
      "execution_count": 239,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WikiMathsDatasetLoader\n",
        "loader = WikiMathsDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=8)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "5c3a1837-953b-4977-a9e9-e1782123eb36"
    },
    {
      "cell_type": "code",
      "execution_count": 240,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "0505e330-b407-4295-b6d1-e9848333b852"
    },
    {
      "cell_type": "code",
      "execution_count": 241,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "641ef841-6811-48cd-99f1-7ff6a14a6fc5"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3,,x_4,x_5,x_6,x_7$\n",
        "-   y:= $x_9$"
      ],
      "id": "44842f9b-55e5-4de7-9186-abcb7f73e75f"
    },
    {
      "cell_type": "code",
      "execution_count": 243,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "2aa752ff-6910-4587-ac93-f29e31237b5a"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8$\n",
        "-   y:= $x_9$"
      ],
      "id": "48d9553c-e3eb-45fe-8fd8-5714bfa854ea"
    },
    {
      "cell_type": "code",
      "execution_count": 245,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "6a1901e1-5fe7-45d4-9073-c16ace7f98ee"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9$\n",
        "-   y:=$x_{10}$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 1068개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7) \\to (x_8)$\n",
        "-   $(x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8) \\to (x_9)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{1068}\\}, t=1,2,\\dots,722$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "68b3f1f0-24a0-4274-ad09-8f6589177166"
    },
    {
      "cell_type": "code",
      "execution_count": 58,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [09:28<00:00, 11.37s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=8, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "c1983c1a-8b6d-4c5b-91fa-c3190a96481d"
    },
    {
      "cell_type": "code",
      "execution_count": 167,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "8ca67ec3-47f1-44d0-9207-a845fc594a37"
    },
    {
      "cell_type": "code",
      "execution_count": 168,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "c1b0351e-6f48-4268-8a8d-7c337f39cb7f"
    },
    {
      "cell_type": "code",
      "execution_count": 61,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "5bce9da9-ced6-4c38-9d06-e8894a149752"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "어떤 페이지에 refer가 되었는지"
      ],
      "id": "d4585464-adc1-4ff2-88d8-1f7e356209cb"
    },
    {
      "cell_type": "code",
      "execution_count": 73,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index[0][:5],_edge_index[1][:5]"
      ],
      "id": "63b1113c-0253-443f-9bd3-0dd481134ad7"
    },
    {
      "cell_type": "code",
      "execution_count": 116,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "6c2fcf60-8bc6-4b13-b890-6919e52b9a07"
    },
    {
      "cell_type": "code",
      "execution_count": 77,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr[:5]"
      ],
      "id": "45def7ce-bbce-4a02-be25-503c02e45e20"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   Weights represent the number of links found at the source Wikipedia\n",
        "    page linking to the target Wikipedia page.\n",
        "\n",
        "가중치는 엣지별 한 페이지에 refer되었는지, 몇 번 되었나 수 나옴"
      ],
      "id": "8b969af5-c94c-40b0-ac03-13ed5282ea3e"
    },
    {
      "cell_type": "code",
      "execution_count": 63,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "0880884f-84ef-4c0d-8add-39f748b3e8e7"
    },
    {
      "cell_type": "code",
      "execution_count": 64,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "c8a5844f-02db-471b-83e8-d0aa84eb37a8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   lag 를 몇으로 지정하느냐에 따라 다르게 추출\n",
        "\n",
        "y\n",
        "\n",
        "-   The target is the daily user visits to the Wikipedia pages between\n",
        "    March 16th 2019 and March 15th 2021 which results in 731 periods.\n",
        "-   매일 위키피디아 해당 페이지에 몇 명의 유저가 방문하는지!\n",
        "-   음수가 왜 나오지.."
      ],
      "id": "0c3ff743-95c7-43ef-b3b7-19518a5d1b41"
    },
    {
      "cell_type": "code",
      "execution_count": 84,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "37917124-3acf-4d1a-befd-11c93e1c22c9"
    },
    {
      "cell_type": "code",
      "execution_count": 117,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[:3]"
      ],
      "id": "96331831-8e40-49fd-afd3-fe04ea680694"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "y_hat[:3].data"
      ],
      "id": "9d358f39-8b1c-4404-b36b-e7c3c2125aff"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Windmill Output Datasets\n",
        "\n",
        "-   An hourly windfarm energy output dataset covering 2 years from a\n",
        "    European country. Edge weights are calculated from the proximity of\n",
        "    the windmills – high weights imply that two windmill stations are in\n",
        "    close vicinity. The size of the dataset relates to the groupping of\n",
        "    windfarms considered; the smaller datasets are more localized to a\n",
        "    single region.\n",
        "\n",
        "## WindmillOutputLargeDatasetLoader\n",
        "\n",
        "Hourly energy output of windmills from a European country for more than\n",
        "2 years. Vertices represent 319 windmills and weighted edges describe\n",
        "the strength of relationships. The target variable allows for regression\n",
        "tasks.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 17470\n",
        "-   V = 풍력발전소\n",
        "-   N = 319 \\# number of nodes\n",
        "-   E = 101761 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# Hourly energy output\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (319,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (319,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `319`\n",
        "\n",
        "-   vertices represent 319 windmills\n",
        "\n",
        "`-`Edges : `101761`\n",
        "\n",
        "-   weighted edges describe the strength of relationships.\n",
        "\n",
        "`-` Time : `17470`\n",
        "\n",
        "-   more than 2 years"
      ],
      "id": "ad04ccf3-a689-474b-851d-d115085d9a95"
    },
    {
      "cell_type": "code",
      "execution_count": 1566,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WindmillOutputLargeDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = WindmillOutputLargeDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=1)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "24ab9414-eca2-4e9d-b33f-5b3cba2cd347"
    },
    {
      "cell_type": "code",
      "execution_count": 1567,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "860d47fc-6119-4401-af8b-4d802a112c0d"
    },
    {
      "cell_type": "code",
      "execution_count": 1279,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "7bfde377-388d-41c2-b10d-0dfdcef61776"
    },
    {
      "cell_type": "code",
      "execution_count": 1280,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "f08c4f10-376f-4113-9125-9c5c371da0fb"
    },
    {
      "cell_type": "code",
      "execution_count": 1281,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "c5ed55a4-4c44-4ba0-96a1-021b45524ef8"
    },
    {
      "cell_type": "code",
      "execution_count": 1282,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(319)).tolist()"
      ],
      "id": "7547534b-c230-4ca2-82f2-4c5e0d497b4e"
    },
    {
      "cell_type": "code",
      "execution_count": 1283,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "3f5ba624-8d74-499f-9279-6446034da57e"
    },
    {
      "cell_type": "code",
      "execution_count": 1284,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "f66ada63-2e42-4f92-94d5-06e2930e31ef"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "time이 너무 많아서 일부만 시각화함!!"
      ],
      "id": "895d2b1d-186d-4a68-9223-47c4cb0606fc"
    },
    {
      "cell_type": "code",
      "execution_count": 1285,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(1000):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "a1f226c6-50ad-4f45-ac46-d4238754b0b2"
    },
    {
      "cell_type": "code",
      "execution_count": 1286,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "b93d8aff-ad50-415e-9c33-f5c569dfc9ec"
    },
    {
      "cell_type": "code",
      "execution_count": 1287,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "66b822c6-7745-4277-913a-79014304e159"
    },
    {
      "cell_type": "code",
      "execution_count": 1288,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n+H+pkcjSXBscVQAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "bdb16bef-be7d-446d-a425-80cdda6a95f4"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "5c38da10-51cf-49f4-8626-ce11c0f80f66"
    },
    {
      "cell_type": "code",
      "execution_count": 1568,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "45339833-2463-441e-bec6-491b9d39cdc3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "470d2ba7-9520-4560-a643-3e6461fb65a5"
    },
    {
      "cell_type": "code",
      "execution_count": 246,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WindmillOutputLargeDatasetLoader\n",
        "loader = WindmillOutputLargeDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "503cf76a-1928-45ae-a6f6-fa94d36bc133"
    },
    {
      "cell_type": "code",
      "execution_count": 247,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "76436e57-8bd0-4848-81d4-2e41447d2ef9"
    },
    {
      "cell_type": "code",
      "execution_count": 248,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "71315c10-2070-4b15-9f96-0ed39533ad41"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "e2c8a787-a87a-4047-b941-f3e2e5fb859b"
    },
    {
      "cell_type": "code",
      "execution_count": 249,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0], (data[1][1]).y[0]"
      ],
      "id": "91890912-8591-4252-93eb-726a0f55f70f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "c4a4b92b-2861-490f-89ff-c3b84744ef59"
    },
    {
      "cell_type": "code",
      "execution_count": 250,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "7d2477a9-3e25-42f4-94cd-a99165bd7c41"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 319개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{319}\\}, t=1,2,\\dots,17470$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "5c5c0875-5002-49fc-9cf3-aa2e934247d2"
    },
    {
      "cell_type": "code",
      "execution_count": 145,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 5/5 [1:06:03<00:00, 792.70s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(5)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "c14e79eb-3f9d-4a10-a3d5-2919ff5b9092"
    },
    {
      "cell_type": "code",
      "execution_count": 146,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "6d16845f-dda9-4107-90ff-aea49696acf4"
    },
    {
      "cell_type": "code",
      "execution_count": 147,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "c53bed14-6848-4099-a501-e912f9764272"
    },
    {
      "cell_type": "code",
      "execution_count": 148,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "c4d5ab02-0aeb-422c-af9c-6d740fd440fd"
    },
    {
      "cell_type": "code",
      "execution_count": 149,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "5236c958-54f7-4d16-80bb-ad5085ae97f8"
    },
    {
      "cell_type": "code",
      "execution_count": 150,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "e6387e39-fcaa-4f52-8bfe-91f7599b4868"
    },
    {
      "cell_type": "code",
      "execution_count": 151,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "80c152f6-0a9d-4e4a-9f7d-0a6e079ef51c"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-   The target variable allows for regression tasks."
      ],
      "id": "81b75064-4027-4221-a66d-25e8adfd9970"
    },
    {
      "cell_type": "code",
      "execution_count": 152,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "7e956bdd-13f5-4234-9b78-b0fb0606b85d"
    },
    {
      "cell_type": "code",
      "execution_count": 154,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "718585dc-9051-4618-aee0-1d58ea6e6fc3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## WindmillOutputMediumDatasetLoader\n",
        "\n",
        "Hourly energy output of windmills from a European country for more than\n",
        "2 years. Vertices represent 26 windmills and weighted edges describe the\n",
        "strength of relationships. The target variable allows for regression\n",
        "tasks.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 17470\n",
        "-   V = 풍력발전소\n",
        "-   N = 319 \\# number of nodes\n",
        "-   E = 101761 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# Hourly energy output\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (319,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (319,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `26`\n",
        "\n",
        "-   vertices represent 26 windmills\n",
        "\n",
        "`-`Edges : `225`\n",
        "\n",
        "-   weighted edges describe the strength of relationships\n",
        "\n",
        "`-` Time : `676`\n",
        "\n",
        "-   more than 2 years"
      ],
      "id": "46b02fd6-9724-4090-98b9-85771508f950"
    },
    {
      "cell_type": "code",
      "execution_count": 1569,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WindmillOutputMediumDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = WindmillOutputMediumDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=1)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "bdca14f1-4cb9-46c8-b216-6ac98cc58021"
    },
    {
      "cell_type": "code",
      "execution_count": 1570,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "a265dd2b-acb2-480a-940e-1d50d7c8e5da"
    },
    {
      "cell_type": "code",
      "execution_count": 1319,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "a7d1e75e-564e-4306-98af-0c0a4a5945d4"
    },
    {
      "cell_type": "code",
      "execution_count": 1320,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "196cdd44-eb97-4a61-9dfd-7eb89dac1511"
    },
    {
      "cell_type": "code",
      "execution_count": 1321,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "76c6867e-f4c1-40b4-a653-e2fcc453425d"
    },
    {
      "cell_type": "code",
      "execution_count": 1322,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(26)).tolist()"
      ],
      "id": "1c95d66e-247a-4570-86a8-7c0ba50350d7"
    },
    {
      "cell_type": "code",
      "execution_count": 1323,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "6da49250-6075-4200-9fe4-d592efd983bc"
    },
    {
      "cell_type": "code",
      "execution_count": 1324,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "a0542752-1e8d-45cc-99ed-23a45110c837"
    },
    {
      "cell_type": "code",
      "execution_count": 1325,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(17463):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "edcdce5f-a540-4fd1-ae46-fd9e0e76ba49"
    },
    {
      "cell_type": "code",
      "execution_count": 1326,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "acca99f1-0f06-4535-8825-58ce212630dc"
    },
    {
      "cell_type": "code",
      "execution_count": 1327,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "cb2fb7e5-f287-4cb0-98d2-e049f4ccf783"
    },
    {
      "cell_type": "code",
      "execution_count": 1328,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "79858b20-10c0-40c6-91e7-4e215c3654de"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "6df751f4-6ae6-4932-b0d4-a830e9cc6ade"
    },
    {
      "cell_type": "code",
      "execution_count": 1571,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "07d63efb-bc85-4b91-9a08-03e268d3aa75"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "60664974-0416-4889-89a8-bb35603dcd15"
    },
    {
      "cell_type": "code",
      "execution_count": 251,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import  WindmillOutputMediumDatasetLoader\n",
        "loader = WindmillOutputMediumDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "c3d8a3d1-8cde-45d8-9f88-a1c1cbd4196d"
    },
    {
      "cell_type": "code",
      "execution_count": 252,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "c8e6bd8c-7965-4504-b20e-9eef766324e3"
    },
    {
      "cell_type": "code",
      "execution_count": 253,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "a17cf5e5-67c5-4f69-9b26-945c554a90f9"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "9582d5a4-7c1f-4516-bf76-199a3cca86d3"
    },
    {
      "cell_type": "code",
      "execution_count": 254,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "f65256a6-39a7-4e50-8d9b-2a9e9c5b619e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "6bc28ba6-da61-47f6-a871-4878b0776319"
    },
    {
      "cell_type": "code",
      "execution_count": 255,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "0c0ab108-15e4-48bf-9b93-9b0a520fb91b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 26개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{26}\\}, t=1,2,\\dots,177470$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "7d815257-83d6-48fc-8b98-526fe039b5e8"
    },
    {
      "cell_type": "code",
      "execution_count": 161,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 5/5 [03:23<00:00, 40.73s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(5)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "6d52d210-7868-42e2-8d84-0177b5020e27"
    },
    {
      "cell_type": "code",
      "execution_count": 162,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "59f0d87d-46c3-4db8-8245-5291cd2afc58"
    },
    {
      "cell_type": "code",
      "execution_count": 163,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "05726933-1fee-418b-b276-61b0b22940c7"
    },
    {
      "cell_type": "code",
      "execution_count": 164,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "efdc6e81-92be-430e-8ceb-57ca7e75a9a7"
    },
    {
      "cell_type": "code",
      "execution_count": 165,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "5cfff3ab-ac31-4a89-93a3-62e307c091db"
    },
    {
      "cell_type": "code",
      "execution_count": 166,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "355a8d5c-c5c0-4d5a-85b6-20d150c58f9c"
    },
    {
      "cell_type": "code",
      "execution_count": 167,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "d202d76b-5b2d-49e7-ad8f-f9fb36e649ff"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-   The target variable allows for regression tasks."
      ],
      "id": "3e54e763-3046-4a50-be2c-be8ef2a9d71d"
    },
    {
      "cell_type": "code",
      "execution_count": 168,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "66bc6d3d-7bfb-4fa2-b466-d216a71d7d16"
    },
    {
      "cell_type": "code",
      "execution_count": 169,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "5939da59-d3c3-4a1b-a249-ac2517a2390d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## WindmillOutputSmallDatasetLoader\n",
        "\n",
        "Hourly energy output of windmills from a European country for more than\n",
        "2 years. Vertices represent 11 windmills and weighted edges describe the\n",
        "strength of relationships. The target variable allows for regression\n",
        "tasks.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 17470\n",
        "-   V = 풍력발전소\n",
        "-   N = 11 \\# number of nodes\n",
        "-   E = 121 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# Hourly energy output\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (11,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (11,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `11`\n",
        "\n",
        "-   vertices represent 11 windmills\n",
        "\n",
        "`-`Edges : `121`\n",
        "\n",
        "-   weighted edges describe the strength of relationships\n",
        "\n",
        "`-` Time : `17470`\n",
        "\n",
        "-   more than 2 years"
      ],
      "id": "6f4028ac-c104-428f-a8f4-747b86eb722f"
    },
    {
      "cell_type": "code",
      "execution_count": 1572,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import WindmillOutputSmallDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = WindmillOutputSmallDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "7ab01cf4-1056-4121-81fc-f7823aaddd85"
    },
    {
      "cell_type": "code",
      "execution_count": 1573,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "2da45d1a-1add-4060-82b0-cad391101ca5"
    },
    {
      "cell_type": "code",
      "execution_count": 1303,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "2a7c65d7-0d0a-4879-8baf-5252c79cf179"
    },
    {
      "cell_type": "code",
      "execution_count": 1304,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "6e010267-90c8-4bd3-9fe1-b62c57359fe1"
    },
    {
      "cell_type": "code",
      "execution_count": 1305,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "306955b2-d279-4c6e-8922-fa51aa7844af"
    },
    {
      "cell_type": "code",
      "execution_count": 1306,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "2c281aad-7f59-45f1-95cc-436130843347"
    },
    {
      "cell_type": "code",
      "execution_count": 1307,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(11)).tolist()"
      ],
      "id": "a19803de-63c1-426d-a2bb-a0c0c3cac2c9"
    },
    {
      "cell_type": "code",
      "execution_count": 1308,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "7abf3a26-6250-4af7-bd8e-a9424c6f65f1"
    },
    {
      "cell_type": "code",
      "execution_count": 1313,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(17463):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "a1501f7b-f0f7-431d-abfc-89491cc9db45"
    },
    {
      "cell_type": "code",
      "execution_count": 1314,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "7cd228a7-acbe-42d0-b2b3-8fde1b883a07"
    },
    {
      "cell_type": "code",
      "execution_count": 1315,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "92b4b5de-05ff-498c-8d7a-e66bb28ab1c7"
    },
    {
      "cell_type": "code",
      "execution_count": 1316,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\niyLBJ4QQwqL8H3WjCVmSpoupAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "dd0769bb-ae05-449b-b8f2-7f15a1d213b8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "22bbb347-b27f-45fe-9971-ecf0d1f3aaf0"
    },
    {
      "cell_type": "code",
      "execution_count": 1574,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "7523218c-0ab8-4845-9fe6-80792d85fb9f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "9b821f3d-44a4-44df-bbe3-aee4c945dff7"
    },
    {
      "cell_type": "code",
      "execution_count": 256,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import WindmillOutputSmallDatasetLoader\n",
        "loader = WindmillOutputSmallDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "705448a7-d215-455a-a2cc-05db86f913bf"
    },
    {
      "cell_type": "code",
      "execution_count": 257,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "fdcf2ca8-5aef-4742-b7c9-ccff00008657"
    },
    {
      "cell_type": "code",
      "execution_count": 258,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "419b9bfd-eb07-40ca-9f7f-ff9f89ef2a9e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "006c6938-3a38-41ac-8f29-f70a78e7c070"
    },
    {
      "cell_type": "code",
      "execution_count": 260,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "4bf64604-ee19-47db-806a-9e2fadd57959"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "15a8e2f8-bd80-4477-af7b-4fb019811c87"
    },
    {
      "cell_type": "code",
      "execution_count": 261,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "317cc694-c337-4006-8a05-04861a996624"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 11개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{11}\\}, t=1,2,\\dots,17463$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "75e9c306-3cf1-4c4d-afca-2abf561bb006"
    },
    {
      "cell_type": "code",
      "execution_count": 174,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 5/5 [02:55<00:00, 35.01s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(5)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "a30ecf77-b59b-4d2b-9aa1-09de3d8c3fb3"
    },
    {
      "cell_type": "code",
      "execution_count": 175,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "bbd7579b-709b-48a0-8a7d-bb247a537d5c"
    },
    {
      "cell_type": "code",
      "execution_count": 176,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "3abe7234-01ab-4622-b208-9bdb868c0890"
    },
    {
      "cell_type": "code",
      "execution_count": 177,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "46c4138c-c750-4129-9ea5-099e47cb6f3b"
    },
    {
      "cell_type": "code",
      "execution_count": 178,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "7a18d3dd-b2a6-487d-a72c-d07b560ba33f"
    },
    {
      "cell_type": "code",
      "execution_count": 179,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "ff3aa017-a8ad-4fa2-a192-01ce27307b58"
    },
    {
      "cell_type": "code",
      "execution_count": 180,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "00c25af9-d518-4d90-92ce-2d28e295d40c"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-   The target variable allows for regression tasks."
      ],
      "id": "30ab4eba-9ef7-45e9-b53a-0294df889c12"
    },
    {
      "cell_type": "code",
      "execution_count": 181,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "ad7cf98c-69d2-4881-bff5-36e3bc8bb430"
    },
    {
      "cell_type": "code",
      "execution_count": 211,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y"
      ],
      "id": "b1b19456-64c8-4f62-9585-2577fbde07ba"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## METRLADatasetLoader_real world traffic dataset\n",
        "\n",
        "A traffic forecasting dataset based on Los Angeles Metropolitan traffic\n",
        "conditions. The dataset contains traffic readings collected from 207\n",
        "loop detectors on highways in Los Angeles County in aggregated 5 minute\n",
        "intervals for 4 months between March 2012 to June 2012.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 33\n",
        "-   V = 구역\n",
        "-   N = 207 \\# number of nodes\n",
        "-   E = 225\n",
        "-   $f(v,t)$의 차원? (3,) \\# Hourly energy output\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (207,4) (N,2,12),\n",
        "    $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11}$\n",
        "-   y: (207,) (N,), $(x_{12})$\n",
        "-   예제코드적용가능여부: No\n",
        "\n",
        "https://arxiv.org/pdf/1707.01926.pdf\n",
        "\n",
        "`-` Nodes : `207`\n",
        "\n",
        "-   vertices are localities\n",
        "\n",
        "`-`Edges : `225`\n",
        "\n",
        "-   edges are spatial_connections\n",
        "\n",
        "`-` Time : `33`\n",
        "\n",
        "-   between 2020 and 2021\n",
        "-   per weeks"
      ],
      "id": "ffd1a3b6-f1e3-441a-a10d-26926ead8dca"
    },
    {
      "cell_type": "code",
      "execution_count": 1575,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import METRLADatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = METRLADatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "0f7894e7-cb8b-493a-9150-687532a031f3"
    },
    {
      "cell_type": "code",
      "execution_count": 1576,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "a652a649-907e-4c7e-81cc-968685492480"
    },
    {
      "cell_type": "code",
      "execution_count": 1331,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "b3efa5b2-816e-4c7e-8f8d-cd07b124cb4a"
    },
    {
      "cell_type": "code",
      "execution_count": 1332,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "8bb2bbac-3728-47ea-b7f9-c9cdd6cb4b02"
    },
    {
      "cell_type": "code",
      "execution_count": 1334,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "640e624d-f5e6-4a05-bd5f-afe2e6755867"
    },
    {
      "cell_type": "code",
      "execution_count": 1335,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "0b71feb8-05cc-4976-8e55-ffa0b7e25510"
    },
    {
      "cell_type": "code",
      "execution_count": 1336,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(20)).tolist()"
      ],
      "id": "ef6e7b7e-5835-40f7-99a4-673c264010a7"
    },
    {
      "cell_type": "code",
      "execution_count": 1337,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "f6794bfa-5597-4bf7-bd38-b53b8a71bcb8"
    },
    {
      "cell_type": "code",
      "execution_count": 1341,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(1000):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "ed3d8b75-15fc-46ae-a5f7-69112bd7be45"
    },
    {
      "cell_type": "code",
      "execution_count": 1342,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "2710746d-cb1b-4bc9-9aa1-5c51c1bb33f3"
    },
    {
      "cell_type": "code",
      "execution_count": 1343,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "5c73dada-a610-42c6-b185-3498fe7750a6"
    },
    {
      "cell_type": "code",
      "execution_count": 1345,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nmecKWfhkZGRkZJ4r/h8ncQm6g2UZBgAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "c05e373c-7c38-44cb-b5ba-cf96f4b2daf2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "656c3419-57e2-40fe-b38d-61ccdbcbda9b"
    },
    {
      "cell_type": "code",
      "execution_count": 1577,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "1ead947a-3a32-46be-8d87-6bfc8040c64f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "논문 내용 중\n",
        "\n",
        "<figure>\n",
        "<img\n",
        "src=\"attachment:2022-12-21-ST-GCN_Dataset_files/figure-ipynb/37a3da87-4414-4f4a-9e56-e4844a164c58-1-11ce66b1-dc5e-45b1-9309-a4b44c38de95.png\"\n",
        "alt=\"image.png\" />\n",
        "<figcaption aria-hidden=\"true\">image.png</figcaption>\n",
        "</figure>"
      ],
      "attachments": {
        "2022-12-21-ST-GCN_Dataset_files/figure-ipynb/37a3da87-4414-4f4a-9e56-e4844a164c58-1-11ce66b1-dc5e-45b1-9309-a4b44c38de95.png": {
          "image/png": "iVBORw0KGgoAAAANSUhEUgAABYgAAAGwCAYAAAADs4FkAAAMPWlDQ1BJQ0MgUHJvZmlsZQAASImV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\nAUfAEXAEHAFHwBFwBBwBR8ARWAsI/C88+iLCS+YvNgAAAABJRU5ErkJggg==\n"
        }
      },
      "id": "7cbd1dac-532d-4d94-b2b9-92860fc6ddc7"
    },
    {
      "cell_type": "code",
      "execution_count": 262,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import METRLADatasetLoader\n",
        "loader = METRLADatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "79f7e613-ee73-481d-bb93-56ec038bf080"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "> **Note**\n",
        ">\n",
        "> `lags option 없어서 error 뜸` : get_dataset() got an unexpected\n",
        "> keyword argument ‘lags’"
      ],
      "id": "e3837be2-8ade-4a9b-8c5e-d912a4394f26"
    },
    {
      "cell_type": "code",
      "execution_count": 263,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "03d2a13e-cb70-4659-8aa5-37bff5541da8"
    },
    {
      "cell_type": "code",
      "execution_count": 264,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "793a0344-14fd-4956-8a51-bca19d85186b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X,Z$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11}$\n",
        "-   Z:= $z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11}$\n",
        "-   y:= $x_{12}$"
      ],
      "id": "ca5f9988-001a-49f0-925f-835f6aca8672"
    },
    {
      "cell_type": "code",
      "execution_count": 266,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "0abe11a4-0770-4b45-8198-840b1bddea0d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12}$\n",
        "-   Z:= $z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12}$\n",
        "-   y:= $x_{13}$"
      ],
      "id": "2c88f7ab-72db-4ad1-a622-fd5fbd141067"
    },
    {
      "cell_type": "code",
      "execution_count": 267,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "c3882440-1c22-47f1-b16a-9bc8edba994f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12},x_{13}$\n",
        "-   Z:= $z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12},z_{13}$\n",
        "-   y:= $x_{14}$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 207개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11} \\to (x_{12})$\n",
        "-   $x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12},z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12} \\to (x_{13})$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{207}\\}, t=1,2,\\dots,34248$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "28501a4a-3570-4c83-9c46-9a0e80495672"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "30819e5f-4303-4d18-9aec-511a01a8fd90"
    },
    {
      "cell_type": "code",
      "execution_count": 43,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "03d2215e-9252-4efe-a0e4-e36bc1804ca7"
    },
    {
      "cell_type": "code",
      "execution_count": 44,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "6930be35-a1ea-416b-9079-3d7bb2cabb8e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   node 207개, traffic sensor 2개"
      ],
      "id": "3ca10c2f-7601-4394-97a8-9b4dc9c1b4b2"
    },
    {
      "cell_type": "code",
      "execution_count": 45,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "24cea284-ed34-42d7-aa0a-6220a735606e"
    },
    {
      "cell_type": "code",
      "execution_count": 46,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "a37e38dd-9fe7-4da9-b828-de6a973b82f6"
    },
    {
      "cell_type": "code",
      "execution_count": 47,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "0695fc91-89fe-426b-bc4a-4c884b129c4e"
    },
    {
      "cell_type": "code",
      "execution_count": 48,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "77192f92-38b3-4e0b-a355-622685a041f3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "y\n",
        "\n",
        "-   traffic speed"
      ],
      "id": "e3049b15-b5e3-4a1d-9890-64e966da6375"
    },
    {
      "cell_type": "code",
      "execution_count": 49,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0]"
      ],
      "id": "5c8117c9-9be1-400d-850d-7e9e640d2500"
    },
    {
      "cell_type": "code",
      "execution_count": 50,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "2929102d-e5d4-43c7-a877-861ee1e712aa"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## PemsBayDatasetLoader\n",
        "\n",
        "https://onlinelibrary.wiley.com/doi/pdf/10.1111/tgis.12644\n",
        "\n",
        "A traffic forecasting dataset as described in Diffusion Convolution\n",
        "Layer Paper.\n",
        "\n",
        "This traffic dataset is collected by California Transportation Agencies\n",
        "(CalTrans) Performance Measurement System (PeMS). It is represented by a\n",
        "network of 325 traffic sensors in the Bay Area with 6 months of traffic\n",
        "readings ranging from Jan 1st 2017 to May 31th 2017 in 5 minute\n",
        "intervals.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 17470\n",
        "-   V = 풍력발전소\n",
        "-   N = 325 \\# number of nodes\n",
        "-   E = 101761 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# Hourly energy output\n",
        "-   시간에 따라서 N이 변하는지? False\n",
        "-   시간에 따라서 E가 변하는지? False\n",
        "-   X: (325,2,12) (N,2,12),\n",
        "    -   $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11}$\n",
        "    -   $z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11}$\n",
        "-   y: (325,) (N,2,12),\n",
        "    -   $x_{13},x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23},x_{24}$\n",
        "    -   $z_{13},z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23},z_{24}$\n",
        "-   예제코드적용가능여부: No\n",
        "\n",
        "`-` Nodes : `325`\n",
        "\n",
        "-   vertices are sensors\n",
        "\n",
        "`-`Edges : `2694`\n",
        "\n",
        "-   weighted edges are between seonsor paris measured by the road\n",
        "    nretwork distance\n",
        "\n",
        "`-` Time : `52081`\n",
        "\n",
        "-   6 months of traffic readings ranging from Jan 1st 2017 to May 31th\n",
        "    2017 in 5 minute intervals"
      ],
      "id": "59059db7-e4e1-405c-b68f-f032786ec148"
    },
    {
      "cell_type": "code",
      "execution_count": 28,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import PemsBayDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = PemsBayDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "dfebd554-0aac-4daa-86df-b09ae31ff541"
    },
    {
      "cell_type": "code",
      "execution_count": 10,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "9cc73813-a7a5-4599-8935-bd3561a833f3"
    },
    {
      "cell_type": "code",
      "execution_count": 11,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "1abae4cd-a23f-46d2-a799-a20ca776c9ec"
    },
    {
      "cell_type": "code",
      "execution_count": 12,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "e4cbd91d-0a31-44a4-80eb-a78ad1ef0d77"
    },
    {
      "cell_type": "code",
      "execution_count": 13,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "73bc848a-7ba0-4495-9d57-8e9f14ad086e"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(325)).tolist()"
      ],
      "id": "d1b3c59d-ce84-496e-8275-119bba16cd25"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "4622d304-5e38-42ef-a813-f52e4d9ece03"
    },
    {
      "cell_type": "code",
      "execution_count": 16,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "1399196d-4ae5-4eee-9697-5dc18530943a"
    },
    {
      "cell_type": "code",
      "execution_count": 17,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(1000):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "62f804d9-3861-4f4a-ae44-d1c7d913fcec"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "41b51a23-e4cd-4e3e-9e67-752020f1f7dd"
    },
    {
      "cell_type": "code",
      "execution_count": 19,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "c6358cd1-21c1-458d-970e-5fb6e64bc3ca"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,node_color='green',node_size=50,font_color='white',width=1)"
      ],
      "id": "31b83dff-6210-4f90-a1d1-f8d54457d531"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "51309aa1-85bd-46b4-8034-af7980775686"
    },
    {
      "cell_type": "code",
      "execution_count": 1580,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "c85393ab-4514-49e6-a970-3ec76e8cfaf5"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "169c7663-afb6-41f1-9184-b62c79e6f3ef"
    },
    {
      "cell_type": "code",
      "execution_count": 268,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import PemsBayDatasetLoader\n",
        "loader = PemsBayDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "01e927f4-d63f-4c75-93d9-c12bfcf404a3"
    },
    {
      "cell_type": "code",
      "execution_count": 269,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "c5530c08-b2a2-4081-afa4-b236afa0b95b"
    },
    {
      "cell_type": "code",
      "execution_count": 270,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "fd039bb6-f7e1-4083-89c0-142255c82102"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X,Z$와 $y,s$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11}$\n",
        "-   Z:= $z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11}$\n",
        "-   y:=\n",
        "    $x_{12},x_{13},x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23}$\n",
        "-   s:=\n",
        "    $z_{12},z_{13},z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23}$"
      ],
      "id": "cbdebac4-0857-47d7-af34-174c450b79bd"
    },
    {
      "cell_type": "code",
      "execution_count": 272,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "88f90480-c65a-4e2b-981f-35a73e92d729"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12}$\n",
        "-   Z:= $z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12}$\n",
        "-   y:=\n",
        "    $x_{13},x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23},x_{24}$\n",
        "-   s:=\n",
        "    $z_{13},z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23},z_{24}$"
      ],
      "id": "2c457726-496c-4b3a-8cf0-d00dcbc003a0"
    },
    {
      "cell_type": "code",
      "execution_count": 273,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "6b9a73e5-8384-44d9-b616-cfade81991d6"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12},x_{13}$\n",
        "-   Z:= $z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12},z_{13}$\n",
        "-   y:=\n",
        "    $x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23},x_{24},x_{25}$\n",
        "-   s:=\n",
        "    $z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23},z_{24},z_{25}$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 325개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $x_0,x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11} \\to x_{12},x_{13},x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23}$\n",
        "-   $z_0,z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11} \\to z_{12},z_{13},z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23}$\n",
        "-   $x_1,x_2,x_3,x_4,x_5,x_6,x_7,x_8,x_9,x_{10},x_{11},x_{12} \\to x_{13},x_{14},x_{15},x_{16},x_{17},x_{18},x_{19},x_{20},x_{21},x_{22},x_{23},x_{24}$\n",
        "-   $z_1,z_2,z_3,z_4,z_5,z_6,z_7,z_8,z_9,z_{10},z_{11},z_{12} \\to z_{13},z_{14},z_{15},z_{16},z_{17},z_{18},z_{19},z_{20},z_{21},z_{22},z_{23},z_{24}$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{325}\\}, t=1,2,\\dots,52081$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "389eb36f-9cc7-4642-9900-64deb7598f00"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "6d181941-40ed-4055-9747-ac865d0d4fdc"
    },
    {
      "cell_type": "code",
      "execution_count": 60,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "15a7b717-44ab-4c39-82d3-0cbc623a921f"
    },
    {
      "cell_type": "code",
      "execution_count": 61,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "cbc52cd4-b84d-4d02-8085-f276e7343196"
    },
    {
      "cell_type": "code",
      "execution_count": 62,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "451b8bdc-b156-409f-85c9-af9b8aa861e6"
    },
    {
      "cell_type": "code",
      "execution_count": 63,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "246cd945-c8cc-434f-8c29-967027c88609"
    },
    {
      "cell_type": "code",
      "execution_count": 64,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "b0b57b6a-e6b6-4afe-b629-5858303fec21"
    },
    {
      "cell_type": "code",
      "execution_count": 65,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "d2451710-9d95-49df-8be2-dd57228c88dc"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   .!\n",
        "\n",
        "y\n",
        "\n",
        "-   capturing temporal dependencies..?\n",
        "\n",
        "edges connect sensors\n",
        "\n",
        "For instance, the traffic conditions on one road on Wednesday at 3:00\n",
        "p.m. are similar to the traffic conditions on Thursday at the same time."
      ],
      "id": "99a20251-c01b-4c90-9ecc-920546dd837a"
    },
    {
      "cell_type": "code",
      "execution_count": 66,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "18a9a8bc-9f62-4296-9df2-cd9f21d1c788"
    },
    {
      "cell_type": "code",
      "execution_count": 68,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "675e2f37-b0b8-435f-b143-92aadb75da79"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## EnglandCovidDatasetLoader\n",
        "\n",
        "Covid19 England\n",
        "\n",
        "-   A dataset about mass mobility between regions in England and the\n",
        "    number of confirmed COVID-19 cases from March to May 2020 \\[38\\].\n",
        "    Each day contains a different mobility graph and node features\n",
        "    corresponding to the number of cases in the previous days. Mobility\n",
        "    stems from Facebook Data For Good 1 and cases from gov.uk 2\n",
        "\n",
        "https://arxiv.org/pdf/2009.08388.pdf\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 52\n",
        "-   V = 지역\n",
        "-   N = 129 \\# number of nodes\n",
        "-   E = 2158\n",
        "-   $f(v,t)$의 차원? (1,) \\# 코로나확진자수\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   X: (20,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (20,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `129`\n",
        "\n",
        "-   vertices are correspond to the number of COVID-19 cases in the\n",
        "    region in the past window days.\n",
        "\n",
        "`-`Edges : `2158`\n",
        "\n",
        "-   the spatial edges capture county-to-county movement at a specific\n",
        "    date, and a county is connected to a number of past instances of\n",
        "    itself with temporal edges.\n",
        "\n",
        "`-` Time : `52`\n",
        "\n",
        "-   from 3 March to 12 of May"
      ],
      "id": "b285189e-741d-4977-b51a-071af420d123"
    },
    {
      "cell_type": "code",
      "execution_count": 1581,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import EnglandCovidDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = EnglandCovidDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "ef24b09c-6bd8-4f9e-977b-7ab709359e02"
    },
    {
      "cell_type": "code",
      "execution_count": 1582,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "4ceedd34-be26-4aaf-87d4-303948045f5b"
    },
    {
      "cell_type": "code",
      "execution_count": 1366,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "cd4ad0bd-7791-4c02-b859-fc7552f544e4"
    },
    {
      "cell_type": "code",
      "execution_count": 1367,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "e1f66443-a819-42dc-8b5e-44b710fd4506"
    },
    {
      "cell_type": "code",
      "execution_count": 1368,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "7a03134c-6b8b-40a8-bdf8-2a5d67c82d6a"
    },
    {
      "cell_type": "code",
      "execution_count": 1369,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(129)).tolist()"
      ],
      "id": "b60e8aa3-bc3a-47ec-a6ba-9a0b18d48f9a"
    },
    {
      "cell_type": "code",
      "execution_count": 1370,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "dbd9dcec-4017-46c2-b3a0-3a3b2fb9c4fe"
    },
    {
      "cell_type": "code",
      "execution_count": 1371,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[-1]"
      ],
      "id": "9f4a64fb-c78d-4581-942d-50fc734d5501"
    },
    {
      "cell_type": "code",
      "execution_count": 1387,
      "metadata": {},
      "outputs": [],
      "source": [
        "len(data[0][1].edge_index[0])"
      ],
      "id": "ac96fa5a-8f36-4ae6-b29c-961750e6ae1e"
    },
    {
      "cell_type": "code",
      "execution_count": 1392,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(52):\n",
        "    for j in range(100):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "c2ba8036-935a-4032-8eff-34758bc35260"
    },
    {
      "cell_type": "code",
      "execution_count": 1393,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "cbc9869b-5f78-47e7-a498-8a84edab1bae"
    },
    {
      "cell_type": "code",
      "execution_count": 1394,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "c00ab06c-40b4-4ce0-a299-c934b86be7a5"
    },
    {
      "cell_type": "code",
      "execution_count": 1396,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n8AGQcgFpEVDQOfl2/AAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "a3c9f724-c931-49f9-a7e5-a841436df51f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "e0737bb4-0775-4af4-afbf-466b1042230b"
    },
    {
      "cell_type": "code",
      "execution_count": 1590,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[2][1].edge_index !=data[2][1].edge_index)"
      ],
      "id": "ff43d127-3efc-43b1-ac49-48ad494d1830"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "4efcb353-bfe6-4faa-8f14-a9cb03378d23"
    },
    {
      "cell_type": "code",
      "execution_count": 274,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import EnglandCovidDatasetLoader\n",
        "loader = EnglandCovidDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "4bcd84af-304f-41e1-b72b-f79b5e66a715"
    },
    {
      "cell_type": "code",
      "execution_count": 275,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "d25b8950-bfdc-48fa-809f-5ad698165fde"
    },
    {
      "cell_type": "code",
      "execution_count": 276,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "f362ccc7-8bd8-4bf3-b97a-f4287bf3404f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "9700d1e3-ffdf-45b1-82c4-28fb55a8a175"
    },
    {
      "cell_type": "code",
      "execution_count": 279,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "1b38186c-b222-4255-8013-0a1097623c9e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "ea52d5c0-28a2-44d5-9626-347505236245"
    },
    {
      "cell_type": "code",
      "execution_count": 280,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "29387dce-0f2f-47d8-b413-fc8b52ae5c82"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 129개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{129}\\}, t=1,2,\\dots,52$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "41a8fbda-e111-46ac-87c8-ab7e49642bbb"
    },
    {
      "cell_type": "code",
      "execution_count": 81,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:07<00:00,  6.30it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "06e21770-4118-4972-80a6-23f3b25390e3"
    },
    {
      "cell_type": "code",
      "execution_count": 82,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "fbd9e66a-7d73-447a-9602-26a92fbd0803"
    },
    {
      "cell_type": "code",
      "execution_count": 83,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "ccfa96f3-fd58-4a8c-a223-851860f8efea"
    },
    {
      "cell_type": "code",
      "execution_count": 84,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "81bec8f7-acf8-453c-91ea-82b712c2bc9d"
    },
    {
      "cell_type": "code",
      "execution_count": 85,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "3fac2f89-ebee-42cc-9cad-7412d02326f9"
    },
    {
      "cell_type": "code",
      "execution_count": 86,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "efe2c13c-2e34-41b1-9609-1499e0860e56"
    },
    {
      "cell_type": "code",
      "execution_count": 97,
      "metadata": {},
      "outputs": [],
      "source": [
        "y_hat.shape"
      ],
      "id": "9d4d7dea-e037-4250-833a-d00ddd5f6fe9"
    },
    {
      "cell_type": "code",
      "execution_count": 87,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "8fed3f10-1d61-4414-9e49-392bb734db4d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-   \n",
        "\n",
        "The node features correspond to the number of COVID-19 cases in the\n",
        "region in the past window days.\n",
        "\n",
        "The task is to predict the number of cases in each node after 1 day"
      ],
      "id": "fb45b9db-0d1c-44d6-9cb3-f15489219d77"
    },
    {
      "cell_type": "code",
      "execution_count": 88,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "ad683b6b-77a5-4e4f-9cb6-0743d6f4f8df"
    },
    {
      "cell_type": "code",
      "execution_count": 90,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[:3]"
      ],
      "id": "10c673b8-5554-4132-9f6c-84340356909c"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## MontevideoBusDatasetLoader\n",
        "\n",
        "https://www.fing.edu.uy/~renzom/msc/uploads/msc-thesis.pdf\n",
        "\n",
        "Montevideo Buses\n",
        "\n",
        "-   A dataset about the hourly passenger inflow at bus stop level for\n",
        "    eleven bus lines from the city of Montevideo. Nodes are bus stops\n",
        "    and edges represent connections between the stops; the dataset\n",
        "    covers a whole month of traffic patterns.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 739\n",
        "-   V = 버스정류장\n",
        "-   N = 675 \\# number of nodes\n",
        "-   E = 101761 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# passenger inflow\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   시간에 따라서 Number of nodes가 변하는지? False\n",
        "-   X: (675,4) (N,4), $f(v,t_0),f(v,t_1),f(v,t_2),f(v,t_3)$\n",
        "-   y: (675,,) (N,), $f(v,t_4)$\n",
        "-   예제코드적용가능여부: Yes\n",
        "\n",
        "`-` Nodes : `675`\n",
        "\n",
        "-   vertices are bus stops\n",
        "\n",
        "`-`Edges : `690`\n",
        "\n",
        "-   edges are links between bus stops when a bus line connects them and\n",
        "    the weight represent the road distance\n",
        "\n",
        "`-` Time : `739`\n",
        "\n",
        "-   hourly inflow passenger data at bus stop level for 11 bus lines\n",
        "    during October 2020 from Montevideo city (Uruguay)."
      ],
      "id": "60b4b0cc-a127-420f-8673-8655ace6b2b7"
    },
    {
      "cell_type": "code",
      "execution_count": 1591,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import MontevideoBusDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = MontevideoBusDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "cf8faecc-cc6e-498a-ad25-f00c02ee51ef"
    },
    {
      "cell_type": "code",
      "execution_count": 1592,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "246d0392-4a65-45fe-8533-6b29b4f99a1e"
    },
    {
      "cell_type": "code",
      "execution_count": 1399,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "015fc2bb-25fb-428f-b860-fda6ce96c63c"
    },
    {
      "cell_type": "code",
      "execution_count": 1400,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "b126e881-ba75-45a7-98c8-9cb1f399c3b3"
    },
    {
      "cell_type": "code",
      "execution_count": 1401,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "65ecde78-e690-434e-9ff3-0564a994fbc7"
    },
    {
      "cell_type": "code",
      "execution_count": 1402,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(675)).tolist()"
      ],
      "id": "5fbcfb0e-c77c-4208-ba68-17882a2664c3"
    },
    {
      "cell_type": "code",
      "execution_count": 1403,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "be87ad74-df93-4085-81d8-d657887efa12"
    },
    {
      "cell_type": "code",
      "execution_count": 1404,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(739):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "f5382d25-cfc3-4200-9e2f-aec320b17efd"
    },
    {
      "cell_type": "code",
      "execution_count": 1405,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "000cff82-2492-4503-b6cf-c91199b4e538"
    },
    {
      "cell_type": "code",
      "execution_count": 1406,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "1737c19f-37c4-4b1e-af4b-b54ad02a0784"
    },
    {
      "cell_type": "code",
      "execution_count": 1410,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,node_color='green',node_size=50,font_color='white',width=1)"
      ],
      "id": "97b04214-d253-49a9-a1da-13ec0fe8ba03"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "9dde7ad9-0fb7-462b-9bd9-98c1fbf0f541"
    },
    {
      "cell_type": "code",
      "execution_count": 1593,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[10][1].edge_index)"
      ],
      "id": "b9743a72-5a24-4d64-a192-1fed9e5c1f33"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "aaf3451b-2a84-4ba2-8455-bcace72333f8"
    },
    {
      "cell_type": "code",
      "execution_count": 281,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import MontevideoBusDatasetLoader\n",
        "loader = MontevideoBusDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "e52d27b5-e22c-4197-8e1e-c3f5645a590f"
    },
    {
      "cell_type": "code",
      "execution_count": 282,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "50927dcd-d8eb-48ef-8e5e-894579e6a4a1"
    },
    {
      "cell_type": "code",
      "execution_count": 283,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "6f6dd313-c58b-4b64-bfd0-8d90ca4c142e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "$t=0$에서 $X$와 $y$를 정리하면 아래와 같음.\n",
        "\n",
        "-   X:= $x_0,x_1,x_2,x_3$\n",
        "-   y:= $x_4$"
      ],
      "id": "ee07cde5-fab8-447c-976d-6dfb64043e95"
    },
    {
      "cell_type": "code",
      "execution_count": 284,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "13443b21-9e4c-4d80-abc3-9f0829607d63"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:= $x_1,x_2,x_3,x_4$\n",
        "-   y:= $x_5$"
      ],
      "id": "429e9769-0e9f-46ee-8c46-84ff3c8eba02"
    },
    {
      "cell_type": "code",
      "execution_count": 285,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "882532d3-a32d-4143-ba77-b756cda2d272"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   X:=$x_2,x_3,x_4,x_5$\n",
        "-   y:=$x_6$\n",
        "\n",
        "하나의 노드에 길이가 $T$인 시계열이 맵핑되어 있음. (노드는 총 675개)\n",
        "\n",
        "각 노드마다 아래와 같은 과정으로 예측이 됨\n",
        "\n",
        "-   $(x_0,x_1,x_2,x_3) \\to (x_4)$\n",
        "-   $(x_1,x_2,x_3,x_4) \\to (x_5)$\n",
        "\n",
        "$f(v,t), v \\in \\{v_1,\\dots,v_{675}\\}, t=1,2,\\dots,739$\n",
        "\n",
        "$${\\bf X}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=1) & f(v_1,t=2) & f(v_1,t=3)&  f(v_1,t=4) \\\\ \n",
        "f(v_2,t=1) & f(v_2,t=2) & f(v_2,t=3)&  f(v_2,t=4) \\\\ \n",
        "\\dots & \\dots  & \\dots & \\dots  \\\\ \n",
        "f(v_{20},t=1) & f(v_{20},t=2) & f(v_{20},t=3)&  f(v_{20},t=4) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "$${\\bf y}_{t=1} = \\begin{bmatrix} \n",
        "f(v_1,t=5) \\\\ \n",
        "f(v_2,t=5) \\\\ \n",
        "\\dots  \\\\ \n",
        "f(v_{20},t=5) \n",
        "\\end{bmatrix}$$\n",
        "\n",
        "#### Learn"
      ],
      "id": "c3536b15-4f06-4b2e-914d-189838e93ed8"
    },
    {
      "cell_type": "code",
      "execution_count": 99,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [01:51<00:00,  2.23s/it]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=4, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "9b2aaf5d-f014-4fe3-9cf3-8e55c3b99745"
    },
    {
      "cell_type": "code",
      "execution_count": 100,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "16fbaaa9-b50b-4f59-aad5-d44c64409b93"
    },
    {
      "cell_type": "code",
      "execution_count": 101,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "16b05dc0-33fd-49ed-b41c-ba598ad16037"
    },
    {
      "cell_type": "code",
      "execution_count": 102,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "4d61d344-f711-473d-a707-94bb6073ef4e"
    },
    {
      "cell_type": "code",
      "execution_count": 103,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "c14de653-0e30-4feb-9e92-795563af812f"
    },
    {
      "cell_type": "code",
      "execution_count": 104,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "75e8256b-6af0-4f7e-aea0-78cad0905ade"
    },
    {
      "cell_type": "code",
      "execution_count": 105,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "98651b4d-a7d4-4512-aa0b-db665b7f136e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-   The target is the passenger inflow.\n",
        "-   This is a curated dataset made from different data sources of the\n",
        "    Metropolitan Transportation System (STM) of Montevide"
      ],
      "id": "167012b9-0a00-4dbb-8fca-c6d8c115f8e7"
    },
    {
      "cell_type": "code",
      "execution_count": 106,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "6bd406ca-458f-4bbd-86ed-4d42fbaba004"
    },
    {
      "cell_type": "code",
      "execution_count": 109,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[:3]"
      ],
      "id": "4e8b5972-bf6d-4184-91a9-b5118ed1adf2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## TwitterTennisDatasetLoader\n",
        "\n",
        "https://appliednetsci.springeropen.com/articles/10.1007/s41109-018-0080-5?ref=https://githubhelp.com\n",
        "\n",
        "Twitter Tennis RG and UO\n",
        "\n",
        "-   Twitter mention graphs of major tennis tournaments from 2017. Each\n",
        "    snapshot contains the graph of popular player or sport news accounts\n",
        "    and mentions between them \\[5, 6\\]. Node labels encode the number of\n",
        "    mentions received and vertex features are structural properties\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 52081\n",
        "-   V = 트위터계정  \n",
        "-   N = 1000 \\# number of nodes\n",
        "-   E = 119 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (1,) \\# passenger inflow\n",
        "-   시간에 따라서 N이 변하는지? ??\n",
        "-   시간에 따라서 E가 변하는지? True\n",
        "-   X: ?\n",
        "-   y: ?\n",
        "-   예제코드적용가능여부: No\n",
        "\n",
        "`-` Nodes : `1000`\n",
        "\n",
        "-   vertices are Twitter accounts\n",
        "\n",
        "`-`Edges : `119`\n",
        "\n",
        "-   edges are mentions between them\n",
        "\n",
        "`-` Time : `52081`\n",
        "\n",
        "-   Twitter mention graphs related to major tennis tournaments from 2017"
      ],
      "id": "c08d244b-4b34-4766-b6e2-9c5283c79ca6"
    },
    {
      "cell_type": "code",
      "execution_count": 1621,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import TwitterTennisDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = TwitterTennisDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "b824f1e8-4731-4f6c-9ddf-4c5bf76d8e15"
    },
    {
      "cell_type": "code",
      "execution_count": 1622,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "17d1a26a-c2a5-466e-8c56-568342c0929d"
    },
    {
      "cell_type": "code",
      "execution_count": 1623,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "8f72fc6c-4bb6-4e4f-b696-b988dbc3275d"
    },
    {
      "cell_type": "code",
      "execution_count": 1624,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "2997e627-9e66-4ea7-9aa3-0e3cba486753"
    },
    {
      "cell_type": "code",
      "execution_count": 1630,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[0][1].x[0]"
      ],
      "id": "17485dc9-c4ff-4fd2-a174-2d545477add4"
    },
    {
      "cell_type": "code",
      "execution_count": 1631,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[0][1].edge_index[0]"
      ],
      "id": "4e9b30fb-2779-4508-98e1-89ada19f22fb"
    },
    {
      "cell_type": "code",
      "execution_count": 1633,
      "metadata": {},
      "outputs": [],
      "source": [
        "data[0][1].edge_attr"
      ],
      "id": "998fe143-0ea6-4b06-a80d-b549b87313d4"
    },
    {
      "cell_type": "code",
      "execution_count": 1438,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "e8db2dcc-183e-4de4-a329-a9297c814202"
    },
    {
      "cell_type": "code",
      "execution_count": 1439,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(1000)).tolist()"
      ],
      "id": "76df8944-10aa-49ca-bd83-51b81772a68d"
    },
    {
      "cell_type": "code",
      "execution_count": 1440,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "183d5660-0659-4130-9719-42e64e23c017"
    },
    {
      "cell_type": "code",
      "execution_count": 1441,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(119):\n",
        "    for j in range(40):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "473b84b5-5d84-4107-81be-93750cc1ef07"
    },
    {
      "cell_type": "code",
      "execution_count": 1442,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "7a072624-c874-4d46-8e91-9d5227e370a2"
    },
    {
      "cell_type": "code",
      "execution_count": 1443,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "bb418682-f3ad-4433-b599-fec3ee95bf0d"
    },
    {
      "cell_type": "code",
      "execution_count": 1444,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAAA/9UlEQVR4nO3deXgUZdY28Lu7090hJMoAI4GwiEgQMERQEAcc2QwQwFER4icq\nvAYXlsGwmejgMi4gvAITWQadzDiAoCDOKMomoIIBjfqyJsoijgQMCIiEDkk66eX7AzuTpbq7qrqq\nu6rr/l3XXNdIL6l0uurU8zznnMfk9Xq9ICIiMghzpA+AiIgonBj4iIjIUBj4iIjIUBj4iIjIUBj4\niIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjI\nUBj4iIjIUBj4iIjIUBj4iIjIUBj4iIjIUGIifQBEkeJwOrCmaA2O/nwUHZt1REbXDCTYEyJ9WCSg\nsrIS+/fvx8GDB/Htt9/i448/BgAMGDAAnTt3RkpKClJTUxEbGxvhIyU9MHm9Xm+kD4Io3PKL85G+\nKh0erweXqi+hsbUxzCYzNo7ZiL5t+0b68OhXBw8exLJly/D222+jbdu2SE1NRZcuXVBaWgqv14sm\nTZrgm2++wYEDB3D8+HHce++9eOyxx5CSkhLpQycNY+CjqBNsJOdwOpC0IAmOKkeD1ybYElAyvQTx\ntvhwHjLVU15ejqeffhqrV6/GhAkT8D//8z9o06ZNwNcUFxfjn//8J5YuXYoxY8bghRdeQFxcXJiO\nmPSEgY+iipiRXN6ePGRtzsKl6ksNXt/Y2hi5Q3KR2SMz3IdOvzp37hwGDhyIrl274tVXX0Xz5s0l\nv37KlCkoKirC9u3bJb+eoh+TWyhqOJwOpK9Kh6PKURPULlVfgqPq8r+XVZUBAI7+fFQw6Pme/935\n70I6hrw9ecjemo28PXlwOBuOKsm/0tJSDBgwAMOGDcOqVatkBa3mzZtj1apVSE9Px8CBA1FaWqrC\nkZKeMbmFNEtq8smaojXweD2Cj3m8HqwpXIPMHpno2KwjGlsb+x3xXdv0WlnHKzTanLZlGtcNJZg5\ncyZ69eqFl156CSaTye/zgn03TCYTZs+ejTNnzmDmzJl4/fXXw3H4pBOc6iRNkpN8kr01G/N2z/P7\nnjl9cjBn0BxV1vjUek8jZZ1+/vnnGD16NIqKinDFFVf4fZ6U70ZpaSlSUlKwZs0a3HLLLWr/CqQT\nnOokzRE7ZVmfbyQnpPZILsGegI1jNiLBllDz/MbWxkiwXf53OYktYkabUuQX5yNpQRKyNmdh3u55\nyNqchaQFScgvzpd8bHqxePFizJgxI2DQk/rduPLKKzF9+nQsXrxY1WMnfWHgI9VJXfeSG0QyumbA\nbBL+SptNZmRcn1Hz333b9kXJ9BLkDslFTp8c5A7JRcn0EtlTklLWDYN9HnIDv55dunQJH3zwAR54\n4IGAz5Pz3XjggQfwwQcf4NIl4b8PGQ/X+EhVcta95Caf+EZy/qbB6o/k4m3ximVvil03FPN5iF2r\njCYHDhxAx44d0bRp04DPk/PdaNq0KTp27IiDBw+id+/eihwv6RtHfKQatacshSg9khNLzGhTC1mn\nWvXNN9/g+uuvD/o8ud+NlJQUFBUVhXSMFD0Y+Eg14ZiyFOIbyc0ZNAeZPTLDUowuZt1Q7OcRSuDX\nq+rqajRq1Cjo8+R+Nxo1aoSqqqqA781SFOPgVGeUi2RmYLimLNUg53PzjTbXFK7Bd+e/w7VNr0XG\n9Rk1xyv288jomoFpW6YJPk9M4NejmJgYOJ3OoM+T+91wOp2IifF/uWMpirEw8EWxz45/hqGrhsLj\n8aDCXYFGlkaYunkqNt2/KSwncyj1csGCiJoBPZSLYKB1Q7Gfh9SLezSUPVx33XX429/+Juq5wb4b\nQoqKipCZKfx3qT0F7eP7G6WvSmcLuyjEOr4oc/bsWaxcuRLrPliHz3/3OWBr+BxTlQnDDw/HuPvG\nYcSIEbBaraoci1o9MdVsMK1mH0+p711WVRb04h4tzbYdDgeSkpJw8uTJgOUMcly8eBGtW7fGjz/+\niISEhjcEbGFnPFzjixIXL17EpEmTkJycjP3796PXQ738NuiNjYtF89uaIzc3F23btsUbb7wBofuf\nUNc81KiXUzvVX+l6vNqkfh7B1iqjqewhISEBaWlpWL16teLv/dZbbyEtLU0w6AHGTCYyOk51RoGC\nggKMGjUKaWlpOHbsGJo2bYrsrdko/75c8PkVrgq06NwC/9jxD+zduxeZmZlYs2YN1qxZgyuvvBKA\ncmsecqalAlE71V/ti6CSn0e0lT1MmjQJ48ePx4MPPhjSrgq1p37bJbTDKwtfQd7SPL/PV6uFHWkX\nA5/OffHFF7jjjjuQl5eHO+64o+bfxZ7M3bt3R0FBAbKysjB48GBs2bIF5lizomseStbLqR2YwnER\nVOrziLaRSv/+/dGrVy/86U9/wsKFC2W9R/0bNqvXCu9oL2zXCsz5/yr92nT80ftHwceiNZnI6DjV\nqWNnzpzBnXfeiTfeeKNO0AOkpX1brVYsXrwYqampGDduHN4ufFu16b5QqZ3qH2opRThFsuxBrdT/\nV199FR9++CFeeeUVyT9baOq32lQNl8Xld+o3vzgf1y25Dqg30x8bExt0Sp7lD/rF5BYdu/fee9Gu\nXTvMnTtX8PGlXy3FpI2TGvz7kvQlmNhzYoN/dzqd6N69OzpO7Ij1P6/3+3N9zZ4jIRybyOolYSRS\nG+qq/fmcPHkS/fv3R1paGl5++eU6a3OBfvahc4ckJakE+vzsFjt+yPoBifGJEfkMSF0c8enUoUOH\n8Omnn+K5554TfNzhdCBnW47gYznbcgTvfu12O1599VV8veVrzRZQq5EwU1+kur9IFY7Por5wJNS0\nbt0aX375JSoqKpCSkoJFixbh/PnzQX/2/xX/n6Sp30BrpDHmGGw4skHwsWhKKjIqrvHpVF5eHsaN\nG+e324XcxIeBAwei0ZRGuHDzBcHXamG6T+mEGSFKrkuqKRyfRW1qJdQI1SL+4x//QH5+PpYuXYqn\nn34aLYe1RGXHSkBgm75LFZfw99V/h6WzBW6zu8HjQjdsctdIoy2pyIgY+HTq448/xtKlS/0+Lvek\nNplMuHv43fjF+wvW2NZErHNKMHoJTOEQzs9CjYSagBnEffuib9++OH/+PB5b9xgOnTok+B4eiweP\njXkMK79ZKTh1KXTDJjeRKdqSioyIU506VF1djUOHDqFbt25+nxNK4kP37t1xft95XUz3UXgpnVAj\ndtqwadOmSLspLeDP7tGmh6SpX7mJTEbspRptGPh0qKysDHa7PWCtUyjZiYmJiTh//nxEmj2Ttimd\n9SqlYYCYny1lfVbuGqmeMn9JGKc6dSpYMm4ojZ6Z6Ev+KN1AXMq0odifLWXqV84aqRaaqFNoGPh0\n6IorroDL5UJpaWlNpxUhchMfiouL0bJlS6UPm6KEkgk1UtfZ1EjmkbNGGu6kIlIW6/hCFKnO+L17\n98bLL7+Mfv36Kf7eU6ZMQevWrfHEE08o/t5EtUWqFpGMjYEvBJEsYn3++edx+vTpgJmdcrhcLrRr\n1w5btmwRtSM2Uaj0WgweDdtBGRUDn0yh3qmGetKcPHkS3bp1w3fffYemTZvK+h2ErF27Fn/5y1+w\ne/duxd6TKBgxWzBpiV6DNV3GwCdTKHt4KXXSPP7447hw4QKWL18u+LjU4HrhwgWkpKRg5cqVqkyh\nEmmNnBvQSE7PcpSpDAY+mbK3ZmPe7nl+H/fXz1LJk6asrAypqamYOXMmHnvssTqPSQ2uTqcTI0eO\nRNu2bRWfPiXSIrk3oJHauJajTOWwjk8muUWsSm50Gh8fj48++gizZ8/GwoUL4fFcft9ARcFD3xza\noJfghQsXMHLkSNhsNuTm5or++UR6FUq/TbmdW0LZzYH9QZXFwCeT3CJWpdsddejQAZ9++inefvtt\nDBw4EIWFhQGDa1l1GV7c8SIAwO1245133sH111+Pq6++GmvWrIHVapX084n0KJQbUDk3vfnF+Uha\nkISszVmYt3sesjZnIWlBEvKL81U/XmqIdXwyyS1iVWOj02uuuQa7d+/Gq6++irS0NJhuN+HSNcLB\nFQDmfz4fnh0evLX8LbRq1QqrV6/G73//e8k/l0ivQrkBzeiagWlbpgk+JnTTW3u0VvtnAOI3dmZ/\nUGVxxBcCOdvXqNXuyGKxYOrUqSguLsbd/e6G2eP/T+t2u3HQcxAbNmxAQUEBgx4ZTij9NsW2OvNN\nbY56ZxScbqfge4kdrbE/qLKY3BIBai9SO5wONJvXDNWear/PieRmskSRpkSSWaASjPrneCBizkUW\n+iuLU50iKZlGrHa7owR7AqbeMhXzdglnnfIOkYxOiX6b/lqdCU1t+iP2XGR/UGVxxCdCKCO0SNXd\nOJwOtFrQSjDbi3eIRJepUTgfqNyhPsklTDor9NcqBr4gQpliiHTdTaR/PpERBavxBcBzMcI41RmE\nmDRisdMdUjO5QsUO8kThFyhz226xY0D7ARjZeaTgucjOLOHBwBeE3DRiuQFTaXK2XCEi+QKVO9gs\nNqwdtVbw5lNohmbalmkcFaqA5QxByE0jZt0NkTHJ2dk9HJ1ZQukcE2044gtCarGqjxqF6kSkD1KX\nGdSeIeJosi4GviDkphHLDZhScU2ASJukLDOoOUOkhXwDrWHgE0FOkkg46m54F0cUHcTOEMm50dVK\nvoGWsJxBZf7qbkIdqbGTA1H0EHM+7zu9T1Z5ktwt1KKZ4UZ84Z4aFJruUGKkxrs4Iv0Idt0JNkPk\n9XplT1cy36AhQwU+LUwNKjXfzqxRIn0Qc91xOB04dO4QxvcYj5/Lf0azRs3Q9aquNTNEeXvyZN/o\nhivfQE8ME/i0ssCr1EiNd3FE2ifmuhNoCtN3TRJ7o+tvZMk+n3UZJvBpZWpQqZEa7+KItC/YdWf5\nvuV4cvuTQW/IxdzoBhtZsovTfxmmgF0rU4NK7aslp0iWiMIr2HXnwyMfitpZPdg+nukd04MWwPvy\nDeYMmoPMHpmGvkYYJvBpZSNHJTeilbMRLhGFT7DrDgBRN+TBbnQ3HN0gKoDSZYaZ6tTK1KDS8+3s\nxUmkXcGuO8OSh+Gz4s9ErdUHmq784PAHmpjR0ouoDnz1F3rXjV6He9beE/EF3tQWqZg9cDY2HNkA\nABiePBxjbxhr6KkHomgU7EY3tUUqntr+lOBrhW7I/d3ohprsZrQOUFFbwO5vL7p1o9fhROmJiC3w\nco88IuMJtIGs2GtCoOCk531DIyEqA59Wu5po9biIKLKC7awuJjgFek5qi1TBoGnUa1JUTnVqpXSh\nPq0eFxFFVqC1erE1yP7WAPed3oekBUmCZQ6Hzh2SfU3yer04ceIEzp8/j/PnzyMxMRHt27dHo0aN\nQvw01BeVgU8rpQv1afW4iEi7pNww1w+gwYJmZvdMSdekw/85jJw3c/DVsa/w89GfceXJK3Hp/CWU\nlZUhOTkZxcXFaNeuHW6++WaMHTsW/fr1g9msveIB7R2RArRSulCfVo+LiLQrlBvmYEHzfOV5Udek\ns2fPIm18Gq7Luw4fuj7Ej+1/hDndjPLHyrGpaBO8Xi8OHz6M0tJSvPPOO+jRoweysrLQqVMnbNq0\nSeJvrL6oCny+HYYLzxTC7XULPieSXU2UrOEjImMI5YY5WNBs3qh50GvSpk2b0LVHV+xovQOwAS6z\nCwBQ7ipvsEO8zWZDSkoKHn/8cezfvx9LlizBxIkTkZmZiaqqKim/tqqiJvDlF+cjaUESsjZnIbcg\nF/g1ZSc2JhaANrqasNsKEUkVyg1zsKDZ5bddAl6TPtnyCcaOHYuH5j8Eq80q+D7+CuRNJhPS0tJw\n8OBBnD17Fvfeey+qq6uD/bphERVZnYEyk+wWOyb1moQuzbtopjddsAwuIqLa5JYciM3aFLomnfz+\nJPr27YuNGzfi3dJ3Q9rTz+l04q677kLnzp0xf/58ab+8CqIiuSXQPHaMOQZdmnfRVLYku60QkRRy\nm0yL7RRV/5rk8XiQmZmJ5557Dr169cKBPQdCKpC32+1YsWIFUlJSMHr0aNx8880yPgXlREXgY7Yk\nEUU7uTfMcoLmxx9/DIfDgYkTJwJQpuVj8+bN8fzzz+Oll17C+vXrJf8eSoqKwMe96YiI/JMaNF9/\n/XVMmDChphTBN3Ic+uZQVHmqUOWugs1ig81sk5SfcN999yE7OxsnT55E69atZf0uSoiK5BZmSxIR\nKcPr9WLbtm246667Gj5oAkww/fp/Tfj1/4rWuHFjDBo0CDt27FDgSOXTdeDzlS+8uPNFTOg5AfHW\neGZLEhGF4MSJE7Db7UhMTKz5N18hfFlVGZxuJwDA6XairKqsTjmDGN27d8fevXsVP24pdDvVKZTl\nZDKZMPmmyTCZTJKyJY3WmZyIyJ+ff/65TtADlG23mJiYiCNHjoR8nKHQZeAL1IZn6ddLJTVWFQqg\nvj520dqZnIgokPpVbkomEGqhgk6XU51i7j7EqB1AfX/US9WXGnQjICIyisTERJw8ebJOgFKy3eKJ\nEycajCjDTZeBT6m7D6UCKBFRtGjZsiViYmJQXFxc829KJhDu2bMH3bt3D/k4Q6HLwKfU3Qfr/4iI\nGho6dCjWrl1b899KtVv85ZdfsGPHDgwYMECV4xZLl4FPqbsP7pZARNTQI488gmXLltVpLO0rhM8d\nkoucPjnIHZKLkuklknIh/v73v2Po0KFo3ry5Goctmm57dcrtXVebUXcfJiIKxOv1YsSIEejZsyee\nffZZRd7z+PHjuOmmm7Bz50507txZkfeUS7eBD1Cm2bMSAZSIKNqcPHkSN954I9544w2kp6eH9F6l\npaVIS0vDnXfeiSeffFKhI5RP04EvXPV13C2BiKihL774AnfccQeWLFmCUaNGNXhczDX61KlTuPvu\nu9GjRw8sXrwYJpPEdi8q0GzgCzQSS22RyoJzIqIw+Oqrr3DffffhxhtvxLx589C2bVsAwWfLqqqq\nsGLFCjz11FOYMGECnnvuOU0EPUCjgS/Q2lucNQ5mmOGFl1OTRERhUFFRgeeffx6vvfYaevfujRH3\njMCMUzNQ7ipv8NxG5kYYXzoea1auQZcuXbBw4ULccMMN4T/oADQZ+PL25CFrc5bfUgMhTEYhIlJX\neXk53n33XSzatQhfN/8aXmvD8GF2mzHUOxQLHliA5OTkCBxlcJosZwhUX+cPC86JiNQVFxeHBx54\nAP1H9hcMegDgsXiQcluKZoMeoNHAF6i+zh8WnBMRhYfea6A1GfgCFaj7o4cPm4goGmR0zYAXwiM+\nL7ya3wNVk4HPX3uceFs8GsU0EnxNsI4tvr37srdmI29PHhzOhokzREQkjr/0EA2mjTSgyeQWH6H6\nun2n90kuOGeROhGRcgIlIDa2NkbukFzR+/NFgqb344u3xTf48Hz94sQWnAfauy99VTozQYmIJNJ7\ng39NBr5g3QCEAqI/Su4cTKRVFy9ehMPhgMViQUJCAho3lpYcRiSFL7nF34hP6/kWmgt8Su+Irvc7\nEyIhx48fx/Lly7Fr1y4cOHAAFy9eRHn55WLi2NhYJCYmolu3bhg4cCDGjBmDZs2aRfiIKZpkdM3A\ntC3TBB+Tuj9fJGgquUWNHdH1nnZLVNt3332H4cOHo0ePHjhz5gymTJmCgoIClJWVwev1wuv1oqys\nDFu2bMH999+PL7/8Eh06dMBDDz2Ec+fORfrwKUqI2Z9PywmFmkpuUWPBlFsPkRo8Hg++//57HDhw\nACdOnMB7772HP/zhDzUjreTkZMTEKDuhsmTJEjz77LM1vQ8bNRLOcK7v/PnzePHFF/HWW28hLy8P\nw4YNU/S4yLj8NfjXekKhpgJf9tZszNs9z+/jOX1yMGfQHMnvq/U/AumD1+vFV199hby8PKxduxZN\nmjRBSkoKrr76arzzzjsYPXo0fvzxRxw4cAAlJSW44447MH78ePTv3x9mc2iTK7Nnz8aKFSuwYcMG\ndOjQQdZ77Nq1CyNHjsTSpUtx9913h3Q8RP7oYbChqTU+OQumYrbFkJoJSlRfSUkJJk6ciP379+OR\nRx5BUVERkpKSah5ftGhRneefP38eq1evRlZWFpo0aYK8vDx06tRJ1s9evXo1/vnPf2LHjh1o2bKl\n7N+hT58+2LRpEwYPHox27drhxhtvlP1eRP7oIaFQUyM+qXcKHMlROOTn5+Puu+/Go48+ilmzZsFu\nt4t+rdvtxpIlS/D8889j2bJluOeeeyT97J9++gndunXDhg0bcNNNN0k9dEFvvvkm/vd//xdfffUV\nbDabIu9J5KPWzJ2SNJXcImbB1EeNRBii+nbv3o277roLb775Jl544QVJQQ8ALBYLpkyZgm3btmHy\n5Mn497//Len1CxcuxOjRoxULegBqsjzXrl2r2HuS8fhLXtFDQqGmRnw+YnZE13vnANK+0tJSpKSk\n4K9//asiCSF79uzB4MGD8fXXX6Ndu3ZBn19VVYW2bdtix44dsqdJ/Xn33XeRm5uLnTt3Kvq+ZAzB\nNgrX+hpfRAOfmPU5f/QwnCZ9mzx5MqqqqvD6668r9p6zZ8/G559/jg8++CDoc7/88ks8/PDD2L9/\nv2I/36eqqgpNmjTBmTNnEB/PtW4ST8ySlJzWkuEUseSWUAvV9d45gLTtwoULWLVqFQ4fPqzo+86Y\nMQNt27bFkSNHgu5XtnfvXvTo0UPRn+9js9nQpUsX7N+/H3369FHlZ1B0Epu8ouWEwogEPiX6Z+q9\ncwBp25o1a5CWloarrrpK8mt/+eUXHDx4EEeOHEFBQQGuuuoqJCcno2vXrujSpQvGjh2LN954A3Pm\nBJ6R+Omnn9C6dWu5v0JQbdq0wU8//aTa+1N0EtsNS0pryXCLSHKLmDuGYKQkwhBJtXv3btx+++2i\nn3/mzBm88sor6Nq1K9q2bYvs7Gzs2rULBQUF2Lt3Lz766COMHz8ezZo1w8aNG/Gvf/0Lly4JXzxq\nM5lMofwaRIrTQ/JKMBEJfEr1z/TV5+UOyUVOnxzkDslFyfQSTcwhk74dOHAAqampQZ/ndrsxf/58\ndO7cGUVFRXjttddQWlqKzz//HHPmzEFOTg66deuGixcvori4GJWVlfB4PDh69CiSkpKwcOFCv+/d\nvHlznDp1Sslfq45Tp06hefPmqr0/RadAG4XrZbYtIlOdSq7PaXk4TfpVUVGBhITAiVYXL17EiBEj\nYLFYanpiAsC2bdswe/ZsFBQUoF27drh48SKSk5Nxzz33oEWLFmjfvj0efvhh9OnTB0888QReeukl\nzJo1C23atEFhYWFNG7SvvvoK8fHxqKysRLdu3dCjRw/cdtttirRCc7lcOHjwoKjgTlSbb7bNX/KK\nHmbbIpLVKbelTShZoERSdO7cGe+88w6uv/56wccdDgcGDx6MG264AYsXL4bZbEZ+fj4efvhhHDly\nBFdddRV69+6Nrl27orCwEO3bt4fJZEJhYSH27duHc+fO4ZVXXkFqaipGjRqFCxcuoHHjxsjIyMCg\nQYPQqlUrnDlzBpmZmfjTn/6EU6dOYdeuXfjxxx8xbtw4TJ8+HU2bNpX9+23cuBHPPfccvvzyS9nv\nQcYmpuxMqyJWziC16wq7tFA4DR8+HA899JDfnpaPPvooysvLsWLFCjgcDkyZMgWrVq1CamoqVqxY\ngS5dutQ8t/4NW3J1MsbeOxZNmjTB/v37MWLECHz//fe46aabsGHDBqxduxb9+vUDADz++OOIjY3F\n3LlzAQCFhYVYtGgRPvjgAyxatAgjR46U/fvdeeedGD9+vKzXE+lZROv4xN4x6KHpKUWXZ599FpWV\nlTUBp7bPPvsM9913HwoLC/HLL79gwIABuHDhAsaPH4+5c+fWSUgRumFzVbvQZEMTdG7cGTNmzMCs\nWbOQlJSEgoICvP7663jkkUewceNG9OzZE8XFxejRowd27txZJ5ju2rULDz74IB577DHMnDlT0u/2\n/vvvY8aMGThw4IDoHR6IookmO7fUxy4tFG6FhYUYPHgwjh8/3mBN7e6778aQIUOQnp6OW2+9FVdf\nfTWSkpKwcuXKyzdzv47u2lzZBk9uf1KwfZ652owz2WfQLKEZKioqcMcdd+A///kPMjMzcc011+DP\nf/4z9u7dC7vdjr/+9a947bXX8Mknn+A3v/lNzXucPHkS/fv3x7Rp0zBhwgRRv9fRo0dx22234a23\n3sJtt90W2odEpFO6CHzs0kKR0LdvXzz88MMYO3Zszb+dPXsWycnJOH78OEaNGoWOHTti3bp1KCoq\nwreXvq0zurNZbKhyVwm+d/0btoqKCvTo0QPnz5/H6dOnceedd+LWW2/FjBkz4PV6MW3aNOTn5+PD\nDz9EixYtat7n2LFjuPnmm7Hts234uuLrgOvfRUVFGDJkCJ599llOcZKhaapJtT/RUDdC+pObm4sn\nnniiTpF3QUEBevbsiQ8//BBnz56FyWTC+PHjYYu3NWia7i/oAQ3Ldho1aoS3334bZ8+exaFDh/Dk\nk09i2bJl8Hg8MJlMWLBgAYYNG4Zu3bphxYoVcLvdAIAOHTrg3ifuRc+3eiJrcxbm7Z6HrM1ZSFqQ\nhPzifABAZWUlZs+ejdtuuw2zZ89m0CPD08WIj2t8FCl//vOfsX79emzbtg2/+c1vMGfOHJw/fx47\nd+7ErFmz8PDDD2PTx5swa/csbDq5CV6TuNNJaIre4/GgWbNmaNeuHVq2bIlt27bBZXYB1wOxSbFo\nZW+FLt4u+GbvN3C5XMjMzETfgX3xhx1/QFl1w+nUOEscxp4bi3dWvYNbbrkFixYtEtUcmyjaaWoj\nWn+ioW6E9OmZZ55BaWkp+vXrh9WrV6O8vBxOpxM//vgjUlNTcfE3F3HT6pvgMXsAi4Q39qKm0Ne3\nZ99f/vIXVFVV4YcffsALL7yAyqsq8fk1n8NitaC8uhwl5hL86PkRba5qg1M/nMKyL5fhtb2voaxL\nGSCwrV6lsxLFVxSjoKAA11xzjTIfCFEQeig708WIz0fPdSOkX16vF6+//jpmzZqFTp06IS4uDgkJ\nCTjx0wl89fuvgGBb9HkBi8kCN9yItcTC6/bC9p4NQzKG4Ir2V2D72u1oXdoaC+YswDPPPIOPP/4Y\nP5z6Ae0XtYcTTr9va/Fa4Pa4AwbcMSlj8Obdb8r7xYkk0kvZma4CH1EknThxAuPGjcOnn34Ki8WC\n5mnNcfqG0/BaA59CsaZYPNnzSTw7/1k8+eiT6HV9L9y77l44XU7ADNhgg91mx8YxGzFuwDjYbDbc\n9cJdeKXwFVTB/zphDS8APy097RY7zj1xjjeIpDo9LUlFbHcGrQ+FKXrJ/f41uaoJek/qjY8tH6N1\n49aIbx+PU9YgvTS9QKWrEs9OfRboDMz5bA5QhMuB6tfUsipUoaqqCoNWDIL5ohk3droR/yn9j7ig\nB/gNesDlkaZvmxgiNYndrkgLwh74Qt2HjygU+cX5GLpqKKrd1XC6nbBb7Ji6ZSo2jdmEa23X4v33\n38f+/ftx8OBBnDp1CseOHUPHjh2R0DUBB1MPwuPxAH2AEm8JLDEWoBKANcAPNOHyWXZvrf/2w+l2\nwjTBhHP/dw594vvA4rbAbXGH9PuWu8pFN30nCoVSmw+EQ1gDnxL78BHJ5XA6MPjNwSivLq/5N6fb\nCafbiX5/74f4v8ZjxOAR6NmzJ0aPHo1WrVrB47l8g3bre7ei2lNds57mMrngcrvEn0Eidxfymr04\ndNMhzGw9E579EhJm/Ex3styHwkVPm4OHtY5PiX34iORavn95naBXm9vsxtPvPo2VK1diypQp6Nev\nH5KTk3Hddddhb/VemC1+ThXXr/8LbWBWlwl4ZOsjSDiWcDmgiXyNEJfHhaKzRcjbkweHs+HaC5FS\n9LRdUVgDn56GwhR9PjzyYcDH1x1eJ/jvgb63sALYA3SI6xDi0dXl9rpxsdNF0SNFuC6v5+HX+0qr\n+fL8q8lkwsIvFjYoaidSmp42Bw/rVKeehsJkPF+c/ALfn/we17T+b82bw+nA6bLTiDHFwOV1NXyR\nF0BP4FjFMWVvI02//i9AxmYdlsvB0vfcak81gMuJNQCXFCg8fJuDa73sLGyBz+F0oNJViWp3teDj\nWhsKU/QZnjwcW45t8f8EN3DdPdfhsV6P4ZlnnsGh8kNIX5UOt9ctHPSA/wYlsSMzqcS+r8jj0Fp2\nHUUfPWwOHpY6vvqZnLVptcCRoo/D6UDTuU39BzEAHX/qiON/Pw5PYw88f/Rc7sgSZdjUnYxO9RGf\nUCanj9Vsxdzb52Js6li/Q2HW/JGSro+7HvvK9gmOjCxuC0YNHIVbHrsFd/7rTngQfUGPSwpEYQh8\ngTI5bRYbYi2xfoMea/5IKb7vUnllud+1uJiYGPzzqX9i7ui5cMcomaapHVxSIApDVqfcTM7aI0Xf\n6y9VX4Kj6vK/C23uSSSk9nfJbW4Y0OJi4pBgS8C2cdvw9MqnEWPVRe92yWwWm+ay60h/HE4H8vbk\nIXtrtm7LZFQ/w+Vmcuqp/Q2Fj5yp70DfJavZilFdR2Fx+mLE2+LxweEP4PT6bwytVzaLDQvSFnCm\nhEIiZhZOzjka7iUt1ZNb5DYu5a7rVJ+czu8OpwOj3hkVMJuz6TdNMQiD0CmlE/KvzMdnv3wWMAFG\nj3zNqr1eL9fMSRYx1/J9p/dJPkcjsaOD6iM+uXvpseaPapPT7s53Qjnd/kdwja2NMeX+KXD/5MbL\nJ19G9bnqMLd1CA+n24lHP3wU6w+thxderpmTZMFm4ZbvW44ntz8p6RyNVBvLsJziqS1SMXvgbNza\n9lYM7TAUcwfNRcn0koAnm57a35D6pLa7q31CVbn973Lg9rpx3y33Yf6Z+ag2RWfQ81l9cDXKqsu4\nZk6yBMvX2HBkg+SWlJFqY6n6iE9oGJt/Ih+piakBAx93Xafagp10Of+bg7fPvY0WLVogMTERx5sd\nR1V18G19XB4Xrv/r9ajyiNwCKApxzZzECDYL55tJEOIvkTFSbSxVDXyhDmP10v6G1BfopIuLicPk\n+ybjd7G/w+nTp3H69Gns+GUHnPbgSSouT3St5clxqfoSis4URfowSOMyumZg2pZpgo+ZTWYMSx6G\nz4o/k7Q8FaklLVWTW/L25CFrc5bfXyp3SC7vMkkUqUlSgb571JDdYse2B7dxrY8CCpSIktoiVXIi\nY6R2bVd1RYO7MZBSpHZ+D7RGTA053U4MfnMw1/ooIN8sXO6QXOT0yUHukNyafA05uzNEakeHiI74\n5g6aC3uMnanVJFpZVZnoqe/6d6cmmOAVvcGdMb1y+yuY/rvpkT4M0jEp52gorwmFqoEv0DA2zhoH\nM8x1UqvZrJqUVvuEev/w+/j23LeRPiRNs5gs+HTcpzwHKaqpXsAuNCdsMpng9rhR4apo8Hw153XJ\nOIQ6Qbz2f69h5taZkT40zeM5SNEuLNsS1R/GVrgqkLMth0kvpAp/C/CZ3TPxl4K/RPrwNI/nIClB\nyzvrhCXw1ResHdnQDkOR0iJFcx8WaZ/D6UCr+a1QVt0wScNqttbsTE6BsSUghSISbcikiEgb+kC1\nGwDw8Q8fY9OxTWypRDXE3j2+uPNFwaAHANVVvwa96Nx8QTFWs5UtAUm2SLUhkyIiI75ASS9CuOZg\nbGLvHh1OB5rPax64C4sbgEX9Y9az2JhYnJ15lucbyaKH+u2wFzr57txHdBoBu8WOuJg4AJe3TfFH\nzZ5tpG1i9mV0uVz47rvvMOvtWXB7/G8ga3KbkHIpBTEc8gX0/r3vM+iRbHqo3w7rFUDozt3tdWNM\nyhj8XP4zNh/bLPg6rXxYFH6BmtiWV5Tj2j9ciwufXEBiYiJwO+Bu7T/wxVhjsHvObjicDrTPbR9w\n14ao4QVgCv60GFMMLGYL1v+/9UjrkKb6YVH00sPOOmEb8fm7c690VWL94fUYljyspnK/Pq18WBR+\nge4e3RY3RowdgQsXLuCHH37ArAmz/H6HAGDaLdMQb4tHy4SW2PbgtjrdIqJWkKBnMVkwtMNQLBu+\nDOeeOMegRyHTw846YQt8wbafMMGk+Q+Lws939yiksbUxeif3RmxsLIDAJ1y8LR6zfj+r5r9rt16a\n1nsabGb/U+3RzO11IzUxFZk9Mjm9SYqIVBsyKcIW+ILN+568eFLzHxaFn5S7x0An3KYxmxp8h+Jt\n8cjskYn5g+dj+9jtiLPGqfeLaJTNYuNsCikuUE9PLQhbVqfYTJ9w92wj7ZNaEyTnO+RwOrB8/3K8\nf/h9fHPmG5y+dNrvDEU0ibfG49SMUzzHyFDCFvgClTDEW+MxZ9AcnCg9waJ1EqTmDVH9wBpjioHL\nG/379MVaYrH1wa2auQsnbdByxxWlhLWOT+jO3eP1wGQywQSTJiv8KbpJrSnVC1+XmhhzDFweV00w\nt5guFzFO6TUFzw94niM9qkPrHVeUEvYC9tp37q2vaI2c7TmCe4CxaJ3CISo3rPUCHUwdcMJ8AiaT\nCU63E3aLHV54MfXmqZh12yyeV9RApDaFjYSwF7D7EgrmDJoDe4wd/uIui9YpHAIlXQGXR066YwK+\n93yPKk9VTa2i0+1ElbsKS79eGuGDI60Klnkf7HrscDqQtycP2VuzkbcnDw6ndmdRItbCwuF0YN03\n6zRf4U/RLVCxbVxMHEZ1HYWW8S3hdDmxsGBhBI5QOovJAovVgip3w9ZtvgtYpFtGkfaE0nFFaIpU\ny32WIxL4fB9SoM4ZLFqncMjomoFpW6YJPmYxW7A4fXHN9M7PBT9jpWclvGZt7+Lu9rrhdgt3sOEN\nJfkjt+NKsKbUhycfxoajGzSVLBP2NT6xyQRanlM2QtaTkfhb0F83ah2KLxbj6M9H0aiiEV7946uo\neqQKl1z+p0Z9ySRapZUmwaQ9ctf4Aq2Tx8bEwuv1IsYco6lkmbCP+ALNIwOA3WKHzWJTvWjdX/AK\nFtT0NqSn4HzFtrXLJdpc2Qb3rL2n5u9sdplhfsjst8G13WLH7IGzcaX9SnzywydY9806VFdXw2P2\niO6XKctpAM0h+kxmFyTyx9cAwl9Wp7/rcaAp0kpXJQDUzO5pZXuisI/4gm5Ce+1QrB21VtUPxBe8\n3B43yl3lNQ16Zw+cjec+fc5vKq+Rsp6MTG6JQ+3NW3d+sRMDHx8I15UuJLRMQKvUVjhcevhyAJQQ\nBANtnmu32NHv6n7YcmxL0Ndr5U6btE9qzayczOhIzzyEfcQXbB55ZOeRqo/06s9Hu7wuuNwuTP9o\nep3n+o5x8IrBWNphKd777j1UuCoEc2GZNBA9gs1KCGlsbYzWV7TG4i8X471v38PO/TvhutUFeIGy\nhDIcdhyWlENtt9hRNLEIm7/bjKlbpgoGP5vFhuHJw5FfnB80OYddkEgsX+a9WIHWyf2J9Fpz2ANf\noA/JZDKhwlWB7K3Zqq2drSlaE3DPNiEVzgos+mQRYq6KgcsqvH4T6T8kKSdYiYMQL7yY8dEMVLov\nT+3gyrqPCbGarfB4PHCj7vcxzhqHLfdvQYemHTCp1ySkJqbWmX6ym+ywWS8vB6S2SMVT258SfP/6\nyTlEYknJY/A3Rer2ugEv/ntO1BLp5MWwBz5/H5IXXrg9buRsy1F17ezoz0dR7iqX9BpvjBe3j74d\nHZp2QOHmQk3vM0WhCzQrEWuJBUyXSwZ831OTyQS32y14ggdiMpmQm54LeIENRzcAXmBYp2EYmzq2\nTrCqvQa5atMq4Bdg/ez1Nc+Rsy5D5I+cPAahdfL0junotLiT4HkR6bXmsK/x+TTo4LItB2XV6ndw\nyduThwkfTpDUi9E3Hz2662iu8RlAsLXcI388gg1HNtSc4BWuCkz/aLpg3VwwtdcFxfj6668xbtw4\nFBYW1vl3NncnJSidx6DVFmgRK2CvPY+ctyfP73SQ0mtnGV0zMHnjZLjc4gOf7+4k3hbPu2sDCJbd\nlhifWOf7mL01W1bQk7Ml0A033ICTJ0/i7Nmz+O1vf1vz71LXZYiEiOneIuV7JjQS1MJNWcQCX22h\ndAyQKsGegPX/bz0GvznY73PiYuJQ7ioXDGpa/UOSsqT8nTs26wibxSY5+NnMNsnTPTExMejTpw92\n7tyJkSNHSnotUTBqXIu1eFOmicAXrG1UiaNE0YSXtA5p2HL/Fvzh7T/A7XHXSfdeN3odTpSeCHix\n0+IfkpQn9u+c0TUDUzdPlRT4GsU0wqb7G26OK0bv23pjyedL8OUVX7KBAilKbvcWH70094jYGl9t\nweqmfH8IpeeHuS5CSskvzkfayrTL5S5+dPltF7S7sh2GdRyGsTeMlfVdyy/Ox+AVg1FRWQGv1auZ\nNROKDqGs8Wl1PU+IJgIf0PBD8003CmEiCWlRWVUZlu+7vIv7idITKHWWwm6x43dtfof5g+cjMT4x\npPdnAwUKBzkBTG/fTc0EPqDuCKzEUYJ3v33X75BbTNW/XobdRGIE6pAR6U4YFF2U7N6ixe+mJtb4\nfGqvqWRvzQ5pkZU9NSnahDMJjIxNah6D3r6bYd+IVizfIquQYIustduS+f4Yl6ovwVF1+d+Fdnwn\n0rpQzgkiNentu6nZwJfRNQNmk/DhBav6D3UnYSItCuWcIFKT3r6bmgt8vu3rX9z5Iib0nIB4a3zN\nnURja2Mk2BKCFovrbdhNJIavsD7BloA4a9zlf/Rebp+W2T0TGlquJ4Op/d2Uer2OBE0ltwity5lM\nJky6aRJMJpPokgO9LbQSSfHRsY8wfPVwVLur62xx5GtuzTVsihS9lIhpJvApmQ6rt9RaIrEcTgda\nzW8l2NcWuJyUcGr6KX6/iQLQzFSnkutyeht2E4m1pmgNqjz+O8RUu6u5hk2a4Vu6yt6ajbw9eXA4\npW3urBbNlDMovS7HnpoUjY7+fDRgazSn28k1bNIELZeUaSbwhdojTgh7alK0CdYQ226xay51nPRP\najOQ2iVlPr5re/qq9IgvN+l6jY+dWchouMZH4SanhZnWEww1s8YndV0uvzgfSQuSkLU5C/N2z0PW\n5iwkLUhCfnF+JA6fKCwS7AnYdP8mNIpp1OCxOGscNo2Rt+MDkRC5zUC0XlKmmalOQPy6nJxhNEeH\nFC36tu2LMzPPYPm+5dhwdAPgBYZ1GoaxqfJ2fCDyJ1DSodPtxPJ9yzGp16QGj6mxdKUkzUx1SiF1\nGK2n7TKIiLQie2s25u2e5/dxm8WG7Q9ub3AddTgdaLWgleCIUAslZZqZ6pRCyjCafTuJiOQJ1IMT\nAKrcVYLX0f0/7Yfb427w/DhrnCZKynQZ+KQ0RGXfTiIieQL14PSpfx31DTaENmU2w4wbEm9Q+jAl\n02Xgk9IQVeuLrEREalCieNyXdGg1W/0+p/51NNBgwwuvJgYbugx8UjJA9bZdBhFRqJTMeu/bti8W\nDF4Au8Uu+Hj966geBhu6TG7xEdMQlX07ichI1LjmSXlPrdfwARoe8YkZpvs6s8wZNAeZPTIF/5js\n20lERqJWXsOEmybAZrbVjPz8XUf1sDefpur4fJTu8ca+nURkFEpPNda+Hld5qmCz2GA1WzG512TM\n+v2sBtdR32DDXwmZFq67mpvq5NQkEZF8gaYaASD7d9l4+faXRb1XKNdjLe/Np7mpTpYfEBHJl9E1\nA6baOxTXs+TrJaLrl0O5HotZiooUzQU+tTKCtLovFBGRkhLsCZjYa6Lfx71e8SUFesjQlENza3xq\n9HjT8r5QRESKC7CAJSVgab3nplyaG/EpnRHElmVEZDRK1S/rIUNTDs0FPqXLD7hmSERGo1TAitZy\nMM1NdQLKlh9E6xw1EZE/cksKhLZvi8ZyMM2VMyhND10EiIjUIKWkwEjbt0V94GNdIBFRYEa7Tmpu\njU9p0TpHTUSkFKPlQmhyjU9p0ThHTUTkI7Q2l2BPEP16MbkQof4MLYn6qU4iomimxNpcsFyIyT0n\nY+nXS6Nm/Y+Bj4hIp5Ramwv0PvHWeMAEwZpnva7/Rf0aHxFRtFJqbS5QLsTEXhPhb3yk1/U/Q6zx\nERFFIzl1yv7W6vzlQryw44Woq4Vm4CMi0impvTSD9S327agQys/QA67xERHplJQ1PrnrgdFY42eI\nNT5uSURE0aD+tQyA6DplueuB0VgLHfVTnaFsSaR03Uo01cEQUXgFupaJqVMOpW9xtNVCR/VUZyhD\ndKX71hmpDx4RKUuJ6Ub2Lf6vqJ7qlDu0V3oPP+4JSEShUKJsIVr31pMjqgOf3KG90n3rjNYHj4iU\npcT2atG4VidXVK/xyU3DVXoPP+4JSEShUKqkINrW6uSK6sCX0TUD07ZME3ws0NBe6bqVaKyDISLl\nBEt8E3stE5NAJ1SrZzRRndwCyEsqUbpuJRrrYIhIGWKvUcGexwQ68aI+8AHSdiH2YVYnEalN6k2x\nv2sZb66lMUTgk0tOwAzn+xGRvilVYsBSBWmieo1PjEBz4krPhdd/P18XBha0ExmTUolvTKCTxtCB\nL5SuLkKkdGZR+mcTkf4olfjGBDppDDvVqfScuJQ1PM7HE0UXue0Iw7GRLK8pDUV1AXsgShaVS+3M\nwoJ2ouiRX5yPpAVJyNqchXm75yFrcxaSFiQhvzg/6GuVKipncbo0hp3qVHJOXEwgq722x/l4ouhQ\n+6bXx3dup69KFzXSUqqovG/bvjg8+TBytufg8LnD6NS8E14e+DJaJrSsc7xslG/gwKfknLjUQMb5\neKLoIPWm1x8lEunqL7cUninEv7/9d8A6P6PmFRh2qlPJhq2+QCZEKJCxWSxRdNDK7E2w5ZZTjlNs\nlF+LYQOfknPiUgMZ5+OJooPUm161BBt55mzPYV5BLYad6gSUm1v3BTJ/WZ1C71f7Z39z9hucqziH\nprFNcejcIaS2SDXkvDuR3sjtB6y0YCPPw+cOa2JkqhWGDnyAckXqcoJovC0enZp3wtQtUznvTqRD\ncm561RAsb6BT804oPFPIvIJfGbaOr75IZDux9oYoOshpR6jkNSfYteTw5MPotLgTrzW/YuBDeBpI\nC33J1xStYX89IgNS45rD3RvEM3zgC8eoy98XbkTyCKwuXO33dTl9cjBn0JyQfjYRaYua15xgI082\nyr/M8Gt8StXh+BOowPVfh/6FuJg4lLvKG7zOiPPuREag5jUnWM4CN6G9zLDlDD5q1+EE+pKbTWa4\nvW6/j7Gejyj6aKX2z8gMH/jUrsMJ9CUvry7HPV3uYT0fkYFopfbPyAwf+NTuohLsS97/6v4omV6C\n3CG5yOmTg9whuSiZXmK4xWYio2DnpsgzfHILID7DSk76MUsWiNQh5XzUWnNmZlhGFgPfr4JlO4Xy\nReWXnJSmtQt5uEk5p8J9/on924SSYWn0v3+oGPhEUGLUxjRiUorRb6SknI/hnnEJx9/G6H9/JRh+\njU8MJTaO9aURzxk0B5k9Mhn0SBapmx5Ho0DnY6WrEpM2ToLD6Qj6XKWbM4fjb8O/vzIY+ERg+jFp\nRTgv5FoV6Hys9lRj9YHVNTugh/PcDcffhn9/ZTDwicD0Y9IK3oQFPh8BwOV11YyA2lzZJmznbjj+\nNvz7K4OBTwQjpx87nA7k7clD9tZs5O3Jq5lCosgIdtE3wpJ9oPOxNo/XAxNMYTt3pdwgyz2veBOu\nDCa3iGTEBWUpvzOzzMLD4XSg1fxWKKsWXsuJt8Xj1PRTultDlvr98X03K12VqPZU+31eTp8cDEse\nFpZzV2wiTSjXEpZHKYOBTwIpmZl6DwRSTjAj3hREUva2bMzbNU/wMT3u6iH3+1NWVYZJGydh9YHV\ncHldDR6v/VmEK6s62O+iRODi+RY6Bj4VaLVuSIq8PXmitkziHWj4ZW/NxrzdwoEP0NeuHqF+f0ou\nluCaV6+B0+2U9Xo1BAqyYs+rUH4GBWf43RmUFmg3hvRV6WGpG1JiB3exi+hq725BDQXbbVtP6zyh\nfH98332TyVTn32MtsbBarBHrdxtoBwSlklO4y0JomNyisGipGxK7iM4ss/CLpmQrud+f2t/9Sldl\n3QdNwJE/HtHEtF/9JJZwZpmSfxzxKUxrdUNy7wozumZg2pZpgo/VvrhG0+hDLxLsl3fv8Dedrqcp\nL7nfn0DffYvJgg1HNkR8RCQ0G2MymQJuU6anmxY9Y+BTmFKBQMy6nZpBVuzFVWyADETviUCR0Ldt\nX5RML9H9Oo/c708kZhqkNsX2t+QRZ41DvDUeXnh1fdOiZwx8ClMiEIhdt1N7tCXm4hrq6EOtNUoj\niIZ1Hrnfn3DPNEj9ngYakZpgwsu3v4xYS6yub1r0jFmdKghXnY6WMtrkZJkplRHKEaM6wvm5Sv3+\nBPruWM1WLBi8AGNTxypyvHK+p9GUeRuNOOJTQSjTUGLX7bSW0SZn9KHEGqUeRox6DMzh/lylfn+E\nRoo+1Z5q5GzLwVPbn1LkeOV8T7n2rW0MfCqROw0lZu1CaP2gxq8ZbYnxiQ0e0toFWMo6jdCxAwhr\n6YgcegjM9YW7JEcu3w3m8n3LMe2jaahyV9U8puTxyllPVGLJg9TDcgaNEVNGICajrb784nwkLUhC\n1uYszNs9D1mbs2o62EeK2JIJf8f+4mcvarpTvV63kNHTDgDxtnjYY+ywmq2CjytxvHL6Y/pGpAm2\nhJrXNrY2RoItgUksGsDApzFiarSk3oFq9QIs5ncNdOwLP1+o6RpCPQQQoWbJeqvNVPt45dZN+kak\nuUNykdMnB7lDclEyvUSzI30j4VSnxojJcpO6fqDV7ipifte8PXn+s+NMJtgtdsHkHi2so2g9gPib\nhp3Qc4Ku1qekng9Sp/xDyVyOhszbaMSsTo0KlOUmNcssWIbZzUk3Y3yP8RFb8wv0uwY7dpvFVmdt\nx0cLfUKV6suohkDfoXhrPGCC4EyAFj7X+sLVUJ39MaMHA59OSTmBA12AfbTa4T1Y8JjcczKWfr1U\nk53qtdzAW8+fqxAx54OW/x4UXgx8Oib2DjTQCV+f1i4AYi5WADR7Jx6pLWSCTeeJqTP70+//pNnP\nVUiw80HLI3AKL67x6ZjY9YNANU/1qb3mp9b6ilYvWJFoLSamhELMupje1qeCHa/W11wpfDjiMxDf\nHfHf9vwNBT8W+H2eWl0luL6iPrHTeXqa9lOq/pQjPvJh4DOgSFwA9HSh1TMpf1s97OSt5DHyO0g+\nnOo0IDW6SgS7Kw+1pELOXb/WOtWEg9jOP77PZfbA2TDBhJMXT2puJK10B5lo2s6JQsPAZ0BKXwDE\nrCmFsr4ip+2XHluFKSHY2p3X60XSgiRNj/J81Kg/jZbtnCg0nOo0MCXWzcROH8mdXpUzPaXElJaa\no0W13zta6vO4wwGphS3LDMyXBTdn0Bxk9siUddET25ZLbtsnOW2/Qm0VpmZfU7V7pgbqETmx10T4\nu8/VSgu12uT0yCQSg4GPQiJ2ClNu0145U6ShTKuq2dc0XD1T/fWIhBcRSecX6gcqhtybJaJguMZH\nIZHSJ1HO+oqcfc1C2QtNqXUloenMcPZMFappi8QecaGstTIZhdTCNT4Kidop4uFc43M4HRj1zihs\nObbF7/GIWVfyl4I/InkEVheuDum9QxHudH6lfh5rOElpnOqkkKi975ic95fzGt/a2yc/fOL3WMSM\nigJNZ/7r0L8QFxMn+71DFe494pTalkmJtWii2jjVSSFTO0VczvtLeU3AHe1rEbOuFOhibzaZ4fa4\nZb+3EsKZzs8WYaRVDHykCLX7Osp5f7GvCRSsAMBuscNmsYkaFQW62JdXl2NMyhisP7w+omtW4erB\nGYk1RSIxGPjI8AIFKwAY0H4A1o5aKyowBbvY97+6P5YNX2aINSs1OgQRKYGBjwwvWLAa2Xmk6MAk\n5mKvt10P5GJWJmkVszrJ8JTOdtRD8+dwYlYmaQ0DHxGUD1a82BNpFwMf0a8YrIiMgYGPiIgMhQXs\nRERkKAx8RERkKAx8RERkKAx8RERkKAx8RERkKAx8RERkKAx8RERkKAx8RERkKAx8RERkKAx8RERk\nKAx8RERkKAx8RERkKAx8RERkKAx8RERkKP8fzzjTRa6iU8IAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,node_color='green',node_size=50,width=1)"
      ],
      "id": "4cd29fc1-aa38-4149-8416-b661d9207f2d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "edc30b48-951b-48f3-8a0b-c23c241e3be0"
    },
    {
      "cell_type": "code",
      "execution_count": 1603,
      "metadata": {},
      "outputs": [],
      "source": [
        "len(data[2][1].edge_index[0])"
      ],
      "id": "0a40565c-90f5-4426-b799-e1f297ee0261"
    },
    {
      "cell_type": "code",
      "execution_count": 1606,
      "metadata": {},
      "outputs": [],
      "source": [
        "len(data[0][1].edge_index[0])"
      ],
      "id": "66d39960-c9ef-4a63-a9eb-fa549d89151b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "다름..\n",
        "\n",
        "------------------------------------------------------------------------"
      ],
      "id": "4d983c05-ba53-4011-b6c2-731cdeecc52a"
    },
    {
      "cell_type": "code",
      "execution_count": 296,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import TwitterTennisDatasetLoader\n",
        "loader = TwitterTennisDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "65629378-d7d2-4f73-a1a1-7d000db16ae3"
    },
    {
      "cell_type": "code",
      "execution_count": 297,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "d8b352d7-2739-4cbe-82d1-673a08fb31fa"
    },
    {
      "cell_type": "code",
      "execution_count": 298,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "43290d27-e40b-4756-8f49-c1ac5f31ddba"
    },
    {
      "cell_type": "code",
      "execution_count": 299,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "1111c9f2-8123-4bc7-92f0-810f61eaf0b1"
    },
    {
      "cell_type": "code",
      "execution_count": 300,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[2][1]).x[0],(data[2][1]).y[0]"
      ],
      "id": "bc57904f-343c-4ef0-b0f7-2de54c2f899e"
    },
    {
      "cell_type": "code",
      "execution_count": 301,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[3][1]).x[0],(data[3][1]).y[0]"
      ],
      "id": "3f97c6a2-083d-4dc4-8806-092dffe541b3"
    },
    {
      "cell_type": "code",
      "execution_count": 117,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "c73c819d-b34c-49fb-a8e0-3d1125328705"
    },
    {
      "cell_type": "code",
      "execution_count": 118,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "34a0ee20-c1ff-47e2-9117-b48070cf57ec"
    },
    {
      "cell_type": "code",
      "execution_count": 119,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "d610edb6-6fd9-4937-b2ae-68a504fc95f9"
    },
    {
      "cell_type": "code",
      "execution_count": 120,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "31b82e27-1a6a-4f6a-be1a-e3ccdf6032ce"
    },
    {
      "cell_type": "code",
      "execution_count": 121,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "ede40048-8e5e-414c-9f81-24f7303dbf0e"
    },
    {
      "cell_type": "code",
      "execution_count": 122,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "3708f8f4-0216-4965-ad3c-fa15a458f1ef"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   \n",
        "\n",
        "y\n",
        "\n",
        "-"
      ],
      "id": "76c364a9-b78d-446e-a844-1c792e9275c2"
    },
    {
      "cell_type": "code",
      "execution_count": 123,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0:3]"
      ],
      "id": "eea847a2-467c-491c-a573-634aa38b11a7"
    },
    {
      "cell_type": "code",
      "execution_count": 125,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "fec0a0c2-3859-4c95-a20d-db29fa327775"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## MTMDatasetLoader\n",
        "\n",
        "MTM-1 Hand Motions\n",
        "\n",
        "-   A temporal dataset of MethodsTime Measurement-1 \\[36\\] motions,\n",
        "    signalled as consecutive graph frames of 21 3D hand key points that\n",
        "    were acquired via MediaPipe Hands \\[64\\] from original RGB-Video\n",
        "    material. Node features encode the normalized xyz-coordinates of\n",
        "    each finger joint and the vertices are connected according to the\n",
        "    human hand structure.\n",
        "\n",
        "데이터정리\n",
        "\n",
        "-   T = 14452\n",
        "-   V = 손의 shape에 대응하는 dot  \n",
        "-   N = 325 \\# number of nodes\n",
        "-   E = 19 = N^2 \\# edges\n",
        "-   $f(v,t)$의 차원? (Grasp, Release, Move, Reach, Poision, -1)\n",
        "-   시간에 따라서 N이 변하는지? ??\n",
        "-   시간에 따라서 E가 변하는지? ??\n",
        "-   X: ?\n",
        "-   y: ?\n",
        "-   예제코드적용가능여부: No\n",
        "\n",
        "`-` Nodes : `325`\n",
        "\n",
        "-   vertices are are the finger joints of the human hand\n",
        "\n",
        "`-`Edges : `19`\n",
        "\n",
        "-   edges are the bones connecting them\n",
        "\n",
        "`-` Time : `14452`"
      ],
      "id": "523f338d-3456-4b8b-94e3-25f275ad4683"
    },
    {
      "cell_type": "code",
      "execution_count": 1607,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import MTMDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = MTMDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=1)"
      ],
      "id": "cc6bed7a-1c09-48ec-86af-03634c60f8e1"
    },
    {
      "cell_type": "code",
      "execution_count": 1608,
      "metadata": {},
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "d25db929-6d9a-4fb4-86a8-a045a028ca86"
    },
    {
      "cell_type": "code",
      "execution_count": 1609,
      "metadata": {},
      "outputs": [],
      "source": [
        "time"
      ],
      "id": "0a2011d1-db19-4021-b26d-a4f043856b62"
    },
    {
      "cell_type": "code",
      "execution_count": 1448,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x.shape,(data[0][1]).edge_index.shape,(data[0][1]).edge_attr.shape"
      ],
      "id": "d3955c49-9116-49ee-bb40-404f866a8e79"
    },
    {
      "cell_type": "code",
      "execution_count": 1449,
      "metadata": {},
      "outputs": [],
      "source": [
        "G = nx.Graph()"
      ],
      "id": "5169a9f6-9627-441b-b2ca-3349cdac41b7"
    },
    {
      "cell_type": "code",
      "execution_count": 1450,
      "metadata": {},
      "outputs": [],
      "source": [
        "node_list = torch.tensor(range(21)).tolist()"
      ],
      "id": "82a1edde-506b-4769-a949-a2603d553414"
    },
    {
      "cell_type": "code",
      "execution_count": 1451,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_nodes_from(node_list)"
      ],
      "id": "9cc74ac7-ecfb-4d2c-b0a7-1862479e16d4"
    },
    {
      "cell_type": "code",
      "execution_count": 1453,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_list=[]\n",
        "for i in range(14452):\n",
        "    for j in range(len(data[0][1].edge_index[0])):\n",
        "        edge_list.append([data[i][1].edge_index[0][j].tolist(),data[i][1].edge_index[1][j].tolist()])"
      ],
      "id": "8cce1eca-e439-4b52-a3ba-285fd15229fe"
    },
    {
      "cell_type": "code",
      "execution_count": 1454,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.add_edges_from(edge_list)"
      ],
      "id": "2b6b71bf-aa55-4ef0-9b44-836dc03a672f"
    },
    {
      "cell_type": "code",
      "execution_count": 1455,
      "metadata": {},
      "outputs": [],
      "source": [
        "G.number_of_nodes(),G.number_of_edges()"
      ],
      "id": "9c0a8428-22be-4ddc-8462-204bece097fd"
    },
    {
      "cell_type": "code",
      "execution_count": 1457,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAb4AAAEuCAYAAADx63eqAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAAA5yUlEQVR4nO3de1yUZfo/8M8MM+DAcFAUhREEK7EgxbOJu2na5lqpaSyUJZJm\nh23DrTWyra9W24q5ZdDJrVaiTQOpxDXXcrW0Dc20PA0eSFdQTg6iHGYGmBnm+f3hj0mcYQBljs/n\n/Xr5Sua55+YmH7h47sN1SQRBEEBERCQSUlcPgIiIyJkY+IiISFQY+IiISFQY+IiISFQY+IiISFQY\n+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiI\nSFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFQY+IiISFRkrh4AkSsJgoDimmKU1ZVBa9BC\n6avEoJBBiA+Ld/XQiMhBGPhIlPRGPfLUeVhZtBIVDRWQSWUwC2ZIJVKYzCaoglTISMxASnwK/OX+\nrh4uEfUgiSAIgqsHQeRMBcUFSNuUBgkk0Bq1HbZT+iohCAJyZuYgKS7JiSMkIkfiGh+JStbeLKQW\npkJn1NkNegCgNWihM+qQWpiKrL1ZThohETkan/hINAqKC5BamIomU1O336uQKZA7K5dPfkRegE98\nJAp6ox5pm9I6DHop8SkQlgkQlglYfcdqq+tNpiakbUqD3qh39FCJyMEY+EgU8tR5kEBi85oqUIV3\npr8DY6vRbh8SiQT56nxHDI+InIiBj7yeIAjI/C6zwzW93Fm5qGysxGfHPrPbj9agxcqilY4YIhE5\nEQMfeb3immJUNlbavLZ4/GJMjJqIuZ/PRbOpudO+yhvKodaoe3qIROREDHzk9crqyiCTWh9ZjesX\nhxVTVuD/dv4fDp071KW+ZFIZztSf6ekhEpET8QA7eT2tQQuzYLZ6fc5Nc+Dr44tbB92KX0X9CsP7\nDwcAzIidgSZTE57b8ZzVe8yCGY0tjQ4fMxE5DgMfeT2lrxJSifXkhgQSSCVSTL9hervXB/cejFsG\n3mKzL6lEikC/QIeMk4icg1Od5PUGhQyCyWyyev3FXS9C8qLE8ufDgx8CAN74/g1Mzp1ssy+j2Yio\n4ChHDpeIHIyBj7xeXL84qIJUPdJXZFAkE1gTeThmbiFRWHtgLdK3pneapswepa8S2dOykTYirQdH\nRkTOxsBHoqA36hG2Kgw6o+6q+wiQB0CzRMNqDUQejlOdJAr+cn/kzMyBQqa4qvcrZArkzMxh0CPy\nAgx8JBpJcUlYMXVFt4OfQqZA5tRMJqgm8hKc6iTRsdTjk0igNbAeH5HYMPCRKOmNeuSr85FZlImK\nhgrodXr4+/tD5iODyWzCwKCByEjMQHJ8Mqc3ibwMAx+JnlqjxtQ5U/HnF/+M6yKvQ1RwFI8sEHkx\nBj4iAFFRUSgqKkJkZKSrh0JEDsbNLUQAjEYjZDJm8CMSA36nk2gJgoDimmKU1ZVBF63DN+XfYJjP\nME5zEnk5TnWS6OiNeuSp87CyaCUqGiogk8pQ31CPoMAgtAqtUAWpkJGYgZT4FG5sIfJCDHwkKpaj\nDJDYTV/GowxE3otrfCQaWXuzkFqYCp1R12nOTq1BC51Rh9TCVGTtzXLSCInIGfjER6JQUFyA1MJU\nNJmauv1ehUyB3Fm5fPIj8hIMfOT17CWo/nDmh5g6eCr6+vdFo6ER+yv3Y+mOpThYfbBdOyaoJvIe\nnOokr5enzoMEEpvXBoUMwq6yXVh7cC1q9bWYdv00FCYXWrWTSCTIV+c7eKRE5Ax84iOvJggCYt+K\nxc8Xfu607YgBI/DTIz+h1dyKXq/0sqraHhsai+NPHHfUUInISXiOj7xacU0xKhsr7bb5/Zjf46Z+\nN2FKzBQAwGt7XrMKegBQ3lAOtUbNc35EHo6Bj7xaWV0ZZFL7t/m9N92LSdGTAABn68+i6GyRzXYy\nqQxn6s8w8BF5OK7xkVfTGrQwC2a7bSbnTkavv/TCzLyZiAiMwKdJn2JQ8CCrdmbBjMaWRkcNlYic\nhIGPvJrSVwmpxPZt3kvWy3KtpbUFX578ElqDFnIfOWJ6x1i1l0qkCPQLdOh4icjxONVJXm1QyCCb\n63UAME41DuvnrMe3Zd/iYvNF/CrqVwjuFQyNToOfqn6yam80GxEVHOXoIRORgzHwkVeL6xcHVZAK\nJbUlVtcqGytRUluC2wffjkC/QNToarCheANe2vUSGloarNpHBkVyfY/IC/A4A3m9tQfWIn1reqdp\nyuxR+iqRPS0baSPSenBkROQKDHzk9exlbukqZm4h8h7c3EJez1/uj5yZOVDIFFf1foVMgZyZOQx6\nRF6CgY9EISkuCSumruh28FPIFMicmskE1URehFOdJCqWenwSCbQG1uMjEiMGPhIdvVGPfHU+Mosy\nUdFQgZamFsh95fCV+8JkNmFg0EBkJGYgOT6Z05tEXoiBj0RNrVEjeVEykuYmYWzCWEQFR/HIApGX\n4zk+ErX4sHhITkowZ+gc3HzDza4eDhE5ATe3kOjV1dUhJCTE1cMgIidh4CPRu3jxInr37u3qYRCR\nkzDwkagZDAYYDAYEBAS4eihE5CQMfCRqbdOcEonE1UMhIidh4CNRq6ur4zQnkcgw8JGoXbx4kRtb\niESGgY9EjU98ROLDwEeiJAgC1Bo1dpzdgYaoBmwp2QK1Ru3qYRGREzBzC4mK3qhHnjoPK4tWoqKh\nAq2mVrS2tsJf4Q+T2QRVkAoZiRlIiU9hujIiL8XAR6JhSVANid2itExQTeTdONVJopC1NwuphanQ\nGXWdVmLXGrTQGXVILUxF1t4sJ42QiJyFT3zk9QqKC5BamIomU1O336uQKZA7K5dPfkRehIGPvJre\nqEfYqjDojDrLa+/d/R4SIxMRFRyFFlML9lbsxZL/LMHRmqM2+wiQB0CzRMM1PyIvwalO8mp56jxI\n0D4ry8MjH0ZDSwM+UX+ChpYGTL9hOr564Cv4+fjZ7EMikSBfne+M4RKRE/CJj7yWIAiIfSsWP1/4\nud3rtwy8BXvK9wAABgUPQuniUgDAyL+PxIHqAzb7ig2NxfEnjjt0vETkHHziI69VXFOMysZKq9fb\ngh4A+Pr4AgBaza2o0lZ12Fd5QznP+RF5CQY+8lpldWWQSTuutRwgD8CHsz4EALy25zVUa6s7bCuT\nynCm/kxPD5GIXICBj7yW1qCFWTDbvBaqCMXXqV9jQuQEvPfje8jYnmG3L7NgRmNLoyOGSUROxsBH\nXkvpq4RUYn2LRwVHoeihIoxVjcWK71bgkS8e6bQvqUSKQL9ARwyTiJys43kgIg83KGQQTGaT1eu7\nH9oNVZAKZXVlUMgUWH3HagDA+iPrsa9yn82+jGYjooKjHDpeInIOBj7yWnH94qAKUqGktqTd66og\nFYBLgXHx+MWW1w9WH+ww8EUGRSI+LN5hYyUi52HgI68lkUiQkZiB9K3p7dKUSV7sXrV1pa8SGYn2\n1wCJyHPwHB95NVuZW7qLmVuIvAs3t5BX85f7I2dmDhQyxVW9XyFTIGdmDoMekRdh4COvlxSXhBVT\nV3Q7+ClkCmROzWSCaiIvw6lOEg1LPT6JBFoD6/ERiRUDH4mK3qhHvjofmUWZKKkqQZAyCAIESCVS\nmMwmDAwaiIzEDCTHJ3N6k8hLMfCRKNXX1yM8IRyfbvsUjS2NCPQLRFRwFI8sEIkAjzOQKFVUVCDK\nLwrTb5ju6qEQkZNxcwuJUkVFBVQqlauHQUQuwMBHolRRUYGIiAhXD4OIXICBj0SpsrKST3xEIsXA\nR6LEqU4i8WLgI1Fi4CMSLwY+EiUGPiLx4nEGEqXKykpubiGvJwgCimuKUVZXBq1BC6WvEoNCBon+\nvCoPsJPomEwm+Pv7Q6fTQS6Xu3o4RD1Ob9QjT52HlUUrUdFQAZlUBrNgtmQoUgWpkJGYgZT4FFFm\nKGLgI9GpqKjA6NGjUVVV5eqhEPU4S05aSNrVobySmHPSco2PRIfre+StsvZmIbUwFTqjzm7QAwCt\nQQudUYfUwlRk7c1y0gjdAwMfiQ4DH3mjguICLN2+FE2mpm69r8nUhKXbl6KguMBBI3M/DHwkCoIg\nQK1RY0vJFmw+vRmmGBPUGrWrh0XUI/RGPdI2pWHRqEU49OghmF4wQVgmYNmty9q1iwqOwidzPsH5\nJefR9OcmlDxRgtk3zkaTqQlpm9KgN+pd9BU4F3d1kleztcjf1NwESW8Jxn8wXvSL/OQd8tR5kECC\nUeGjcKHpAs42nEV0SHS7NqGKUBQ9VISBQQOx++xuHD53GIOCByEmJAYAIJFIkK/OR9qINBd8Bc7F\nzS3ktbjIT2IgCAJi34rFzxd+try2MXkjZg2dheU7l+PFXS8CAF6a/BJe+PUL+PDgh0jbZDu4xYbG\n4vgTx50yblfiVCd5JS7yk1gU1xSjsrGy03ZTYqYAACICI1D1dBXOLzmPf97zT4QqQi1tyhvKRbEE\nwMBHXoeL/CQmZXVlkEk7X7Xq698XAPCrqF/h3z//GzX6Gjww7AF8MOMDSxuZVIYz9WccNlZ3wcBH\nXqVtkf/KoJc+Lt3uon8bsS3yk+fTGrQwC+ZO29XoagAAaw+uxYJ/LcCDGx8EAPz2+t/CR+IDADAL\nZjS2NDpusG6CgY+8Stsi/5UuX/TvTNsiP5EnUPoqIZV0/qP8sOZwu4/bvk+aTc1oFVoBAFKJFIF+\ngT0/SDfDXZ3kNQRBQOZ3mTbX9OYVzgNwadH/yt1uV9IatFhZtFIUu9vI8w0KGQST2QQAWDBiASZG\nTcTI8JEAgFlDZyE6JBqFxwuxes9qLByxEA8lPASFTIFbBt4CAPjo8EeWvoxmI6KCo5z/RTgZn/jI\na3R1kb8rxLLIT54vrl8cVEGXEjJMjJqI+QnzLcErYUAC5ifMR8KABPx84Wfc9cldOHb+GO6/+X4o\n5Ar89b9/xZJtSyx9RQZFiiKBNZ/4yGt0dZG/K9oW+cXwQ4A8m0QiQUZiBtK3piNtU1qHRxUAYNup\nbdh2apvNa0pfJTISMxw1TLfCwEdeo6uL/F0hlkV+8g4p8Sl4cuuT19SHIAhIjk+2+bq3lTZi4COv\n0dVF/q4QyyI/eQd/uT9yZuYgtTC128d4AEDaKsXIqpHwMftYXvPm0kZc4yOvcfki/5UWjFiAnJk5\n7Rb9c2bmYGbsTJvtxbLIT94jKS4JK6augEKm6Nb7FDIFVt6+En01fTFt2jRcvHgRBcUFCFsVhvSt\n6SipLYHOqEN9Sz0aDY2ob6mHzqhDSW0J0r9MR9iqMI87+8onPvIabYv8JbUlVtfaFv3bJAxIQMKA\nBJTWlWLTiU1W7cWyyE/eJX1cOiKUEZdS9Ukk0Bq6nqqvdUIrlixZgqHzh6JhTAOaW5s7/Xxt/acW\npqJSW4n0cek99rU4EnN1kldZe2At0remd5qmzB6lrxLZ07J5nIE8lt6oR746H5lFmTanKQcGDURG\nYgaS45PbTVMWFBfg+7PfI3VEKuL6xcFH6tMu32fq8FR8OOtDq883+r3ROFpzFLmzcj0i3y2f+Mir\nOHKRn8hT+Mv9kTYiDWkj0qDWqHGm/gwaWxoR6BeIqOAom7MZbVmP3r3z3Q4rPLTZdmobjtYctXx8\nTnfOkvXoziF3uv2aHwMfeZVrXeRXyBTImZnj9t+4RF0VHxbfpWn7tqxHXUn2sP7IeuQeyrV63VNK\nG3FzC3mda1nkz5ya6RFTNUQ9yV7WI1uypmVB/5wex35/DE+O+2WGpS3rkbvjEx95pWtZ5CcSm65m\nPTILZvxQ8QMOnTuEUEUoZsTOQNa0LDQZm/D+T+8D+CXrkTtvDuMTH3mtpLgkaJZokD0tG0NCh0Bi\nkkApUyLQNxDBfsEIkAcgNjQW2dOyoVmiYdAj0epq1qN/Hv4nxn0wDos2L8KcDXOwavcqAMCcG+dY\n2nhCaSM+8ZFXa1vknzdsHvyj/ZH771wYJUa7i/xEYtPVrEfX9b4Opy6esnq9rboD4BlZjxj4SBTO\nnj2LMIRh9s2zXT0UIrdzedYjexUeFo9fjD6KPthXuQ+9e/XGjNgZAIBP1J9Y+vKErEcMfCQKJ06c\nQGxsrKuHQeSWLs96ZC/Zw8eHP8aiUYsw58Y58JH44PC5w8jam4WPD39sae8JWY94gJ1E4c0338Sx\nY8fwzjvvuHooRG5HEAQMfXuozaxH3RUbGovjTxzvgVE5jsc88XljhnByHj7xEXXs8tJG15r1yBNK\nG7l94HN2hnAGWO9UUlKCO++809XDIHJbYsp65NZTnQXFBZfOYUFi97eQnjiH5c0lOAiIjo7Gjh07\ncN1117l6KERuq6C44JqyHnlKrk63DXxZe7OwdPvSbv0DKGQKrJi6otsZwp0ZYMn5mpqa0KdPH2i1\nWvj4+HT+BiIRu9qfvZlTM9tlcXFnbjnVWVBc0O3/8QDQZGrC0u1LEaGM6HJg6s4/srNKcHC6tWed\nPHkSMTExDHpEXSCGrEdu98SnN+oRtioMOqOu3evD+w/HyqkrMTpiNBRyBUrrSvHWD2/h3f3vWvUR\nIA+AZomm0ylJd3us53SrY3z66adYt24dNm7c6OqhEHkMe6WNGnWNiAiMwEu3v2RV2sgTuF3g66ie\n2un004gOicbhc4dRUluC2TfOhlQixeTcydhZurNd267UU7MVYG8ddCt2zt9ps/38wvlW2ci7GmC7\ngtOtjvPXv/4V9fX1WLnS/ZPnErmjK0sbbf54M4JbgpGZmenqoV0Vt5rq7ChDuEwqQ2RQJADg/s/u\nR3FNMfY9vA+jI0bbLJvRliHcXuBrK8FxufKGcrzx/RuWj5W+SiwcuRAAcPLCSas+eqoEhztOt3qT\nEydO4Ne//rWrh0Hksa4sbaScosRTTz8FtUbtkUsybhX4OsoQbjKbkLU3C0/d8hTWzV6Hny/8jJHh\nI3Gw+iA2HrM9fWUvQ3hHAfbUxVP441d/tHz8xNgnAAA/Vf2EorNFVv10JcB2xpnrmdfKU9ceS0pK\n8PDDD7t6GEReQW/U47jiOH6a8BPGvT8Och+5xy3JuFXgs5chvPB4Ie4Zeg+GDxiO4QOGw9BqQOHx\nQjQabCdDlUKKknMliOsXB4mk/ZNdV0tw/GHsHwAAq79f3WGbaynB0VbxuKOgN2voLDw38TnEh8XD\n0GrAEc0R3P3J3ahrrgMAp1U89vS1x5KSEgwZMsTVwyDyeJcvyQh9BOhNesDUvk1JbQnSv0zHk1uf\ndNslGbcKfB1lCO+j6IOtc7ciwDcAE9dORHFNMb564Cssn7QcGp3G5gaXRl0jUlJTIBwREBQUhODg\nYMufpoFNMAw2AHY2+d015C4MCR2CqsYq5KvzO2zXVoLjagKfrenWNinxKfhkzidoNjWj8HghtAYt\nxkSMgb/c3xL4AMdXPO7K2qM73+jnz5+H2WxGv379XD0UIo/mTUsybhX4Ls8QfrmYkBgE+AbA0GrA\nvsp9MLQacKzmGMaqxuLGfjfa7Cs4MBjr89fj9ujbUV9fj4aGBtTX16O+vh5bSrfg8JnDMArGDsey\neNxiAMA7+9+B0dxxuxZDC3bt2YU+tX3Qt29f9OvXD0FBQVZPmVfqrOLxyqmXNmJM+3gadpXt6rCf\nnphu7Yg33OhtT3ud/XsQUcc8aUmmK9wq8F2eIfxyx84fQ62+FqH+odgxbwdOXTiF+26+DwDw3Znv\nbPbVliFcLpejb9++6Nu3r+WarkSH96vfR3NLs833xofFY8rgKWgyNmHN/jV2x9xqasXXX36NnW/v\nxPnz51FTU4Pm5mbL52wLhlf+vVHRiPL6cpt93tDnBkQFR0Fv1OOZxGfwxf1foFpbjdXfr8Y7+6yT\nLDui4rG33OgnTpzgNCfRNWhbklk0ahEeGvEQ4vrFwUfqg+U7l+PFXS+2a9tH0QdHHjuCiMAI1DXX\noffK3k5bkukOtwp8cf3ioApSWWUI1xv1mL5+Ov4y+S8YGT4SI8NH4uSFk/j7j3/HhuINNvuKDIrs\nMBB0FGDbLB6/GACw7sg6nNeftztmeS85ct7Iafe5WlpacP78ecufmpoay9+PHTuG8+fP47j5OFqG\ntAC+1n329b8UpP3l/hjcezA2FG/AffH34e3pb6OioQKbTmxq1/5aplttsbf2+E3qN5gUPanda2qN\nGje/e7PlY1ff6Jdvwtl0chMChwT2+C8GRGLRtiQzKnwULjRdwNmGszZ30wPAmjvXoJ+/9bKCo5dk\nusutAp+9DOE/VPyA33z8my7101mG8I4CLACEKkJxf/z9ANDuaENHbAVYPz8/qFQqqFSqDt+Xr87H\nw5sftrk5p0ZfY/n7gxsfxP7K/WgyNeH3Y36PGbEzrAKfvkmPj/I/gmagBuHh4ZY/oaGhkEqtp447\nY2/tsc3l/2+qtFVW111xo9vahKPz0UEOOTZ+sNHtN+EQuZvLl2TmFc4DAGxM3mgz8M0bPg+zb5yN\nl799GcsnLW93zZFLMlfDrQIf4JwM4fYCbG1TLfz/2rUfitdSgqOj9Uzg0u7W+uZ6BPcK/mXM/z8Q\n2Uof5CP1Qau+Fd988w2qqqpQWVmJqqoqaLVa9O/f3xIIIyIi2gXGto/79etnSefV2dpjm8uPfdji\n7Bu9w004PpeOw8Ds3ptwiNxRV3fARwVHIXtaNl7b85pVQpE2jliSuVpuF/j85f7ImZlzTanEcmbm\ndPobvatLcNibbjWajXhj7xtYdusyfDTrI+wp34P74u+DyWzCuiPrrNpL5VIse2yZ1Q3V3NyM6upq\nVFVVWf5UVlZi9+7d7T6+ePEi+vXrh4iICATEBOD0TaeBTh4ULzxzAcClM47P7ngW+yv3W7Vx1o3u\nDZtwiNyRvSNmbSSQ4KNZH+F03Wk8//XzmBA5wWa7nl6SuRZuF/gAICkuCZXayqvOEN6V3+SdFWA7\nYm+6FQBe3vUyfH18MX/4fCTHJUOtUWPZzmX4oeIHq7YdrWf26tUL0dHRiI6OtjsWo9GIc+fOobKy\nEpuPb8YPpT/AJNgOyo0tjdh8YjMqGitwy8BbMGXwFHwV/hVuevsmnNOda9fWGTe6t2zCIXJHHR0x\nu1xkcCRujb4Vh6oP4fPkzxGqCAVwKaXj5vs246FND6FGXwOzYEZji+1z187mloEPcE6GcGcE2I50\nVvG4VWjFczuew3M7nrPbT09UPJbL5Rg4cCAGDhyI0/6nIa+Qo9lge8frjLwZv7xPKkfJH0oQHRKN\nyTGTkafOa9dW36zHhk0bYBpiQkxMDGJiYqBUKq9prO3672ATjp+PH1b9ZhWS45IR6BuIn6p+wlPb\nnrL6pcHVm3CI3J29JZk2bcswbclF2sh95LhryF2W7y2pRIpAv0DHDbYb3DbwAZcC051D7uwwQ7jJ\nbMLAoIHISMy46gzhrizB4erpVlvs3egKmQIhvUJsbmZpNbdaveYj8cH5yvP4+zd/x+nTp1FaWgp/\nf39LEIyJiUF0dLTl74MGDUKvXr26PNaONuG8Me0NPDr6URw5dwQ7NDuQHJ+M/zz4HwzOGozaptp2\nbd1ttxmRO7l8SWbBiAWYGDURI8NHAriUWSo6JBqFxwshefGX78O2ZP9txxnatB0xcwduHfiAS1OS\naSPSkDYizSpDeFRwVI9MozkjwNri6ulWW+ytPYYFhOHEEyfw9emvUVZfhlsG3oLokGhUa6vx9emv\nrdpL5VJkPptp+TcSBAEajQanT5+2BMIDBw7g888/R2lpKc6ePYs+ffrYDIrR0dGIjIyEXC639GVr\nE04//354aMRDaDW3YspHU1Cjr4HJbMKDwx/EE2OfsDp35G67zYjcyeVLMhOjJmJ+wnzLtYQBCUgY\nkIDSulKrnea22Dti5mxuV5bIHTgqwHbEnSoeC4KAoW8Ptbn2qPRV4vU7Xsdt0bchIjAC9S312HN2\nD57/5nkcrTlq1T42NBbHnzje5c/d2tqKyspKS1C8PECePn0a1dXVCA8PR0xMDIJvCMa/Vf+GEe2z\n6kyKnoRvUr/B6YunMTh7MADgyXFPImta1qV8r/n3WH3eAHkAvl/4vdt8UxK5k45KxXVHV0rFOZPb\nP/G5wpUlOBzNnSoe21t71Bq0WLR5UZf6uZq1Rx8fH0RGRiIyMtJmGSGDwYCzZ8+itLQUm45tgvS8\nFFfOdPYP6G8Zaxud4VLNxQHKATY/rzvtNiNyN+64JHOtun+6mRwiKS4JmiUaZE/LxpDQIQiQByDY\nLxiBvoEI9gtGgDwAsaGxyJ6WDc0SjUN3IqbEp0DAtU0EOOJG9/X1xXXXXYcpU6YgcVIifP2s0960\n7SxV+v6yiabt79Xaapv9utNuMyJ307Yko5Aprur9jliSuVZ84nMjzljP7Oo43G3t8UodbcI5WnMU\nhlYDooKjEBYQBo1OgzERYwAAh84dstmXO+02I3JHbTvgn/nqGRgEQ5ff1xM74B2Ba3zUIXdae7yS\nWqPG+A/GQ2fUWV37+11/x6JRi6DWqKHWqPG7uN9BZ9BhcPZgm7lXFTIFfnj4B051EtlhNBoR9dso\n1N1aB5lM5tIlmWvFwEd2WVKBuXjt8Ur2NuH0kvXC337zN/zupt8h0O/SOb6ntz2N78u/t9mX9IIU\niQcSkZKSgjlz5qB///4OG7MnVrAn8bB3j2ZlZWHr1q347F+fYUPxBqfugO9pDHzUKb1R7/SjHl3R\nU7vNXpv6GgZUDUB+fj62bNmC0aNHIzk5GbNnz0ZoaOg1j9PTK9iT9+vsHh0QMADnPjuHb978BqOH\nj7a8z5VLMteCgY+6xZ1udL1Rj7BVYTanO7sqQB4AzRKNJeDo9Xr8+9//Rn5+PrZt24YJEyYgJSUF\ns2bNQnBwcCe9WetKBXvA/aeGyHt19R6Vm+Xw9fP1inuUgY88WkFxwTVtwsmdldvhN7FWq8XmzZuR\nn5+Pr7/+GpMnT0ZycjJmzJjRpdRrV7tGumLqCibPJqcQ6z3K4wzk0ZLikrBi6opub7Xuym4zpVKJ\n++67D4WFhThz5gxmz56Njz/+GCqVCklJSfj000+h1+ttvvdak2cXFBd0631E3VVQXIDy+nJ8v/B7\nmF4wQVgmYNmtyyzXk25KQvHjxWhc2gjtUi3Uj6nx2OjHvOIe5RMfeQVnbsKpra3Fxo0bkZeXh/37\n92P69OlITk7GtGnT4OfnZ5mCXThyIR4a8RDi+sXBR+qD5TuXW1KmnU4/bbOY587SnZicO9lqCpao\nJ7Xdo+/e+S4igyMRHRKN6JDodvfonyb8CbdF34bS+lJEBkXiriF3AQAm507GztKdHn2P8hwfeYW2\nfKvZO7LxwlcvwK+fn8M24YSGhmLhwoVYuHAhzp07h88++wyvv/460tLSMGPGDPS+7VJi3lHho3Ch\n6QLONpy1CnJrD6xFH0Ufy8ezb5yNqOAonLxwEgCTZ5NjtSV4t1dV/W+7/4a/7f6b5eNDjx7CsP7D\nEBMSg53Y6dH3KAMfeQ1/uT8GVA/AnKo5eH7p807ZhNO/f388/vjjePzxx1FRUYENGzbgOfVzaA5o\ntvtD5eVvX7b8va9/Xzwy6hEAQPbebABMnk2O01GCd1vGRIzB3GFzcV3v6zCs/zAcrTlqSUjtyfco\nAx95laKiIiQmJjo93yoAqFQq3D73drzwwQu4Ine2XY+OfhQKuQI7/rcDRzRHLK87q4I9iUtxTTEq\nGyu71PamfjdZNrG0mlvx5ckv26X389R7lJtbyKu0BT5XKasrg0za9d8nZVIZHhv9GADgjb1vWF07\nU3+mJ4dH1K17NPdQLqQvSnF99vU4WH0QT93yFJYkLrFc99R7lIGPvMaFCxdQXl6OYcOGuWwMWoMW\nZsHc5fYp8SmICIzAz7U/Y0vJlnbXmDybHKGr92hbcncBAk5dPIX9VfsBAEP6DLG08dR7lFOd5DV2\n796NsWPHQiZz3W1tr4K9LW3TSFl7s6wqYjB5NjnC5feovarqr97+Kk5fPI3/1f0PqkAV7rzhTgDA\nV6e+svTlqfcoAx95DVdPcwLtK9jb+6Gy6cQmTIyaiNERo1HXXIcPD35o1ZfRbERUcJQzh08icPk9\naq+q+vb/bcf0G6ZjUvQk6Iw67K/cj3f2v4NP1J9Y2nvqPcrAR16jqKgIzz//vEvHENcvDqogFUpq\nS+z+UNl0YpPlae+Dnz6wmXatt7Q3bgy90VlDJ5G4/B5N25SGtE1XvyszMijS4za2ADzATl7CYDCg\nT58+qKysRFBQkEvH0hPJs/0kfgg/GA7pISmefPJJpKWlufzrIu/RUwnes6dle+RxBm5uIa/w008/\n4frrr3eL4NATFexlMhnUeWp8/PHH2LNnD6Kjo7F48WKcOnWqR8YoCALUGjW2lGxBvjofW0q2QK1R\n90jf5P564h4VBAHJ8ck9NCLnYuAjr1BUVIQJEya4ehgAfqlg3938oW3aKtgH+AbglltuQV5eHg4d\nOgSFQoHx48dj5syZ+Prrr3E1kzV6ox5rD6zF0LeHYvwH4zH387l4ePPDmPv5XIz/YDxi34rF2gNr\noTfazkFK3qGn7lFPTFcGcKqTvMScOXMwe/ZszJ0719VDsXBEBXu9Xo9//vOfyMrKgkwmw+LFi3H/\n/fejV69enfbNEkl0JUfco56AgY88niAICA8Px/fff4/o6GhXD6cdRyXPFgQB27dvxxtvvIH9+/dj\n0aJFeOyxxxAREWGzvVjLz1DnnJng3V0w8JHHO3XqFH7961+jvLwcEonE1cOx4ugK9idOnMCbb76J\n9evXY/r06UhPT8eYMWMs1x1Zs5C8g6PvUXfDwEce76OPPsIXX3yBDRs2uHoonXJkBfu6ujr84x//\nwJtvvgmVSoXFixfjjrvuQMTqCLslknx9fPHq7a/inqH3oH9Af9Q21WLbqW146quncLH5okeXn6Hu\nc+Q96i54jo88jiAIKK4pRlldGbQGLT7Z/wmGjx/u6mF1iSOTZ4eEhODpp59Geno6/vWvf+GNN97A\nI2segfHXRrslkpZOXIr0cemoa67Dp0c/xW0xt2F+wnxIIMH8TfM9uvwMdZ8rErw7G3d1ksfoaEfi\ntsBtyNJncUfi/yeTyTB79mzs2rULgb8NhAEGzCuch8m5k3Gw+qBV++t6Xwfg0kH6BzY+gFf++woA\nWAJkW/kZIm/BJz7yCHZ3JPoCza3NKKktQfqX6Xhy65NesQB/rYprilFrqO203Zof12Dm0JlYOHIh\nBigHYErMFOgMOqzavcrSxlPLzxDZwic+cntZe7OQWpgKnVHXaaYJrUELnVGH1MJUZO3NctII3VNX\ny88crTmKbae2IaRXCB4Y9gDCA8Oxt2JvuwPtnlp+hsgWBj5yawXFBd3ehg8ATaYmLN2+FAXFBQ4a\nmfvravmZNXeuwb033Yu3970NxSsKZGzPwG0xt2FD0i+bhTy1/AyRLQx85Lb0Rj3SNqVZBb0b+96I\nf6X8CzVLatDwbAM2Jm+0mSG+ydSEtE1pol3z62qJpLiwOADA/sr9aDY144eKHwBc+v/cxlPLzxDZ\nwjU+clt56jxI0P5cXrBfMP7z4H+gClJh84nNMLQaMOemObi+z/UY9u4wq/yDYt6R2NUSSUVnixAf\nFo/MKZkYP3A8psZMBQB8d+Y7S1+eWn6GyBY+8ZFbEgQBmd9lWq3pJUYlQhWkwumLpzEjbwbuLbgX\nB6sPIj4sHvfceI9VP2LekdhWfgb4pe5aW/BKGJCA+QnzkTAgAX/a9ie89cNbaDY1Y/7w+VDIFcg9\nmIv5m+Zb+vLU8jNEtvCJj9xScU0xKhsrrV5vNjUDAEL9QxETEgNDqwERgZfSdA3vPxyfH/vc6j1i\n3ZEokUiQkZiB9K3pndZd+8PWP+APW/9g85rcLMejNz/qqGESOR2f+MgtdbQjcVfpLnx35jsE+QXh\nf+n/Q/lT5QgLCAMADFAOsNmXmHck9kT5GUiAl373El588UVotVdfv43IXTDwkVvqaEdiq9CKybmT\nMffzuXjlv6/gkS8ewbrD6wAANfoam32JeUdiT5SfWZe0Dvv37MeJEycwZMgQrFmzBkajsdt9sQYg\nuQtOdZJbsrcjUQIJ1h9ZDwDo698Xf5n8FwDA9v9tt9le7DsSk+KSUKmtvOryM22JANavX48ff/wR\nGRkZWL16NVasWIF77rmn08TgeqMeeeo8rCxaaTMBsipIhYzEDKTEpzAfKDkFk1STW1Jr1Bj/wXjo\njDqra9+kfoPz+vOob6nHb6//LSICI/BFyRe4+5O7bfblL/fH3oV7RbfGd6WeKj8jCAK2bduGZ555\nBgEBAXj11VcxceJE+5+TNQDJjTDwkVsSBAFD3x6KktoSq2tZ07KQHJeMPoo+qNJWYf2R9Vi+czla\nWlts9hUbGovjTxx39JA9Qk+Wn2ltbcW6devwwgsvYMSIEVixYgVuvPGXs3+sAUjuioGP3NbaA2uR\nvjW90zRl9ih9lcieli3Kc3yd6anyM83NzXjrrbewcuVK3HPPPVi+fDmKLhaxBiC5LQY+clt6ox5h\nq8JsTnd2FWvJOc+FCxewYsUK/OOjf0D7mBaPj3+8wxqAfj5+eOHWF3B//P0IDwzHyQsnsWznMstx\nFP67kSNxVye5rZ7YkZgzM4c/PJ2kT58+WLVqFZauWwpBENrVALzS63e8jj//6s8wmo346NBHCFeG\noyCpAOMHjgfwS8YdIkdg4CO3lhSXhBVTV3Q7+F25I5GcQxAEvH/sfZikJrs1AJNuuvTv8vDmh/HI\nF4/g5W9fhlQixXMTnwMg7ow75HgMfOT20selI3dWLgLkAVD6Ku22VfoqESAPQO6sXDw57kknjZDa\ndJRx50ptGXhGho9EL1kvDO8/HAAwfMBwS5u2jDtEPY2BjzxCUlwSNEs0yJ6WjVCEQi7IEewXjEDf\nQAT7BSNAHoDY0FhkT8uGZomGT3ou0tUagH/97q8AgNV3rEbTn5ssm48uz74j5ow75Fg8wE4ew1/u\nj7QRadjyyhaMu3sc4ibEXfOOROpZXa4BuH8Nfqz8Eb+57jeQSCSobKzEP2b8AzW6X7LviDnjDjkW\nAx95nMOHD+Oll17CTTfc5Oqh0BW6WgNQLpVjX+U+7KvcBwDImZkDoH32HbFn3CHHYeAjj6LT6VBe\nXo4hQ4a4eihkQ1drAKqCVJh781wc0RxBfL94JEYloq65Di9/+7KlL9YAJEdh4COPUlxcjKFDh0Im\n463rjtpqAJbUllhqALZJGJCAhAEJKK0rxZ7yPeij6IPU4akwtBqw+cRmPLvjWZy6eMrSnjUAyVF4\ngJ08yvvvv4+ioiJ8+OGHrh4KdaBHMu7Ilcj+becZdwRBQHFNMcrqyqA1aKH0VWJQyCAGTLKLvzaT\nRzl8+DCGDx/eeUNymZT4FDy59dqOkuib9BjjP6bj66z4QNeAxxnIoxw+fBjDhg1z9TDIjp7IuPOA\n8gFMSpyE7OxsmM3td4kWFBcgbFUY0remo6S2BDqjDvUt9Wg0NKK+pR46ow4ltSVI/zIdYavCUFBc\n0BNfFnkRBj7yGIIgMPB5iGvNuJObkYvdu3djw4YNmDRpEk6ePAngUsWH1MJU6Iy6TqdStQYtdEYd\nUgtTkbU366q/FvI+XOMjj3H27FmMHTsWVVVVrh4KddG11gBsbW1FdnY2XnnlFdydcTfyDfms+EDX\njIGPPMaWLVuQnZ2Nr776ytVDoW7oiRqAh48dxoj1I7DmnjVIjExEVHAUWkwt2FuxF0v+swRHa45a\n2t57071YfutyXN/nelRpq/DOvnewavcqVnwgC25uIY9x6NAhTnN6oLaMO2kj0q66BuD+5v3wV/jj\n4ZEP4/vy7/GJ+hNMjZmK6TdMx7D+w3B99vVoaW3B+IHjkX9vPnQGHfLUeZgyeApevf1V1LfUY/2R\n9chX57M2I/GJjzxHSkoK7rzzTjz44IOuHgo5kSAIiH0rFj9f+Bm3DLwFe8r3AAAGBQ9C6eJSAMDI\nv4/EgeoD2Ji8EbOGzsLT257G63tex20xt2HHvB0orStFTFYMYkNjcfyJ4y78asgd8ImP3NaVZ7SK\naoqQFMM1GrG5vOJDW9ADAF8fXwBAq7kVVdpL674jBowAAOyv3N/uv9Eh0Qj2C7ZUfOA5P3Fj4CO3\n09EZrcaxjZj37Tw8d/A5ntESEVsVHwLkAfhw1ocAgNf2vIZqbTUAoL+yPwBYNtLoDDrLewYoB6Ba\nW40z9WcY+ESOxxnIrdg7o4Vel4Iiz2iJy5UVH0IVofg69WtMiJyA9358DxnbMyzXzmnPAYClbuPl\n9RurtdWs+EAAGPjIjfCMFtlyecWHqOAoFD1UhLGqsVjx3Qo88sUj7dq2VXsfqxoLABijupT9payu\nDPUt9az4QAA41UluoqC4AEu3L+32Ga0mUxOWbl+KCGUEz2h5qcsrPux+aDdUQSqU1ZVBIVNg9R2r\nAQDrj6zHvsp9eHX3q7g79m4su3UZ4vvFY+rgqQCAzKJMAKz4QJdwVye5nN6oR9iqMCwcuRAPjXgI\ncf3i4CP1wfKdy/Hirhct7To6nwWAZ7S8mCAIGPr2UJTUlkBYZvvH1fzC+cg9lAsA+F3c77Ds1mW4\nvs/1qNZW451972Bl0UoA4K5OAsAnPnIDeeo8SCDBqPBRuNB0AWcbziI6JLpdG3vns9778T1IJBKe\n0fJSEokEGYkZSN+aDsmLkk7bbyjegA3FG6xeV/oqkZGYYeMdJDZc4yOXEgQBmd9lQmvUYl7hPEzO\nnWxZp7lcRmIGpBIplu9ajvmb5iO1MBUAsHTiUgCX1vzafqsn75MSnwIB1zY5JQgCkuOTe2hE5MkY\n+MilLj+jZU9n57MAWM5okffpiYoPOTNzOBVOABj4yMVsndGypbPzWQAgk8pwpv6MA0ZJ7uBaKz5w\n8xO1YeAjl7ryjFZHOjufBYBntEQgfVw6cmflIkAe0O4esEXpq0SAPAC5s3Lx5LhrK4xL3oWBj1zq\n8jNa9nR2PgsAz2iJRFJcEjRLNMielo0hoUMQIA9AsF8wAn0DEewXjAB5AGJDY5E9LRuaJRo+6ZEV\nHmcgl1Jr1Bj/wXjojDosGLEAE6Mm4raY2xAVHIWD1QdxsPogCo8XokZfg/+m/Rd6ox6fHf0MUwdP\nhSpIhce2PIY1+9cAuLQOtHfhXqajEpmrrfhA4sXARy51+RmtnJk5mJ8w36pN23k+e+ezAJ7RIqKu\nYeAjl1t7YC3St6Z3mqbMHqWvEtnTsnmOj4g6xcBHLteWuUVn1HXeuAPM3EJEXcXNLeRyPKNFRM7E\nwEdugWe0iMhZONVJbqWguABpm9IgkUgsh9VtUfoqIQgCcmbmMOgRUbcw8JHb0Rv1yFfnI7MoE6W1\npYAZ8OvlB6lECpPZhIFBA5GRmIHk+GRObxJRtzHwkVtbsHQBTAEmTJ81nWe0iKhHsCwRuTVTpQmT\nJk1iVn0i6jHc3EJurbq6GgMGDHD1MIjIizDwkVurqqpCeHi4q4dBRF6EgY/cGp/4iKincXMLuS2j\n0Qh/f380NzfDx8fH1cMhIi/BJz5yWxqNBn379mXQI6IexcBHbovre0TkCDzOQG5FEAQU1xSjrK4M\n3x79FtKhUqg1ap7dI6IewzU+cgt6ox556jysLFqJioYKyKQytBha0NraCl8/X6iCVMhIzEBKfAqz\ntRDRNWHgI5ez5OeExG5NPubnJKKewDU+cqmsvVlILUyFzqjrtBCt1qCFzqhDamEqsvZmOWmERORt\n+MRHLlNQXIDUwlQ0mZq6/V6FTIHcWbl88iOibuMTH7mE3qhH2qY0LBq1CIcePQTTCyYIywQsu3WZ\npc2w/sOw/cHtaHi2AcIyAafTT1uuNZmakLYpDXqj3hXDJyIPxsBHLpGnzoMEEowKH4ULTRdwtuGs\nVZuo4CgMUA7AgeoDNvuQSCTIV+c7eqhE5GUY+MjpBEFA5neZ0Bq1mFc4D5NzJ+Ng9UGrdl+UfIH4\nd+Px+p7XbfajNWixsmilg0dLRN6GgY+crrimGJWNlT3SV3lDOdQadY/0RUTiwMBHTldWVwaZtGdy\nJ8ikMpypP9MjfRGRODDwkdNpDVqYBXOP9GUWzGhsaeyRvohIHBj4yOmUvkpIJT1z60klUgT6BfZI\nX0QkDszVSU43KGQQTGYTAGDBiAWYGDURI8NHAgBmDZ2F6JBoFB4vxPHzx/HsxGcRFRwFAOjr3xc5\nM3NwXn8eS/6zBABgNBst14mIuoIH2MnpBEHA0LeHoqS2BDkzczA/Yb5Vm+U7l2Nn6U7snL/T6lpp\nXSlismIAALGhsTj+xHEHj5iIvAkDH7nE2gNrkb41vdM0ZfYofZXInpaNtBFpPTgyIvJ2DHzkEnqj\nHmGrwqAz6q66jwB5ADRLNKzWQETdws0t5BL+cn/kzMyBQqa4qvcrZArkzMxh0COibmPgI5dJikvC\niqkruh38FDIFMqdmMkE1EV0VTnWSy1nq8Ukk0BpYj4+IHIuBj9yC3qhHvjofmUWZlgrsDY0NUAYo\nYYYZA4MGIiMxA8nxyZzeJKJrwsBHbketUeNM/RksemIRnn/meUy8eSLiw+JdPSwi8hI8wE5uJz4s\nHvFh8QirCcPY3mMZ9IioRzHwkdsRBAHFNcVoGtiEL0q/QJWyCoNCBjEAElGP4FQnuQ29UY88dR5W\nFq1ERUMFmpua4efnB7lMDpPZBFWQChmJGUiJT+E6HxFdNQY+cguWnZ2Q2M3mwp2dRHSteI6PXC5r\nbxZSC1OhM+o6TWGmNWihM+qQWpiKrL1ZThohEXkTPvGRSxUUFyC1MBVNpqZuv1chUyB3Vi6f/Iio\nW/jERy6jN+qRtikNi0YtwqFHD8H0ggnCMgHLbl1maZMSn4Jv538LzZ800D2nw5HHjiAt4VJS6iZT\nE9I2pUFv1LvqSyAiD8TARy6Tp86DBBKMCh+FC00XcLbhrFWbO667A4N7D8ZXp77Cd2e+Q3xYPNbO\nXIu7htwFAJBIJMhX5zt76ETkwRj4yCUEQUDmd5nQGrWYVzgPk3Mn42D1Qat2b/3wFmKyYvDgxgdx\nx8d3YGfpTgDA7YNvB3BpzW9l0UonjpyIPB0DH7lEcU0xKhsrO233Y9WPMJqNlo99fXwBAOUN5ZbX\nyhvKodaoe36QROSVGPjIJcrqyiCTdi9/wh/H/xETIifg59qfsWb/GsvrMqkMZ+rP9PQQichLMfCR\nS2gNWpgFc5fb/9+t/4fX73gdpy6cwpSPpqDR0Gi5ZhbMaGxptPNuIqJfMGUZuYTSVwmppPPfuySQ\n4K3pb+HxMY/jp6qfMH3ddJzTnWvXRiqRItAv0FFDJSIvw8BHLjEoZBBMZhMAYMGIBZgYNREjw0cC\nAGYNnYXokGgUHi/EGNUYPD7mcbSaW3Gg+gCenfgsAODkhZN4e9/bAACj2Yio4CjXfCFE5HEY+Mgl\n4vrFQRWkQkltCSZGTcT8hPmWawkDEpAwIAGldaVQBaoAAD5SHywYscDSZmfpTkvgiwyKZAJrIuoy\nZm4hl1l7YC3St6Z3mqbMHqWvEtnTspE2Iq0HR0ZE3oyBj1xGb9QjbFUYdEbdVfcRIA+AZomG1RqI\nqMu4q5Ncxl/uj5yZOVDIFFf1foVMgZyZOQx6RNQtDHzkUklxSVgxdUW3g59CpkDm1EwmqCaibuNU\nJ7kFSz0+iQRaA+vxEZHjMPCR29Ab9chX5yOzKBMVDRWQSWUwC2ZIJVKYzCYMDBqIjMQMJMcnc3qT\niK4aAx+5JbVGjTP1Z9DY0ohAv0BEBUfxyAIR9QgGPiIiEhVubiEiIlFh4CMiIlFh4CMiIlFh4CMi\nIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh\n4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlFh4CMiIlH5f32LV9D3pc4NAAAAAElF\nTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "nx.draw(G,with_labels=True,font_weight='bold',node_color='green',node_size=350,font_color='white',width=1)"
      ],
      "id": "55a3efce-b519-4410-830f-e613671e2260"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------\n",
        "\n",
        "time별 같은 edge 정보를 가지고 있나 확인"
      ],
      "id": "85f596af-c771-478b-afc5-7cdbfb39db57"
    },
    {
      "cell_type": "code",
      "execution_count": 1611,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.where(data[0][1].edge_index != data[12][1].edge_index)"
      ],
      "id": "68bbc0e4-da60-4fdd-92fd-38f3adfe4360"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "6326d768-48f1-4403-ab69-73f9731f842c"
    },
    {
      "cell_type": "code",
      "execution_count": 303,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import MTMDatasetLoader\n",
        "loader = MTMDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset()\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "c001180b-c42d-4cbe-b8a8-7e4e5e0e394e"
    },
    {
      "cell_type": "code",
      "execution_count": 304,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "data=[]\n",
        "for time, snapshot in enumerate(train_dataset):\n",
        "    data.append([time,snapshot])"
      ],
      "id": "ef20d811-8082-49a4-b4ea-edc485687bbc"
    },
    {
      "cell_type": "code",
      "execution_count": 305,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[0][1]).x[0], (data[0][1]).y[0]"
      ],
      "id": "3fb6072b-3b3c-4d7a-aad3-5d9eb12201ff"
    },
    {
      "cell_type": "code",
      "execution_count": 306,
      "metadata": {},
      "outputs": [],
      "source": [
        "(data[1][1]).x[0],(data[1][1]).y[0]"
      ],
      "id": "d3ffe995-578d-4f9f-925c-8d06d13d6e96"
    },
    {
      "cell_type": "code",
      "execution_count": 129,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "ab3ad2b8-37ec-4a78-bfa6-9cceaae712b6"
    },
    {
      "cell_type": "code",
      "execution_count": 130,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "b8211903-94a5-4685-bf52-bd06413e65cb"
    },
    {
      "cell_type": "code",
      "execution_count": 131,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "daf9ef23-4d80-4caa-9efe-9350448ed7fa"
    },
    {
      "cell_type": "code",
      "execution_count": 132,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "ff3fb6a8-2851-4795-aa1c-4b2dbbeb9d7a"
    },
    {
      "cell_type": "code",
      "execution_count": 133,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "3d0dd2d0-b347-4c2a-b34a-6524440982f5"
    },
    {
      "cell_type": "code",
      "execution_count": 134,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "1cd3d13e-e114-4371-b29c-cbf82a091cca"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "x\n",
        "\n",
        "-   The data x is returned in shape (3, 21, T),\n",
        "\n",
        "y\n",
        "\n",
        "-   The targets are manually labeled for each frame, according to one of\n",
        "    the five MTM-1 motions (classes ): Grasp, Release, Move, Reach,\n",
        "    Position plus a negative class for frames without graph signals (no\n",
        "    hand present).\n",
        "-   the target is returned one-hot-encoded in shape (T, 6)."
      ],
      "id": "70fcee11-4930-4d64-9f4a-4f7d6fba7146"
    },
    {
      "cell_type": "code",
      "execution_count": 143,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x[0]"
      ],
      "id": "984fbe8f-722f-4a5e-8202-5d1d444d32ae"
    },
    {
      "cell_type": "code",
      "execution_count": 137,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y[0]"
      ],
      "id": "e8963aa9-e08b-49d5-bdbd-9108c74e7e1f"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3 (ipykernel)",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.8.12"
    }
  }
}